/*
 * chaucer.cpp
 *
 * Provides excerpts from Chaucer's Canterbury Tales as PROGDATA strings under 32 kB
 *
 * published under GNU General Public License, version 3 (GPL-3.0)
 * author Stefan Rueger
 *
 * v 1.0
 * 02.01.2021
 */

// Text is an extract from The Canterbury Tales
// full text at http://www.gutenberg.org/cache/epub/2383/pg2383.txt
#include "chaucer.h"

const char tocPreface[] PGMSECTION = // { // 12356 bytes
  "\n"
  "                      THE CANTERBURY TALES\n"
  "                         And other Poems\n"
  "                               of\n"
  "                        GEOFFREY CHAUCER\n"
  "\n"
  "                   Edited for Popular Perusal\n"
  "                               by\n"
  "                         D. Laing Purves\n"
  "\n"
  "\n"
  "\n"
  "                            CONTENTS\n"
  "\n"
  "\n"
  "PREFACE\n"
  "LIFE OF CHAUCER\n"
  "THE CANTERBURY TALES\n"
  "     The General Prologue\n"
  "     The Knight's Tale\n"
  "     The Miller's tale\n"
  "     The Reeve's Tale\n"
  "     The Cook's Tale\n"
  "     The Man of Law's Tale\n"
  "     The Wife of Bath's Tale\n"
  "     The Friar's Tale\n"
  "     The Sompnour's Tale\n"
  "     The Clerk's Tale\n"
  "     The Merchant's Tale\n"
  "     The Squire's Tale\n"
  "     The Franklin's Tale\n"
  "     The Doctor's Tale\n"
  "     The Pardoner's Tale\n"
  "     The Shipman's Tale\n"
  "     The Prioress's Tale\n"
  "     Chaucer's Tale of Sir Thopas\n"
  "     Chaucer's Tale of Meliboeus\n"
  "     The Monk's Tale\n"
  "     The Nun's Priest's Tale\n"
  "     The Second Nun's Tale\n"
  "     The Canon's Yeoman's Tale\n"
  "     The Manciple's Tale\n"
  "     The Parson's Tale\n"
  "     Preces de Chauceres\n"
  "THE COURT OF LOVE <1>\n"
  "THE CUCKOO AND THE NIGHTINGALE <1>\n"
  "THE ASSEMBLY OF FOWLS\n"
  "THE FLOWER AND THE LEAF <1>\n"
  "THE HOUSE OF FAME\n"
  "TROILUS AND CRESSIDA\n"
  "CHAUCER'S DREAM <1>\n"
  "THE PROLOGUE TO THE LEGEND OF GOOD WOMEN\n"
  "CHAUCER'S A.B.C.\n"
  "MISCELLANEOUS POEMS\n"
  "\n"
  "\n"
  "Transcriber's Note.\n"
  "\n"
  "1. Modern scholars believe that Chaucer was not the author of\n"
  "these poems.\n"
  "\n"
  "\n"
  "\n"
  "                            PREFACE.\n"
  "\n"
  "\n"
  "THE object of this volume is to place before the general reader\n"
  "our two early poetic masterpieces -- The Canterbury Tales and\n"
  "The Faerie Queen; to do so in a way that will render their\n"
  "\"popular perusal\" easy in a time of little leisure and unbounded\n"
  "temptations to intellectual languor; and, on the same conditions,\n"
  "to present a liberal and fairly representative selection from the\n"
  "less important and familiar poems of Chaucer and Spenser.\n"
  "There is, it may be said at the outset, peculiar advantage and\n"
  "propriety in placing the two poets side by side in the manner\n"
  "now attempted for the first time.  Although two centuries divide\n"
  "them, yet Spenser is the direct and really the immediate\n"
  "successor to the poetical inheritance of Chaucer.  Those two\n"
  "hundred years, eventful as they were, produced no poet at all\n"
  "worthy to take up the mantle that fell from Chaucer's shoulders;\n"
  "and Spenser does not need his affected archaisms, nor his\n"
  "frequent and reverent appeals to \"Dan Geffrey,\" to vindicate for\n"
  "himself a place very close to his great predecessor in the literary\n"
  "history of England. If Chaucer is the \"Well of English\n"
  "undefiled,\" Spenser is the broad and stately river that yet holds\n"
  "the tenure of its very life from the fountain far away in other\n"
  "and ruder scenes.\n"
  "\n"
  "The Canterbury Tales, so far as they are in verse, have been\n"
  "printed without any abridgement or designed change in the\n"
  "sense.  But the two Tales in prose -- Chaucer's Tale of\n"
  "Meliboeus, and the Parson's long Sermon on Penitence -- have\n"
  "been contracted, so as to exclude thirty pages of unattractive\n"
  "prose, and to admit the same amount of interesting and\n"
  "characteristic poetry.  The gaps thus made in the prose Tales,\n"
  "however, are supplied by careful outlines of the omitted matter,\n"
  "so that the reader need be at no loss to comprehend the whole\n"
  "scope and sequence of the original.  With The Faerie Queen a\n"
  "bolder course has been pursued. The great obstacle to the\n"
  "popularity of Spencer's splendid work has lain less in its\n"
  "language than in its length.  If we add together the three great\n"
  "poems of antiquity -- the twenty-four books of the Iliad, the\n"
  "twenty-four books of the Odyssey, and the twelve books of the\n"
  "Aeneid -- we get at the dimensions of only one-half of The\n"
  "Faerie Queen.  The six books, and the fragment of a seventh,\n"
  "which alone exist of the author's contemplated twelve, number\n"
  "about 35,000 verses; the sixty books of Homer and Virgil\n"
  "number no more than 37,000. The mere bulk of the poem, then,\n"
  "has opposed a formidable barrier to its popularity; to say\n"
  "nothing of the distracting effect produced by the numberless\n"
  "episodes, the tedious narrations, and the constant repetitions,\n"
  "which have largely swelled that bulk.  In this volume the poem\n"
  "is compressed into two-thirds of its original space, through the\n"
  "expedient of representing the less interesting and more\n"
  "mechanical passages by a condensed prose outline, in which it\n"
  "has been sought as far as possible to preserve the very words of\n"
  "the poet.  While deprecating a too critical judgement on the\n"
  "bare and constrained precis standing in such trying\n"
  "juxtaposition, it is hoped that the labour bestowed in saving the\n"
  "reader the trouble of wading through much that is not essential\n"
  "for the enjoyment of Spencer's marvellous allegory, will not be\n"
  "unappreciated.\n"
  "\n"
  "As regards the manner in which the text of the two great works,\n"
  "especially of The Canterbury Tales, is presented, the Editor is\n"
  "aware that some whose judgement is weighty will differ from\n"
  "him.  This volume has been prepared \"for popular perusal;\" and\n"
  "its very raison d'etre would have failed, if the ancient\n"
  "orthography had been retained.  It has often been affirmed by\n"
  "editors of Chaucer in the old forms of the language, that a little\n"
  "trouble at first would render the antiquated spelling and\n"
  "obsolete inflections a continual source, not of difficulty, but of\n"
  "actual delight, for the reader coming to the study of Chaucer\n"
  "without any preliminary acquaintance with the English of his\n"
  "day -- or of his copyists' days.  Despite this complacent\n"
  "assurance, the obvious fact is, that Chaucer in the old forms has\n"
  "not become popular, in the true sense of the word; he is not\n"
  "\"understanded of the vulgar.\"  In this volume, therefore, the text\n"
  "of Chaucer has been presented in nineteenth-century garb.  But\n"
  "there has been not the slightest attempt to \"modernise\"\n"
  "Chaucer, in the wider meaning of the phrase; to replace his\n"
  "words by words which he did not use; or, following the example\n"
  "of some operators, to translate him into English of the modern\n"
  "spirit as well as the modern forms.  So far from that, in every\n"
  "case where the old spelling or form seemed essential to metre,\n"
  "to rhyme, or meaning, no change has been attempted.  But,\n"
  "wherever its preservation was not essential, the spelling of the\n"
  "monkish transcribers -- for the most ardent purist must now\n"
  "despair of getting at the spelling of Chaucer himself -- has been\n"
  "discarded for that of the reader's own day.  It is a poor\n"
  "compliment to the Father of English Poetry, to say that by such\n"
  "treatment the bouquet and individuality of his works must be\n"
  "lost.  If his masterpiece is valuable for one thing more than any\n"
  "other, it is the vivid distinctness with which English men and\n"
  "women of the fourteenth century are there painted, for the study\n"
  "of all the centuries to follow.  But we wantonly balk the artist's\n"
  "own purpose, and discredit his labour, when we keep before his\n"
  "picture the screen of dust and cobwebs which, for the English\n"
  "people in these days, the crude forms of the infant language\n"
  "have practically become.  Shakespeare has not suffered by\n"
  "similar changes; Spencer has not suffered; it would be surprising\n"
  "if Chaucer should suffer, when the loss of popular\n"
  "comprehension and favour in his case are necessarily all the\n"
  "greater for his remoteness from our day.  In a much smaller\n"
  "degree -- since previous labours in the same direction had left\n"
  "far less to do -- the same work has been performed for the\n"
  "spelling of Spenser; and the whole endeavour in this department\n"
  "of the Editor's task has been, to present a text plain and easily\n"
  "intelligible to the modern reader, without any injustice to the old\n"
  "poet.  It would be presumptuous to believe that in every case\n"
  "both ends have been achieved together; but the laudatores\n"
  "temporis acti - the students who may differ most from the plan\n"
  "pursued in this volume -- will best appreciate the difficulty of\n"
  "the enterprise, and most leniently regard any failure in the\n"
  "details of its accomplishment.\n"
  "\n"
  "With all the works of Chaucer, outside The Canterbury Tales, it\n"
  "would have been absolutely impossible to deal within the scope\n"
  "of this volume.  But nearly one hundred pages, have been\n"
  "devoted to his minor poems; and, by dint of careful selection\n"
  "and judicious abridgement -- a connecting outline of the story in\n"
  "all such cases being given -- the Editor ventures to hope that he\n"
  "has presented fair and acceptable specimens of Chaucer's\n"
  "workmanship in all styles.  The preparation of this part of the\n"
  "volume has been a laborious task; no similar attempt on the\n"
  "same scale has been made; and, while here also the truth of the\n"
  "text in matters essential has been in nowise sacrificed to mere\n"
  "ease of perusal, the general reader will find opened up for him a\n"
  "new view of Chaucer and his works.  Before a perusal of these\n"
  "hundred pages, will melt away for ever the lingering tradition or\n"
  "prejudice that Chaucer was only, or characteristically, a coarse\n"
  "buffoon, who pandered to a base and licentious appetite by\n"
  "painting and exaggerating the lowest vices of his time.  In these\n"
  "selections -- made without a thought of taking only what is to\n"
  "the poet's credit from a wide range of poems in which hardly a\n"
  "word is to his discredit -- we behold Chaucer as he was; a\n"
  "courtier, a gallant, pure-hearted gentleman, a scholar, a\n"
  "philosopher, a poet of gay and vivid fancy, playing around\n"
  "themes of chivalric convention, of deep human interest, or\n"
  "broad-sighted satire.  In The Canterbury Tales, we see, not\n"
  "Chaucer, but Chaucer's times and neighbours; the artist has lost\n"
  "himself in his work. To show him honestly and without disguise,\n"
  "as he lived his own life and sung his own songs at the brilliant\n"
  "Court of Edward III, is to do his memory a moral justice far\n"
  "more material than any wrong that can ever come out of\n"
  "spelling.  As to the minor poems of Spenser, which follow The\n"
  "Faerie Queen, the choice has been governed by the desire to\n"
  "give at once the most interesting, and the most characteristic of\n"
  "the poet's several styles; and, save in the case of the Sonnets,\n"
  "the poems so selected are given entire. It is manifest that the\n"
  "endeavours to adapt this volume for popular use, have been\n"
  "already noticed, would imperfectly succeed without the aid of\n"
  "notes and glossary, to explain allusions that have become\n"
  "obsolete, or antiquated words which it was necessary to retain.\n"
  "An endeavour has been made to render each page self-\n"
  "explanatory, by placing on it all the glossarial and illustrative\n"
  "notes required for its elucidation, or -- to avoid repetitions that\n"
  "would have occupied space -- the references to the spot where\n"
  "information may be found.  The great advantage of such a plan\n"
  "to the reader, is the measure of its difficulty for the editor.  It\n"
  "permits much more flexibility in the choice of glossarial\n"
  "explanations or equivalents; it saves the distracting and time-\n"
  "consuming reference to the end or the beginning of the book;\n"
  "but, at the same time, it largely enhances the liability to error.\n"
  "The Editor is conscious that in the 12,000 or 13,000 notes, as\n"
  "well as in the innumerable minute points of spelling,\n"
  "accentuation, and rhythm, he must now and again be found\n"
  "tripping; he can only ask any reader who may detect all that he\n"
  "could himself point out as being amiss, to set off against\n"
  "inevitable mistakes and misjudgements, the conscientious labour\n"
  "bestowed on the book, and the broad consideration of its fitness\n"
  "for the object contemplated.\n"
  "\n"
  " From books the Editor has derived valuable help; as from Mr\n"
  "Cowden Clarke's revised modern text of The Canterbury Tales,\n"
  "published in Mr Nimmo's Library Edition of the English Poets;\n"
  "from Mr Wright's scholarly edition of the same work; from the\n"
  "indispensable Tyrwhitt; from Mr Bell's edition of Chaucer's\n"
  "Poem; from Professor Craik's \"Spenser and his Poetry,\"\n"
  "published twenty-five years ago by Charles Knight; and from\n"
  "many others. In the abridgement of the Faerie Queen,  the plan\n"
  "may at first sight seem to be modelled on the lines of Mr Craik's\n"
  "painstaking condensation; but the coincidences are either\n"
  "inevitable or involuntary.  Many of the notes, especially of those\n"
  "explaining classical references and those attached to the minor\n"
  "poems of Chaucer, have been prepared specially for this edition.\n"
  "The Editor leaves his task with the hope that his attempt to\n"
  "remove artificial obstacles to the popularity of  England's\n"
  "earliest poets, will not altogether miscarry.\n"
  "\n"
  "D. LAING PURVES.\n"
  "\n"
  "\n"
  "\n"
  "";
// }

const char lifeOfGeoffreyChaucer0[] PGMSECTION = // { // 28884 bytes
  "                    LIFE OF GEOFFREY CHAUCER.\n"
  "\n"
  "\n"
  "NOT in point of genius only, but even in point of time, Chaucer\n"
  "may claim the proud designation of \"first\" English poet. He\n"
  "wrote \"The Court of Love\" in 1345, and \"The Romaunt of the\n"
  "Rose,\" if not also \"Troilus and Cressida,\" probably within the\n"
  "next decade: the dates usually assigned to the poems of\n"
  "Laurence Minot extend from 1335 to 1355, while \"The Vision\n"
  "of Piers Plowman\" mentions events that occurred in 1360 and\n"
  "1362 -- before which date Chaucer had certainly written \"The\n"
  "Assembly of Fowls\" and his \"Dream.\" But, though they were\n"
  "his contemporaries, neither Minot nor Langland (if Langland\n"
  "was the author of the Vision) at all approached Chaucer in the\n"
  "finish, the force, or the universal interest of their works and the\n"
  "poems of earlier writer; as Layamon and the author of the\n"
  "\"Ormulum,\" are less English than Anglo-Saxon or Anglo-\n"
  "Norman. Those poems reflected the perplexed struggle for\n"
  "supremacy between the two grand elements of our language,\n"
  "which marked the twelfth and thirteenth centuries; a struggle\n"
  "intimately associated with the political relations between the\n"
  "conquering Normans and the subjugated Anglo-Saxons.\n"
  "Chaucer found two branches of the language; that spoken by\n"
  "the people, Teutonic in its genius and its forms; that spoken by\n"
  "the learned and the noble, based on the French  Yet each branch\n"
  "had begun to borrow of the other -- just as nobles and people\n"
  "had been taught to recognise that each needed the other in the\n"
  "wars and the social tasks of the time; and Chaucer, a scholar, a\n"
  "courtier, a man conversant with all orders of society, but\n"
  "accustomed to speak, think, and write in the words of the\n"
  "highest, by his comprehensive genius cast into the simmering\n"
  "mould a magical amalgamant which made the two half-hostile\n"
  "elements unite and interpenetrate each other. Before Chaucer\n"
  "wrote, there were two tongues in England, keeping alive the\n"
  "feuds and resentments of cruel centuries; when he laid down his\n"
  "pen, there was practically but one speech -- there was, and ever\n"
  "since has been, but one people.\n"
  "\n"
  "Geoffrey Chaucer, according to the most trustworthy traditions-\n"
  "for authentic testimonies on the subject are wanting -- was born\n"
  "in 1328; and London is generally believed to have been his\n"
  "birth-place. It is true that Leland, the biographer of England's\n"
  "first great poet who lived nearest to his time, not merely speaks\n"
  "of Chaucer as having been  born many years later than the date\n"
  "now assigned, but mentions Berkshire or Oxfordshire as the\n"
  "scene of his birth. So great uncertainty have some felt on the\n"
  "latter score, that elaborate parallels have been drawn between\n"
  "Chaucer, and Homer -- for whose birthplace several cities\n"
  "contended, and whose descent was traced to the demigods.\n"
  "Leland may seem to have had fair opportunities of getting at the\n"
  "truth about Chaucer's birth -- for Henry VIII had him, at the\n"
  "suppression of the monasteries throughout England, to search\n"
  "for records of public interest the archives of the religious\n"
  "houses. But it may be questioned whether he was likely to find\n"
  "many authentic particulars regarding the personal history of the\n"
  "poet in the quarters which he explored; and Leland's testimony\n"
  "seems to be set aside by Chaucer's own evidence as to his\n"
  "birthplace, and by the contemporary references which make him\n"
  "out an aged man for years preceding the accepted date of his\n"
  "death. In one of his prose works, \"The Testament of Love,\" the\n"
  "poet speaks of himself in terms that strongly confirm the claim\n"
  "of London to the honour of giving him birth; for he there\n"
  "mentions \"the city of London, that is to me so dear and sweet,\n"
  "in which I was forth growen; and more kindly love,\" says he,\n"
  "\"have I to that place than to any other in earth; as every kindly\n"
  "creature hath full appetite to that place of his kindly engendrure,\n"
  "and to will rest and peace in that place to abide.\" This tolerably\n"
  "direct evidence is supported -- so far as it can be at such an\n"
  "interval of time -- by the learned Camden; in his Annals of\n"
  "Queen Elizabeth, he describes Spencer, who was certainly born\n"
  "in London, as being a fellow-citizen of Chaucer's -- \"Edmundus\n"
  "Spenserus, patria Londinensis, Musis adeo arridentibus natus, ut\n"
  "omnes Anglicos superioris aevi poetas, ne Chaucero quidem\n"
  "concive excepto, superaret.\" <1> The records of the time notice\n"
  "more than one person of the name of Chaucer, who held\n"
  "honourable positions about the Court; and though we cannot\n"
  "distinctly trace the poet's relationship with any of these\n"
  "namesakes or antecessors, we find excellent ground for belief\n"
  "that his family or friends stood well at Court, in the ease with\n"
  "which Chaucer made his way there, and in his subsequent\n"
  "career.\n"
  "\n"
  "Like his great successor, Spencer, it was the fortune of Chaucer\n"
  "to live under a splendid, chivalrous, and high-spirited reign.\n"
  "1328 was the second year of Edward III; and, what with Scotch\n"
  "wars, French expeditions, and the strenuous and costly struggle\n"
  "to hold England in a worthy place among the States of Europe,\n"
  "there was sufficient bustle, bold achievement, and high ambition\n"
  "in the period to inspire a poet who was prepared to catch the\n"
  "spirit of the day. It was an age of elaborate courtesy, of high-\n"
  "paced gallantry, of courageous venture, of noble disdain for\n"
  "mean tranquillity; and Chaucer, on the whole a man of peaceful\n"
  "avocations, was penetrated to the depth of his consciousness\n"
  "with the lofty and lovely civil side of that brilliant and restless\n"
  "military period. No record of his youthful years, however,\n"
  "remains to us; if we believe that at the age of eighteen he was a\n"
  "student of Cambridge, it is only on the strength of a reference in\n"
  "his \"Court of Love\", where the narrator is made to say that his\n"
  "name is Philogenet, \"of Cambridge clerk;\" while he had  already\n"
  "told us that when he was stirred to seek the Court of Cupid he\n"
  "was \"at eighteen year of age.\" According to Leland, however,\n"
  "he was educated at Oxford, proceeding thence to France and\n"
  "the Netherlands, to finish his studies; but there remains no\n"
  "certain evidence of his having belonged to either University. At\n"
  "the same time, it is not doubted that his family was of good\n"
  "condition; and, whether or not we accept the assertion that his\n"
  "father held the rank of knighthood -- rejecting the hypotheses\n"
  "that make him a merchant, or a vintner \"at the corner of Kirton\n"
  "Lane\" -- it is plain, from Chaucer's whole career, that he had\n"
  "introductions to public life, and recommendations to courtly\n"
  "favour, wholly independent of his genius. We have the clearest\n"
  "testimony that his mental training was of wide range and\n"
  "thorough excellence, altogether rare for a mere courtier in those\n"
  "days: his poems attest his intimate acquaintance with the\n"
  "divinity, the philosophy, and the scholarship of his time, and\n"
  "show him to have had the sciences, as then developed and\n"
  "taught, \"at his fingers' ends.\" Another proof of Chaucer's good\n"
  "birth and fortune would he found in the statement that, after his\n"
  "University career was completed, he entered the Inner Temple -\n"
  "- the expenses of which could be borne only by men of noble\n"
  "and opulent families; but although there is a story that he was\n"
  "once fined two shillings for thrashing a Franciscan friar in Fleet\n"
  "Street, we have no direct authority for believing that the poet\n"
  "devoted himself to the uncongenial study of the law. No special\n"
  "display of knowledge on that subject appears in his works; yet\n"
  "in the sketch of the Manciple, in the Prologue to the Canterbury\n"
  "Tales, may be found indications of his familiarity with the\n"
  "internal economy of the Inns of Court; while numerous legal\n"
  "phrases and references hint that his comprehensive information\n"
  "was not at fault on legal matters. Leland says that he quitted the\n"
  "University \"a ready logician, a smooth rhetorician, a pleasant\n"
  "poet, a grave philosopher, an ingenious mathematician, and a\n"
  "holy divine;\" and by all accounts, when Geoffrey Chaucer\n"
  "comes before us authentically for the first time, at the age of\n"
  "thirty-one, he was possessed of knowledge and\n"
  "accomplishments far beyond the common standard of his day.\n"
  "\n"
  "Chaucer at this period possessed also other qualities fitted to\n"
  "recommend him to favour in a Court like that of Edward III.\n"
  "Urry describes him, on the authority of a portrait, as being then\n"
  "\"of a fair beautiful complexion, his lips red and full, his size of a\n"
  "just medium, and his port and air graceful and majestic. So,\"\n"
  "continues the ardent biographer, -- \"so that every ornament that\n"
  "could claim the approbation of the great and fair, his abilities to\n"
  "record the valour of the one, and celebrate the beauty of the\n"
  "other, and his wit and gentle behaviour to converse with both,\n"
  "conspired to make him a complete courtier.\"  If we believe that\n"
  "his \"Court of Love\" had received such publicity as the literary\n"
  "media of the time allowed in the somewhat narrow and select\n"
  "literary world -- not to speak of \"Troilus and Cressida,\" which,\n"
  "as Lydgate mentions it first among Chaucer's works, some have\n"
  "supposed to be a youthful production -- we find a third and not\n"
  "less powerful recommendation to the favour of the great co-\n"
  "operating with his learning and his gallant bearing. Elsewhere\n"
  "<2> reasons have been shown for doubt whether \"Troilus and\n"
  "Cressida\" should not be assigned to a later period of Chaucer's\n"
  "life; but very little is positively known about the dates and\n"
  "sequence of his various works. In the year 1386, being called as\n"
  "witness with regard to a contest on a point of heraldry between\n"
  "Lord Scrope and Sir Robert Grosvenor, Chaucer deposed that\n"
  "he entered on his military career in 1359. In that year Edward\n"
  "III invaded France, for the third time, in pursuit of his claim to\n"
  "the French crown; and we may fancy that, in describing the\n"
  "embarkation of the knights in \"Chaucer's Dream\", the poet\n"
  "gained some of the vividness and stir of his picture from his\n"
  "recollections of the embarkation of the splendid and well-\n"
  "appointed royal host at Sandwich, on board the eleven hundred\n"
  "transports provided for the enterprise. In this expedition the\n"
  "laurels of Poitiers were flung on the ground; after vainly\n"
  "attempting Rheims and Paris, Edward was constrained, by cruel\n"
  "weather and lack of provisions, to retreat toward his ships; the\n"
  "fury of the elements made the retreat more disastrous than an\n"
  "overthrow in pitched battle; horses and men perished by\n"
  "thousands, or fell into the hands of the pursuing French.\n"
  "Chaucer, who had been made prisoner at the siege of Retters,\n"
  "was among the captives in the possession of France when the\n"
  "treaty of Bretigny -- the \"great peace\" -- was concluded, in\n"
  "May, 1360. Returning to England, as we may suppose, at the\n"
  "peace, the poet, ere long, fell into another and a pleasanter\n"
  "captivity; for his marriage is generally believed to have taken\n"
  "place shortly after his release from foreign durance.  He had\n"
  "already gained the personal friendship and favour of John of\n"
  "Gaunt, Duke of Lancaster, the King's son; the Duke, while Earl\n"
  "of Richmond, had courted, and won to wife after a certain\n"
  "delay, Blanche, daughter and co-heiress of Henry Duke of\n"
  "Lancaster; and Chaucer is by some believed to have written\n"
  "\"The Assembly of Fowls\" to celebrate the wooing, as he wrote\n"
  "\"Chaucer's Dream\" to celebrate the wedding, of his patron. The\n"
  "marriage took place in 1359, the year of Chaucer's expedition to\n"
  "France; and as, in \"The Assembly of Fowls,\" the formel or\n"
  "female eagle, who is supposed to represent the Lady Blanche,\n"
  "begs that her choice of a mate may be deferred for a year, 1358\n"
  "and 1359 have been assigned as the respective dates of the two\n"
  "poems already mentioned.  In the \"Dream,\" Chaucer\n"
  "prominently introduces his own lady-love, to whom, after the\n"
  "happy union of his patron with the Lady Blanche, he is wedded\n"
  "amid great rejoicing; and various expressions in the same poem\n"
  "show that not only was the poet high in favour with the\n"
  "illustrious pair, but that his future wife had also peculiar claims\n"
  "on their regard.  She was the younger daughter of Sir Payne\n"
  "Roet, a native of Hainault, who had, like many of his\n"
  "countrymen, been attracted to England by the example and\n"
  "patronage of Queen Philippa. The favourite attendant on the\n"
  "Lady Blanche was her elder sister Katherine: subsequently\n"
  "married to Sir Hugh Swynford, a gentleman of Lincolnshire;\n"
  "and destined, after the death of Blanche, to be in succession\n"
  "governess of her children, mistress of John of Gaunt, and\n"
  "lawfully-wedded Duchess of Lancaster. It is quite sufficient\n"
  "proof that Chaucer's position at Court was of no mean\n"
  "consequence, to find that his wife, the sister of the future\n"
  "Duchess of Lancaster, was one of the royal maids of honour,\n"
  "and even, as Sir Harris Nicolas conjectures, a god-daughter of\n"
  "the Queen -- for her name also was Philippa.\n"
  "\n"
  "Between 1359, when the poet himself testifies that he was made\n"
  "prisoner while bearing arms in France, and September 1366,\n"
  "when Queen Philippa granted to her former maid of honour, by\n"
  "the name of Philippa Chaucer, a yearly pension of ten marks, or\n"
  "L6, 13s. 4d., we have no authentic mention of Chaucer, express\n"
  "or indirect. It is plain from this grant that the poet's marriage\n"
  "with Sir Payne Roet's daughter was not celebrated later than\n"
  "1366; the probability is, that it closely followed his return from\n"
  "the wars. In 1367, Edward III. settled upon Chaucer a life-\n"
  "pension of twenty marks, \"for the good service which our\n"
  "beloved Valet -- 'dilectus Valettus noster' -- Geoffrey Chaucer\n"
  "has rendered, and will render in time to come.\" Camden\n"
  "explains 'Valettus hospitii' to signify a Gentleman of the Privy\n"
  "Chamber; Selden says that the designation was bestowed \"upon\n"
  "young heirs designed to he knighted, or young gentlemen of\n"
  "great descent and quality.\" Whatever the strict meaning of the\n"
  "word, it is plain that the poet's position was honourable and\n"
  "near to the King's person, and also that his worldly\n"
  "circumstances were easy, if not affluent -- for it need not be said\n"
  "that twenty marks in those days represented twelve or twenty\n"
  "times the sum in these.  It is believed that he found powerful\n"
  "patronage, not merely from the Duke of Lancaster and his wife,\n"
  "but from Margaret Countess of Pembroke, the King's daughter.\n"
  "To her Chaucer is supposed to have addressed the \"Goodly\n"
  "Ballad\", in which the lady is celebrated under the image of the\n"
  "daisy; her he is by some understood to have represented under\n"
  "the title of Queen Alcestis, in the \"Court of Love\" and the\n"
  "Prologue to \"The Legend of Good Women;\" and in her praise\n"
  "we may read his charming descriptions and eulogies of the daisy\n"
  "-- French, \"Marguerite,\" the name of his Royal patroness. To\n"
  "this period of Chaucer's career we may probably attribute the\n"
  "elegant and courtly, if somewhat conventional, poems of \"The\n"
  "Flower and the Leaf,\" \"The Cuckoo and the Nightingale,\" &c.\n"
  "\"The Lady Margaret,\" says Urry, \". . . would frequently\n"
  "compliment him upon his poems. But this is not to be meant of\n"
  "his Canterbury Tales, they being written in the latter part of his\n"
  "life, when the courtier and the fine gentleman gave way to solid\n"
  "sense and plain descriptions. In his love-pieces he was obliged\n"
  "to have the strictest regard to modesty and decency; the ladies\n"
  "at that time insisting so much upon the nicest punctilios of\n"
  "honour, that it was highly criminal to depreciate their sex, or do\n"
  "anything that might offend virtue.\" Chaucer, in their estimation,\n"
  "had sinned against the dignity and honour of womankind by his\n"
  "translation of the French \"Roman de la Rose,\" and by his\n"
  "\"Troilus and Cressida\" -- assuming it to have been among his\n"
  "less mature works; and to atone for those offences the Lady\n"
  "Margaret (though other and older accounts say that it was the\n"
  "first Queen of Richard II., Anne of Bohemia), prescribed to him\n"
  "the task of writing \"The Legend of Good Women\" (see\n"
  "introductory note to that poem). About this period, too, we\n"
  "may place the composition of Chaucer's A. B. C., or The Prayer\n"
  "of Our Lady, made at the request of the Duchess Blanche, a\n"
  "lady of great devoutness in her private life. She died in 1369;\n"
  "and Chaucer, as he had allegorised her wooing, celebrated her\n"
  "marriage, and aided her devotions, now lamented her death, in a\n"
  "poem entitled \"The Book of the Duchess; or, the Death of\n"
  "Blanche.<3>\n"
  "\n"
  "In 1370, Chaucer was employed on the King's service abroad;\n"
  "and in November 1372, by the title of \"Scutifer noster\" -- our\n"
  "Esquire or Shield-bearer -- he was associated with \"Jacobus\n"
  "Pronan,\" and \"Johannes de Mari civis Januensis,\" in a royal\n"
  "commission, bestowing full powers to treat with the Duke of\n"
  "Genoa, his Council, and State.  The object of the embassy was\n"
  "to negotiate upon the choice of an English port at which the\n"
  "Genoese might form a commercial establishment; and Chaucer,\n"
  "having quitted England in December, visited Genoa and\n"
  "Florence, and returned to England before the end of November\n"
  "1373 -- for on that day he drew his pension from the Exchequer\n"
  "in person. The most interesting point connected with this Italian\n"
  "mission is the question, whether Chaucer visited Petrarch at\n"
  "Padua. That he did, is unhesitatingly affirmed by the old\n"
  "biographers; but the authentic notices of Chaucer during the\n"
  "years 1372-1373, as shown by the researches of Sir Harris\n"
  "Nicolas, are confined to the facts already stated; and we are left\n"
  "to answer the question by the probabilities of the case, and by\n"
  "the aid of what faint light the poet himself affords. We can\n"
  "scarcely fancy that Chaucer, visiting Italy for the first time, in a\n"
  "capacity which opened for him easy access to the great and the\n"
  "famous, did not embrace the chance of meeting a poet whose\n"
  "works he evidently knew in their native tongue, and highly\n"
  "esteemed.  With Mr Wright, we are strongly disinclined to\n"
  "believe \"that Chaucer did not profit by the opportunity . . . of\n"
  "improving his acquaintance with the poetry, if not the poets, of\n"
  "the country he thus visited, whose influence was now being felt\n"
  "on the literature of most countries of Western Europe.\" That\n"
  "Chaucer was familiar with the Italian language appears not\n"
  "merely from his repeated selection as Envoy to Italian States,\n"
  "but by many passages in his poetry, from \"The Assembly of\n"
  "Fowls\" to \"The Canterbury Tales.\" In the opening of the first\n"
  "poem  there is a striking parallel to Dante's inscription on the\n"
  "gate of Hell.  The first Song of Troilus, in \"Troilus and\n"
  "Cressida\", is a nearly literal translation of Petrarch's 88th\n"
  "Sonnet. In the Prologue to \"The Legend of Good Women\",\n"
  "there is a reference to Dante which can hardly have reached the\n"
  "poet at second- hand. And in Chaucer's great work -- as in The\n"
  "Wife of Bath's Tale, and The Monk's Tale  -- direct reference by\n"
  "name is made to Dante, \"the wise poet of Florence,\" \"the great\n"
  "poet of Italy,\" as the source whence the author has quoted.\n"
  "When we consider the poet's high place in literature and at\n"
  "Court, which could not fail to make him free of the hospitalities\n"
  "of the brilliant little Lombard States; his familiarity with the\n"
  "tongue and the works of Italy's greatest bards, dead and living;\n"
  "the reverential regard which he paid to the memory of great\n"
  "poets, of which we have examples in \"The House of Fame,\" and\n"
  "at the close of \"Troilus and Cressida\" <4>; along with his own\n"
  "testimony in the Prologue to The Clerk's Tale, we cannot fail to\n"
  "construe that testimony as a declaration that the Tale was\n"
  "actually told to Chaucer by the lips of Petrarch, in 1373, the\n"
  "very year in which Petrarch translated it into Latin, from\n"
  "Boccaccio's \"Decameron.\"<5>   Mr Bell notes the objection to\n"
  "this interpretation, that the words are put into the mouth, not of\n"
  "the poet, but of the Clerk; and meets it by the counter-\n"
  "objection, that the Clerk, being a purely imaginary personage,\n"
  "could not have learned the story at Padua from Petrarch -- and\n"
  "therefore that Chaucer must have departed from the dramatic\n"
  "assumption maintained in the rest of the dialogue. Instances\n"
  "could be adduced from Chaucer's writings to show that such a\n"
  "sudden \"departure from the dramatic assumption\" would not be\n"
  "unexampled: witness the \"aside\" in The Wife of Bath's\n"
  "Prologue, where, after the jolly Dame has asserted that \"half so\n"
  "boldly there can no man swear and lie as a woman can\", the\n"
  "poet hastens to interpose, in his own person, these two lines:\n"
  "\n"
  "\"I say not this by wives that be wise,\n"
  "But if it be when they them misadvise.\"\n"
  "\n"
  "And again, in the Prologue to the \"Legend of Good Women,\"\n"
  "from a description of the daisy --\n"
  "\n"
  "\"She is the clearness and the very light,\n"
  "That in this darke world me guides and leads,\"\n"
  "\n"
  "the poet, in the very next lines, slides into an address to his lady:\n"
  "\n"
  "\"The heart within my sorrowful heart you dreads\n"
  "And loves so sore, that ye be, verily,\n"
  "The mistress of my wit, and nothing I,\" &c.\n"
  "\n"
  "When, therefore, the Clerk of Oxford is made to say that he will\n"
  "tell a tale --\n"
  "\n"
  "                          \"The which that I\n"
  "Learn'd at Padova of a worthy clerk,\n"
  "As proved by his wordes and his werk.\n"
  "He is now dead, and nailed in his chest,\n"
  "I pray to God to give his soul good rest.\n"
  "Francis Petrarc', the laureate poete,\n"
  "Highte this clerk, whose rhetoric so sweet\n"
  "Illumin'd all Itaile of poetry. . . .\n"
  "But forth to tellen of this worthy man,\n"
  "That taughte me this tale, as I began.\" . . .\n"
  "\n"
  "we may without violent effort believe that Chaucer speaks in his\n"
  "own person, though dramatically the words are on the Clerk's\n"
  "lips.  And the belief is not impaired by the sorrowful way in\n"
  "which the Clerk lingers on Petrarch's death -- which would be\n"
  "less intelligible if the fictitious narrator had only read the story\n"
  "in the Latin translation, than if we suppose the news of\n"
  "Petrarch's death at Arqua in July 1374 to have closely followed\n"
  "Chaucer to England, and to have cruelly and irresistibly mingled\n"
  "itself with our poet's personal recollections of his great Italian\n"
  "contemporary.  Nor must we regard as without significance the\n"
  "manner in which the Clerk is made to distinguish between the\n"
  "\"body\" of Petrarch's tale, and the fashion in which it was set\n"
  "forth in writing, with a proem that seemed \"a thing\n"
  "impertinent\", save that the poet had chosen in that way to\n"
  "\"convey his matter\" -- told, or \"taught,\" so much more directly\n"
  "and simply by word of mouth. It is impossible to pronounce\n"
  "positively on the subject; the question whether Chaucer saw\n"
  "Petrarch in 1373 must remain a moot-point, so long as we have\n"
  "only our present information; but fancy loves to dwell on the\n"
  "thought of the two poets conversing under the vines at Arqua;\n"
  "and we find in the history and the writings of Chaucer nothing\n"
  "to contradict, a good deal to countenance, the belief that such a\n"
  "meeting occurred.\n"
  "\n"
  "Though we have no express record, we have indirect testimony,\n"
  "that Chaucer's Genoese mission was discharged satisfactorily;\n"
  "for on the 23d of April 1374, Edward III grants at Windsor to\n"
  "the poet, by the title of \"our beloved squire\" -- dilecto Armigero\n"
  "nostro -- unum pycher. vini, \"one pitcher of wine\" daily, to be\n"
  "\"perceived\" in the port of London; a grant which, on the\n"
  "analogy of more modern usage, might he held equivalent to\n"
  "Chaucer's appointment as Poet Laureate. When we find that\n"
  "soon afterwards the grant was commuted for a money payment\n"
  "of twenty marks per annum, we need not conclude that\n"
  "Chaucer's circumstances were poor; for it may be easily\n"
  "supposed that the daily \"perception\" of such an article of\n"
  "income was attended with considerable prosaic inconvenience.\n"
  "A permanent provision for Chaucer was made on the 8th of\n"
  "June 1374, when he was appointed Controller of the Customs in\n"
  "the Port of London, for the lucrative imports of wools, skins or\n"
  "\"wool-fells,\" and tanned hides -- on condition that he should\n"
  "fulfil the duties of that office in person and not by deputy, and\n"
  "should write out the accounts with his own hand.  We have\n"
  "what seems evidence of Chaucer's compliance with these terms\n"
  "in \"The House of Fame\", where, in the mouth of the eagle, the\n"
  "poet describes himself, when he has finished his labour and\n"
  "made his reckonings, as not seeking rest and news in social\n"
  "intercourse, but going home to his own house, and there, \"all so\n"
  "dumb as any stone,\" sitting \"at another book,\" until his look is\n"
  "dazed; and again, in the record that in 1376 he received a grant\n"
  "of L731, 4s. 6d., the amount of a fine levied on one John Kent,\n"
  "whom Chaucer's vigilance had frustrated in the attempt to ship a\n"
  "quantity of wool for Dordrecht without paying the duty. The\n"
  "seemingly derogatory condition, that the Controller should\n"
  "write out the accounts or rolls (\"rotulos\") of his office with his\n"
  "own hand, appears to have been designed, or treated, as merely\n"
  "formal; no records in Chaucer's handwriting are known to exist\n"
  "-- which could hardly be the case if, for the twelve years of his\n"
  "Controllership (1374-1386), he had duly complied with the\n"
  "condition; and during that period he was more than once\n"
  "employed abroad, so that the condition was evidently regarded\n"
  "as a formality even by those who had imposed it.  Also in 1374,\n"
  "the Duke of Lancaster, whose ambitious views may well have\n"
  "made him anxious to retain the adhesion of a man so capable\n"
  "and accomplished as Chaucer, changed into a joint life-annuity\n"
  "remaining to the survivor, and charged on the revenues of the\n"
  "Savoy, a pension of L10 which two years before he settled on\n"
  "the poet's wife -- whose sister was then the governess of the\n"
  "Duke's two daughters, Philippa and Elizabeth, and the Duke's\n"
  "own mistress.  Another proof of Chaucer's personal reputation\n"
  "and high Court favour at this time, is his selection (1375) as\n"
  "ward to the son of Sir Edmond Staplegate of Bilsynton, in Kent;\n"
  "a charge on the surrender of which the guardian received no\n"
  "less a sum than L104.\n"
  "\n"
  "We find Chaucer in 1376 again employed on a foreign mission.\n"
  "In 1377, the last year of Edward III., he was sent to Flanders\n"
  "with Sir Thomas Percy, afterwards Earl of Worcester, for the\n"
  "purpose of obtaining a prolongation of the truce; and in January\n"
  "13738, he was associated with Sir Guichard d'Angle and other\n"
  "Commissioners, to pursue certain negotiations for a marriage\n"
  "between Princess Mary of France and the young King Richard\n"
  "II., which had been set on foot before the death of Edward III.\n"
  "The negotiation, however, proved fruitless; and in May 1378,\n"
  "Chaucer was selected to accompany Sir John Berkeley on a\n"
  "mission to the Court of Bernardo Visconti, Duke of Milan, with\n"
  "the view, it is supposed, of concerting military plans against the\n"
  "outbreak of war with France.  The new King, meantime, had\n"
  "shown that he was not insensible to Chaucer's merit  -- or to the\n"
  "influence of his tutor and the poet's patron, the Duke of\n"
  "Lancaster; for Richard II. confirmed to Chaucer his pension of\n"
  "twenty marks, along with an equal annual sum, for which the\n"
  "daily pitcher of wine granted in 1374 had been commuted.\n"
  "Before his departure for Lombardy, Chaucer -- still holding his\n"
  "post in the Customs -- selected two representatives or trustees,\n"
  "to protect his estate against legal proceedings in his absence, or\n"
  "to sue in his name defaulters and offenders against the imposts\n"
  "which he was charged to enforce. One of these trustees was\n"
  "called Richard Forrester; the other was John Gower, the poet,\n"
  "the most famous English contemporary of Chaucer, with whom\n"
  "he had for many years been on terms of admiring friendship --\n"
  "although, from the strictures passed on certain productions of\n"
  "Gower's in the Prologue to The Man of Law's Tale,<6> it has\n"
  "been supposed that in the later years of Chaucer's life the\n"
  "friendship suffered some diminution. To the \"moral Gower\" and\n"
  "\"the philosophical Strode,\" Chaucer \"directed\" or dedicated his\n"
  "\"Troilus and Cressida;\" <7> while, in the \"Confessio Amantis,\"\n"
  "Gower introduces a handsome compliment to his greater\n"
  "contemporary, as the \"disciple and the poet\" of Venus, with\n"
  "whose glad songs and ditties, made in her praise during the\n"
  "flowers of his youth, the land was filled everywhere.  Gower,\n"
  "however -- a monk and a Conservative -- held to the party of\n"
  "the Duke of Gloucester, the rival of the Wycliffite and\n"
  "innovating Duke of Lancaster, who was Chaucer's patron, and\n"
  "whose cause was not a little aided by Chaucer's strictures on the\n"
  "clergy; and thus it is not impossible that political differences\n"
  "may have weakened the old bonds of personal friendship and\n"
  "poetic esteem. Returning from Lombardy early in 1379,\n"
  "Chaucer seems to have been again sent abroad; for the records\n"
  "exhibit no trace of him between May and December of that\n"
  "year. Whether by proxy or in person, however, he received his\n"
  "pensions regularly until 1382, when his income was increased\n"
  "by his appointment to the post of Controller of Petty Customs\n"
  "in the port of London.  In November 1384, he obtained a\n"
  "month's leave of absence on account of his private affairs, and a\n"
  "deputy was appointed to fill his place; and in February of the\n"
  "next year he was permitted to appoint a permanent deputy --\n"
  "thus at length gaining relief from that close attention to business\n"
  "which probably curtailed the poetic fruits of the poet's most\n"
  "powerful years. <8>\n"
  "\n"
  "";
// }

const char lifeOfGeoffreyChaucer1[] PGMSECTION = // { // 26321 bytes
  "Chaucer is next found occupying a post which has not often\n"
  "been held by men gifted with his peculiar genius -- that of a\n"
  "county member. The contest between the Dukes of Gloucester\n"
  "and Lancaster, and their adherents, for the control of the\n"
  "Government, was coming to a crisis; and when the recluse and\n"
  "studious Chaucer was induced to offer himself to the electors of\n"
  "Kent as one of the knights of their shire -- where presumably he\n"
  "held property -- we may suppose that it was with the view of\n"
  "supporting his patron's cause in the impending conflict. The\n"
  "Parliament in which the poet sat assembled at Westminster on\n"
  "the 1st of October, and was dissolved on the 1st of November,\n"
  "1386. Lancaster was fighting and intriguing abroad, absorbed in\n"
  "the affairs of his Castilian succession; Gloucester and his friends\n"
  "at home had everything their own way; the Earl of Suffolk was\n"
  "dismissed from the woolsack, and impeached by the Commons;\n"
  "and although Richard at first stood out courageously for the\n"
  "friends of his uncle Lancaster, he was constrained, by the refusal\n"
  "of supplies, to consent to the proceedings of Gloucester. A\n"
  "commission was wrung from him, under protest, appointing\n"
  "Gloucester, Arundel, and twelve other Peers and prelates, a\n"
  "permanent council to inquire into the condition of all the public\n"
  "departments, the courts of law, and the royal household, with\n"
  "absolute powers of redress and dismissal. We need not ascribe\n"
  "to Chaucer's Parliamentary exertions in his patron's behalf, nor\n"
  "to any malpractices in his official conduct, the fact that he was\n"
  "among the earliest victims of the commission.<9>  In December\n"
  "1386, he was dismissed from both his offices in the port of\n"
  "London; but he retained his pensions, and drew them regularly\n"
  "twice a year at the Exchequer until 1388. In 1387, Chaucer's\n"
  "political reverses were aggravated by a severe domestic\n"
  "calamity: his wife died, and with her died the pension which had\n"
  "been settled on her by Queen Philippa in 1366, and confirmed to\n"
  "her at Richard's accession in 1377.  The change made in\n"
  "Chaucer's pecuniary position, by the loss of his offices and his\n"
  "wife's pension, must have been very great. It would appear that\n"
  "during his prosperous times he had lived in a style quite equal to\n"
  "his income, and had no ample resources against a season of\n"
  "reverse; for, on the 1st of May 1388, less than a year and a half\n"
  "after being dismissed from the Customs, he was constrained to\n"
  "assign his pensions, by surrender in Chancery, to one John\n"
  "Scalby.  In May 1389, Richard II., now of age, abruptly\n"
  "resumed the reins of government, which, for more than two\n"
  "years, had been ably but cruelly managed by Gloucester. The\n"
  "friends of Lancaster were once more supreme in the royal\n"
  "councils, and Chaucer speedily profited by the change. On the\n"
  "12th of July he was appointed Clerk of the King's Works at the\n"
  "Palace of Westminster, the Tower, the royal manors of\n"
  "Kennington, Eltham, Clarendon, Sheen, Byfleet, Childern\n"
  "Langley, and Feckenham, the castle of Berkhamstead, the royal\n"
  "lodge of Hathenburgh in the New Forest, the lodges in the\n"
  "parks of Clarendon, Childern Langley, and Feckenham, and the\n"
  "mews for the King's falcons at Charing Cross; he received a\n"
  "salary of two shillings per day, and was allowed to perform the\n"
  "duties by deputy. For some reason unknown, Chaucer held this\n"
  "lucrative office <10> little more than two years, quitting it\n"
  "before the 16th of September 1391, at which date it had passed\n"
  "into the hands of one John Gedney. The next two years and a\n"
  "half are a blank, so far as authentic records are concerned;\n"
  "Chaucer is supposed to have passed them in retirement,\n"
  "probably devoting them principally to the composition of The\n"
  "Canterbury Tales. In February 1394, the King conferred upon\n"
  "him a grant of L20 a year for life; but he seems to have had no\n"
  "other source of income, and to have become embarrassed by\n"
  "debt, for frequent memoranda of small advances on his pension\n"
  "show that his circumstances were, in comparison, greatly\n"
  "reduced.  Things appear to have grown worse and worse with\n"
  "the poet; for in May 1398 he was compelled to obtain from the\n"
  "King letters of protection against arrest, extending over a term\n"
  "of two years. Not for the first time, it is true -- for similar\n"
  "documents had been issued at the beginning of Richard's reign;\n"
  "but at that time Chaucer's missions abroad, and his responsible\n"
  "duties in the port of London, may have furnished reasons for\n"
  "securing him against annoyance or frivolous prosecution, which\n"
  "were wholly wanting at the later date.  In 1398, fortune began\n"
  "again to smile upon him; he received a royal grant of a tun of\n"
  "wine annually, the value being about L4. Next year, Richard II\n"
  "having been deposed by the son of John of Gaunt <11>  --\n"
  "Henry of Bolingbroke, Duke of Lancaster -- the new King, four\n"
  "days after hits accession, bestowed on Chaucer a grant of forty\n"
  "marks (L26, 13s. 4d.) per annum, in addition to the pension of\n"
  "L20 conferred by Richard II. in 1394.  But the poet, now\n"
  "seventy-one years of age, and probably broken down by the\n"
  "reverses of the past few years, was not destined long to enjoy\n"
  "his renewed prosperity.  On Christmas Eve of 1399, he entered\n"
  "on the possession of a house in the garden of the Chapel of the\n"
  "Blessed Mary of Westminster -- near to the present site of\n"
  "Henry VII.'s Chapel -- having obtained a lease from Robert\n"
  "Hermodesworth, a monk of the adjacent convent, for fifty-three\n"
  "years, at the annual rent of four marks (L2, 13s. 4d.) Until the\n"
  "1st of March 1400, Chaucer drew his pensions in person; then\n"
  "they were received for him by another hand; and on the 25th of\n"
  "October, in the same year, he died, at the age of seventy-two.\n"
  "The only lights thrown by his poems on his closing days are\n"
  "furnished in the little ballad called \"Good Counsel of Chaucer,\"\n"
  "-- which, though said to have been written when \"upon his\n"
  "death-bed lying in his great anguish, \"breathes the very spirit of\n"
  "courage, resignation, and philosophic calm; and by the\n"
  "\"Retractation\" at the end of The Canterbury Tales, which, if it\n"
  "was not foisted in by monkish transcribers, may be supposed the\n"
  "effect of Chaucer's regrets and self-reproaches on that solemn\n"
  "review of his life-work which the close approach of death\n"
  "compelled. The poet was buried in Westminster Abbey; <12>\n"
  "and not many years after his death a slab was  placed on a pillar\n"
  "near his grave, bearing the lines, taken from an epitaph or\n"
  "eulogy made by Stephanus Surigonus of Milan, at the request of\n"
  "Caxton:\n"
  "\n"
  "\"Galfridus Chaucer, vates, et fama poesis\n"
  "Maternae, hoc sacra sum tumulatus humo.\" <13>\n"
  "\n"
  "About 1555, Mr Nicholas Brigham, a gentleman of Oxford who\n"
  "greatly admired the genius of Chaucer, erected the present\n"
  "tomb, as near to the spot where the poet lay, \"before the chapel\n"
  "of St Benet,\" as was then possible by reason of the \"cancelli,\"\n"
  "<14> which the Duke of Buckingham subsequently obtained\n"
  "leave to remove, that room might be made for the tomb of\n"
  "Dryden.  On the structure of Mr Brigham, besides a full-length\n"
  "representation of Chaucer, taken from a portrait drawn by his\n"
  "\"scholar\" Thomas Occleve, was -- or is, though now almost\n"
  "illegible -- the following inscription:--\n"
  "\n"
  "                              M. S.\n"
  "            QUI FUIT ANGLORUM VATES TER MAXIMUS OLIM,\n"
  "             GALFRIDUS CHAUCER CONDITUR HOC TUMULO;\n"
  "            ANNUM SI QUAERAS DOMINI, SI TEMPORA VITAE,\n"
  "           ECCE NOTAE SUBSUNT, QUE TIBI CUNCTA NOTANT.\n"
  "                        25 OCTOBRIS 1400.\n"
  "                    AERUMNARUM REQUIES MORS.\n"
  "           N. BRIGHAM HOS FECIT MUSARUM NOMINE SUMPTUS\n"
  "                              1556. <15>\n"
  "\n"
  "Concerning his personal appearance and habits, Chaucer has not\n"
  "been reticent in his poetry. Urry sums up the traits of his aspect\n"
  "and character fairly thus: \"He was of a middle stature, the latter\n"
  "part of his life inclinable to be fat and corpulent, as appears by\n"
  "the Host's bantering him in the journey to Canterbury, and\n"
  "comparing shapes with him.<16>  His face was fleshy, his\n"
  "features just and regular, his complexion fair, and somewhat\n"
  "pale, his hair of a dusky yellow, short and thin; the hair of his\n"
  "beard in two forked tufts, of a wheat colour; his forehead broad\n"
  "and smooth; his eyes inclining usually to the ground, which is\n"
  "intimated by the Host's words; his whole face full of liveliness, a\n"
  "calm, easy sweetness, and a studious Venerable aspect. . . . As\n"
  "to his temper, he had a mixture of the gay, the modest, and the\n"
  "grave. The sprightliness of his humour was more distinguished\n"
  "by his writings than by his appearance; which gave occasion to\n"
  "Margaret Countess of Pembroke often to rally him upon his\n"
  "silent modesty in company, telling him, that his absence was\n"
  "more agreeable to her than his conversation, since the first was\n"
  "productive of agreeable pieces of wit in his writings, <17> but\n"
  "the latter was filled with a modest deference, and a too distant\n"
  "respect.  We see nothing merry or jocose in his behaviour with\n"
  "his pilgrims, but a silent attention to their mirth, rather than any\n"
  "mixture of his own. . .  When disengaged from public affairs, his\n"
  "time was entirely spent in study and reading; so agreeable to\n"
  "him was this exercise, that he says he preferred it to all other\n"
  "sports and diversions.<18>  He lived within himself, neither\n"
  "desirous to hear nor busy to concern himself with the affairs of\n"
  "his neighbours. His course of living was temperate and regular;\n"
  "he went to rest with the sun, and rose before it; and by that\n"
  "means enjoyed the pleasures of the better part of the day, his\n"
  "morning walk and fresh contemplations.  This gave him the\n"
  "advantage of describing the morning in so lively a manner as he\n"
  "does everywhere in his works. The springing sun glows warm in\n"
  "his lines, and the fragrant air blows cool in his descriptions; we\n"
  "smell the sweets of the bloomy haws, and hear the music of the\n"
  "feathered choir, whenever we take a forest walk with him. The\n"
  "hour of the day is not easier to be discovered from the reflection\n"
  "of the sun in Titian's paintings, than in Chaucer's morning\n"
  "landscapes. . . . His reading was deep and extensive, his\n"
  "judgement sound and discerning. . . In one word, he was a great\n"
  "scholar, a pleasant wit, a candid critic, a sociable companion, a\n"
  "steadfast friend, a grave philosopher, a temperate economist,\n"
  "and a pious Christian.\"\n"
  "\n"
  "Chaucer's most important poems are \"Troilus and Cressida,\"\n"
  "\"The Romaunt of the Rose,\" and \"The Canterbury Tales.\"  Of\n"
  "the first, containing 8246 lines, an abridgement, with a prose\n"
  "connecting outline of the story, is given in this volume. With the\n"
  "second, consisting of 7699 octosyllabic verses, like those in\n"
  "which \"The House of Fame\" is written, it was found impossible\n"
  "to deal in the present edition. The poem is a curtailed translation\n"
  "from the French \"Roman de la Rose\" -- commenced by\n"
  "Guillaume de Lorris, who died in 1260, after contributing 4070\n"
  "verses, and completed, in the last quarter of the thirteenth\n"
  "century, by Jean de Meun, who added some 18,000 verses. It is\n"
  "a satirical allegory, in which the vices of courts, the corruptions\n"
  "of the clergy, the disorders and inequalities of society in general,\n"
  "are unsparingly attacked, and the most revolutionary doctrines\n"
  "are advanced; and though, in making his translation, Chaucer\n"
  "softened or eliminated much of the satire of the poem, still it\n"
  "remained, in his verse, a caustic exposure of the abuses of the\n"
  "time, especially those which discredited the Church.\n"
  "\n"
  "The Canterbury Tales are presented in this edition with as near\n"
  "an approach to completeness as regard for the popular character\n"
  "of the volume permitted. The 17,385 verses, of which the\n"
  "poetical Tales consist, have been given without abridgement or\n"
  "purgation -- save in a single couplet; but, the main purpose of\n"
  "the volume being to make the general reader acquainted with\n"
  "the \"poems\" of Chaucer and Spenser, the Editor has ventured to\n"
  "contract the two prose Tales -- Chaucer's Tale of Meliboeus,\n"
  "and the Parson's Sermon or Treatise on Penitence -- so as to\n"
  "save about thirty pages for the introduction of Chaucer's minor\n"
  "pieces. At the same time, by giving prose outlines of the omitted\n"
  "parts, it has been sought to guard the reader against the fear\n"
  "that he was losing anything essential, or even valuable. It is\n"
  "almost needless to describe the plot, or point out the literary\n"
  "place, of the Canterbury Tales. Perhaps in the entire range of\n"
  "ancient and modern literature there is no work that so clearly\n"
  "and freshly paints for future times the picture of the past;\n"
  "certainly no Englishman has ever approached Chaucer in the\n"
  "power of fixing for ever the fleeting traits of his own time.  The\n"
  "plan of the poem had been adopted before Chaucer chose it;\n"
  "notably in the \"Decameron\" of Boccaccio -- although, there, the\n"
  "circumstances under which the tales were told, with the terror\n"
  "of the plague hanging over the merry company, lend a grim\n"
  "grotesqueness to the narrative, unless we can look at it\n"
  "abstracted from its setting.  Chaucer, on the other hand, strikes\n"
  "a perpetual key-note of gaiety whenever he mentions the word\n"
  "\"pilgrimage;\" and at every stage of the connecting story we\n"
  "bless the happy thought which gives us incessant incident,\n"
  "movement, variety, and unclouded but never monotonous\n"
  "joyousness.\n"
  "\n"
  "The poet, the evening before he starts on a pilgrimage to the\n"
  "shrine of St Thomas at Canterbury, lies at the Tabard Inn, in\n"
  "Southwark, curious to know in what companionship he is\n"
  "destined to fare forward on the morrow. Chance sends him\n"
  "\"nine and twenty in a company,\" representing all orders of\n"
  "English society, lay and clerical, from the Knight and the Abbot\n"
  "down to the Ploughman and the Sompnour. The jolly Host of\n"
  "the Tabard, after supper, when tongues are loosened and hearts\n"
  "are opened, declares that \"not this year\" has he seen such a\n"
  "company at once under his roof-tree, and proposes that, when\n"
  "they set out next morning, he should ride with them and make\n"
  "them sport. All agree, and Harry Bailly unfolds his scheme: each\n"
  "pilgrim, including the poet, shall tell two tales on the road to\n"
  "Canterbury, and two on the way back to London; and he whom\n"
  "the general voice pronounces to have told the best tale, shall be\n"
  "treated to a supper at the common cost -- and, of course, to\n"
  "mine Host's profit -- when the cavalcade returns from the saint's\n"
  "shrine to the Southwark hostelry. All joyously assent; and early\n"
  "on the morrow, in the gay spring sunshine, they ride forth,\n"
  "listening to the heroic tale of the brave and gentle Knight, who\n"
  "has been gracefully chosen by the Host to lead the spirited\n"
  "competition of story-telling.\n"
  "\n"
  "To describe thus the nature of the plan, and to say that when\n"
  "Chaucer conceived, or at least began to execute it, he was\n"
  "between sixty and seventy years of age, is to proclaim that The\n"
  "Canterbury Tales could never be more than a fragment. Thirty\n"
  "pilgrims, each telling two tales on the way out, and two more\n"
  "on the way back -- that makes 120 tales; to say nothing of the\n"
  "prologue, the description of the journey, the occurrences at\n"
  "Canterbury, \"and all the remnant of their pilgrimage,\" which\n"
  "Chaucer also undertook. No more than twenty-three of the 120\n"
  "stories are told in the work as it comes down to us; that is, only\n"
  "twenty-three of the thirty pilgrims tell the first of the two stories\n"
  "on the road to Canterbury; while of the stories on the return\n"
  "journey we have not one, and nothing is said about the doings\n"
  "of the pilgrims at Canterbury -- which would, if treated like the\n"
  "scene at the Tabard, have given us a still livelier \"picture of the\n"
  "period.\" But the plan was too large; and although the poet had\n"
  "some reserves, in stories which he had already composed in an\n"
  "independent form, death cut short his labour ere he could even\n"
  "complete the arrangement and connection of more than a very\n"
  "few of the Tales. Incomplete as it is, however, the magnum\n"
  "opus of Chaucer was in his own time received with immense\n"
  "favour; manuscript copies are numerous even now -- no slight\n"
  "proof of its popularity; and when the invention of printing was\n"
  "introduced into England by William Caxton, The Canterbury\n"
  "Tales issued from his press in the year after the first English-\n"
  "printed book, \"The Game of the Chesse,\" had been struck off.\n"
  "Innumerable editions have since been published; and it may\n"
  "fairly be affirmed, that few books have been so much in favour\n"
  "with the reading public of every generation as this book, which\n"
  "the lapse of every generation has been rendering more\n"
  "unreadable.\n"
  "\n"
  "Apart from \"The Romaunt of the Rose,\" no really important\n"
  "poetical work of Chaucer's is omitted from or unrepresented in\n"
  "the present edition. Of \"The Legend of Good Women,\" the\n"
  "Prologue only is given -- but it is the most genuinely Chaucerian\n"
  "part of the poem.  Of \"The Court of Love,\" three-fourths are\n"
  "here presented; of \"The Assembly of Fowls,\" \"The Cuckoo and\n"
  "the Nightingale,\" \"The Flower and the Leaf,\" all; of \"Chaucer's\n"
  "Dream,\" one-fourth; of \"The House of Fame,\" two-thirds; and\n"
  "of the minor poems such a selection as may give an idea of\n"
  "Chaucer's power in the \"occasional\" department of verse.\n"
  "Necessarily, no space whatever could be given to Chaucer's\n"
  "prose works -- his translation of Boethius' Treatise on the\n"
  "Consolation of Philosophy; his Treatise on the Astrolabe,\n"
  "written for the use of his son Lewis; and his \"Testament of\n"
  "Love,\" composed in his later years, and reflecting the troubles\n"
  "that then beset the poet. If, after studying in a simplified form\n"
  "the salient works of England's first great bard, the reader is\n"
  "tempted to regret that he was not introduced to a wider\n"
  "acquaintance with the author, the purpose of the Editor will\n"
  "have been more than attained.\n"
  "\n"
  "The plan of the volume does not demand an elaborate\n"
  "examination into the state of our language when Chaucer wrote,\n"
  "or the nice questions of grammatical and metrical structure\n"
  "which conspire with the obsolete orthography to make his\n"
  "poems a sealed book for the masses. The most important\n"
  "element in the proper reading of Chaucer's verses -- whether\n"
  "written in the decasyllabic or heroic metre, which he introduced\n"
  "into our literature, or in the octosyllabic measure used with such\n"
  "animated effect in \"The House of Fame,\" \"Chaucer's Dream,\"\n"
  "&c. -- is the sounding of the terminal \"e\" where it is now silent.\n"
  "That letter is still valid in French poetry; and Chaucer's lines can\n"
  "be scanned only by reading them as we would read Racine's or\n"
  "Moliere's. The terminal \"e\" played an important part in\n"
  "grammar; in many cases it was the sign of the infinitive -- the\n"
  "\"n\" being dropped from the end; at other times it pointed the\n"
  "distinction between singular and plural, between adjective and\n"
  "adverb. The pages that follow, however, being prepared from\n"
  "the modern English point of view, necessarily no account is\n"
  "taken of those distinctions; and the now silent \"e\" has been\n"
  "retained in the text of Chaucer only when required by the\n"
  "modern spelling, or by the exigencies of metre.\n"
  "\n"
  "Before a word beginning with a vowel, or with the letter \"h,\"\n"
  "the final \"e\" was almost without exception mute; and in such\n"
  "cases, in the plural forms and infinitives of verbs, the terminal\n"
  "\"n\" is generally retained for the sake of euphony. No reader\n"
  "who is acquainted with the French language will find it hard to\n"
  "fall into Chaucer's accentuation; while, for such as are not, a\n"
  "simple perusal of the text according to the rules of modern\n"
  "verse, should remove every difficulty.\n"
  "\n"
  "\n"
  "Notes to Life of Geoffrey Chaucer\n"
  "\n"
  "\n"
  "1. \"Edmund Spenser, a native of London, was born with a Muse\n"
  "of such power, that he was superior to all English poets of\n"
  "preceding ages, not excepting his fellow-citizen Chaucer.\"\n"
  "\n"
  "2. See introduction to \"The Legend of Good Women\".\n"
  "\n"
  "3. Called in the editions before 1597 \"The Dream of Chaucer\".\n"
  "The poem, which is not included in the present edition, does\n"
  "indeed, like many of Chaucer's smaller works, tell the story of a\n"
  "dream, in which a knight, representing John of Gaunt, is found\n"
  "by the poet mourning the loss of his lady; but the true \"Dream\n"
  "of Chaucer,\" in which he celebrates the marriage of his patron,\n"
  "was published for the first time by Speght in 1597. John of\n"
  "Gaunt, in the end of 1371, married his second wife, Constance,\n"
  "daughter to Pedro the Cruel of Spain; so that \"The Book of the\n"
  "Duchess\" must have been written between 1369 and 1371.\n"
  "\n"
  "4. Where he bids his \"little book\"\n"
  "\"Subject be unto all poesy,\n"
  "And kiss the steps, where as thou seest space,\n"
  "Of Virgil, Ovid, Homer, Lucan, Stace.\"\n"
  "\n"
  "5. See note 1 to The Tale in The Clerk's Tale.\n"
  "\n"
  "6. See note 1 to The Man of Law's Tale.\n"
  "\n"
  "7. \"Written,\" says Mr Wright, \"in the sixteenth year of the reign\n"
  "of Richard II. (1392-1393);\" a powerful confirmation of the\n"
  "opinion that this poem was really produced in Chaucer's mature\n"
  "age. See the introductory notes to it and to the Legend of Good\n"
  "Women.\n"
  "\n"
  "8. The old biographers of Chaucer, founding on what they took\n"
  "to be autobiographic allusions in \"The Testament of Love,\"\n"
  "assign to him between 1354 and 1389 a very different history\n"
  "from that here given on the strength of authentic records\n"
  "explored and quoted by Sir H. Nicolas. Chaucer is made to\n"
  "espouse the cause of John of Northampton, the Wycliffite Lord\n"
  "Mayor of London, whose re-election in 1384 was so\n"
  "vehemently opposed by the clergy, and who was imprisoned in\n"
  "the sequel of the grave disorders that arose. The poet, it is said,\n"
  "fled to the Continent, taking with him a large sum of money,\n"
  "which he spent in supporting companions in exile; then,\n"
  "returning by stealth to England in quest of funds, he was\n"
  "detected and sent to the Tower, where he languished for three\n"
  "years, being released only on the humiliating condition of\n"
  "informing against his associates in the plot. The public records\n"
  "show, however, that, all the time of his alleged exile and\n"
  "captivity, he was quietly living in London, regularly drawing his\n"
  "pensions in person, sitting in Parliament, and discharging his\n"
  "duties in the Customs until his dismissal in 1386. It need not be\n"
  "said, further, that although Chaucer freely handled the errors,\n"
  "the ignorance, and vices of the clergy, he did so rather as a man\n"
  "of sense and of conscience, than as a Wycliffite -- and there is\n"
  "no evidence that he espoused the opinions of the zealous\n"
  "Reformer, far less played the part of an extreme and self-\n"
  "regardless partisan of his old friend and college-companion.\n"
  "\n"
  "9. \"The Commissioners appear to have commenced their\n"
  "labours with examining the accounts of the officers employed in\n"
  "the collection of the revenue; and the sequel affords a strong\n"
  "presumption that the royal administration [under Lancaster and\n"
  "his friends] had been foully calumniated. We hear not of any\n"
  "frauds discovered, or of defaulters punished, or of grievances\n"
  "redressed.\" Such is the testimony of Lingard (chap. iv., 1386),\n"
  "all the more valuable for his aversion from the Wycliffite\n"
  "leanings of John of Gaunt. Chaucer's department in the London\n"
  "Customs was in those days one of the most important and\n"
  "lucrative in the kingdom; and if mercenary abuse of his post\n"
  "could have been proved, we may be sure that his and his\n"
  "patron's enemies would not have been content with simple\n"
  "dismissal, but would have heavily amerced or imprisoned him.\n"
  "\n"
  "10. The salary was L36, 10s. per annum; the salary of the Chief\n"
  "Judges was L40, of the Puisne Judges about L27. Probably the\n"
  "Judges -- certainly the Clerk of the Works -- had fees or\n"
  "perquisites besides the stated payment.\n"
  "\n"
  "11. Chaucer's patron had died earlier in 1399, during the exile\n"
  "of his son (then Duke of Hereford) in France. The Duchess\n"
  "Constance had died in 1394; and the Duke had made reparation\n"
  "to Katherine Swynford -- who had already borne him four\n"
  "children -- by marrying her in 1396, with the approval of\n"
  "Richard II., who legitimated the children, and made the eldest\n"
  "son of the poet's sister-in-law Earl of Somerset. From this long-\n"
  "illicit union sprang the house of Beaufort -- that being the\n"
  "surname of the Duke's children by Katherine, after the name of\n"
  "the castle in Anjou (Belfort, or Beaufort) where they were born.\n"
  "\n"
  "12. Of Chaucer's two sons by Philippa Roet, his only wife, the\n"
  "younger, Lewis, for whom he wrote the Treatise on the\n"
  "Astrolabe, died young.  The elder, Thomas, married Maud, the\n"
  "second daughter and co-heiress of Sir John Burghersh, brother\n"
  "of the Bishop of Lincoln, the Chancellor and Treasurer of\n"
  "England. By this marriage Thomas Chaucer acquired great\n"
  "estates in Oxfordshire and elsewhere; and he figured\n"
  "prominently in the second rank of courtiers for many years. He\n"
  "was Chief Butler to Richard II.; under Henry IV. he was\n"
  "Constable of Wallingford Castle, Steward of the Honours of\n"
  "Wallingford and St Valery, and of the Chiltern Hundreds; and\n"
  "the queen of Henry IV. granted him the farm of several of her\n"
  "manors, a grant subsequently confirmed to him for life by the\n"
  "King, after the Queen's death. He sat in Parliament repeatedly\n"
  "for Oxfordshire, was Speaker in 1414, and in the same year\n"
  "went to France as commissioner to negotiate the marriage of\n"
  "Henry V. with the Princess Katherine. He held, before he died\n"
  "in 1434, various other posts of trust and distinction; but he left\n"
  "no heirs-male.  His only child, Alice Chaucer, married twice;\n"
  "first Sir John Philip; and afterwards the Duke of Suffolk --\n"
  "attainted and beheaded in 1450.  She had three children by the\n"
  "Duke; and her eldest son married the Princess Elizabeth, sister\n"
  "of Edward IV. The eldest son of this marriage, created Earl of\n"
  "Lincoln, was declared by Richard III heir-apparent to the\n"
  "throne, in case the Prince of Wales should die without issue; but\n"
  "the death of Lincoln himself, at the battle of Stoke in 1487,\n"
  "destroyed all prospect that the poet's descendants might\n"
  "succeed to the crown of England; and his family is now believed\n"
  "to be extinct.\n"
  "\n"
  "13. \"Geoffrey Chaucer, bard, and famous mother of poetry, is\n"
  "buried in this sacred ground.\"\n"
  "\n"
  "14. Railings.\n"
  "\n"
  "15 Translation of the epitaph: This tomb was built for Geoffrey\n"
  "Chaucer, who in his time was the greatest poet of the English. If\n"
  "you ask the year of his death, behold the words beneath, which\n"
  "tell you all. Death gave him rest from his toil, 25th of October\n"
  "1400.  N Brigham bore the cost of these words in the name of\n"
  "the Muses. 1556.\n"
  "\n"
  "16. See the Prologue to Chaucer's Tale of Sir Thopas.\n"
  "\n"
  "17. See the \"Goodly Ballad of Chaucer,\" seventh stanza.\n"
  "\n"
  "18. See the opening of the Prologue to \"The Legend of Good\n"
  "Women,\" and the poet's account of his habits in \"The House of\n"
  "Fame\".\n"
  "\n"
  "\n"
  "\n"
  "";
// }

const char prologue0[] PGMSECTION = // { // 26306 bytes
  "                      THE CANTERBURY TALES.\n"
  "\n"
  "\n"
  "                          THE PROLOGUE.\n"
  "\n"
  "\n"
  "WHEN that Aprilis, with his showers swoot*,                       *sweet\n"
  "The drought of March hath pierced to the root,\n"
  "And bathed every vein in such licour,\n"
  "Of which virtue engender'd is the flower;\n"
  "When Zephyrus eke with his swoote breath\n"
  "Inspired hath in every holt* and heath                    *grove, forest\n"
  "The tender croppes* and the younge sun                    *twigs, boughs\n"
  "Hath in the Ram <1> his halfe course y-run,\n"
  "And smalle fowles make melody,\n"
  "That sleepen all the night with open eye,\n"
  "(So pricketh them nature in their corages*);       *hearts, inclinations\n"
  "Then longe folk to go on pilgrimages,\n"
  "And palmers <2> for to seeke strange strands,\n"
  "To *ferne hallows couth*  in sundry lands;     *distant saints known*<3>\n"
  "And specially, from every shire's end\n"
  "Of Engleland, to Canterbury they wend,\n"
  "The holy blissful Martyr for to seek,\n"
  "That them hath holpen*, when that they were sick.                *helped\n"
  "\n"
  "Befell that, in that season on a day,\n"
  "In Southwark at the Tabard <4> as I lay,\n"
  "Ready to wenden on my pilgrimage\n"
  "To Canterbury with devout corage,\n"
  "At night was come into that hostelry\n"
  "Well nine and twenty in a company\n"
  "Of sundry folk, *by aventure y-fall            *who had by chance fallen\n"
  "In fellowship*, and pilgrims were they all,           into company.* <5>\n"
  "That toward Canterbury woulde ride.\n"
  "The chamber, and the stables were wide,\n"
  "And *well we weren eased at the best.*            *we were well provided\n"
  "And shortly, when the sunne was to rest,                  with the best*\n"
  "So had I spoken with them every one,\n"
  "That I was of their fellowship anon,\n"
  "And made forword* early for to rise,                            *promise\n"
  "To take our way there as I you devise*.                *describe, relate\n"
  "\n"
  "But natheless, while I have time and space,\n"
  "Ere that I farther in this tale pace,\n"
  "Me thinketh it accordant to reason,\n"
  "To tell you alle the condition\n"
  "Of each of them, so as it seemed me,\n"
  "And which they weren, and of what degree;\n"
  "And eke in what array that they were in:\n"
  "And at a Knight then will I first begin.\n"
  "\n"
  "A KNIGHT there was, and that a worthy man,\n"
  "That from the time that he first began\n"
  "To riden out, he loved chivalry,\n"
  "Truth and honour, freedom and courtesy.\n"
  "Full worthy was he in his Lorde's war,\n"
  "And thereto had he ridden, no man farre*,                       *farther\n"
  "As well in Christendom as in Heatheness,\n"
  "And ever honour'd for his worthiness\n"
  "At Alisandre <6> he was when it was won.\n"
  "Full often time he had the board begun\n"
  "Above alle nations in Prusse.<7>\n"
  "In Lettowe had he reysed,* and in Russe,                      *journeyed\n"
  "No Christian man so oft of his degree.\n"
  "In Grenade at the siege eke had he be\n"
  "Of Algesir, and ridden in Belmarie. <8>\n"
  "At Leyes was he, and at Satalie,\n"
  "When they were won; and in the Greate Sea\n"
  "At many a noble army had he be.\n"
  "At mortal battles had he been fifteen,\n"
  "And foughten for our faith at Tramissene.\n"
  "In listes thries, and aye slain his foe.\n"
  "This ilke* worthy knight had been also                         *same <9>\n"
  "Some time with the lord of Palatie,\n"
  "Against another heathen in Turkie:\n"
  "And evermore *he had a sovereign price*.            *He was held in very\n"
  "And though that he was worthy he was wise,                 high esteem.*\n"
  "And of his port as meek as is a maid.\n"
  "He never yet no villainy ne said\n"
  "In all his life, unto no manner wight.\n"
  "He was a very perfect gentle knight.\n"
  "But for to telle you of his array,\n"
  "His horse was good, but yet he was not gay.\n"
  "Of fustian he weared a gipon*,                            *short doublet\n"
  "Alle *besmotter'd with his habergeon,*     *soiled by his coat of mail.*\n"
  "For he was late y-come from his voyage,\n"
  "And wente for to do his pilgrimage.\n"
  "\n"
  "With him there was his son, a younge SQUIRE,\n"
  "A lover, and a lusty bacheler,\n"
  "With lockes crulle* as they were laid in press.                  *curled\n"
  "Of twenty year of age he was I guess.\n"
  "Of his stature he was of even length,\n"
  "And *wonderly deliver*, and great of strength.      *wonderfully nimble*\n"
  "And he had been some time in chevachie*,                  *cavalry raids\n"
  "In Flanders, in Artois, and Picardie,\n"
  "And borne him well, *as of so little space*,      *in such a short time*\n"
  "In hope to standen in his lady's grace.\n"
  "Embroider'd was he, as it were a mead\n"
  "All full of freshe flowers, white and red.\n"
  "Singing he was, or fluting all the day;\n"
  "He was as fresh as is the month of May.\n"
  "Short was his gown, with sleeves long and wide.\n"
  "Well could he sit on horse, and faire ride.\n"
  "He coulde songes make, and well indite,\n"
  "Joust, and eke dance, and well pourtray and write.\n"
  "So hot he loved, that by nightertale*                        *night-time\n"
  "He slept no more than doth the nightingale.\n"
  "Courteous he was, lowly, and serviceable,\n"
  "And carv'd before his father at the table.<10>\n"
  "\n"
  "A YEOMAN had he, and servants no mo'\n"
  "At that time, for *him list ride so*         *it pleased him so to ride*\n"
  "And he was clad in coat and hood of green.\n"
  "A sheaf of peacock arrows<11> bright and keen\n"
  "Under his belt he bare full thriftily.\n"
  "Well could he dress his tackle yeomanly:\n"
  "His arrows drooped not with feathers low;\n"
  "And in his hand he bare a mighty bow.\n"
  "A nut-head <12> had he, with a brown visiage:\n"
  "Of wood-craft coud* he well all the usage:                         *knew\n"
  "Upon his arm he bare a gay bracer*,                        *small shield\n"
  "And by his side a sword and a buckler,\n"
  "And on that other side a gay daggere,\n"
  "Harnessed well, and sharp as point of spear:\n"
  "A Christopher on his breast of silver sheen.\n"
  "An horn he bare, the baldric was of green:\n"
  "A forester was he soothly* as I guess.                        *certainly\n"
  "\n"
  "There was also a Nun, a PRIORESS,\n"
  "That of her smiling was full simple and coy;\n"
  "Her greatest oathe was but by Saint Loy;\n"
  "And she was cleped*  Madame Eglentine.                           *called\n"
  "Full well she sang the service divine,\n"
  "Entuned in her nose full seemly;\n"
  "And French she spake full fair and fetisly*                    *properly\n"
  "After the school of Stratford atte Bow,\n"
  "For French of Paris was to her unknow.\n"
  "At meate was she well y-taught withal;\n"
  "She let no morsel from her lippes fall,\n"
  "Nor wet her fingers in her sauce deep.\n"
  "Well could she carry a morsel, and well keep,\n"
  "That no droppe ne fell upon her breast.\n"
  "In courtesy was set full much her lest*.                       *pleasure\n"
  "Her over-lippe wiped she so clean,\n"
  "That in her cup there was no farthing* seen                       *speck\n"
  "Of grease, when she drunken had her draught;\n"
  "Full seemely after her meat she raught*:           *reached out her hand\n"
  "And *sickerly she was of great disport*,     *surely she was of a lively\n"
  "And full pleasant, and amiable of port,                     disposition*\n"
  "And *pained her to counterfeite cheer              *took pains to assume\n"
  "Of court,* and be estately of mannere,            a courtly disposition*\n"
  "And to be holden digne* of reverence.                            *worthy\n"
  "But for to speaken of her conscience,\n"
  "She was so charitable and so pitous,*                      *full of pity\n"
  "She woulde weep if that she saw a mouse\n"
  "Caught in a trap, if it were dead or bled.\n"
  "Of smalle houndes had she, that she fed\n"
  "With roasted flesh, and milk, and *wastel bread.*   *finest white bread*\n"
  "But sore she wept if one of them were dead,\n"
  "Or if men smote it with a yarde* smart:                           *staff\n"
  "And all was conscience and tender heart.\n"
  "Full seemly her wimple y-pinched was;\n"
  "Her nose tretis;* her eyen gray as glass;<13>               *well-formed\n"
  "Her mouth full small, and thereto soft and red;\n"
  "But sickerly she had a fair forehead.\n"
  "It was almost a spanne broad I trow;\n"
  "For *hardily she was not undergrow*.       *certainly she was not small*\n"
  "Full fetis* was her cloak, as I was ware.                          *neat\n"
  "Of small coral about her arm she bare\n"
  "A pair of beades, gauded all with green;\n"
  "And thereon hung a brooch of gold full sheen,\n"
  "On which was first y-written a crown'd A,\n"
  "And after, *Amor vincit omnia.*                      *love conquers all*\n"
  "Another Nun also with her had she,\n"
  "[That was her chapelleine, and PRIESTES three.]\n"
  "\n"
  "A MONK there was, a fair *for the mast'ry*,       *above all others*<14>\n"
  "An out-rider, that loved venery*;                               *hunting\n"
  "A manly man, to be an abbot able.\n"
  "Full many a dainty horse had he in stable:\n"
  "And when he rode, men might his bridle hear\n"
  "Jingeling <15> in a whistling wind as clear,\n"
  "And eke as loud, as doth the chapel bell,\n"
  "There as this lord was keeper of the cell.\n"
  "The rule of Saint Maur and of Saint Benet, <16>\n"
  "Because that it was old and somedeal strait\n"
  "This ilke* monk let olde thinges pace,                             *same\n"
  "And held after the newe world the trace.\n"
  "He *gave not of the text a pulled hen,*                *he cared nothing\n"
  "That saith, that hunters be not holy men:                  for the text*\n"
  "Ne that a monk, when he is cloisterless;\n"
  "Is like to a fish that is waterless;\n"
  "This is to say, a monk out of his cloister.\n"
  "This ilke text held he not worth an oyster;\n"
  "And I say his opinion was good.\n"
  "Why should he study, and make himselfe wood*                   *mad <17>\n"
  "Upon a book in cloister always pore,\n"
  "Or swinken* with his handes, and labour,                           *toil\n"
  "As Austin bid? how shall the world be served?\n"
  "Let Austin have his swink to him reserved.\n"
  "Therefore he was a prickasour* aright:                       *hard rider\n"
  "Greyhounds he had as swift as fowl of flight;\n"
  "Of pricking* and of hunting for the hare                         *riding\n"
  "Was all his lust,* for no cost would he spare.                 *pleasure\n"
  " I saw his sleeves *purfil'd at the hand       *worked at the end with a\n"
  "With gris,* and that the finest of the land.          fur called \"gris\"*\n"
  "And for to fasten his hood under his chin,\n"
  "He had of gold y-wrought a curious pin;\n"
  "A love-knot in the greater end there was.\n"
  "His head was bald, and shone as any glass,\n"
  "And eke his face, as it had been anoint;\n"
  "He was a lord full fat and in good point;\n"
  "His eyen steep,* and rolling in his head,                      *deep-set\n"
  "That steamed as a furnace of a lead.\n"
  "His bootes supple, his horse in great estate,\n"
  "Now certainly he was a fair prelate;\n"
  "He was not pale as a forpined* ghost;                            *wasted\n"
  "A fat swan lov'd he best of any roast.\n"
  "His palfrey was as brown as is a berry.\n"
  "\n"
  "A FRIAR there was, a wanton and a merry,\n"
  "A limitour <18>, a full solemne man.\n"
  "In all the orders four is none that can*                          *knows\n"
  "So much of dalliance and fair language.\n"
  "He had y-made full many a marriage\n"
  "Of younge women, at his owen cost.\n"
  "Unto his order he was a noble post;\n"
  "Full well belov'd, and familiar was he\n"
  "With franklins *over all* in his country,                   *everywhere*\n"
  "And eke with worthy women of the town:\n"
  "For he had power of confession,\n"
  "As said himselfe, more than a curate,\n"
  "For of his order he was licentiate.\n"
  "Full sweetely heard he confession,\n"
  "And pleasant was his absolution.\n"
  "He was an easy man to give penance,\n"
  "*There as he wist to have a good pittance:*      *where he know he would\n"
  "For unto a poor order for to give                      get good payment*\n"
  "Is signe that a man is well y-shrive.\n"
  "For if he gave, he *durste make avant*,                 *dared to boast*\n"
  "He wiste* that the man was repentant.                              *knew\n"
  "For many a man so hard is of his heart,\n"
  "He may not weep although him sore smart.\n"
  "Therefore instead of weeping and prayeres,\n"
  "Men must give silver to the poore freres.\n"
  "His tippet was aye farsed* full of knives                       *stuffed\n"
  "And pinnes, for to give to faire wives;\n"
  "And certainly he had a merry note:\n"
  "Well could he sing and playen *on a rote*;                 *from memory*\n"
  "Of yeddings* he bare utterly the prize.                           *songs\n"
  "His neck was white as is the fleur-de-lis.\n"
  "Thereto he strong was as a champion,\n"
  "And knew well the taverns in every town.\n"
  "And every hosteler and gay tapstere,\n"
  "Better than a lazar* or a beggere,                                *leper\n"
  "For unto such a worthy man as he\n"
  "Accordeth not, as by his faculty,\n"
  "To have with such lazars acquaintance.\n"
  "It is not honest, it may not advance,\n"
  "As for to deale with no such pouraille*,                  *offal, refuse\n"
  "But all with rich, and sellers of vitaille*.                   *victuals\n"
  "And *ov'r all there as* profit should arise,      *in every place where&\n"
  "Courteous he was, and lowly of service;\n"
  "There n'as no man nowhere so virtuous.\n"
  "He was the beste beggar in all his house:\n"
  "And gave a certain farme for the grant, <19>\n"
  "None of his bretheren came in his haunt.\n"
  "For though a widow hadde but one shoe,\n"
  "So pleasant was his In Principio,<20>\n"
  "Yet would he have a farthing ere he went;\n"
  "His purchase was well better than his rent.\n"
  "And rage he could and play as any whelp,\n"
  "In lovedays <21>; there could he muchel* help.                  *greatly\n"
  "For there was he not like a cloisterer,\n"
  "With threadbare cope as is a poor scholer;\n"
  "But he was like a master or a pope.\n"
  "Of double worsted was his semicope*,                        *short cloak\n"
  "That rounded was as a bell out of press.\n"
  "Somewhat he lisped for his wantonness,\n"
  "To make his English sweet upon his tongue;\n"
  "And in his harping, when that he had sung,\n"
  "His eyen* twinkled in his head aright,                             *eyes\n"
  "As do the starres in a frosty night.\n"
  "This worthy limitour <18> was call'd Huberd.\n"
  "\n"
  "A MERCHANT was there with a forked beard,\n"
  "In motley, and high on his horse he sat,\n"
  "Upon his head a Flandrish beaver hat.\n"
  "His bootes clasped fair and fetisly*.                            *neatly\n"
  "His reasons aye spake he full solemnly,\n"
  "Sounding alway th' increase of his winning.\n"
  "He would the sea were kept <22> for any thing\n"
  "Betwixte Middleburg and Orewell<23>\n"
  "Well could he in exchange shieldes* sell              *crown coins <24>\n"
  "This worthy man full well his wit beset*;                      *employed\n"
  "There wiste* no wight** that he was in debt,                 *knew **man\n"
  "So *estately was he of governance*                  *so well he managed*\n"
  "With his bargains, and with his chevisance*.          *business contract\n"
  "For sooth he was a worthy man withal,\n"
  "But sooth to say, I n'ot* how men him call.                    *know not\n"
  "\n"
  "A CLERK there was of Oxenford* also,                             *Oxford\n"
  "That unto logic hadde long y-go*.                       *devoted himself\n"
  "As leane was his horse as is a rake,\n"
  "And he was not right fat, I undertake;\n"
  "But looked hollow*, and thereto soberly**.               *thin; **poorly\n"
  "Full threadbare was his *overest courtepy*,      *uppermost short cloak*\n"
  "For he had gotten him yet no benefice,\n"
  "Ne was not worldly, to have an office.\n"
  "For him was lever* have at his bed's head                        *rather\n"
  "Twenty bookes, clothed in black or red,\n"
  "Of Aristotle, and his philosophy,\n"
  "Than robes rich, or fiddle, or psalt'ry.\n"
  "But all be that he was a philosopher,\n"
  "Yet hadde he but little gold in coffer,\n"
  "But all that he might of his friendes hent*,                     *obtain\n"
  "On bookes and on learning he it spent,\n"
  "And busily gan for the soules pray\n"
  "Of them that gave him <25> wherewith to scholay*                  *study\n"
  "Of study took he moste care and heed.\n"
  "Not one word spake he more than was need;\n"
  "And that was said in form and reverence,\n"
  "And short and quick, and full of high sentence.\n"
  "Sounding in moral virtue was his speech,\n"
  "And gladly would he learn, and gladly teach.\n"
  "\n"
  "A SERGEANT OF THE LAW, wary and wise,\n"
  "That often had y-been at the Parvis, <26>\n"
  "There was also, full rich of excellence.\n"
  "Discreet he was, and of great reverence:\n"
  "He seemed such, his wordes were so wise,\n"
  "Justice he was full often in assize,\n"
  "By patent, and by plein* commission;                               *full\n"
  "For his science, and for his high renown,\n"
  "Of fees and robes had he many one.\n"
  "So great a purchaser was nowhere none.\n"
  "All was fee simple to him, in effect\n"
  "His purchasing might not be in suspect*                       *suspicion\n"
  "Nowhere so busy a man as he there was\n"
  "And yet he seemed busier than he was\n"
  "In termes had he case' and doomes* all                       *judgements\n"
  "That from the time of King Will. were fall.\n"
  "Thereto he could indite, and make a thing\n"
  "There coulde no wight *pinch at* his writing.          *find fault with*\n"
  "And every statute coud* he plain by rote                           *knew\n"
  "He rode but homely in a medley* coat,                     *multicoloured\n"
  "Girt with a seint* of silk, with barres small;                     *sash\n"
  "Of his array tell I no longer tale.\n"
  "\n"
  "A FRANKELIN* was in this company;                        *Rich landowner\n"
  "White was his beard, as is the daisy.\n"
  "Of his complexion he was sanguine.\n"
  "Well lov'd he in the morn a sop in wine.\n"
  "To liven in delight was ever his won*,                             *wont\n"
  "For he was Epicurus' owen son,\n"
  "That held opinion, that plein* delight                             *full\n"
  "Was verily felicity perfite.\n"
  "An householder, and that a great, was he;\n"
  "Saint Julian<27> he was in his country.\n"
  "His bread, his ale, was alway *after one*;              *pressed on one*\n"
  "A better envined* man was nowhere none;                *stored with wine\n"
  "Withoute bake-meat never was his house,\n"
  "Of fish and flesh, and that so plenteous,\n"
  "It snowed in his house of meat and drink,\n"
  "Of alle dainties that men coulde think.\n"
  "After the sundry seasons of the year,\n"
  "So changed he his meat and his soupere.\n"
  "Full many a fat partridge had he in mew*,                     *cage <28>\n"
  "And many a bream, and many a luce* in stew**<29>       *pike **fish-pond\n"
  "Woe was his cook, *but if* his sauce were                       *unless*\n"
  "Poignant and sharp, and ready all his gear.\n"
  "His table dormant* in his hall alway                              *fixed\n"
  "Stood ready cover'd all the longe day.\n"
  "At sessions there was he lord and sire.\n"
  "Full often time he was *knight of the shire*      *Member of Parliament*\n"
  "An anlace*, and a gipciere** all of silk,                *dagger **purse\n"
  "Hung at his girdle, white as morning milk.\n"
  "A sheriff had he been, and a countour<30>\n"
  "Was nowhere such a worthy vavasour<31>.\n"
  "\n"
  " An HABERDASHER, and a CARPENTER,\n"
  "A WEBBE*, a DYER, and a TAPISER**,              *weaver **tapestry-maker\n"
  "Were with us eke, cloth'd in one livery,\n"
  "Of a solemn and great fraternity.\n"
  "Full fresh and new their gear y-picked* was.                     *spruce\n"
  "Their knives were y-chaped* not with brass,                     *mounted\n"
  "But all with silver wrought full clean and well,\n"
  "Their girdles and their pouches *every deal*.            *in every part*\n"
  "Well seemed each of them a fair burgess,\n"
  "To sitten in a guild-hall, on the dais. <32>\n"
  "Evereach, for the wisdom that he can*,                             *knew\n"
  "Was shapely* for to be an alderman.                              *fitted\n"
  "For chattels hadde they enough and rent,\n"
  "And eke their wives would it well assent:\n"
  "And elles certain they had been to blame.\n"
  "It is full fair to be y-clep'd madame,\n"
  "And for to go to vigils all before,\n"
  "And have a mantle royally y-bore.<33>\n"
  "\n"
  "A COOK they hadde with them for the nones*,                    *occasion\n"
  "To boil the chickens and the marrow bones,\n"
  "And powder merchant tart and galingale.\n"
  "Well could he know a draught of London ale.\n"
  "He could roast, and stew, and broil, and fry,\n"
  "Make mortrewes, and well bake a pie.\n"
  "But great harm was it, as it thoughte me,\n"
  "That, on his shin a mormal* hadde he.                             *ulcer\n"
  "For blanc manger, that made he with the best <34>\n"
  "\n"
  "A SHIPMAN was there, *wonned far by West*:                *who dwelt far\n"
  "For ought I wot, be was of Dartemouth.                      to the West*\n"
  "He rode upon a rouncy*, as he couth,                               *hack\n"
  "All in a gown of falding* to the knee.                     *coarse cloth\n"
  "A dagger hanging by a lace had he\n"
  "About his neck under his arm adown;\n"
  "The hot summer had made his hue all brown;\n"
  "And certainly he was a good fellaw.\n"
  "Full many a draught of wine he had y-draw\n"
  "From Bourdeaux-ward, while that the chapmen sleep;\n"
  "Of nice conscience took he no keep.\n"
  "If that he fought, and had the higher hand,\n"
  "*By water he sent them home to every land.*              *he drowned his\n"
  "But of his craft to reckon well his tides,                    prisoners*\n"
  "His streames and his strandes him besides,\n"
  "His herberow*, his moon, and lodemanage**,                   *harbourage\n"
  "There was none such, from Hull unto Carthage              **pilotage<35>\n"
  "Hardy he was, and wise, I undertake:\n"
  "With many a tempest had his beard been shake.\n"
  "He knew well all the havens, as they were,\n"
  "From Scotland to the Cape of Finisterre,\n"
  "And every creek in Bretagne and in Spain:\n"
  "His barge y-cleped was the Magdelain.\n"
  "\n"
  "With us there was a DOCTOR OF PHYSIC;\n"
  "In all this worlde was there none him like\n"
  "To speak of physic, and of surgery:\n"
  "For he was grounded in astronomy.\n"
  "He kept his patient a full great deal\n"
  "In houres by his magic natural.\n"
  "Well could he fortune* the ascendent                     *make fortunate\n"
  "Of his images for his patient,.\n"
  "He knew the cause of every malady,\n"
  "Were it of cold, or hot, or moist, or dry,\n"
  "And where engender'd, and of what humour.\n"
  "He was a very  perfect practisour\n"
  "The cause y-know,* and of his harm the root,                      *known\n"
  "Anon he gave to the sick man his boot*                           *remedy\n"
  "Full ready had he his apothecaries,\n"
  "To send his drugges and his lectuaries\n"
  "For each of them made other for to win\n"
  "Their friendship was not newe to begin\n"
  "Well knew he the old Esculapius,\n"
  "And Dioscorides, and eke Rufus;\n"
  "Old Hippocras, Hali, and Gallien;\n"
  "Serapion, Rasis, and Avicen;\n"
  "Averrois, Damascene, and Constantin;\n"
  "Bernard, and Gatisden, and Gilbertin. <36>\n"
  "Of his diet measurable was he,\n"
  "For it was of no superfluity,\n"
  "But of great nourishing, and digestible.\n"
  "His study was but little on the Bible.\n"
  "In sanguine* and in perse** he clad was all                  *red **blue\n"
  "Lined with taffeta, and with sendall*.                        *fine silk\n"
  "And yet *he was but easy of dispense*:            *he spent very little*\n"
  "He kept *that he won in the pestilence*.              *the money he made\n"
  "For gold in physic is a cordial;                      during the plague*\n"
  "Therefore he loved gold in special.\n"
  "\n"
  "A good WIFE was there OF beside BATH,\n"
  "But she was somedeal deaf, and that was scath*.            *damage; pity\n"
  "Of cloth-making she hadde such an haunt*,                         *skill\n"
  "She passed them of Ypres, and of Gaunt. <37>\n"
  "In all the parish wife was there none,\n"
  "That to the off'ring* before her should gon,       *the offering at mass\n"
  "And if there did, certain so wroth was she,\n"
  "That she was out of alle charity\n"
  "Her coverchiefs* were full fine of ground                  *head-dresses\n"
  "I durste swear, they weighede ten pound <38>\n"
  "That on the Sunday were upon her head.\n"
  "Her hosen weren of fine scarlet red,\n"
  "Full strait y-tied, and shoes full moist* and new            *fresh <39>\n"
  "Bold was her face, and fair and red of hue.\n"
  "She was a worthy woman all her live,\n"
  "Husbands at the church door had she had five,\n"
  "Withouten other company in youth;\n"
  "But thereof needeth not to speak as nouth*.                         *now\n"
  "And thrice had she been at Jerusalem;\n"
  "She hadde passed many a strange stream\n"
  "At Rome she had been, and at Bologne,\n"
  "In Galice at Saint James, <40> and at Cologne;\n"
  "She coude* much of wand'rng by the Way.                            *knew\n"
  "Gat-toothed* was she, soothly for to say.              *Buck-toothed<41>\n"
  "Upon an ambler easily she sat,\n"
  "Y-wimpled well, and on her head an hat\n"
  "As broad as is a buckler or a targe.\n"
  "A foot-mantle about her hippes large,\n"
  "And on her feet a pair of spurres sharp.\n"
  "In fellowship well could she laugh and carp*                 *jest, talk\n"
  "Of remedies of love she knew perchance\n"
  "For of that art she coud* the olde dance.                          *knew\n"
  "\n"
  "A good man there was of religion,\n"
  "That was a poore PARSON of a town:\n"
  "But rich he was of holy thought and werk*.                         *work\n"
  "He was also a learned man, a clerk,\n"
  "That Christe's gospel truly woulde preach.\n"
  "His parishens* devoutly would he teach.                    *parishioners\n"
  "Benign he was, and wonder diligent,\n"
  "And in adversity full patient:\n"
  "And such he was y-proved *often sithes*.                    *oftentimes*\n"
  "Full loth were him to curse for his tithes,\n"
  "But rather would he given out of doubt,\n"
  "Unto his poore parishens about,\n"
  "Of his off'ring, and eke of his substance.\n"
  "*He could in little thing have suffisance*.       *he was satisfied with\n"
  "Wide was his parish, and houses far asunder,                very little*\n"
  "But he ne left not, for no rain nor thunder,\n"
  "In sickness and in mischief to visit\n"
  "The farthest in his parish, *much and lit*,            *great and small*\n"
  "Upon his feet, and in his hand a staff.\n"
  "This noble ensample to his sheep he gaf*,                          *gave\n"
  "That first he wrought, and afterward he taught.\n"
  "Out of the gospel he the wordes caught,\n"
  "And this figure he added yet thereto,\n"
  "That if gold ruste, what should iron do?\n"
  "For if a priest be foul, on whom we trust,\n"
  "No wonder is a lewed* man to rust:                            *unlearned\n"
  "And shame it is, if that a priest take keep,\n"
  "To see a shitten shepherd and clean sheep:\n"
  "Well ought a priest ensample for to give,\n"
  "By his own cleanness, how his sheep should live.\n"
  "He sette not his benefice to hire,\n"
  "And left his sheep eucumber'd in the mire,\n"
  "And ran unto London, unto Saint Paul's,\n"
  "To seeke him a chantery<42> for souls,\n"
  "Or with a brotherhood to be withold:*                          *detained\n"
  "But dwelt at home, and kepte well his fold,\n"
  "So that the wolf ne made it not miscarry.\n"
  "He was a shepherd, and no mercenary.\n"
  "And though he holy were, and virtuous,\n"
  "He was to sinful men not dispitous*                              *severe\n"
  "Nor of his speeche dangerous nor dign*                       *disdainful\n"
  "But in his teaching discreet and benign.\n"
  "To drawen folk to heaven, with fairness,\n"
  "By good ensample, was his business:\n"
  "*But it were* any person obstinate,                     *but if it were*\n"
  "What so he were of high or low estate,\n"
  "Him would he snibbe* sharply for the nones**.  *reprove **nonce,occasion\n"
  "A better priest I trow that nowhere none is.\n"
  "He waited after no pomp nor reverence,\n"
  "Nor maked him a *spiced conscience*,             *artificial conscience*\n"
  "But Christe's lore, and his apostles' twelve,\n"
  "He taught, and first he follow'd it himselve.\n"
  "\n"
  "";
// }

const char prologue1[] PGMSECTION = // { // 24818 bytes
  "With him there was a PLOUGHMAN, was his brother,\n"
  "That had y-laid of dung full many a fother*.                        *ton\n"
  "A true swinker* and a good was he,                          *hard worker\n"
  "Living in peace and perfect charity.\n"
  "God loved he beste with all his heart\n"
  "At alle times, were it gain or smart*,                       *pain, loss\n"
  "And then his neighebour right as himselve.\n"
  "He woulde thresh, and thereto dike*, and delve,             *dig ditches\n"
  "For Christe's sake, for every poore wight,\n"
  "Withouten hire, if it lay in his might.\n"
  "His tithes payed he full fair and well,\n"
  "Both of his *proper swink*, and his chattel**   *his own labour* **goods\n"
  "In a tabard* he rode upon a mare.                     *sleeveless jerkin\n"
  "\n"
  "There was also a Reeve, and a Millere,\n"
  "A Sompnour, and a Pardoner also,\n"
  "A Manciple, and myself, there were no mo'.\n"
  "\n"
  "The MILLER was a stout carle for the nones,\n"
  "Full big he was of brawn, and eke of bones;\n"
  "That proved well, for *ov'r all where* he came,            *wheresoever*\n"
  "At wrestling he would bear away the ram.<43>\n"
  "He was short-shouldered, broad, a thicke gnarr*,          *stump of wood\n"
  "There was no door, that he n'old* heave off bar,              *could not\n"
  "Or break it at a running with his head.\n"
  "His beard as any sow or fox was red,\n"
  "And thereto broad, as though it were a spade.\n"
  "Upon the cop* right of his nose he had                        *head <44>\n"
  "A wart, and thereon stood a tuft of hairs\n"
  "Red as the bristles of a sowe's ears.\n"
  "His nose-thirles* blacke were and wide.                   *nostrils <45>\n"
  "A sword and buckler bare he by his side.\n"
  "His mouth as wide was as a furnace.\n"
  "He was a jangler, and a goliardais*,                       *buffoon <46>\n"
  "And that was most of sin and harlotries.\n"
  "Well could he steale corn, and tolle thrice\n"
  "And yet he had a thumb of gold, pardie.<47>\n"
  "A white coat and a blue hood weared he\n"
  "A baggepipe well could he blow and soun',\n"
  "And therewithal he brought us out of town.\n"
  "\n"
  "A gentle MANCIPLE <48> was there of a temple,\n"
  "Of which achatours* mighte take ensample                         *buyers\n"
  "For to be wise in buying of vitaille*.                         *victuals\n"
  "For whether that he paid, or took *by taile*,                 *on credit\n"
  "Algate* he waited so in his achate**,                 *always **purchase\n"
  "That he was aye before in good estate.\n"
  "Now is not that of God a full fair grace\n"
  "That such a lewed* mannes wit shall pace**          *unlearned **surpass\n"
  "The wisdom of an heap of learned men?\n"
  "Of masters had he more than thries ten,\n"
  "That were of law expert and curious:\n"
  "Of which there was a dozen in that house,\n"
  "Worthy to be stewards of rent and land\n"
  "Of any lord that is in Engleland,\n"
  "To make him live by his proper good,\n"
  "In honour debtless, *but if he were wood*,          *unless he were mad*\n"
  "Or live as scarcely as him list desire;\n"
  "And able for to helpen all a shire\n"
  "In any case that mighte fall or hap;\n"
  "And yet this Manciple *set their aller cap*         *outwitted them all*\n"
  "\n"
  "The REEVE <49> was a slender choleric man\n"
  "His beard was shav'd as nigh as ever he can.\n"
  "His hair was by his eares round y-shorn;\n"
  "His top was docked like a priest beforn\n"
  "Full longe were his legges, and full lean\n"
  "Y-like a staff, there was no calf y-seen\n"
  "Well could he keep a garner* and a bin*           *storeplaces for grain\n"
  "There was no auditor could on him win\n"
  "Well wist he by the drought, and by the rain,\n"
  "The yielding of his seed and of his grain\n"
  "His lorde's sheep, his neat*, and his dairy                      *cattle\n"
  "His swine, his horse, his store, and his poultry,\n"
  "Were wholly in this Reeve's governing,\n"
  "And by his cov'nant gave he reckoning,\n"
  "Since that his lord was twenty year of age;\n"
  "There could no man bring him in arrearage\n"
  "There was no bailiff, herd, nor other hine*                     *servant\n"
  "That he ne knew his *sleight and his covine*       *tricks and cheating*\n"
  "They were adrad* of him, as of the death                       *in dread\n"
  "His wonning* was full fair upon an heath                          *abode\n"
  "With greene trees y-shadow'd was his place.\n"
  "He coulde better than his lord purchase\n"
  "Full rich he was y-stored privily\n"
  "His lord well could he please subtilly,\n"
  "To give and lend him of his owen good,\n"
  "And have a thank, and yet* a coat and hood.                        *also\n"
  "In youth he learned had a good mistere*                           *trade\n"
  "He was a well good wright, a carpentere\n"
  "This Reeve sate upon a right good stot*,                          *steed\n"
  "That was all pomely* gray, and highte** Scot.          *dappled **called\n"
  "A long surcoat of perse* upon he had,                          *sky-blue\n"
  "And by his side he bare a rusty blade.\n"
  "Of Norfolk was this Reeve, of which I tell,\n"
  "Beside a town men clepen* Baldeswell,                              *call\n"
  "Tucked he was, as is a friar, about,\n"
  "And ever rode the *hinderest of the rout*.       *hindmost of the group*\n"
  "\n"
  "A SOMPNOUR* was there with us in that place,              *summoner <50>\n"
  "That had a fire-red cherubinnes face,\n"
  "For sausefleme* he was, with eyen narrow.                 *red or pimply\n"
  "As hot he was and lecherous as a sparrow,\n"
  "With scalled browes black, and pilled* beard:                    *scanty\n"
  "Of his visage children were sore afeard.\n"
  "There n'as quicksilver, litharge, nor brimstone,\n"
  "Boras, ceruse, nor oil of tartar none,\n"
  "Nor ointement that woulde cleanse or bite,\n"
  "That him might helpen of his whelkes* white,                   *pustules\n"
  "Nor of the knobbes* sitting on his cheeks.                      *buttons\n"
  "Well lov'd he garlic, onions, and leeks,\n"
  "And for to drink strong wine as red as blood.\n"
  "Then would he speak, and cry as he were wood;\n"
  "And when that he well drunken had the wine,\n"
  "Then would he speake no word but Latin.\n"
  "A fewe termes knew he, two or three,\n"
  "That he had learned out of some decree;\n"
  "No wonder is, he heard it all the day.\n"
  "And eke ye knowen well, how that a jay\n"
  "Can clepen* \"Wat,\" as well as can the Pope.                        *call\n"
  "But whoso would in other thing him grope*,                       *search\n"
  "Then had he spent all his philosophy,\n"
  "Aye, Questio quid juris,<51> would he cry.\n"
  "\n"
  "He was a gentle harlot* and a kind;                    *a low fellow<52>\n"
  "A better fellow should a man not find.\n"
  "He woulde suffer, for a quart of wine,\n"
  "A good fellow to have his concubine\n"
  "A twelvemonth, and excuse him at the full.\n"
  "Full privily a *finch eke could he pull*.               *\"fleece\" a man*\n"
  "And if he found owhere* a good fellaw,                         *anywhere\n"
  "He woulde teache him to have none awe\n"
  "In such a case of the archdeacon's curse;\n"
  "*But if* a manne's soul were in his purse;                      *unless*\n"
  "For in his purse he should y-punished be.\n"
  "\"Purse is the archedeacon's hell,\" said he.\n"
  "But well I wot, he lied right indeed:\n"
  "Of cursing ought each guilty man to dread,\n"
  "For curse will slay right as assoiling* saveth;               *absolving\n"
  "And also 'ware him of a significavit<53>.\n"
  "In danger had he at his owen guise\n"
  "The younge girles of the diocese, <54>\n"
  "And knew their counsel, and was of their rede*.                 *counsel\n"
  "A garland had he set upon his head,\n"
  "As great as it were for an alestake*:      *The post of an alehouse sign\n"
  "A buckler had he made him of a cake.\n"
  "\n"
  "With him there rode a gentle PARDONERE <55>\n"
  "Of Ronceval, his friend and his compere,\n"
  "That straight was comen from the court of Rome.\n"
  "Full loud he sang, \"Come hither, love, to me\"\n"
  "This Sompnour *bare to him a stiff burdoun*,             *sang the bass*\n"
  "Was never trump of half so great a soun'.\n"
  "This Pardoner had hair as yellow as wax,\n"
  "But smooth it hung, as doth a strike* of flax:                    *strip\n"
  "By ounces hung his lockes that he had,\n"
  "And therewith he his shoulders oversprad.\n"
  "Full thin it lay, by culpons* one and one,                *locks, shreds\n"
  "But hood for jollity, he weared none,\n"
  "For it was trussed up in his wallet.\n"
  "Him thought he rode all of the *newe get*,          *latest fashion*<56>\n"
  "Dishevel, save his cap, he rode all bare.\n"
  "Such glaring eyen had he, as an hare.\n"
  "A vernicle*  had he sew'd upon his cap.            *image of Christ <57>\n"
  "His wallet lay before him in his lap,\n"
  "Bretful* of pardon come from Rome all hot.                      *brimful\n"
  "A voice he had as small as hath a goat.\n"
  "No beard had he, nor ever one should have.\n"
  "As smooth it was as it were new y-shave;\n"
  "I trow he were a gelding or a mare.\n"
  "But of his craft, from Berwick unto Ware,\n"
  "Ne was there such another pardonere.\n"
  "For in his mail* he had a pillowbere**,           *bag <58> **pillowcase\n"
  "Which, as he saide, was our Lady's veil:\n"
  "He said, he had a gobbet* of the sail                             *piece\n"
  "That Sainte Peter had, when that he went\n"
  "Upon the sea, till Jesus Christ him hent*.                 *took hold of\n"
  "He had a cross of latoun* full of stones,                        *copper\n"
  "And in a glass he hadde pigge's bones.\n"
  "But with these relics, whenne that he fond\n"
  "A poore parson dwelling upon lond,\n"
  "Upon a day he got him more money\n"
  "Than that the parson got in moneths tway;\n"
  "And thus with feigned flattering and japes*,                      *jests\n"
  "He made the parson and the people his apes.\n"
  "But truely to tellen at the last,\n"
  "He was in church a noble ecclesiast.\n"
  "Well could he read a lesson or a story,\n"
  "But alderbest* he sang an offertory:                        *best of all\n"
  "For well he wiste, when that song was sung,\n"
  "He muste preach, and well afile* his tongue,                     *polish\n"
  "To winne silver, as he right well could:\n"
  "Therefore he sang full merrily and loud.\n"
  "\n"
  "Now have I told you shortly in a clause\n"
  "Th' estate, th' array, the number, and eke the cause\n"
  "Why that assembled was this company\n"
  "In Southwark at this gentle hostelry,\n"
  "That highte the Tabard, fast by the Bell.<59>\n"
  "But now is time to you for to tell\n"
  "*How that we baren us that ilke night*,    *what we did that same night*\n"
  "When we were in that hostelry alight.\n"
  "And after will I tell of our voyage,\n"
  "And all the remnant of our pilgrimage.\n"
  "But first I pray you of your courtesy,\n"
  "That ye *arette it not my villainy*,       *count it not rudeness in me*\n"
  "Though that I plainly speak in this mattere.\n"
  "To tellen you their wordes and their cheer;\n"
  "Not though I speak their wordes properly.\n"
  "For this ye knowen all so well as I,\n"
  "Whoso shall tell a tale after a man,\n"
  "He must rehearse, as nigh as ever he can,\n"
  "Every word, if it be in his charge,\n"
  "*All speak he* ne'er so rudely and so large;             *let him speak*\n"
  "Or elles he must tell his tale untrue,\n"
  "Or feigne things, or finde wordes new.\n"
  "He may not spare, although he were his brother;\n"
  "He must as well say one word as another.\n"
  "Christ spake Himself full broad in Holy Writ,\n"
  "And well ye wot no villainy is it.\n"
  "Eke Plato saith, whoso that can him read,\n"
  "The wordes must be cousin to the deed.\n"
  "Also I pray you to forgive it me,\n"
  "*All have I* not set folk in their degree,             *although I have*\n"
  "Here in this tale, as that they shoulden stand:\n"
  "My wit is short, ye may well understand.\n"
  "\n"
  "Great cheere made our Host us every one,\n"
  "And to the supper set he us anon:\n"
  "And served us with victual of the best.\n"
  "Strong was the wine, and well to drink us lest*.                *pleased\n"
  "A seemly man Our Hoste was withal\n"
  "For to have been a marshal in an hall.\n"
  "A large man he was with eyen steep*,                          *deep-set.\n"
  "A fairer burgess is there none in Cheap<60>:\n"
  "Bold of his speech, and wise and well y-taught,\n"
  "And of manhoode lacked him right naught.\n"
  "Eke thereto was he right a merry man,\n"
  "And after supper playen he began,\n"
  "And spake of mirth amonges other things,\n"
  "When that we hadde made our reckonings;\n"
  "And saide thus; \"Now, lordinges, truly\n"
  "Ye be to me welcome right heartily:\n"
  "For by my troth, if that I shall not lie,\n"
  "I saw not this year such a company\n"
  "At once in this herberow*, am is now.                          *inn <61>\n"
  "Fain would I do you mirth, an* I wist* how.                  *if I knew*\n"
  "And of a mirth I am right now bethought.\n"
  "To do you ease*, and it shall coste nought.                    *pleasure\n"
  "Ye go to Canterbury; God you speed,\n"
  "The blissful Martyr *quite you your meed*;               *grant you what\n"
  "And well I wot, as ye go by the way,                        you deserve*\n"
  "Ye *shapen you* to talken and to play:                       *intend to*\n"
  "For truely comfort nor mirth is none\n"
  "To ride by the way as dumb as stone:\n"
  "And therefore would I make you disport,\n"
  "As I said erst, and do you some comfort.\n"
  "And if you liketh all by one assent\n"
  "Now for to standen at my judgement,\n"
  "And for to worken as I shall you say\n"
  "To-morrow, when ye riden on the way,\n"
  "Now by my father's soule that is dead,\n"
  "*But ye be merry, smiteth off* mine head.         *unless you are merry,\n"
  "Hold up your hands withoute more speech.              smite off my head*\n"
  "\n"
  "Our counsel was not longe for to seech*:                           *seek\n"
  "Us thought it was not worth to *make it wise*,    *discuss it at length*\n"
  "And granted him withoute more avise*,                     *consideration\n"
  "And bade him say his verdict, as him lest.\n"
  "Lordings (quoth he), now hearken for the best;\n"
  "But take it not, I pray you, in disdain;\n"
  "This is the point, to speak it plat* and plain.                    *flat\n"
  "That each of you, to shorten with your way\n"
  "In this voyage, shall tellen tales tway,\n"
  "To Canterbury-ward, I mean it so,\n"
  "And homeward he shall tellen other two,\n"
  "Of aventures that whilom have befall.\n"
  "And which of you that bear'th him best of all,\n"
  "That is to say, that telleth in this case\n"
  "Tales of best sentence and most solace,\n"
  "Shall have a supper *at your aller cost*        *at the cost of you all*\n"
  "Here in this place, sitting by this post,\n"
  "When that ye come again from Canterbury.\n"
  "And for to make you the more merry,\n"
  "I will myselfe gladly with you ride,\n"
  "Right at mine owen cost, and be your guide.\n"
  "And whoso will my judgement withsay,\n"
  "Shall pay for all we spenden by the way.\n"
  "And if ye vouchesafe that it be so,\n"
  "Tell me anon withoute wordes mo'*,                                 *more\n"
  "And I will early shape me therefore.\"\n"
  "\n"
  "This thing was granted, and our oath we swore\n"
  "With full glad heart, and prayed him also,\n"
  "That he would vouchesafe for to do so,\n"
  "And that he woulde be our governour,\n"
  "And of our tales judge and reportour,\n"
  "And set a supper at a certain price;\n"
  "And we will ruled be at his device,\n"
  "In high and low: and thus by one assent,\n"
  "We be accorded to his judgement.\n"
  "And thereupon the wine was fet* anon.                          *fetched.\n"
  "We drunken, and to reste went each one,\n"
  "Withouten any longer tarrying\n"
  "A-morrow, when the day began to spring,\n"
  "Up rose our host, and was *our aller cock*,    *the cock to wake us all*\n"
  "And gather'd us together in a flock,\n"
  "And forth we ridden all a little space,\n"
  "Unto the watering of Saint Thomas<62>:\n"
  "And there our host began his horse arrest,\n"
  "And saide; \"Lordes, hearken if you lest.\n"
  "Ye *weet your forword,* and I it record.             *know your promise*\n"
  "If even-song and morning-song accord,\n"
  "Let see now who shall telle the first tale.\n"
  "As ever may I drinke wine or ale,\n"
  "Whoso is rebel to my judgement,\n"
  "Shall pay for all that by the way is spent.\n"
  "Now draw ye cuts*, ere that ye farther twin**.                *lots **go\n"
  "He which that hath the shortest shall begin.\"\n"
  "\n"
  "\"Sir Knight (quoth he), my master and my lord,\n"
  "Now draw the cut, for that is mine accord.\n"
  "Come near (quoth he), my Lady Prioress,\n"
  "And ye, Sir Clerk, let be your shamefastness,\n"
  "Nor study not: lay hand to, every man.\"\n"
  "Anon to drawen every wight began,\n"
  "And shortly for to tellen as it was,\n"
  "Were it by a venture, or sort*, or cas**,                  *lot **chance\n"
  "The sooth is this, the cut fell to the Knight,\n"
  "Of which full blithe and glad was every wight;\n"
  "And tell he must his tale as was reason,\n"
  "By forword, and by composition,\n"
  "As ye have heard; what needeth wordes mo'?\n"
  "And when this good man saw that it was so,\n"
  "As he that wise was and obedient\n"
  "To keep his forword by his free assent,\n"
  "He said; \"Sithen* I shall begin this game,                        *since\n"
  "Why, welcome be the cut in Godde's name.\n"
  "Now let us ride, and hearken what I say.\"\n"
  "And with that word we ridden forth our way;\n"
  "And he began with right a merry cheer\n"
  "His tale anon, and said as ye shall hear.\n"
  "\n"
  "\n"
  "\n"
  "Notes to the Prologue\n"
  "\n"
  "\n"
  "1. Tyrwhitt points out that \"the Bull\" should be read  here, not\n"
  "\"the Ram,\" which would place the time of  the pilgrimage in the\n"
  "end of March; whereas, in the Prologue to the Man of Law's\n"
  "Tale, the date is given as the \"eight and  twenty day of April,\n"
  "that is messenger to May.\"\n"
  "\n"
  "2. Dante, in the \"Vita Nuova,\" distinguishes three classes of\n"
  "pilgrims: palmieri - palmers who go beyond  sea to the East,\n"
  "and often bring back staves of palm-wood; peregrini, who go\n"
  "the shrine of St Jago in Galicia; Romei, who go to Rome.   Sir\n"
  "Walter Scott, however, says that palmers were in the habit of\n"
  "passing from shrine to shrine, living on charity -- pilgrims on the\n"
  "other hand, made the journey to any shrine only once,\n"
  "immediately returning to their ordinary avocations. Chaucer\n"
  "uses \"palmer\" of all pilgrims.\n"
  "\n"
  "3. \"Hallows\" survives, in the meaning here given, in All Hallows\n"
  "-- All-Saints -- day.  \"Couth,\" past participle of \"conne\" to\n"
  "know, exists in \"uncouth.\"\n"
  "\n"
  "4. The Tabard -- the sign of the inn -- was a sleeveless coat,\n"
  "worn by heralds.  The name of the inn was, some three\n"
  "centuries after Chaucer, changed to the Talbot.\n"
  "\n"
  "5. In y-fall,\" \"y\" is a corruption of the Anglo-Saxon \"ge\"\n"
  "prefixed to participles of verbs.  It is used by Chaucer merely to\n"
  "help the metre  In German,  \"y-fall,\" or  y-falle,\" would be\n"
  "\"gefallen\",  \"y-run,\" or \"y-ronne\", would be \"geronnen.\"\n"
  "\n"
  "6. Alisandre: Alexandria, in Egypt, captured by Pierre de\n"
  "Lusignan, king of Cyprus, in 1365 but abandoned immediately\n"
  "afterwards.  Thirteen years before, the same Prince had taken\n"
  "Satalie, the ancient Attalia, in Anatolia, and in 1367 he won\n"
  "Layas, in Armenia, both places named just below.\n"
  "\n"
  "7. The knight had been placed at the head of the table, above\n"
  "knights of all nations, in Prussia, whither warriors from all\n"
  "countries were wont to repair, to aid the Teutonic Order in their\n"
  "continual conflicts with their heathen neighbours in  \"Lettowe\"\n"
  "or Lithuania (German. \"Litthauen\"), Russia, &c.\n"
  "\n"
  "8. Algesiras was taken from the Moorish king of Grenada, in\n"
  "1344: the Earls of Derby and Salisbury took part in the siege.\n"
  "Belmarie is supposed to have been a Moorish state in Africa;\n"
  "but \"Palmyrie\" has been suggested as the correct reading. The\n"
  "Great Sea, or  the Greek sea, is the Eastern Mediterranean.\n"
  "Tramissene, or Tremessen, is enumerated by Froissart among\n"
  "the Moorish kingdoms in Africa. Palatie, or  Palathia, in\n"
  "Anatolia, was a fief held by the Christian  knights after the\n"
  "Turkish conquests -- the holders paying tribute to the infidel.\n"
  "Our knight had fought with one of those lords against a heathen\n"
  "neighbour.\n"
  "\n"
  "9. Ilke: same; compare the Scottish phrase \"of that ilk,\" --\n"
  "that is, of the estate which bears the same name as its owner's\n"
  "title.\n"
  "\n"
  "10. It was the custom for squires of the highest degree to carve\n"
  "at their fathers' tables.\n"
  "\n"
  "11. Peacock Arrows: Large arrows, with peacocks' feathers.\n"
  "\n"
  "12. A nut-head: With nut-brown hair; or, round like a nut, the\n"
  "hair being cut short.\n"
  "\n"
  "13. Grey eyes appear to have been a mark of female beauty in\n"
  "Chaucer's time.\n"
  "\n"
  "14. \"for the mastery\" was applied to medicines in the sense of\n"
  "\"sovereign\" as we now apply it to a remedy.\n"
  "\n"
  "15. It was fashionable to hang bells on horses' bridles.\n"
  "\n"
  "16. St. Benedict was the first founder of a spiritual order in the\n"
  "Roman church.  Maurus, abbot of Fulda from 822 to 842, did\n"
  "much to re-establish the discipline of the Benedictines on a true\n"
  "Christian basis.\n"
  "\n"
  "17. Wood: Mad, Scottish \"wud\".  Felix says to Paul, \"Too\n"
  "much learning hath made thee mad\".\n"
  "\n"
  "18. Limitour: A friar with licence or privilege to beg, or\n"
  "exercise other functions, within a certain district: as, \"the\n"
  "limitour of Holderness\".\n"
  "\n"
  "19. Farme: rent; that is, he paid a premium for his licence to\n"
  "beg.\n"
  "\n"
  "20. In principio:  the first words of Genesis and John, employed\n"
  "in some part of the mass.\n"
  "\n"
  "21. Lovedays: meetings appointed for friendly settlement of\n"
  "differences; the business was often followed by sports and\n"
  "feasting.\n"
  "\n"
  "22. He would the sea were kept  for any thing: he would for\n"
  "anything that the sea were guarded. \"The old subsidy of\n"
  "tonnage and poundage,\" says Tyrwhitt, \"was given to the king\n"
  "'pour la saufgarde et custodie del mer.' --  for the safeguard and\n"
  "keeping of the sea\" (12 E. IV. C.3).\n"
  "\n"
  "23. Middleburg, at the mouth of the Scheldt, in Holland;\n"
  "Orwell, a seaport in Essex.\n"
  "\n"
  "24. Shields: Crowns, so called from the shields stamped on\n"
  "them; French, \"ecu;\" Italian, \"scudo.\"\n"
  "\n"
  "25. Poor scholars at the universities used then to go about\n"
  "begging for money to maintain them and their studies.\n"
  "\n"
  "26. Parvis: The portico of St. Paul's, which lawyers frequented\n"
  "to meet their clients.\n"
  "\n"
  "27. St Julian: The patron saint of hospitality, celebrated for\n"
  "supplying his votaries with good lodging and good cheer.\n"
  "\n"
  "28. Mew: cage. The place behind Whitehall, where the king's\n"
  "hawks were  caged was called the Mews.\n"
  "\n"
  "29. Many a luce in stew: many a pike in his fish-pond; in those\n"
  "Catholic days, when much fish was eaten, no gentleman's\n"
  "mansion was complete without a \"stew\".\n"
  "\n"
  "30. Countour:  Probably a steward or accountant in the county\n"
  "court.\n"
  "\n"
  "31. Vavasour: A landholder of consequence; holding of a duke,\n"
  "marquis, or earl, and ranking below a baron.\n"
  "\n"
  "32. On the dais:  On the raised platform at the end of the hall,\n"
  "where sat at meat or in judgement those high in authority, rank\n"
  "or honour; in our days the worthy craftsmen might have been\n"
  "described as \"good platform men\".\n"
  "\n"
  "33. To take precedence over all in going to the evening service\n"
  "of the Church, or to festival meetings, to which it was the\n"
  "fashion to carry rich cloaks or mantles against the home-\n"
  "coming.\n"
  "\n"
  "34. The things the cook could make: \"marchand tart\",  some\n"
  "now unknown ingredient used in cookery; \"galingale,\" sweet or\n"
  "long rooted cyprus; \"mortrewes\", a rich soup made by stamping\n"
  "flesh in a mortar; \"Blanc manger\", not what is now called\n"
  "blancmange; one part of it was the brawn of a capon.\n"
  "\n"
  "35. Lodemanage: pilotage, from Anglo-Saxon \"ladman,\" a\n"
  "leader, guide, or pilot; hence \"lodestar,\" \"lodestone.\"\n"
  "\n"
  "36. The authors mentioned here were the chief medical text-\n"
  "books of the middle ages. The names of Galen and Hippocrates\n"
  "were then usually spelt \"Gallien\" and \"Hypocras\" or \"Ypocras\".\n"
  "\n"
  "37. The west of England, especially around Bath, was the seat\n"
  "of the cloth-manufacture, as were Ypres and Ghent (Gaunt) in\n"
  "Flanders.\n"
  "\n"
  "38. Chaucer here satirises the fashion of the time, which piled\n"
  "bulky and heavy waddings on ladies' heads.\n"
  "\n"
  "39. Moist; here used in the sense of \"new\", as in Latin,\n"
  "\"mustum\" signifies new wine; and elsewhere Chaucer speaks of\n"
  "\"moisty ale\", as opposed to \"old\".\n"
  "\n"
  "40. In Galice at Saint James: at the shrine of St Jago of\n"
  "Compostella in Spain.\n"
  "\n"
  "41. Gat-toothed: Buck-toothed; goat-toothed, to signify her\n"
  "wantonness; or gap-toothed -- with gaps between her teeth.\n"
  "\n"
  "42. An endowment to sing masses for the soul of the donor.\n"
  "\n"
  "43. A ram was the usual prize at wrestling matches.\n"
  "\n"
  "44. Cop: Head; German, \"Kopf\".\n"
  "\n"
  "45. Nose-thirles: nostrils; from the Anglo-Saxon, \"thirlian,\" to\n"
  "pierce; hence the word \"drill,\" to bore.\n"
  "\n"
  "46. Goliardais: a babbler and a buffoon; Golias was the founder\n"
  "of a jovial sect called by his name.\n"
  "\n"
  "47. The proverb says that every honest miller has a thumb of\n"
  "gold; probably Chaucer means that this one was as honest as his\n"
  "brethren.\n"
  "\n"
  "48. A Manciple -- Latin, \"manceps,\" a purchaser or contractor -\n"
  "- was an officer charged with the purchase of victuals for inns\n"
  "of court or colleges.\n"
  "\n"
  "49. Reeve: A land-steward; still called \"grieve\" -- Anglo-Saxon,\n"
  "\"gerefa\"  in some parts of Scotland.\n"
  "\n"
  "50. Sompnour: summoner; an apparitor, who cited delinquents\n"
  "to appear in ecclesiastical courts.\n"
  "\n"
  "51. Questio quid juris: \"I ask which law (applies)\"; a cant law-\n"
  "Latin phrase.\n"
  "\n"
  "52 Harlot: a low, ribald fellow; the word was used of both\n"
  "sexes; it comes from the Anglo-Saxon verb to hire.\n"
  "\n"
  "53. Significavit: an ecclesiastical writ.\n"
  "\n"
  "54. Within his jurisdiction he had at his own pleasure the young\n"
  "people (of both sexes) in the diocese.\n"
  "\n"
  "55. Pardoner: a seller of pardons or indulgences.\n"
  "\n"
  "56. Newe get:  new gait, or fashion; \"gait\" is still used in this\n"
  "sense in some parts of the country.\n"
  "\n"
  "57. Vernicle: an image of Christ; so called from St Veronica,\n"
  "who gave the Saviour a napkin to wipe the sweat from  His face\n"
  "as He bore the Cross, and received it back with an impression\n"
  "of His countenance upon it.\n"
  "\n"
  "58. Mail: packet, baggage; French, \"malle,\" a trunk.\n"
  "\n"
  "59. The Bell:  apparently another Southwark tavern; Stowe\n"
  "mentions a \"Bull\" as being near the Tabard.\n"
  "\n"
  "60. Cheap: Cheapside, then inhabited by the richest and most\n"
  "prosperous citizens of London.\n"
  "\n"
  "61. Herberow: Lodging, inn; French, \"Herberge.\"\n"
  "\n"
  "62. The watering of Saint Thomas: At the second milestone on\n"
  "the old Canterbury road.\n"
  "\n"
  "\n"
  "\n"
  "";
// }

// FLASHEND <  16383:   2534 bytes
// FLASHEND >= 16383:  12165 bytes
const char knightsTale0[] PGMSECTION = // { // 27945 bytes
  "                     THE KNIGHT'S TALE <1>\n"
  "\n"
  "\n"
  "WHILOM*, as olde stories tellen us,                            *formerly\n"
  "There was a duke that highte* Theseus.                   *was called <2>\n"
  "Of Athens he was lord and governor,\n"
  "And in his time such a conqueror\n"
  "That greater was there none under the sun.\n"
  "Full many a riche country had he won.\n"
  "What with his wisdom and his chivalry,\n"
  "He conquer'd all the regne of Feminie,<3>\n"
  "That whilom was y-cleped Scythia;\n"
  "And weddede the Queen Hippolyta\n"
  "And brought her home with him to his country\n"
  "With muchel* glory and great solemnity,                           *great\n"
  "And eke her younge sister Emily,\n"
  "And thus with vict'ry and with melody\n"
  "Let I this worthy Duke to Athens ride,\n"
  "And all his host, in armes him beside.\n"
  "\n"
  "And certes, if it n'ere* too long to hear,                     *were not\n"
  "I would have told you fully the mannere,\n"
  "How wonnen* was the regne of Feminie, <4>                           *won\n"
  "By Theseus, and by his chivalry;\n"
  "And of the greate battle for the nonce\n"
  "Betwixt Athenes and the Amazons;\n"
  "And how assieged was Hippolyta,\n"
  "The faire hardy queen of Scythia;\n"
  "And of the feast that was at her wedding\n"
  "And of the tempest at her homecoming.\n"
  "But all these things I must as now forbear.\n"
  "I have, God wot, a large field to ear*                       *plough<5>;\n"
  "And weake be the oxen in my plough;\n"
  "The remnant of my tale is long enow.\n"
  "I will not *letten eke none of this rout*.                *hinder any of\n"
  "Let every fellow tell his tale about,                      this company*\n"
  "And let see now who shall the supper win.\n"
  "There *as I left*, I will again begin.                *where I left off*\n"
  "\n"
  "This Duke, of whom I make mentioun,\n"
  "When he was come almost unto the town,\n"
  "In all his weal, and in his moste pride,\n"
  "He was ware, as he cast his eye aside,\n"
  "Where that there kneeled in the highe way\n"
  "A company of ladies, tway and tway,\n"
  "Each after other, clad in clothes black:\n"
  "But such a cry and such a woe they make,\n"
  "That in this world n'is creature living,\n"
  "That hearde such another waimenting*                      *lamenting <6>\n"
  "And of this crying would they never stenten*,                    *desist\n"
  "Till they the reines of his bridle henten*.                       *seize\n"
  "\"What folk be ye that at mine homecoming\n"
  "Perturben so my feaste with crying?\"\n"
  "Quoth Theseus; \"Have ye so great envy\n"
  "Of mine honour, that thus complain and cry?\n"
  "Or who hath you misboden*, or offended?                         *wronged\n"
  "Do telle me, if it may be amended;\n"
  "And why that ye be clad thus all in black?\"\n"
  "\n"

#if FLASHEND >= 16383
  "The oldest lady of them all then spake,\n"
  "When she had swooned, with a deadly cheer*,                 *countenance\n"
  "That it was ruthe* for to see or hear.                             *pity\n"
  "She saide; \"Lord, to whom fortune hath given\n"
  "Vict'ry, and as a conqueror to liven,\n"
  "Nought grieveth us your glory and your honour;\n"
  "But we beseechen mercy and succour.\n"
  "Have mercy on our woe and our distress;\n"
  "Some drop of pity, through thy gentleness,\n"
  "Upon us wretched women let now fall.\n"
  "For certes, lord, there is none of us all\n"
  "That hath not been a duchess or a queen;\n"
  "Now be we caitives*, as it is well seen:                       *captives\n"
  "Thanked be Fortune, and her false wheel,\n"
  "That *none estate ensureth to be wele*.       *assures no continuance of\n"
  "And certes, lord, t'abiden your presence              prosperous estate*\n"
  "Here in this temple of the goddess Clemence\n"
  "We have been waiting all this fortenight:\n"
  "Now help us, lord, since it lies in thy might.\n"
  "\n"
  "\"I, wretched wight, that weep and waile thus,\n"
  "Was whilom wife to king Capaneus,\n"
  "That starf* at Thebes, cursed be that day:                     *died <7>\n"
  "And alle we that be in this array,\n"
  "And maken all this lamentatioun,\n"
  "We losten all our husbands at that town,\n"
  "While that the siege thereabouten lay.\n"
  "And yet the olde Creon, wellaway!\n"
  "That lord is now of Thebes the city,\n"
  "Fulfilled of ire and of iniquity,\n"
  "He for despite, and for his tyranny,\n"
  "To do the deade bodies villainy*,                                *insult\n"
  "Of all our lorde's, which that been y-slaw,                       *slain\n"
  "Hath all the bodies on an heap y-draw,\n"
  "And will not suffer them by none assent\n"
  "Neither to be y-buried, nor y-brent*,                             *burnt\n"
  "But maketh houndes eat them in despite.\"\n"
  "And with that word, withoute more respite\n"
  "They fallen groff,* and cryden piteously;                    *grovelling\n"
  "\"Have on us wretched women some mercy,\n"
  "And let our sorrow sinken in thine heart.\"\n"
  "\n"
  "This gentle Duke down from his courser start\n"
  "With hearte piteous, when he heard them speak.\n"
  "Him thoughte that his heart would all to-break,\n"
  "When he saw them so piteous and so mate*                         *abased\n"
  "That whilom weren of so great estate.\n"
  "And in his armes he them all up hent*,                     *raised, took\n"
  "And them comforted in full good intent,\n"
  "And swore his oath, as he was true knight,\n"
  "He woulde do *so farforthly his might*        *as far as his power went*\n"
  "Upon the tyrant Creon them to wreak*,                            *avenge\n"
  "That all the people of Greece shoulde speak,\n"
  "How Creon was of Theseus y-served,\n"
  "As he that had his death full well deserved.\n"
  "And right anon withoute more abode*                               *delay\n"
  "His banner he display'd, and forth he rode\n"
  "To Thebes-ward, and all his, host beside:\n"
  "No ner* Athenes would he go nor ride,                            *nearer\n"
  "Nor take his ease fully half a day,\n"
  "But onward on his way that night he lay:\n"
  "And sent anon Hippolyta the queen,\n"
  "And Emily her younge sister sheen*                       *bright, lovely\n"
  "Unto the town of Athens for to dwell:\n"
  "And forth he rit*; there is no more to tell.                       *rode\n"
  "\n"
  "The red statue of Mars with spear and targe*                     *shield\n"
  "So shineth in his white banner large\n"
  "That all the fieldes glitter up and down:\n"
  "And by his banner borne is his pennon\n"
  "Of gold full rich, in which there was y-beat*                   *stamped\n"
  "The Minotaur<8> which that he slew in Crete\n"
  "Thus rit this Duke, thus rit this conqueror\n"
  "And in his host of chivalry the flower,\n"
  "Till that he came to Thebes, and alight\n"
  "Fair in a field, there as he thought to fight.\n"
  "But shortly for to speaken of this thing,\n"
  "With Creon, which that was of Thebes king,\n"
  "He fought, and slew him manly as a knight\n"
  "In plain bataille, and put his folk to flight:\n"
  "And by assault he won the city after,\n"
  "And rent adown both wall, and spar, and rafter;\n"
  "And to the ladies he restored again\n"
  "The bodies of their husbands that were slain,\n"
  "To do obsequies, as was then the guise*.                         *custom\n"
  "\n"
  "But it were all too long for to devise*                        *describe\n"
  "The greate clamour, and the waimenting*,                      *lamenting\n"
  "Which that the ladies made at the brenning*                     *burning\n"
  "Of the bodies, and the great honour\n"
  "That Theseus the noble conqueror\n"
  "Did to the ladies, when they from him went:\n"
  "But shortly for to tell is mine intent.\n"
  "When that this worthy Duke, this Theseus,\n"
  "Had Creon slain, and wonnen Thebes thus,\n"
  "Still in the field he took all night his rest,\n"
  "And did with all the country as him lest*.                      *pleased\n"
  "To ransack in the tas* of bodies dead,                             *heap\n"
  "Them for to strip of *harness and of **weed,           *armour **clothes\n"
  "The pillers* did their business and cure,                 *pillagers <9>\n"
  "After the battle and discomfiture.\n"
  "And so befell, that in the tas they found,\n"
  "Through girt with many a grievous bloody wound,\n"
  "Two younge knightes *ligging by and by*             *lying side by side*\n"
  "Both in *one armes*, wrought full richely:             *the same armour*\n"
  "Of whiche two, Arcita hight that one,\n"
  "And he that other highte Palamon.\n"
  "Not fully quick*, nor fully dead they were,                       *alive\n"
  "But by their coat-armour, and by their gear,\n"
  "The heralds knew them well in special,\n"
  "As those that weren of the blood royal\n"
  "Of Thebes, and *of sistren two y-born*.            *born of two sisters*\n"
  "Out of the tas the pillers have them torn,\n"
  "And have them carried soft unto the tent\n"
  "Of Theseus, and he full soon them sent\n"
  "To Athens, for to dwellen in prison\n"
  "Perpetually, he *n'olde no ranson*.               *would take no ransom*\n"
  "And when this worthy Duke had thus y-done,\n"
  "He took his host, and home he rit anon\n"
  "With laurel crowned as a conquerour;\n"
  "And there he lived in joy and in honour\n"
  "Term of his life; what needeth wordes mo'?\n"
  "And in a tower, in anguish and in woe,\n"
  "Dwellen this Palamon, and eke Arcite,\n"
  "For evermore, there may no gold them quite*                    *set free\n"
  "\n"
  "Thus passed year by year, and day by day,\n"
  "Till it fell ones in a morn of May\n"
  "That Emily, that fairer was to seen\n"
  "Than is the lily upon his stalke green,\n"
  "And fresher than the May with flowers new\n"
  "(For with the rose colour strove her hue;\n"
  "I n'ot* which was the finer of them two),                      *know not\n"
  "Ere it was day, as she was wont to do,\n"
  "She was arisen, and all ready dight*,                           *dressed\n"
  "For May will have no sluggardy a-night;\n"
  "The season pricketh every gentle heart,\n"
  "And maketh him out of his sleep to start,\n"
  "And saith, \"Arise, and do thine observance.\"\n"
  "\n"
  "This maketh Emily have remembrance\n"
  "To do honour to May, and for to rise.\n"
  "Y-clothed was she fresh for to devise;\n"
  "Her yellow hair was braided in a tress,\n"
  "Behind her back, a yarde long I guess.\n"
  "And in the garden at *the sun uprist*                           *sunrise\n"
  "She walketh up and down where as her list.\n"
  "She gathereth flowers, party* white and red,                    *mingled\n"
  "To make a sotel* garland for her head,            *subtle, well-arranged\n"
  "And as an angel heavenly she sung.\n"
  "The greate tower, that was so thick and strong,\n"
  "Which of the castle was the chief dungeon<10>\n"
  "(Where as these knightes weren in prison,\n"
  "Of which I tolde you, and telle shall),\n"
  "Was even joinant* to the garden wall,                         *adjoining\n"
  "There as this Emily had her playing.\n"
  "\n"
  "Bright was the sun, and clear that morrowning,\n"
  "And Palamon, this woful prisoner,\n"
  "As was his wont, by leave of his gaoler,\n"
  "Was ris'n, and roamed in a chamber on high,\n"
  "In which he all the noble city sigh*,                               *saw\n"
  "And eke the garden, full of branches green,\n"
  "There as this fresh Emelia the sheen\n"
  "Was in her walk, and roamed up and down.\n"
  "This sorrowful prisoner, this Palamon\n"
  "Went in his chamber roaming to and fro,\n"
  "And to himself complaining of his woe:\n"
  "That he was born, full oft he said, Alas!\n"
  "And so befell, by aventure or cas*,                              *chance\n"
  "That through a window thick of many a bar\n"
  "Of iron great, and square as any spar,\n"
  "He cast his eyes upon Emelia,\n"
  "And therewithal he blent* and cried, Ah!                  *started aside\n"
  "As though he stungen were unto the heart.\n"
  "And with that cry Arcite anon up start,\n"
  "And saide, \"Cousin mine, what aileth thee,\n"
  "That art so pale and deadly for to see?\n"
  "Why cried'st thou? who hath thee done offence?\n"
  "For Godde's love, take all in patience\n"
  "Our prison*, for it may none other be.                     *imprisonment\n"
  "Fortune hath giv'n us this adversity'.\n"
  "Some wick'* aspect or disposition                                *wicked\n"
  "Of Saturn<11>, by some constellation,\n"
  "Hath giv'n us this, although we had it sworn,\n"
  "So stood the heaven when that we were born,\n"
  "We must endure; this is the short and plain.\n"
  "\n"
  "This Palamon answer'd, and said again:\n"
  "\"Cousin, forsooth of this opinion\n"
  "Thou hast a vain imagination.\n"
  "This prison caused me not for to cry;\n"
  "But I was hurt right now thorough mine eye\n"
  "Into mine heart; that will my bane*  be.                    *destruction\n"
  "The fairness of the lady that I see\n"
  "Yond in the garden roaming to and fro,\n"
  "Is cause of all my crying and my woe.\n"
  "I *n'ot wher* she be woman or goddess,                *know not whether*\n"
  "But Venus is it, soothly* as I guess,                             *truly\n"
  "And therewithal on knees adown he fill,\n"
  "And saide: \"Venus, if it be your will\n"
  "You in this garden thus to transfigure\n"
  "Before me sorrowful wretched creature,\n"
  "Out of this prison help that we may scape.\n"
  "And if so be our destiny be shape\n"
  "By etern word to dien in prison,\n"
  "Of our lineage have some compassion,\n"
  "That is so low y-brought by tyranny.\"\n"
  "\n"
#endif

#if FLASHEND >= 32767
  "And with that word Arcita *gan espy*               *began to look forth*\n"
  "Where as this lady roamed to and fro\n"
  "And with that sight her beauty hurt him so,\n"
  "That if that Palamon was wounded sore,\n"
  "Arcite is hurt as much as he, or more.\n"
  "And with a sigh he saide piteously:\n"
  "\"The freshe beauty slay'th me suddenly\n"
  "Of her that roameth yonder in the place.\n"
  "And but* I have her mercy and her grace,                         *unless\n"
  "That I may see her at the leaste way,\n"
  "I am but dead; there is no more to say.\"\n"
  "This Palamon, when he these wordes heard,\n"
  "Dispiteously* he looked, and answer'd:                          *angrily\n"
  "\"Whether say'st thou this in earnest or in play?\"\n"
  "\"Nay,\" quoth Arcite, \"in earnest, by my fay*.                     *faith\n"
  "God help me so, *me lust full ill to play*.\"          *I am in no humour\n"
  "This Palamon gan knit his browes tway.                      for jesting*\n"
  "\"It were,\" quoth he, \"to thee no great honour\n"
  "For to be false, nor for to be traitour\n"
  "To me, that am thy cousin and thy brother\n"
  "Y-sworn full deep, and each of us to other,\n"
  "That never for to dien in the pain <12>,\n"
  "Till that the death departen shall us twain,\n"
  "Neither of us in love to hinder other,\n"
  "Nor in none other case, my leve* brother;                          *dear\n"
  "But that thou shouldest truly farther me\n"
  "In every case, as I should farther thee.\n"
  "This was thine oath, and mine also certain;\n"
  "I wot it well, thou dar'st it not withsayn*,                       *deny\n"
  "Thus art thou of my counsel out of doubt,\n"
  "And now thou wouldest falsely be about\n"
  "To love my lady, whom I love and serve,\n"
  "And ever shall, until mine hearte sterve*                           *die\n"
  "Now certes, false Arcite, thou shalt not so\n"
  "I lov'd her first, and tolde thee my woe\n"
  "As to my counsel, and my brother sworn\n"
  "To farther me, as I have told beforn.\n"
  "For which thou art y-bounden as a knight\n"
  "To helpe me, if it lie in thy might,\n"
  "Or elles art thou false, I dare well sayn,\"\n"
  "\n"
  "This Arcita full proudly spake again:\n"
  "\"Thou shalt,\" quoth he, \"be rather* false than I,                *sooner\n"
  "And thou art false, I tell thee utterly;\n"
  "For par amour I lov'd her first ere thou.\n"
  "What wilt thou say? *thou wist it not right now*          *even now thou\n"
  "Whether she be a woman or goddess.                          knowest not*\n"
  "Thine is affection of holiness,\n"
  "And mine is love, as to a creature:\n"
  "For which I tolde thee mine aventure\n"
  "As to my cousin, and my brother sworn\n"
  "I pose*, that thou loved'st her beforn:                         *suppose\n"
  "Wost* thou not well the olde clerke's saw<13>,                  *know'st\n"
  "That who shall give a lover any law?\n"
  "Love is a greater lawe, by my pan,\n"
  "Than may be giv'n to any earthly man:\n"
  "Therefore positive law, and such decree,\n"
  "Is broke alway for love in each degree\n"
  "A man must needes love, maugre his head.\n"
  "He may not flee it, though he should be dead,\n"
  "*All be she* maid, or widow, or else wife.              *whether she be*\n"
  "And eke it is not likely all thy life\n"
  "To standen in her grace, no more than I\n"
  "For well thou wost thyselfe verily,\n"
  "That thou and I be damned to prison\n"
  "Perpetual, us gaineth no ranson.\n"
  "We strive, as did the houndes for the bone;\n"
  "They fought all day, and yet their part was none.\n"
  "There came a kite, while that they were so wroth,\n"
  "And bare away the bone betwixt them both.\n"
  "And therefore at the kinge's court, my brother,\n"
  "Each man for himselfe, there is no  other.\n"
  "Love if thee list; for I love and aye shall\n"
  "And soothly, leve brother, this is all.\n"
  "Here in this prison musten we endure,\n"
  "And each of us take his Aventure.\"\n"
  "\n"
  "Great was the strife and long between these tway,\n"
  "If that I hadde leisure for to say;\n"
  "But to the effect: it happen'd on a day\n"
  "(To tell it you as shortly as I may),\n"
  "A worthy duke that hight Perithous<14>\n"
  "That fellow was to the Duke Theseus\n"
  "Since thilke* day that they were children lite**          *that **little\n"
  "Was come to Athens, his fellow to visite,\n"
  "And for to play, as he was wont to do;\n"
  "For in this world he loved no man so;\n"
  "And he lov'd him as tenderly again.\n"
  "So well they lov'd, as olde bookes sayn,\n"
  "That when that one was dead, soothly to sayn,\n"
  "His fellow went and sought him down in hell:\n"
  "But of that story list me not to write.\n"
  "Duke Perithous loved well Arcite,\n"
  "And had him known at Thebes year by year:\n"
  "And finally at request and prayere\n"
  "Of Perithous, withoute ranson\n"
  "Duke Theseus him let out of prison,\n"
  "Freely to go, where him list over all,\n"
  "In such a guise, as I you tellen shall\n"
  "This was the forword*, plainly to indite,                       *promise\n"
  "Betwixte Theseus and him Arcite:\n"
  "That if so were, that Arcite were y-found\n"
  "Ever in his life, by day or night, one stound*               *moment<15>\n"
  "In any country of this Theseus,\n"
  "And he were caught, it was accorded thus,\n"
  "That with a sword he shoulde lose his head;\n"
  "There was none other remedy nor rede*.                          *counsel\n"
  "But took his leave, and homeward he him sped;\n"
  "Let him beware, his necke lieth *to wed*.                    *in pledge*\n"
  "\n"
  "How great a sorrow suff'reth now Arcite!\n"
  "The death he feeleth through his hearte smite;\n"
  "He weepeth, waileth, crieth piteously;\n"
  "To slay himself he waiteth privily.\n"
  "He said; \"Alas the day that I was born!\n"
  "Now is my prison worse than beforn:\n"
  "*Now is me shape* eternally to dwell                *it is fixed for me*\n"
  "Not in purgatory, but right in hell.\n"
  "Alas! that ever I knew Perithous.\n"
  "For elles had I dwelt with Theseus\n"
  "Y-fettered in his prison evermo'.\n"
  "Then had I been in bliss, and not in woe.\n"
  "Only the sight of her, whom that I serve,\n"
  "Though that I never may her grace deserve,\n"
  "Would have sufficed right enough for me.\n"
  "O deare cousin Palamon,\" quoth he,\n"
  "\"Thine is the vict'ry of this aventure,\n"
  "Full blissfully in prison to endure:\n"
  "In prison? nay certes, in paradise.\n"
  "Well hath fortune y-turned thee the dice,\n"
  "That hast the sight of her, and I th' absence.\n"
  "For possible is, since thou hast her presence,\n"
  "And art a knight, a worthy and an able,\n"
  "That by some cas*, since fortune is changeable,                  *chance\n"
  "Thou may'st to thy desire sometime attain.\n"
  "But I that am exiled, and barren\n"
  "Of alle grace, and in so great despair,\n"
  "That there n'is earthe, water, fire, nor air,\n"
  "Nor creature, that of them maked is,\n"
  "That may me helpe nor comfort in this,\n"
  "Well ought I *sterve in wanhope* and distress.          *die in despair*\n"
  "Farewell my life, my lust*, and my gladness.                   *pleasure\n"
  "Alas, *why plainen men so in commune       *why do men so often complain\n"
  "Of purveyance of God*, or of Fortune,              of God's providence?*\n"
  "That giveth them full oft in many a guise\n"
  "Well better than they can themselves devise?\n"
  "Some man desireth for to have richess,\n"
  "That cause is of his murder or great sickness.\n"
  "And some man would out of his prison fain,\n"
  "That in his house is of his meinie* slain.                *servants <16>\n"
  "Infinite harmes be in this mattere.\n"
  "We wot never what thing we pray for here.\n"
  "We fare as he that drunk is as a mouse.\n"
  "A drunken man wot well he hath an house,\n"
  "But he wot not which is the right way thither,\n"
  "And to a drunken man the way is slither*.                      *slippery\n"
  "And certes in this world so fare we.\n"
  "We seeke fast after felicity,\n"
  "But we go wrong full often truely.\n"
  "Thus we may sayen all, and namely* I,                        *especially\n"
  "That ween'd*, and had a great opinion,                          *thought\n"
  "That if I might escape from prison\n"
  "Then had I been in joy and perfect heal,\n"
  "Where now I am exiled from my weal.\n"
  "Since that I may not see you, Emily,\n"
  "I am but dead; there is no remedy.\"\n"
  "\n"
  "Upon that other side, Palamon,\n"
  "When that he wist Arcita was agone,\n"
  "Much sorrow maketh, that the greate tower\n"
  "Resounded of his yelling and clamour\n"
  "The pure* fetters on his shinnes great                        *very <17>\n"
  "Were of his bitter salte teares wet.\n"
  "\n"
  "\"Alas!\" quoth he, \"Arcita, cousin mine,\n"
  "Of all our strife, God wot, the fruit is thine.\n"
  "Thou walkest now in Thebes at thy large,\n"
  "And of my woe thou *givest little charge*.          *takest little heed*\n"
  "Thou mayst, since thou hast wisdom and manhead*,       *manhood, courage\n"
  "Assemble all the folk of our kindred,\n"
  "And make a war so sharp on this country\n"
  "That by some aventure, or some treaty,\n"
  "Thou mayst have her to lady and to wife,\n"
  "For whom that I must needes lose my life.\n"
  "For as by way of possibility,\n"
  "Since thou art at thy large, of prison free,\n"
  "And art a lord, great is thine avantage,\n"
  "More than is mine, that sterve here in a cage.\n"
  "For I must weep and wail, while that I live,\n"
  "With all the woe that prison may me give,\n"
  "And eke with pain that love me gives also,\n"
  "That doubles all my torment and my woe.\"\n"
  "\n"
  "Therewith the fire of jealousy upstart\n"
  "Within his breast, and hent* him by the heart                    *seized\n"
  "So woodly*, that he like was to behold                            *madly\n"
  "The box-tree, or the ashes dead and cold.\n"
  "Then said; \"O cruel goddess, that govern\n"
  "This world with binding of your word etern*                     *eternal\n"
  "And writen in the table of adamant\n"
  "Your parlement* and your eternal grant,                    *consultation\n"
  "What is mankind more *unto you y-hold*                  *by you esteemed\n"
  "Than is the sheep, that rouketh* in the fold!      *lie huddled together\n"
  "For slain is man, right as another beast;\n"
  "And dwelleth eke in prison and arrest,\n"
  "And hath sickness, and great adversity,\n"
  "And oftentimes guilteless, pardie*                               *by God\n"
  "What governance is in your prescience,\n"
  "That guilteless tormenteth innocence?\n"
  "And yet increaseth this all my penance,\n"
  "That man is bounden to his observance\n"
  "For Godde's  sake to *letten of his will*,         *restrain his desire*\n"
  "Whereas a beast may all his lust fulfil.\n"
  "And when a beast is dead, he hath no pain;\n"
  "But man after his death must weep and plain,\n"
  "Though in this worlde he have care and woe:\n"
  "Withoute doubt it maye standen so.\n"
  "\"The answer of this leave I to divines,\n"
  "But well I wot, that in this world great pine* is;        *pain, trouble\n"
  "Alas! I see a serpent or a thief\n"
  "That many a true man hath done mischief,\n"
  "Go at his large, and where him list may turn.\n"
  "But I must be in prison through Saturn,\n"
  "And eke through Juno, jealous and eke wood*,                        *mad\n"
  "That hath well nigh destroyed all the blood\n"
  "Of Thebes, with his waste walles wide.\n"
  "And Venus slay'th me on that other side\n"
  "For jealousy, and fear of him, Arcite.\"\n"
  "\n"
  "Now will I stent* of Palamon a lite**,                   *pause **little\n"
  "And let him in his prison stille dwell,\n"
  "And of Arcita forth I will you tell.\n"
  "The summer passeth, and the nightes long\n"
  "Increase double-wise the paines strong\n"
  "Both of the lover and the prisonere.\n"
  "I n'ot* which hath the wofuller mistere**.         *know not **condition\n"
  "For, shortly for to say, this Palamon\n"
  "Perpetually is damned to prison,\n"
  "In chaines and in fetters to be dead;\n"
  "And Arcite is exiled *on his head*                *on peril of his head*\n"
  "For evermore as out of that country,\n"
  "Nor never more he shall his lady see.\n"
  "You lovers ask I now this question,<18>\n"
  "Who lieth the worse, Arcite or Palamon?\n"
  "The one may see his lady day by day,\n"
  "But in prison he dwelle must alway.\n"
  "The other where him list may ride or go,\n"
  "But see his lady shall he never mo'.\n"
  "Now deem all as you liste, ye that can,\n"
  "For I will tell you forth as I began.\n"
  "\n"
  "When that Arcite to Thebes comen was,\n"
  "Full oft a day he swelt*, and said, \"Alas!\"                     *fainted\n"
  "For see this lady he shall never mo'.\n"
  "And shortly to concluden all his woe,\n"
  "So much sorrow had never creature\n"
  "That is or shall be while the world may dure.\n"
  "His sleep, his meat, his drink is *him byraft*,    *taken away from him*\n"
  "That lean he wex*, and dry as any shaft.                         *became\n"
  "His eyen hollow, grisly to behold,\n"
  "His hue sallow, and pale as ashes cold,\n"
  "And solitary he was, ever alone,\n"
  "And wailing all the night, making his moan.\n"
  "And if he hearde song or instrument,\n"
  "Then would he weepen, he might not be stent*.                   *stopped\n"
  "So feeble were his spirits, and so low,\n"
  "And changed so, that no man coulde know\n"
  "His speech, neither his voice, though men it heard.\n"
  "And in his gear* for all the world he far'd              *behaviour <19>\n"
  "Not only like the lovers' malady\n"
  "Of Eros, but rather y-like manie*                               *madness\n"
  "Engender'd of humours melancholic,\n"
  "Before his head in his cell fantastic.<20>\n"
  "And shortly turned was all upside down,\n"
  "Both habit and eke dispositioun,\n"
  "Of him, this woful lover Dan* Arcite.                         *Lord <21>\n"
  "Why should I all day of his woe indite?\n"
  "When he endured had a year or two\n"
  "This cruel torment, and this pain and woe,\n"
  "At Thebes, in his country, as I said,\n"
  "Upon a night in sleep as he him laid,\n"
  "Him thought how that the winged god Mercury\n"
  "Before him stood, and bade him to be merry.\n"
  "His sleepy yard* in hand he bare upright;                      *rod <22>\n"
  "A hat he wore upon his haires bright.\n"
  "Arrayed was this god (as he took keep*)                          *notice\n"
  "As he was when that Argus<23> took his sleep;\n"
  "And said him thus: \"To Athens shalt thou wend*;                      *go\n"
  "There is thee shapen* of thy woe an end.\"               *fixed, prepared\n"
  "And with that word Arcite woke and start.\n"
  "\"Now truely how sore that e'er me smart,\"\n"
  "Quoth he, \"to Athens right now will I fare.\n"
  "Nor for no dread of death shall I not spare\n"
  "To see my lady that I love and serve;\n"
  "In her presence *I recke not to sterve.*\"         *do not care if I die*\n"
  "And with that word he caught a great mirror,\n"
  "And saw that changed was all his colour,\n"
  "And saw his visage all in other kind.\n"
  "And right anon it ran him ill his mind,\n"
  "That since his face was so disfigur'd\n"
  "Of malady the which he had endur'd,\n"
  "He mighte well, if that he *bare him low,*      *lived in lowly fashion*\n"
  "Live in Athenes evermore unknow,\n"
  "And see his lady wellnigh day by day.\n"
  "And right anon he changed his array,\n"
  "And clad him as a poore labourer.\n"
  "And all alone, save only a squier,\n"
  "That knew his privity* and all his cas**,             *secrets **fortune\n"
  "Which was disguised poorly as he was,\n"
  "To Athens is he gone the nexte*  way.                      *nearest <24>\n"
  "And to the court he went upon a day,\n"
  "And at the gate he proffer'd his service,\n"
  "To drudge and draw, what so men would devise*.                    *order\n"
  "And, shortly of this matter for to sayn,\n"
  "He fell in office with a chamberlain,\n"
  "The which that dwelling was with Emily.\n"
  "For he was wise, and coulde soon espy\n"
  "Of every servant which that served her.\n"
  "Well could he hewe wood, and water bear,\n"
  "For he was young and mighty for the nones*,                    *occasion\n"
  "And thereto he was strong and big of bones\n"
  "To do that any wight can him devise.\n"
  "\n"
  "A year or two he was in this service,\n"
  "Page of the chamber of Emily the bright;\n"
  "And Philostrate he saide that he hight.\n"
  "But half so well belov'd a man as he\n"
  "Ne was there never in court of his degree.\n"
  "He was so gentle of conditioun,\n"
  "That throughout all the court was his renown.\n"
  "They saide that it were a charity\n"
  "That Theseus would *enhance his degree*,           *elevate him in rank*\n"
  "And put him in some worshipful service,\n"
  "There as he might his virtue exercise.\n"
  "And thus within a while his name sprung\n"
  "Both of his deedes, and of his good tongue,\n"
  "That Theseus hath taken him so near,\n"
  "That of his chamber he hath made him squire,\n"
  "And gave him gold to maintain his degree;\n"
  "And eke men brought him out of his country\n"
  "From year to year full privily his rent.\n"
  "But honestly and slyly* he it spent,              *discreetly, prudently\n"
  "That no man wonder'd how that he it had.\n"
  "And three year in this wise his life be lad*,                       *led\n"
  "And bare him so in peace and eke in werre*,                         *war\n"
  "There was no man that Theseus had so derre*.                       *dear\n"
  "And in this blisse leave I now Arcite,\n"
  "And speak I will of Palamon a lite*.                             *little\n"
  "\n"
#endif
  "";
// }

const char knightsTale1[] PGMSECTION = // { // 31126 bytes
  "In darkness horrible, and strong prison,\n"
  "This seven year hath sitten Palamon,\n"
  "Forpined*, what for love, and for distress.          *pined, wasted away\n"
  "Who feeleth double sorrow and heaviness\n"
  "But Palamon? that love distraineth* so,                        *afflicts\n"
  "That wood* out of his wits he went for woe,                         *mad\n"
  "And eke thereto he is a prisonere\n"
  "Perpetual, not only for a year.\n"
  "Who coulde rhyme in English properly\n"
  "His martyrdom? forsooth*, it is not I;                            *truly\n"
  "Therefore I pass as lightly as I may.\n"
  "It fell that in the seventh year, in May\n"
  "The thirde night (as olde bookes sayn,\n"
  "That all this story tellen more plain),\n"
  "Were it by a venture or destiny\n"
  "(As when a thing is shapen* it shall be),              *settled, decreed\n"
  "That soon after the midnight, Palamon\n"
  "By helping of a friend brake his prison,\n"
  "And fled the city fast as he might go,\n"
  "For he had given drink his gaoler so\n"
  "Of a clary <25>, made of a certain wine,\n"
  "With *narcotise and opie* of Thebes fine,          *narcotics and opium*\n"
  "That all the night, though that men would him shake,\n"
  "The gaoler slept, he mighte not awake:\n"
  "And thus he fled as fast as ever he may.\n"
  "The night was short, and *faste by the day            *close at hand was\n"
  "That needes cast he must himself to hide*.          the day during which\n"
  "And to a grove faste there beside       he must cast about, or contrive,\n"
  "With dreadful foot then stalked Palamon.            to conceal himself.*\n"
  "For shortly this was his opinion,\n"
  "That in the grove he would him hide all day,\n"
  "And in the night then would he take his way\n"
  "To Thebes-ward, his friendes for to pray\n"
  "On Theseus to help him to warray*.                        *make war <26>\n"
  "And shortly either he would lose his life,\n"
  "Or winnen Emily unto his wife.\n"
  "This is th' effect, and his intention plain.\n"
  "\n"
  "Now will I turn to Arcita again,\n"
  "That little wist how nighe was his care,\n"
  "Till that Fortune had brought him in the snare.\n"
  "The busy lark, the messenger of day,\n"
  "Saluteth in her song the morning gray;\n"
  "And fiery Phoebus riseth up so bright,\n"
  "That all the orient laugheth at the sight,\n"
  "And with his streames* drieth in the greves**             *rays **groves\n"
  "The silver droppes, hanging on the leaves;\n"
  "And Arcite, that is in the court royal\n"
  "With Theseus, his squier principal,\n"
  "Is ris'n, and looketh on the merry day.\n"
  "And for to do his observance to May,\n"
  "Remembering the point* of his desire,                            *object\n"
  "He on his courser, starting as the fire,\n"
  "Is ridden to the fieldes him to play,\n"
  "Out of the court, were it a mile or tway.\n"
  "And to the grove, of which I have you told,\n"
  "By a venture his way began to hold,\n"
  "To make him a garland of the greves*,                            *groves\n"
  "Were it of woodbine, or of hawthorn leaves,\n"
  "And loud he sang against the sun so sheen*.              *shining bright\n"
  "\"O May, with all thy flowers and thy green,\n"
  "Right welcome be thou, faire freshe May,\n"
  "I hope that I some green here getten may.\"\n"
  "And from his courser*, with a lusty heart,                        *horse\n"
  "Into the grove full hastily he start,\n"
  "And in a path he roamed up and down,\n"
  "There as by aventure this Palamon\n"
  "Was in a bush, that no man might him see,\n"
  "For sore afeard of his death was he.\n"
  "Nothing ne knew he that it was Arcite;\n"
  "God wot he would have *trowed it full lite*.   *full little believed it*\n"
  "But sooth is said, gone since full many years,\n"
  "The field hath eyen*, and the wood hath ears,                      *eyes\n"
  "It is full fair a man *to bear him even*,           *to be on his guard*\n"
  "For all day meeten men at *unset steven*.          *unexpected time <27>\n"
  "Full little wot Arcite of his fellaw,\n"
  "That was so nigh to hearken of his saw*,                 *saying, speech\n"
  "For in the bush he sitteth now full still.\n"
  "When that Arcite had roamed all his fill,\n"
  "And *sungen all the roundel* lustily,           *sang the roundelay*<28>\n"
  "Into a study he fell suddenly,\n"
  "As do those lovers in their *quainte gears*,              *odd fashions*\n"
  "Now in the crop*, and now down in the breres**, <29>           *tree-top\n"
  "Now up, now down, as bucket in a well.                          **briars\n"
  "Right as the Friday, soothly for to tell,\n"
  "Now shineth it, and now it raineth fast,\n"
  "Right so can geary* Venus overcast                            *changeful\n"
  "The heartes of her folk, right as her day\n"
  "Is gearful*, right so changeth she array.                     *changeful\n"
  "Seldom is Friday all the weeke like.\n"
  "When Arcite had y-sung, he gan to sike*,                           *sigh\n"
  "And sat him down withouten any more:\n"
  "\"Alas!\" quoth he, \"the day that I was bore!\n"
  "How longe, Juno, through thy cruelty\n"
  "Wilt thou warrayen* Thebes the city?                            *torment\n"
  "Alas! y-brought is to confusion\n"
  "The blood royal of Cadm' and Amphion:\n"
  "Of Cadmus, which that was the firste man,\n"
  "That Thebes built, or first the town began,\n"
  "And of the city first was crowned king.\n"
  "Of his lineage am I, and his offspring\n"
  "By very line, as of the stock royal;\n"
  "And now I am *so caitiff and so thrall*,         *wretched and enslaved*\n"
  "That he that is my mortal enemy,\n"
  "I serve him as his squier poorely.\n"
  "And yet doth Juno me well more shame,\n"
  "For I dare not beknow* mine owen name,                 *acknowledge <30>\n"
  "But there as I was wont to hight Arcite,\n"
  "Now hight I Philostrate, not worth a mite.\n"
  "Alas! thou fell Mars, and alas! Juno,\n"
  "Thus hath your ire our lineage all fordo*                *undone, ruined\n"
  "Save only me, and wretched Palamon,\n"
  "That Theseus martyreth in prison.\n"
  "And over all this, to slay me utterly,\n"
  "Love hath his fiery dart so brenningly*                       *burningly\n"
  "Y-sticked through my true careful heart,\n"
  "That shapen was my death erst than my shert. <31>\n"
  "Ye slay me with your eyen, Emily;\n"
  "Ye be the cause wherefore that I die.\n"
  "Of all the remnant of mine other care\n"
  "Ne set I not the *mountance of a tare*,               *value of a straw*\n"
  "So that I could do aught to your pleasance.\"\n"
  "\n"
  "And with that word he fell down in a trance\n"
  "A longe time; and afterward upstart\n"
  "This Palamon, that thought thorough his heart\n"
  "He felt a cold sword suddenly to glide:\n"
  "For ire he quoke*, no longer would he hide.                      *quaked\n"
  "And when that he had heard Arcite's tale,\n"
  "As he were wood*, with face dead and pale,                          *mad\n"
  "He start him up out of the bushes thick,\n"
  "And said: \"False Arcita, false traitor wick'*,                   *wicked\n"
  "Now art thou hent*, that lov'st my lady so,                      *caught\n"
  "For whom that I have all this pain and woe,\n"
  "And art my blood, and to my counsel sworn,\n"
  "As I full oft have told thee herebeforn,\n"
  "And hast bejaped* here Duke Theseus,             *deceived, imposed upon\n"
  "And falsely changed hast thy name thus;\n"
  "I will be dead, or elles thou shalt die.\n"
  "Thou shalt not love my lady Emily,\n"
  "But I will love her only and no mo';\n"
  "For I am Palamon thy mortal foe.\n"
  "And though I have no weapon in this place,\n"
  "But out of prison am astart* by grace,                          *escaped\n"
  "I dreade* not that either thou shalt die,                         *doubt\n"
  "Or else thou shalt not loven Emily.\n"
  "Choose which thou wilt, for thou shalt not astart.\"\n"
  "\n"
  "This Arcite then, with full dispiteous* heart,                 *wrathful\n"
  "When he him knew, and had his tale heard,\n"
  "As fierce as lion pulled out a swerd,\n"
  "And saide thus; \"By God that sitt'th above,\n"
  "*N'ere it* that thou art sick, and wood for love,          *were it not*\n"
  "And eke that thou no weap'n hast in this place,\n"
  "Thou should'st never out of this grove pace,\n"
  "That thou ne shouldest dien of mine hand.\n"
  "For I defy the surety and the band,\n"
  "Which that thou sayest I have made to thee.\n"
  "What? very fool, think well that love is free;\n"
  "And I will love her maugre* all thy might.                      *despite\n"
  "But, for thou art a worthy gentle knight,\n"
  "And *wilnest to darraine her by bataille*,             *will reclaim her\n"
  "Have here my troth, to-morrow I will not fail,                by combat*\n"
  "Without weeting* of any other wight,                          *knowledge\n"
  "That here I will be founden as a knight,\n"
  "And bringe harness* right enough for thee;              *armour and arms\n"
  "And choose the best, and leave the worst for me.\n"
  "And meat and drinke this night will I bring\n"
  "Enough for thee, and clothes for thy bedding.\n"
  "And if so be that thou my lady win,\n"
  "And slay me in this wood that I am in,\n"
  "Thou may'st well have thy lady as for me.\"\n"
  "This Palamon answer'd, \"I grant it thee.\"\n"
  "And thus they be departed till the morrow,\n"
  "When each of them hath *laid his faith to borrow*.   *pledged his faith*\n"
  "\n"
  "O Cupid, out of alle charity!\n"
  "O Regne* that wilt no fellow have with thee!                 *queen <32>\n"
  "Full sooth is said, that love nor lordeship\n"
  "Will not, *his thanks*, have any fellowship.             *thanks to him*\n"
  "Well finden that Arcite and Palamon.\n"
  "Arcite is ridd anon unto the town,\n"
  "And on the morrow, ere it were daylight,\n"
  "Full privily two harness hath he dight*,                       *prepared\n"
  "Both suffisant and meete to darraine*                           *contest\n"
  "The battle in the field betwixt them twain.\n"
  "And on his horse, alone as he was born,\n"
  "He carrieth all this harness him beforn;\n"
  "And in the grove, at time and place y-set,\n"
  "This Arcite and this Palamon be met.\n"
  "Then change gan the colour of their face;\n"
  "Right as the hunter in the regne* of Thrace                     *kingdom\n"
  "That standeth at a gappe with a spear\n"
  "When hunted is the lion or the bear,\n"
  "And heareth him come rushing in the greves*,                     *groves\n"
  "And breaking both the boughes and the leaves,\n"
  "Thinketh, \"Here comes my mortal enemy,\n"
  "Withoute fail, he must be dead or I;\n"
  "For either I must slay him at the gap;\n"
  "Or he must slay me, if that me mishap:\"\n"
  "So fared they, in changing of their hue\n"
  "*As far as either of them other knew*.        *When they recognised each\n"
  "There was no good day, and no saluting,                  other afar off*\n"
  "But straight, withoute wordes rehearsing,\n"
  "Evereach of them holp to arm the other,\n"
  "As friendly, as he were his owen brother.\n"
  "And after that, with sharpe speares strong\n"
  "They foined* each at other wonder long.                          *thrust\n"
  "Thou mightest weene*, that this Palamon                           *think\n"
  "In fighting were as a wood* lion,                                   *mad\n"
  "And as a cruel tiger was Arcite:\n"
  "As wilde boars gan they together smite,\n"
  "That froth as white as foam, *for ire wood*.            *mad with anger*\n"
  "Up to the ancle fought they in their blood.\n"
  "And in this wise I let them fighting dwell,\n"
  "And forth I will of Theseus you tell.\n"
  "\n"
  "The Destiny, minister general,\n"
  "That executeth in the world o'er all\n"
  "The purveyance*, that God hath seen beforn;              *foreordination\n"
  "So strong it is, that though the world had sworn\n"
  "The contrary of a thing by yea or nay,\n"
  "Yet some time it shall fallen on a day\n"
  "That falleth not eft* in a thousand year.                         *again\n"
  "For certainly our appetites here,\n"
  "Be it of war, or peace, or hate, or love,\n"
  "All is this ruled by the sight* above.         *eye, intelligence, power\n"
  "This mean I now by mighty Theseus,\n"
  "That for to hunten is so desirous --\n"
  "And namely* the greate hart in May --                        *especially\n"
  "That in his bed there dawneth him no day\n"
  "That he n'is clad, and ready for to ride\n"
  "With hunt and horn, and houndes him beside.\n"
  "For in his hunting hath he such delight,\n"
  "That it is all his joy and appetite\n"
  "To be himself the greate harte's bane*                      *destruction\n"
  "For after Mars he serveth now Diane.\n"
  "Clear was the day, as I have told ere this,\n"
  "And Theseus, with alle joy and bliss,\n"
  "With his Hippolyta, the faire queen,\n"
  "And Emily, y-clothed all in green,\n"
  "On hunting be they ridden royally.\n"
  "And to the grove, that stood there faste by,\n"
  "In which there was an hart, as men him told,\n"
  "Duke Theseus the straighte way doth hold,\n"
  "And to the laund* he rideth him full right,                  *plain <33>\n"
  "There was the hart y-wont to have his flight,\n"
  "And over a brook, and so forth on his way.\n"
  "This Duke will have a course at him or tway\n"
  "With houndes, such as him lust* to command.                     *pleased\n"
  "And when this Duke was come to the laund,\n"
  "Under the sun he looked, and anon\n"
  "He was ware of Arcite and Palamon,\n"
  "That foughte breme*, as it were bulles two.                    *fiercely\n"
  "The brighte swordes wente to and fro\n"
  "So hideously, that with the leaste stroke\n"
  "It seemed that it woulde fell an oak,\n"
  "But what they were, nothing yet he wote*.                          *knew\n"
  "This Duke his courser with his spurres smote,\n"
  "*And at a start* he was betwixt them two,                     *suddenly*\n"
  "And pulled out a sword and cried, \"Ho!\n"
  "No more, on pain of losing of your head.\n"
  "By mighty Mars, he shall anon be dead\n"
  "That smiteth any stroke, that I may see!\n"
  "But tell to me what mister* men ye be,                *manner, kind <34>\n"
  "That be so hardy for to fighte here\n"
  "Withoute judge or other officer,\n"
  "As though it were in listes royally. <35>\n"
  "This Palamon answered hastily,\n"
  "And saide: \"Sir, what needeth wordes mo'?\n"
  "We have the death deserved bothe two,\n"
  "Two woful wretches be we, and caitives,\n"
  "That be accumbered* of our own lives,                          *burdened\n"
  "And as thou art a rightful lord and judge,\n"
  "So give us neither mercy nor refuge.\n"
  "And slay me first, for sainte charity,\n"
  "But slay my fellow eke as well as me.\n"
  "Or slay him first; for, though thou know it lite*,               *little\n"
  "This is thy mortal foe, this is Arcite\n"
  "That from thy land is banisht on his head,\n"
  "For which he hath deserved to be dead.\n"
  "For this is he that came unto thy gate\n"
  "And saide, that he highte Philostrate.\n"
  "Thus hath he japed* thee full many year,                       *deceived\n"
  "And thou hast made of him thy chief esquier;\n"
  "And this is he, that loveth Emily.\n"
  "For since the day is come that I shall die\n"
  "I make pleinly* my confession,                      *fully, unreservedly\n"
  "That I am thilke* woful Palamon,                         *that same <36>\n"
  "That hath thy prison broken wickedly.\n"
  "I am thy mortal foe, and it am I\n"
  "That so hot loveth Emily the bright,\n"
  "That I would die here present in her sight.\n"
  "Therefore I aske death and my jewise*.                        *judgement\n"
  "But slay my fellow eke in the same wise,\n"
  "For both we have deserved to be slain.\"\n"
  "\n"
  "This worthy Duke answer'd anon again,\n"
  "And said, \"This is a short conclusion.\n"
  "Your own mouth, by your own confession\n"
  "Hath damned you, and I will it record;\n"
  "It needeth not to pain you with the cord;\n"
  "Ye shall be dead, by mighty Mars the Red.<37>\n"
  "\n"
  "The queen anon for very womanhead\n"
  "Began to weep, and so did Emily,\n"
  "And all the ladies in the company.\n"
  "Great pity was it as it thought them all,\n"
  "That ever such a chance should befall,\n"
  "For gentle men they were, of great estate,\n"
  "And nothing but for love was this debate\n"
  "They saw their bloody woundes wide and sore,\n"
  "And cried all at once, both less and more,\n"
  "\"Have mercy, Lord, upon us women all.\"\n"
  "And on their bare knees adown they fall\n"
  "And would have kissed his feet there as he stood,\n"
  "Till at the last *aslaked was his mood*                   *his anger was\n"
  "(For pity runneth soon in gentle heart);                       appeased*\n"
  "And though at first for ire he quoke and start\n"
  "He hath consider'd shortly in a clause\n"
  "The trespass of them both, and eke the cause:\n"
  "And although that his ire their guilt accused\n"
  "Yet in his reason he them both excused;\n"
  "As thus; he thoughte well that every man\n"
  "Will help himself in love if that he can,\n"
  "And eke deliver himself out of prison.\n"
  "Of women, for they wepten ever-in-one:*                     *continually\n"
  "And eke his hearte had compassion\n"
  "And in his gentle heart he thought anon,\n"
  "And soft unto himself he saide: \"Fie\n"
  "Upon a lord that will have no mercy,\n"
  "But be a lion both in word and deed,\n"
  "To them that be in repentance and dread,\n"
  "As well as-to a proud dispiteous* man                         *unpitying\n"
  "That will maintaine what he first began.\n"
  "That lord hath little of discretion,\n"
  "That in such case *can no division*:           *can make no distinction*\n"
  "But weigheth pride and humbless *after one*.\"                    *alike*\n"
  "And shortly, when his ire is thus agone,\n"
  "He gan to look on them with eyen light*,               *gentle, lenient*\n"
  "And spake these same wordes *all on height.*                     *aloud*\n"
  "\n"
  "\"The god of love, ah! benedicite*,                         *bless ye him\n"
  "How mighty and how great a lord is he!\n"
  "Against his might there gaine* none obstacles,           *avail, conquer\n"
  "He may be called a god for his miracles\n"
  "For he can maken at his owen guise\n"
  "Of every heart, as that him list devise.\n"
  "Lo here this Arcite, and this Palamon,\n"
  "That quietly were out of my prison,\n"
  "And might have lived in Thebes royally,\n"
  "And weet* I am their mortal enemy,                                 *knew\n"
  "And that their death li'th in my might also,\n"
  "And yet hath love, *maugre their eyen two*,     *in spite of their eyes*\n"
  "Y-brought them hither bothe for to die.\n"
  "Now look ye, is not this an high folly?\n"
  "Who may not be a fool, if but he love?\n"
  "Behold, for Godde's sake that sits above,\n"
  "See how they bleed! be they not well array'd?\n"
  "Thus hath their lord, the god of love, them paid\n"
  "Their wages and their fees for their service;\n"
  "And yet they weene for to be full wise,\n"
  "That serve love, for aught that may befall.\n"
  "But this is yet the beste game* of all,                            *joke\n"
  "That she, for whom they have this jealousy,\n"
  "Can them therefor as muchel thank as me.\n"
  "She wot no more of all this *hote fare*,                 *hot behaviour*\n"
  "By God, than wot a cuckoo or an hare.\n"
  "But all must be assayed hot or cold;\n"
  "A man must be a fool, or young or old;\n"
  "I wot it by myself *full yore agone*:                   *long years ago*\n"
  "For in my time a servant was I one.\n"
  "And therefore since I know of love's pain,\n"
  "And wot how sore it can a man distrain*,                       *distress\n"
  "As he that oft hath been caught in his last*,                *snare <38>\n"
  "I you forgive wholly this trespass,\n"
  "At request of the queen that kneeleth here,\n"
  "And eke of Emily, my sister dear.\n"
  "And ye shall both anon unto me swear,\n"
  "That never more ye shall my country dere*                        *injure\n"
  "Nor make war upon me night nor day,\n"
  "But be my friends in alle that ye may.\n"
  "I you forgive this trespass *every deal*.                   *completely*\n"
  "And they him sware *his asking* fair and well,           *what he asked*\n"
  "And him of lordship and of mercy pray'd,\n"
  "And he them granted grace, and thus he said:\n"
  "\n"
  "\"To speak of royal lineage and richess,\n"
  "Though that she were a queen or a princess,\n"
  "Each of you both is worthy doubteless\n"
  "To wedde when time is; but natheless\n"
  "I speak as for my sister Emily,\n"
  "For whom ye have this strife and jealousy,\n"
  "Ye wot* yourselves, she may not wed the two                        *know\n"
  "At once, although ye fight for evermo:\n"
  "But one of you, *all be him loth or lief,*    *whether or not he wishes*\n"
  "He must *go pipe into an ivy leaf*:                       *\"go whistle\"*\n"
  "This is to say, she may not have you both,\n"
  "All be ye never so jealous, nor so wroth.\n"
  "And therefore I you put in this degree,\n"
  "That each of you shall have his destiny\n"
  "As *him is shape*; and hearken in what wise      *as is decreed for him*\n"
  "Lo hear your end of that I shall devise.\n"
  "My will is this, for plain conclusion\n"
  "Withouten any replication*,                                       *reply\n"
  "If that you liketh, take it for the best,\n"
  "That evereach of you shall go where *him lest*,              *he pleases\n"
  "Freely without ransom or danger;\n"
  "And this day fifty weekes, *farre ne nerre*,     *neither more nor less*\n"
  "Evereach of you shall bring an hundred knights,\n"
  "Armed for listes up at alle rights\n"
  "All ready to darraine* her by bataille,                     *contend for\n"
  "And this behete* I you withoute fail                            *promise\n"
  "Upon my troth, and as I am a knight,\n"
  "That whether of you bothe that hath might,\n"
  "That is to say, that whether he or thou\n"
  "May with his hundred, as I spake of now,\n"
  "Slay his contrary, or out of listes drive,\n"
  "Him shall I given Emily to wive,\n"
  "To whom that fortune gives so fair a grace.\n"
  "The listes shall I make here in this place.\n"
  "*And God so wisly on my soule rue*,              *may God as surely have\n"
  "As I shall even judge be and true.                     mercy on my soul*\n"
  "Ye shall none other ende with me maken\n"
  "Than one of you shalle be dead or taken.\n"
  "And if you thinketh this is well y-said,\n"
  "Say your advice*, and hold yourselves apaid**.      *opinion **satisfied\n"
  "This is your end, and your conclusion.\"\n"
  "Who looketh lightly now but Palamon?\n"
  "Who springeth up for joye but Arcite?\n"
  "Who could it tell, or who could it indite,\n"
  "The joye that is maked in the place\n"
  "When Theseus hath done so fair a grace?\n"
  "But down on knees went every *manner wight*,            *kind of person*\n"
  "And thanked him with all their heartes' might,\n"
  "And namely* these Thebans *ofte sithe*.         *especially *oftentimes*\n"
  "And thus with good hope and with hearte blithe\n"
  "They take their leave, and homeward gan they ride\n"
  "To Thebes-ward, with his old walles wide.\n"
  "\n"
  "I trow men woulde deem it negligence,\n"
  "If I forgot to telle the dispence*                          *expenditure\n"
  "Of Theseus, that went so busily\n"
  "To maken up the listes royally,\n"
  "That such a noble theatre as it was,\n"
  "I dare well say, in all this world there n'as*.                 *was not\n"
  "The circuit a mile was about,\n"
  "Walled of stone, and ditched all without.\n"
  "*Round was the shape, in manner of compass,\n"
  "Full of degrees, the height of sixty pas*               *see note  <39>*\n"
  "That when a man was set on one degree\n"
  "He letted* not his fellow for to see.                          *hindered\n"
  "Eastward there stood a gate of marble white,\n"
  "Westward right such another opposite.\n"
  "And, shortly to conclude, such a place\n"
  "Was never on earth made in so little space,\n"
  "For in the land there was no craftes-man,\n"
  "That geometry or arsmetrike* can**,                   *arithmetic **knew\n"
  "Nor pourtrayor*, nor carver of images,                 *portrait painter\n"
  "That Theseus ne gave him meat and wages\n"
  "The theatre to make and to devise.\n"
  "And for to do his rite and sacrifice\n"
  "He eastward hath upon the gate above,\n"
  "In worship of Venus, goddess of love,\n"
  "*Done make* an altar and an oratory;                 *caused to be made*\n"
  "And westward, in the mind and in memory\n"
  "Of Mars, he maked hath right such another,\n"
  "That coste largely of gold a fother*.                    *a great amount\n"
  "And northward, in a turret on the wall,\n"
  "Of alabaster white and red coral\n"
  "An oratory riche for to see,\n"
  "In worship of Diane of chastity,\n"
  "Hath Theseus done work in noble wise.\n"
  "But yet had I forgotten to devise*                             *describe\n"
  "The noble carving, and the portraitures,\n"
  "The shape, the countenance of the figures\n"
  "That weren in there oratories three.\n"
  "\n"
  "First in the temple of Venus may'st thou see\n"
  "Wrought on the wall,  full piteous to behold,\n"
  "The broken sleepes, and the sikes* cold,                         *sighes\n"
  "The sacred teares, and the waimentings*,                     *lamentings\n"
  "The fiery strokes of the desirings,\n"
  "That Love's servants in this life endure;\n"
  "The oathes, that their covenants assure.\n"
  "Pleasance and Hope, Desire, Foolhardiness,\n"
  "Beauty and Youth, and Bawdry and Richess,\n"
  "Charms and Sorc'ry, Leasings* and Flattery,                  *falsehoods\n"
  "Dispence, Business, and Jealousy,\n"
  "That wore of yellow goldes* a garland,                  *sunflowers <40>\n"
  "And had a cuckoo sitting on her hand,\n"
  "Feasts, instruments, and caroles and dances,\n"
  "Lust and array, and all the circumstances\n"
  "Of Love, which I reckon'd and reckon shall\n"
  "In order, were painted on the wall,\n"
  "And more than I can make of mention.\n"
  "For soothly all the mount of Citheron,<41>\n"
  "Where Venus hath her principal dwelling,\n"
  "Was showed on the wall in pourtraying,\n"
  "With all the garden, and the lustiness*.                   *pleasantness\n"
  "Nor was forgot the porter Idleness,\n"
  "Nor Narcissus the fair of *yore agone*,                    *olden times*\n"
  "Nor yet the folly of King Solomon,\n"
  "Nor yet the greate strength of Hercules,\n"
  "Th' enchantments of Medea and Circes,\n"
  "Nor of Turnus the hardy fierce courage,\n"
  "The rich Croesus *caitif in servage.* <42>         *abased into slavery*\n"
  "Thus may ye see, that wisdom nor richess,\n"
  "Beauty, nor sleight, nor strength, nor hardiness\n"
  "Ne may with Venus holde champartie*,            *divided possession <43>\n"
  "For as her liste the world may she gie*.                          *guide\n"
  "Lo, all these folk so caught were in her las*                     *snare\n"
  "Till they for woe full often said, Alas!\n"
  "Suffice these ensamples one or two,\n"
  "Although I could reckon a thousand mo'.\n"
  "\n"
  "The statue of Venus, glorious to see\n"
  "Was naked floating in the large sea,\n"
  "And from the navel down all cover'd was\n"
  "With waves green, and bright as any glass.\n"
  "A citole <44> in her right hand hadde she,\n"
  "And on her head, full seemly for to see,\n"
  "A rose garland fresh, and well smelling,\n"
  "Above her head her doves flickering\n"
  "Before her stood her sone Cupido,\n"
  "Upon his shoulders winges had he two;\n"
  "And blind he was, as it is often seen;\n"
  "A bow he bare, and arrows bright and keen.\n"
  "\n"
  "Why should I not as well eke tell you all\n"
  "The portraiture, that was upon the wall\n"
  "Within the temple of mighty Mars the Red?\n"
  "All painted was the wall in length and brede*                   *breadth\n"
  "Like to the estres* of the grisly place               *interior chambers\n"
  "That hight the great temple of Mars in Thrace,\n"
  "In thilke* cold and frosty region,                                 *that\n"
  "There as Mars hath his sovereign mansion.\n"
  "In which there dwelled neither man nor beast,\n"
  "With knotty gnarry* barren trees old                            *gnarled\n"
  "Of stubbes sharp and hideous to behold;\n"
  "In which there ran a rumble and a sough*,                *groaning noise\n"
  "As though a storm should bursten every bough:\n"
  "And downward from an hill under a bent*                           *slope\n"
  "There stood the temple of Mars Armipotent,\n"
  "Wrought all of burnish'd steel, of which th' entry\n"
  "Was long and strait, and ghastly for to see.\n"
  "And thereout came *a rage and such a vise*,       *such a furious voice*\n"
  "That it made all the gates for to rise.\n"
  "The northern light in at the doore shone,\n"
  "For window on the walle was there none\n"
  "Through which men mighten any light discern.\n"
  "The doors were all of adamant etern,\n"
  "Y-clenched *overthwart and ende-long*         *crossways and lengthways*\n"
  "With iron tough, and, for to make it strong,\n"
  "Every pillar the temple to sustain\n"
  "Was tunne-great*, of iron bright and sheen.     *thick as a tun (barrel)\n"
  "There saw I first the dark imagining\n"
  "Of felony, and all the compassing;\n"
  "The cruel ire, as red as any glede*,                          *live coal\n"
  "The picke-purse<45>, and eke the pale dread;\n"
  "The smiler with the knife under the cloak,\n"
  "The shepen* burning with the blacke smoke                   *stable <46>\n"
  "The treason of the murd'ring in the bed,\n"
  "The open war, with woundes all be-bled;\n"
  "Conteke* with bloody knife, and sharp menace.       *contention, discord\n"
  "All full of chirking* was that sorry place.     *creaking, jarring noise\n"
  "The slayer of himself eke saw I there,\n"
  "His hearte-blood had bathed all his hair:\n"
  "The nail y-driven in the shode* at night,         *hair of the head <47>\n"
  "The colde death, with mouth gaping upright.\n"
  "Amiddes of the temple sat Mischance,\n"
  "With discomfort and sorry countenance;\n"
  "Eke saw I Woodness* laughing in his rage,                       *Madness\n"
  "Armed Complaint, Outhees*, and fierce Outrage;                   *Outcry\n"
  "The carrain* in the bush, with throat y-corve**,       *corpse **slashed\n"
  "A thousand slain, and not *of qualm y-storve*;        *dead of sickness*\n"
  "The tyrant, with the prey by force y-reft;\n"
  "The town destroy'd, that there was nothing left.\n"
  "Yet saw I brent* the shippes hoppesteres, <48>                    *burnt\n"
  "The hunter strangled with the wilde bears:\n"
  "The sow freting* the child right in the cradle;          *devouring <49>\n"
  "The cook scalded, for all his longe ladle.\n"
  "Nor was forgot, *by th'infortune of Mart*        *through the misfortune\n"
  "The carter overridden with his cart;                             of war*\n"
  "Under the wheel full low he lay adown.\n"
  "There were also of Mars' division,\n"
  "The armourer, the bowyer*, and the smith,                 *maker of bows\n"
  "That forgeth sharp swordes on his stith*.                         *anvil\n"
  "And all above depainted in a tower\n"
  "Saw I Conquest, sitting in great honour,\n"
  "With thilke* sharpe sword over his head                            *that\n"
  "Hanging by a subtle y-twined thread.\n"
  "Painted the slaughter was of Julius<50>,\n"
  "Of cruel Nero, and Antonius:\n"
  "Although at that time they were yet unborn,\n"
  "Yet was their death depainted there beforn,\n"
  "By menacing of Mars, right by figure,\n"
  "So was it showed in that portraiture,\n"
  "As is depainted in the stars above,\n"
  "Who shall be slain, or elles dead for love.\n"
  "Sufficeth one ensample in stories old,\n"
  "I may not reckon them all, though I wo'ld.\n"
  "\n"
  "The statue of Mars upon a carte* stood                          *chariot\n"
  "Armed, and looked grim as he were wood*,                            *mad\n"
  "And over his head there shone two figures\n"
  "Of starres, that be cleped in scriptures,\n"
  "That one Puella, that other Rubeus. <51>\n"
  "This god of armes was arrayed thus:\n"
  "A wolf there stood before him at his feet\n"
  "With eyen red, and of a man he eat:\n"
  "With subtle pencil painted was this story,\n"
  "In redouting* of Mars and of his glory.                 *reverance, fear\n"
  "\n"
  "Now to the temple of Dian the chaste\n"
  "As shortly as I can I will me haste,\n"
  "To telle you all the descriptioun.\n"
  "Depainted be the walles up and down\n"
  "Of hunting and of shamefast chastity.\n"
  "There saw I how woful Calistope,<52>\n"
  "When that Dian aggrieved was with her,\n"
  "Was turned from a woman to a bear,\n"
  "And after was she made the lodestar*:                         *pole star\n"
  "Thus was it painted, I can say no far*;                         *farther\n"
  "Her son is eke a star as men may see.\n"
  "There saw I Dane <53> turn'd into a tree,\n"
  "I meane not the goddess Diane,\n"
  "But Peneus' daughter, which that hight Dane.\n"
  "There saw I Actaeon an hart y-maked*,                              *made\n"
  "For vengeance that he saw Dian all naked:\n"
  "I saw how that his houndes have him caught,\n"
  "And freten* him, for that they knew him not.                     *devour\n"
  "Yet painted was, a little farthermore\n"
  "How Atalanta hunted the wild boar;\n"
  "And Meleager, and many other mo',\n"
  "For which Diana wrought them care and woe.\n"
  "There saw I many another wondrous story,\n"
  "The which me list not drawen to memory.\n"
  "This goddess on an hart full high was set*,                      *seated\n"
  "With smalle houndes all about her feet,\n"
  "And underneath her feet she had a moon,\n"
  "Waxing it was, and shoulde wane soon.\n"
  "In gaudy green her statue clothed was,\n"
  "With bow in hand, and arrows in a case*.                         *quiver\n"
  "Her eyen caste she full low adown,\n"
  "Where Pluto hath his darke regioun.\n"
  "A woman travailing was her beforn,\n"
  "But, for her child so longe was unborn,\n"
  "Full piteously Lucina <54> gan she call,\n"
  "And saide; \"Help, for thou may'st best of all.\"\n"
  "Well could he painte lifelike that it wrought;\n"
  "With many a florin he the hues had bought.\n"
  "Now be these listes made, and Theseus,\n"
  "That at his greate cost arrayed thus\n"
  "The temples, and the theatre every deal*,                     *part <55>\n"
  "When it was done, him liked wonder well.\n"
  "\n"
  "";
// }

const char knightsTale2[] PGMSECTION = // { // 32200 bytes
  "But stint* I will of Theseus a lite**,          *cease speaking **little\n"
  "And speak of Palamon and of Arcite.\n"
  "The day approacheth of their returning,\n"
  "That evereach an hundred knights should bring,\n"
  "The battle to darraine* as I you told;                          *contest\n"
  "And to Athens, their covenant to hold,\n"
  "Hath ev'reach of them brought an hundred knights,\n"
  "Well-armed for the war at alle rights.\n"
  "And sickerly* there trowed** many a man,         *surely <56> **believed\n"
  "That never, sithen* that the world began,                         *since\n"
  "For to speaken of knighthood of their hand,\n"
  "As far as God hath maked sea and land,\n"
  "Was, of so few, so noble a company.\n"
  "For every wight that loved chivalry,\n"
  "And would, *his thankes, have a passant name*,        *thanks to his own\n"
  "Had prayed, that he might be of that game,               efforts, have a\n"
  "And well was him, that thereto chosen was.              surpassing name*\n"
  "For if there fell to-morrow such a case,\n"
  "Ye knowe well, that every lusty knight,\n"
  "That loveth par amour, and hath his might\n"
  "Were it in Engleland, or elleswhere,\n"
  "They would, their thankes, willen to be there,\n"
  "T' fight for a lady; Benedicite,\n"
  "It were a lusty* sighte for to see.                            *pleasing\n"
  "And right so fared they with Palamon;\n"
  "With him there wente knightes many one.\n"
  "Some will be armed in an habergeon,\n"
  "And in a breast-plate, and in a gipon*;                  *short doublet.\n"
  "And some will have *a pair of plates* large;     *back and front armour*\n"
  "And some will have a Prusse* shield, or targe;                 *Prussian\n"
  "Some will be armed on their legges weel;\n"
  "Some have an axe, and some a mace of steel.\n"
  "There is no newe guise*, but it was old.                        *fashion\n"
  "Armed they weren, as I have you told,\n"
  "Evereach after his opinion.\n"
  "There may'st thou see coming with Palamon\n"
  "Licurgus himself, the great king of Thrace:\n"
  "Black was his beard, and manly was his face.\n"
  "The circles of his eyen in his head\n"
  "They glowed betwixte yellow and red,\n"
  "And like a griffin looked he about,\n"
  "With kemped* haires on his browes stout;                     *combed<57>\n"
  "His limbs were great, his brawns were hard and strong,\n"
  "His shoulders broad, his armes round and long.\n"
  "And as the guise* was in his country,                           *fashion\n"
  "Full high upon a car of gold stood he,\n"
  "With foure white bulles in the trace.\n"
  "Instead of coat-armour on his harness,\n"
  "With yellow nails, and bright as any gold,\n"
  "He had a beare's skin, coal-black for old*.                         *age\n"
  "His long hair was y-kempt behind his back,\n"
  "As any raven's feather it shone for black.\n"
  "A wreath of gold *arm-great*, of huge weight,     *thick as a man's arm*\n"
  "Upon his head sate, full of stones bright,\n"
  "Of fine rubies and clear diamants.\n"
  "About his car there wente white alauns*,                *greyhounds <58>\n"
  "Twenty and more, as great as any steer,\n"
  "To hunt the lion or the wilde bear,\n"
  "And follow'd him, with muzzle fast y-bound,\n"
  "Collars of gold, and torettes* filed round.                       *rings\n"
  "An hundred lordes had he in his rout*                           *retinue\n"
  "Armed full well, with heartes stern and stout.\n"
  "\n"
  "With Arcita, in stories as men find,\n"
  "The great Emetrius the king of Ind,\n"
  "Upon a *steede bay* trapped in steel,                        *bay horse*\n"
  "Cover'd with cloth of gold diapred* well,                     *decorated\n"
  "Came riding like the god of armes, Mars.\n"
  "His coat-armour was of *a cloth of Tars*,               *a kind of silk*\n"
  "Couched* with pearls white and round and great                  *trimmed\n"
  "His saddle was of burnish'd gold new beat;\n"
  "A mantelet on his shoulders hanging,\n"
  "Bretful* of rubies red, as fire sparkling.                      *brimful\n"
  "His crispe hair like ringes was y-run,\n"
  "And that was yellow, glittering as the sun.\n"
  "His nose was high, his eyen bright citrine*,                *pale yellow\n"
  "His lips were round, his colour was sanguine,\n"
  "A fewe fracknes* in his face y-sprent**,           *freckles **sprinkled\n"
  "Betwixte yellow and black somedeal y-ment*                   *mixed <59>\n"
  "And as a lion he *his looking cast*                *cast about his eyes*\n"
  "Of five and twenty year his age I cast*                          *reckon\n"
  "His beard was well begunnen for to spring;\n"
  "His voice was as a trumpet thundering.\n"
  "Upon his head he wore of laurel green\n"
  "A garland fresh and lusty to be seen;\n"
  "Upon his hand he bare, for his delight,\n"
  "An eagle tame, as any lily white.\n"
  "An hundred lordes had he with him there,\n"
  "All armed, save their heads, in all their gear,\n"
  "Full richely in alle manner things.\n"
  "For trust ye well, that earles, dukes, and kings\n"
  "Were gather'd in this noble company,\n"
  "For love, and for increase of chivalry.\n"
  "About this king there ran on every part\n"
  "Full many a tame lion and leopart.\n"
  "And in this wise these lordes *all and some*            *all and sundry*\n"
  "Be on the Sunday to the city come\n"
  "Aboute prime<60>, and in the town alight.\n"
  "\n"
  "This Theseus, this Duke, this worthy knight\n"
  "When he had brought them into his city,\n"
  "And inned* them, ev'reach at his degree,                         *lodged\n"
  "He feasteth them, and doth so great labour\n"
  "To *easen them*, and do them all honour,         *make them comfortable*\n"
  "That yet men weene* that no mannes wit                            *think\n"
  "Of none estate could amenden* it.                               *improve\n"
  "The minstrelsy, the service at the feast,\n"
  "The greate giftes to the most and least,\n"
  "The rich array of Theseus' palace,\n"
  "Nor who sate first or last upon the dais.<61>\n"
  "What ladies fairest be, or best dancing\n"
  "Or which of them can carol best or sing,\n"
  "Or who most feelingly speaketh of love;\n"
  "What hawkes sitten on the perch above,\n"
  "What houndes liggen* on the floor adown,                            *lie\n"
  "Of all this now make I no mentioun\n"
  "But of th'effect; that thinketh me the best\n"
  "Now comes the point, and hearken if you lest.*                   *please\n"
  "\n"
  "The Sunday night, ere day began to spring,\n"
  "When Palamon the larke hearde sing,\n"
  "Although it were not day by houres two,\n"
  "Yet sang the lark, and Palamon right tho*                          *then\n"
  "With holy heart, and with an high courage,\n"
  "Arose, to wenden* on his pilgrimage                                  *go\n"
  "Unto the blissful Cithera benign,\n"
  "I meane Venus, honourable and digne*.                            *worthy\n"
  "And in her hour <62> he walketh forth a pace\n"
  "Unto the listes, where her temple was,\n"
  "And down he kneeleth, and with humble cheer*                  *demeanour\n"
  "And hearte sore, he said as ye shall hear.\n"
  "\n"
  "\"Fairest of fair, O lady mine Venus,\n"
  "Daughter to Jove, and spouse of Vulcanus,\n"
  "Thou gladder of the mount of Citheron!<41>\n"
  "For thilke love thou haddest to Adon <63>\n"
  "Have pity on my bitter teares smart,\n"
  "And take mine humble prayer to thine heart.\n"
  "Alas! I have no language to tell\n"
  "Th'effecte, nor the torment of mine hell;\n"
  "Mine hearte may mine harmes not betray;\n"
  "I am so confused, that I cannot say.\n"
  "But mercy, lady bright, that knowest well\n"
  "My thought, and seest what harm that I feel.\n"
  "Consider all this, and *rue upon* my sore,                *take pity on*\n"
  "As wisly* as I shall for evermore                                 *truly\n"
  "Enforce my might, thy true servant to be,\n"
  "And holde war alway with chastity:\n"
  "That make I mine avow*, so ye me help.                     *vow, promise\n"
  "I keepe not of armes for to yelp,*                                *boast\n"
  "Nor ask I not to-morrow to have victory,\n"
  "Nor renown in this case, nor vaine glory\n"
  "Of *prize of armes*, blowing up and down,            *praise for valour*\n"
  "But I would have fully possessioun\n"
  "Of Emily, and die in her service;\n"
  "Find thou the manner how, and in what wise.\n"
  "I *recke not but* it may better be                 *do not know whether*\n"
  "To have vict'ry of them, or they of me,\n"
  "So that I have my lady in mine arms.\n"
  "For though so be that Mars is god of arms,\n"
  "Your virtue is so great in heaven above,\n"
  "That, if you list, I shall well have my love.\n"
  "Thy temple will I worship evermo',\n"
  "And on thine altar, where I ride or go,\n"
  "I will do sacrifice, and fires bete*.                      *make, kindle\n"
  "And if ye will not so, my lady sweet,\n"
  "Then pray I you, to-morrow with a spear\n"
  "That Arcita me through the hearte bear\n"
  "Then reck I not, when I have lost my life,\n"
  "Though that Arcita win her to his wife.\n"
  "This is th' effect and end of my prayere, --\n"
  "Give me my love, thou blissful lady dear.\"\n"
  "When th' orison was done of Palamon,\n"
  "His sacrifice he did, and that anon,\n"
  "Full piteously, with alle circumstances,\n"
  "*All tell I not as now* his observances.       *although I tell not now*\n"
  "But at the last the statue of Venus shook,\n"
  "And made a signe, whereby that he took\n"
  "That his prayer accepted was that day.\n"
  "For though the signe shewed a delay,\n"
  "Yet wist he well that granted was his boon;\n"
  "And with glad heart he went him home full soon.\n"
  "\n"
  "The third hour unequal <64>  that Palamon\n"
  "Began to Venus' temple for to gon,\n"
  "Up rose the sun, and up rose Emily,\n"
  "And to the temple of Dian gan hie.\n"
  "Her maidens, that she thither with her lad*,                        *led\n"
  "Th' incense, the clothes, and the remnant all\n"
  "That to the sacrifice belonge shall,\n"
  "The hornes full of mead, as was the guise;\n"
  "There lacked nought to do her sacrifice.\n"
  "Smoking* the temple full of clothes fair,                  *draping <65>\n"
  "This Emily with hearte debonnair*                                *gentle\n"
  "Her body wash'd with water of a well.\n"
  "But how she did her rite I dare not tell;\n"
  "But* it be any thing in general;                                 *unless\n"
  "And yet it were a game* to hearen all                          *pleasure\n"
  "To him that meaneth well it were no charge:\n"
  "But it is good a man to *be at large*.                   *do as he will*\n"
  "Her bright hair combed was, untressed all.\n"
  "A coronet of green oak cerriall <66>\n"
  "Upon her head was set full fair and meet.\n"
  "Two fires on the altar gan she bete,\n"
  "And did her thinges, as men may behold\n"
  "In Stace of Thebes <67>, and these bookes old.\n"
  "When kindled was the fire, with piteous cheer\n"
  "Unto Dian she spake as ye may hear.\n"
  "\n"
  "\"O chaste goddess of the woodes green,\n"
  "To whom both heav'n and earth and sea is seen,\n"
  "Queen of the realm of Pluto dark and low,\n"
  "Goddess of maidens, that mine heart hast know\n"
  "Full many a year, and wost* what I desire,                      *knowest\n"
  "To keep me from the vengeance of thine ire,\n"
  "That Actaeon aboughte* cruelly:                   *earned; suffered from\n"
  "Chaste goddess, well wottest thou that I\n"
  "Desire to be a maiden all my life,\n"
  "Nor never will I be no love nor wife.\n"
  "I am, thou wost*, yet of thy company,                           *knowest\n"
  "A maid, and love hunting and venery*,                      *field sports\n"
  "And for to walken in the woodes wild,\n"
  "And not to be a wife, and be with child.\n"
  "Nought will I know the company of man.\n"
  "Now help me, lady, since ye may and can,\n"
  "For those three formes <68> that thou hast in thee.\n"
  "And Palamon, that hath such love to me,\n"
  "And eke Arcite, that loveth me so sore,\n"
  "This grace I pray thee withoute more,\n"
  "As sende love and peace betwixt them two:\n"
  "And from me turn away their heartes so,\n"
  "That all their hote love, and their desire,\n"
  "And all their busy torment, and their fire,\n"
  "Be queint*, or turn'd into another place.                      *quenched\n"
  "And if so be thou wilt do me no grace,\n"
  "Or if my destiny be shapen so\n"
  "That I shall needes have one of them two,\n"
  "So send me him that most desireth me.\n"
  "Behold, goddess of cleane chastity,\n"
  "The bitter tears that on my cheekes fall.\n"
  "Since thou art maid, and keeper of us all,\n"
  "My maidenhead thou keep and well conserve,\n"
  "And, while I live, a maid I will thee serve.\n"
  "\n"
  "The fires burn upon the altar clear,\n"
  "While Emily was thus in her prayere:\n"
  "But suddenly she saw a sighte quaint*.                          *strange\n"
  "For right anon one of the fire's *queint\n"
  "And quick'd* again, and after that anon           *went out and revived*\n"
  "That other fire was queint, and all agone:\n"
  "And as it queint, it made a whisteling,\n"
  "As doth a brande wet in its burning.\n"
  "And at the brandes end outran anon\n"
  "As it were bloody droppes many one:\n"
  "For which so sore aghast was Emily,\n"
  "That she was well-nigh mad, and gan to cry,\n"
  "For she ne wiste what it signified;\n"
  "But onely for feare thus she cried,\n"
  "And wept, that it was pity for to hear.\n"
  "And therewithal Diana gan appear\n"
  "With bow in hand, right as an hunteress,\n"
  "And saide; \"Daughter, stint* thine heaviness.                     *cease\n"
  "Among the goddes high it is affirm'd,\n"
  "And by eternal word writ and confirm'd,\n"
  "Thou shalt be wedded unto one of tho*                             *those\n"
  "That have for thee so muche care and woe:\n"
  "But unto which of them I may not tell.\n"
  "Farewell, for here I may no longer dwell.\n"
  "The fires which that on mine altar brenn*,                         *burn\n"
  "Shall thee declaren, ere that thou go henne*,                     *hence\n"
  "Thine aventure of love, as in this case.\"\n"
  "And with that word, the arrows in the case*                      *quiver\n"
  "Of the goddess did clatter fast and ring,\n"
  "And forth she went, and made a vanishing,\n"
  "For which this Emily astonied was,\n"
  "And saide; \"What amounteth this, alas!\n"
  "I put me under thy protection,\n"
  "Diane, and in thy disposition.\"\n"
  "And home she went anon the nexte* way.                          *nearest\n"
  "This is th' effect, there is no more to say.\n"
  "\n"
  "The nexte hour of Mars following this\n"
  "Arcite to the temple walked is\n"
  "Of fierce Mars, to do his sacrifice\n"
  "With all the rites of his pagan guise.\n"
  "With piteous* heart and high devotion                             *pious\n"
  "Right thus to Mars he said his orison\n"
  "\"O stronge god, that in the regnes* old                          *realms\n"
  "Of Thrace honoured art, and lord y-hold*                           *held\n"
  "And hast in every regne, and every land\n"
  "Of armes all the bridle in thine hand,\n"
  "And *them fortunest as thee list devise*,             *send them fortune\n"
  "Accept of me my piteous sacrifice.                        as you please*\n"
  "If so be that my youthe may deserve,\n"
  "And that my might be worthy for to serve\n"
  "Thy godhead, that I may be one of thine,\n"
  "Then pray I thee to *rue upon my pine*,                *pity my anguish*\n"
  "For thilke* pain, and thilke hote fire,                            *that\n"
  "In which thou whilom burned'st for desire\n"
  "Whenne that thou usedest* the beauty                            *enjoyed\n"
  "Of faire young Venus, fresh and free,\n"
  "And haddest her in armes at thy will:\n"
  "And though thee ones on a time misfill*,                   *were unlucky\n"
  "When Vulcanus had caught thee in his las*,                     *net <69>\n"
  "And found thee ligging* by his wife, alas!                        *lying\n"
  "For thilke sorrow that was in thine heart,\n"
  "Have ruth* as well upon my paine's smart.                          *pity\n"
  "I am young and unconning*, as thou know'st,            *ignorant, simple\n"
  "And, as I trow*, with love offended most                        *believe\n"
  "That e'er was any living creature:\n"
  "For she, that doth* me all this woe endure,                      *causes\n"
  "Ne recketh ne'er whether I sink or fleet*                          *swim\n"
  "And well I wot, ere she me mercy hete*,              *promise, vouchsafe\n"
  "I must with strengthe win her in the place:\n"
  "And well I wot, withoute help or grace\n"
  "Of thee, ne may my strengthe not avail:\n"
  "Then help me, lord, to-morr'w in my bataille,\n"
  "For thilke fire that whilom burned thee,\n"
  "As well as this fire that now burneth me;\n"
  "And do* that I to-morr'w may have victory.                        *cause\n"
  "Mine be the travail, all thine be the glory.\n"
  "Thy sovereign temple will I most honour\n"
  "Of any place, and alway most labour\n"
  "In thy pleasance and in thy craftes strong.\n"
  "And in thy temple I will my banner hong*,                          *hang\n"
  "And all the armes of my company,\n"
  "And evermore, until that day I die,\n"
  "Eternal fire I will before thee find\n"
  "And eke to this my vow I will me bind:\n"
  "My beard, my hair that hangeth long adown,\n"
  "That never yet hath felt offension*                           *indignity\n"
  "Of razor nor of shears, I will thee give,\n"
  "And be thy true servant while I live.\n"
  "Now, lord, have ruth upon my sorrows sore,\n"
  "Give me the victory, I ask no more.\"\n"
  "\n"
  "The prayer stint* of Arcita the strong,                           *ended\n"
  "The ringes on the temple door that hong,\n"
  "And eke the doores, clattered full fast,\n"
  "Of which Arcita somewhat was aghast.\n"
  "The fires burn'd upon the altar bright,\n"
  "That it gan all the temple for to light;\n"
  "A sweete smell anon the ground up gaf*,                            *gave\n"
  "And Arcita anon his hand up haf*,                                *lifted\n"
  "And more incense into the fire he cast,\n"
  "With other rites more and at the last\n"
  "The statue of Mars began his hauberk ring;\n"
  "And with that sound he heard a murmuring\n"
  "Full low and dim, that saide thus,  \"Victory.\"\n"
  "For which he gave to Mars honour and glory.\n"
  "And thus with joy, and hope well to fare,\n"
  "Arcite anon unto his inn doth fare.\n"
  "As fain* as fowl is of the brighte sun.                            *glad\n"
  "\n"
  "And right anon such strife there is begun\n"
  "For thilke* granting, in the heav'n above,                         *that\n"
  "Betwixte Venus the goddess of love,\n"
  "And Mars the sterne god armipotent,\n"
  "That Jupiter was busy it to stent*:                                *stop\n"
  "Till that the pale Saturnus the cold,<70>\n"
  "That knew so many of adventures old,\n"
  "Found in his old experience such an art,\n"
  "That he full soon hath pleased every part.\n"
  "As sooth is said, eld* hath great advantage,                        *age\n"
  "In eld is bothe wisdom and usage*:                           *experience\n"
  "Men may the old out-run, but not out-rede*.                      *outwit\n"
  "Saturn anon, to stint the strife and drede,\n"
  "Albeit that it is against his kind,*                             *nature\n"
  "Of all this strife gan a remedy find.\n"
  "\"My deare daughter Venus,\" quoth Saturn,\n"
  "\"My course*, that hath so wide for to turn,                  *orbit <71>\n"
  "Hath more power than wot any man.\n"
  "Mine is the drowning in the sea so wan;\n"
  "Mine is the prison in the darke cote*,                             *cell\n"
  "Mine the strangling and hanging by the throat,\n"
  "The murmur, and the churlish rebelling,\n"
  "The groyning*, and the privy poisoning.                      *discontent\n"
  "I do vengeance and plein* correction,                              *full\n"
  "I dwell in the sign of the lion.\n"
  "Mine is the ruin of the highe halls,\n"
  "The falling of the towers and the walls\n"
  "Upon the miner or the carpenter:\n"
  "I slew Samson in shaking the pillar:\n"
  "Mine also be the maladies cold,\n"
  "The darke treasons, and the castes* old:                          *plots\n"
  "My looking is the father of pestilence.\n"
  "Now weep no more, I shall do diligence\n"
  "That Palamon, that is thine owen knight,\n"
  "Shall have his lady, as thou hast him hight*.                  *promised\n"
  "Though Mars shall help his knight, yet natheless\n"
  "Betwixte you there must sometime be peace:\n"
  "All be ye not of one complexion,\n"
  "That each day causeth such division,\n"
  "I am thine ayel*, ready at thy will;                   *grandfather <72>\n"
  "Weep now no more, I shall thy lust* fulfil.\"                   *pleasure\n"
  "Now will I stenten* of the gods above,                   *cease speaking\n"
  "Of Mars, and of Venus, goddess of love,\n"
  "And telle you as plainly as I can\n"
  "The great effect, for which that I began.\n"
  "\n"
  "Great was the feast in Athens thilke* day;                         *that\n"
  "And eke the lusty season of that May\n"
  "Made every wight to be in such pleasance,\n"
  "That all that Monday jousten they and dance,\n"
  "And spenden it in Venus' high service.\n"
  "But by the cause that they shoulde rise\n"
  "Early a-morrow for to see that fight,\n"
  "Unto their reste wente they at night.\n"
  "And on the morrow, when the day gan spring,\n"
  "Of horse and harness* noise and clattering                       *armour\n"
  "There was in the hostelries all about:\n"
  "And to the palace rode there many a rout*                *train, retinue\n"
  "Of lordes, upon steedes and palfreys.\n"
  "There mayst thou see devising* of harness                    *decoration\n"
  "So uncouth* and so rich, and wrought so weel               *unkown, rare\n"
  "Of goldsmithry, of brouding*, and of steel;                  *embroidery\n"
  "The shieldes bright, the testers*, and trappures**          *helmets<73>\n"
  "Gold-hewen helmets, hauberks, coat-armures;                  **trappings\n"
  "Lordes in parements* on their coursers,           *ornamental garb <74>;\n"
  "Knightes of retinue, and eke squiers,\n"
  "Nailing the spears, and helmes buckeling,\n"
  "Gniding* of shieldes, with lainers** lacing;             *polishing <75>\n"
  "There as need is, they were nothing idle:                     **lanyards\n"
  "The foamy steeds upon the golden bridle\n"
  "Gnawing, and fast the armourers also\n"
  "With file and hammer pricking to and fro;\n"
  "Yeomen on foot, and knaves* many one                           *servants\n"
  "With shorte staves, thick* as they may gon**;              *close **walk\n"
  "Pipes, trumpets, nakeres*, and clariouns,                    *drums <76>\n"
  "That in the battle blowe bloody souns;\n"
  "The palace full of people up and down,\n"
  "There three, there ten, holding their questioun*,          *conversation\n"
  "Divining* of these Theban knightes two.                    *conjecturing\n"
  "Some saiden thus, some said it shall he so;\n"
  "Some helden with him with the blacke beard,\n"
  "Some with the bald, some with the thick-hair'd;\n"
  "Some said he looked grim, and woulde fight:\n"
  "He had a sparth* of twenty pound of weight.           *double-headed axe\n"
  "Thus was the halle full of divining*                       *conjecturing\n"
  "Long after that the sunne gan up spring.\n"
  "The great Theseus that of his sleep is waked\n"
  "With minstrelsy, and noise that was maked,\n"
  "Held yet the chamber of his palace rich,\n"
  "Till that the Theban knightes both y-lich*                        *alike\n"
  "Honoured were, and to the palace fet*.                          *fetched\n"
  "Duke Theseus is at a window set,\n"
  "Array'd right as he were a god in throne:\n"
  "The people presseth thitherward full soon\n"
  "Him for to see, and do him reverence,\n"
  "And eke to hearken his hest* and his sentence**.       *command **speech\n"
  "An herald on a scaffold made an O, <77>\n"
  "Till the noise of the people was y-do*:                            *done\n"
  "And when he saw the people of noise all still,\n"
  "Thus shewed he the mighty Duke's will.\n"
  "\"The lord hath of his high discretion\n"
  "Considered that it were destruction\n"
  "To gentle blood, to fighten in the guise\n"
  "Of mortal battle now in this emprise:\n"
  "Wherefore to shape* that they shall not die,          *arrange, contrive\n"
  "He will his firste purpose modify.\n"
  "No man therefore, on pain of loss of life,\n"
  "No manner* shot, nor poleaxe, nor short knife                   *kind of\n"
  "Into the lists shall send, or thither bring.\n"
  "Nor short sword for to stick with point biting\n"
  "No man shall draw, nor bear it by his side.\n"
  "And no man shall unto his fellow ride\n"
  "But one course, with a sharp y-grounden spear:\n"
  "*Foin if him list on foot, himself to wear.           *He who wishes can\n"
  "And he that is at mischief shall be take*,       fence on foot to defend\n"
  "And not slain, but be brought unto the stake,       himself, and he that\n"
  "That shall be ordained on either side;       is in peril shall be taken*\n"
  "Thither he shall by force, and there abide.\n"
  "And if *so fall* the chiefetain be take                  *should happen*\n"
  "On either side, or elles slay his make*,                   *equal, match\n"
  "No longer then the tourneying shall last.\n"
  "God speede you; go forth and lay on fast.\n"
  "With long sword and with mace fight your fill.\n"
  "Go now your way; this is the lordes will.\n"
  "The voice of the people touched the heaven,\n"
  "So loude cried they with merry steven*:                           *sound\n"
  "God save such a lord that is so good,\n"
  "He willeth no destruction of blood.\n"
  "\n"
  "Up go the trumpets and the melody,\n"
  "And to the listes rode the company\n"
  "*By ordinance*, throughout the city large,            *in orderly array*\n"
  "Hanged with cloth of gold, and not with sarge*.              *serge <78>\n"
  "Full like a lord this noble Duke gan ride,\n"
  "And these two Thebans upon either side:\n"
  "\n"
  "And after rode the queen and Emily,\n"
  "And after them another company\n"
  "Of one and other, after their degree.\n"
  "And thus they passed thorough that city\n"
  "And to the listes came they by time:\n"
  "It was not of the day yet fully prime*.              *between 6 & 9 a.m.\n"
  "When set was Theseus full rich and high,\n"
  "Hippolyta the queen and Emily,\n"
  "And other ladies in their degrees about,\n"
  "Unto the seates presseth all the rout.\n"
  "And westward, through the gates under Mart,\n"
  "Arcite, and eke the hundred of his part,\n"
  "With banner red, is enter'd right anon;\n"
  "And in the selve* moment Palamon                              *self-same\n"
  "Is, under Venus, eastward in the place,\n"
  "With banner white, and hardy cheer* and face                 *expression\n"
  "In all the world, to seeken up and down\n"
  "So even* without variatioun                                       *equal\n"
  "There were such companies never tway.\n"
  "For there was none so wise that coulde say\n"
  "That any had of other avantage\n"
  "Of worthiness, nor of estate, nor age,\n"
  "So even were they chosen for to guess.\n"
  "And *in two ranges faire they them dress*.     *they arranged themselves\n"
  "When that their names read were every one,                  in two rows*\n"
  "That in their number guile* were there none,                      *fraud\n"
  "Then were the gates shut, and cried was loud;\n"
  "\"Do now your devoir, younge knights proud\n"
  "The heralds left their pricking* up and down      *spurring their horses\n"
  "Now ring the trumpet loud and clarioun.\n"
  "There is no more to say, but east and west\n"
  "In go the speares sadly* in the rest;                          *steadily\n"
  "In go the sharpe spurs into the side.\n"
  "There see me who can joust, and who can ride.\n"
  "There shiver shaftes upon shieldes thick;\n"
  "He feeleth through the hearte-spoon<79> the prick.\n"
  "Up spring the speares twenty foot on height;\n"
  "Out go the swordes as the silver bright.\n"
  "The helmes they to-hewen, and to-shred*;          *strike in pieces <80>\n"
  "Out burst the blood, with sterne streames red.\n"
  "With mighty maces the bones they to-brest*.                       *burst\n"
  "He <81> through the thickest of the throng gan threst*.          *thrust\n"
  "There stumble steedes strong, and down go all.\n"
  "He rolleth under foot as doth a ball.\n"
  "He foineth* on his foe with a trunchoun,                 *forces himself\n"
  "And he him hurtleth with his horse adown.\n"
  "He through the body hurt is, and *sith take*,      *afterwards captured*\n"
  "Maugre his head, and brought unto the stake,\n"
  "As forword* was, right there he must abide.                    *covenant\n"
  "Another led is on that other side.\n"
  "And sometime doth* them Theseus to rest,                         *caused\n"
  "Them to refresh, and drinken if them lest*.                     *pleased\n"
  "Full oft a day have thilke Thebans two                            *these\n"
  "Together met and wrought each other woe:\n"
  "Unhorsed hath each other of them tway*                            *twice\n"
  "There is no tiger in the vale of Galaphay, <82>\n"
  "When that her whelp is stole, when it is lite*                   *little\n"
  "So cruel on the hunter, as Arcite\n"
  "For jealous heart upon this Palamon:\n"
  "Nor in Belmarie <83> there is no fell lion,\n"
  "That hunted is, or for his hunger wood*                             *mad\n"
  "Or for his prey desireth so the blood,\n"
  "As Palamon to slay his foe Arcite.\n"
  "The jealous strokes upon their helmets bite;\n"
  "Out runneth blood on both their sides red,\n"
  "Sometime an end there is of every deed\n"
  "For ere the sun unto the reste went,\n"
  "The stronge king Emetrius gan hent*                       *sieze, assail\n"
  "This Palamon, as he fought with Arcite,\n"
  "And made his sword deep in his flesh to bite,\n"
  "And by the force of twenty is he take,\n"
  "Unyielding, and is drawn unto the stake.\n"
  "And in the rescue of this Palamon\n"
  "The stronge king Licurgus is borne down:\n"
  "And king Emetrius, for all his strength\n"
  "Is borne out of his saddle a sword's length,\n"
  "So hit him Palamon ere he were take:\n"
  "But all for nought; he was brought to the stake:\n"
  "His hardy hearte might him helpe naught,\n"
  "He must abide when that he was caught,\n"
  "By force, and eke by composition*.                          *the bargain\n"
  "Who sorroweth now but woful Palamon\n"
  "That must no more go again to fight?\n"
  "And when that Theseus had seen that sight\n"
  "Unto the folk that foughte thus each one,\n"
  "He cried, Ho! no more, for it is done!\n"
  "I will be true judge, and not party.\n"
  "Arcite of Thebes shall have Emily,\n"
  "That by his fortune hath her fairly won.\"\n"
  "Anon there is a noise of people gone,\n"
  "For joy of this, so loud and high withal,\n"
  "It seemed that the listes shoulde fall.\n"
  "\n"
  "What can now faire Venus do above?\n"
  "What saith she now? what doth this queen of love?\n"
  "But weepeth so, for wanting of her will,\n"
  "Till that her teares in the listes fill*                           *fall\n"
  "She said: \"I am ashamed doubteless.\"\n"
  "Saturnus saide: \"Daughter, hold thy peace.\n"
  "Mars hath his will, his knight hath all his boon,\n"
  "And by mine head thou shalt be eased soon.\"\n"
  " The trumpeters with the loud minstrelsy,\n"
  "The heralds, that full loude yell and cry,\n"
  "Be in their joy for weal of Dan* Arcite.                           *Lord\n"
  "But hearken me, and stinte noise a lite,\n"
  "What a miracle there befell anon\n"
  "This fierce Arcite hath off his helm y-done,\n"
  "And on a courser for to shew his face\n"
  "He *pricketh endelong* the large place,          *rides from end to end*\n"
  "Looking upward upon this Emily;\n"
  "And she again him cast a friendly eye\n"
  "(For women, as to speaken *in commune*,                      *generally*\n"
  "They follow all the favour of fortune),\n"
  "And was all his in cheer*,  as his in heart.                *countenance\n"
  "Out of the ground a fire infernal start,\n"
  "From Pluto sent, at request of Saturn\n"
  "For which his horse for fear began to turn,\n"
  "And leap aside, and founder* as he leap                         *stumble\n"
  "And ere that Arcite may take any keep*,                            *care\n"
  "He pight* him on the pummel** of his head.                *pitched **top\n"
  "That in the place he lay as he were dead.\n"
  "His breast to-bursten with his saddle-bow.\n"
  "As black he lay as any coal or crow,\n"
  "So was the blood y-run into his face.\n"
  "Anon he was y-borne out of the place\n"
  "With hearte sore, to Theseus' palace.\n"
  "Then was he carven* out of his harness.                             *cut\n"
  "And in a bed y-brought full fair and blive*                     *quickly\n"
  "For he was yet in mem'ry and alive,\n"
  "And always crying after Emily.\n"
  "\n"
  "Duke Theseus, with all his company,\n"
  "Is come home to Athens his city,\n"
  "With alle bliss and great solemnity.\n"
  "Albeit that this aventure was fall*,                           *befallen\n"
  "He woulde not discomforte* them all                          *discourage\n"
  "Then said eke, that Arcite should not die,\n"
  "He should be healed of his malady.\n"
  "And of another thing they were as fain*.                           *glad\n"
  "That of them alle was there no one slain,\n"
  "All* were they sorely hurt, and namely** one,     *although **especially\n"
  "That with a spear was thirled* his breast-bone.                 *pierced\n"
  "To other woundes, and to broken arms,\n"
  "Some hadden salves, and some hadden charms:\n"
  "And pharmacies of herbs, and eke save*         *sage, Salvia officinalis\n"
  "They dranken, for they would their lives have.\n"
  "For which this noble Duke, as he well can,\n"
  "Comforteth and honoureth every man,\n"
  "And made revel all the longe night,\n"
  "Unto the strange lordes, as was right.\n"
  "Nor there was holden no discomforting,\n"
  "But as at jousts or at a tourneying;\n"
  "For soothly there was no discomfiture,\n"
  "For falling is not but an aventure*.                   *chance, accident\n"
  "Nor to be led by force unto a stake\n"
  "Unyielding, and with twenty knights y-take\n"
  "One person all alone, withouten mo',\n"
  "And harried* forth by armes, foot, and toe,            *dragged, hurried\n"
  "And eke his steede driven forth with staves,\n"
  "With footmen, bothe yeomen and eke knaves*,                    *servants\n"
  "It was *aretted him no villainy:*           *counted no disgrace to him*\n"
  "There may no man *clepen it cowardy*.                *call it cowardice*\n"
  "For which anon Duke Theseus *let cry*, --      *caused to be proclaimed*\n"
  "To stenten* alle rancour and envy, --                              *stop\n"
  "The gree* as well on one side as the other,                *prize, merit\n"
  "And either side alike as other's brother:\n"
  "And gave them giftes after their degree,\n"
  "And held a feaste fully dayes three:\n"
  "And conveyed the kinges worthily\n"
  "Out of  his town a journee* largely                       *day's journey\n"
  "And home went every man the righte way,\n"
  "There was no more but \"Farewell, Have good day.\"\n"
  "Of this bataille I will no more indite\n"
  "But speak of Palamon and of Arcite.\n"
  "\n"
  "";
// }

const char knightsTale3[] PGMSECTION = // { // 32147 bytes
  "Swelleth the breast of Arcite and the sore\n"
  "Increaseth at his hearte more and more.\n"
  "The clotted blood, for any leache-craft*                 *surgical skill\n"
  "Corrupteth and is *in his bouk y-laft*                *left in his body*\n"
  "That neither *veine blood nor ventousing*,    *blood-letting or cupping*\n"
  "Nor drink of herbes may be his helping.\n"
  "The virtue expulsive or animal,\n"
  "From thilke virtue called natural,\n"
  "Nor may the venom voide, nor expel\n"
  "The pipes of his lungs began to swell\n"
  "And every lacert* in his breast adown                     *sinew, muscle\n"
  "Is shent* with venom and corruption.                          *destroyed\n"
  "Him gaineth* neither, for to get his life,                     *availeth\n"
  "Vomit upward, nor downward laxative;\n"
  "All is to-bursten thilke region;\n"
  "Nature hath now no domination.\n"
  "And certainly where nature will not wirch,*                        *work\n"
  "Farewell physic: go bear the man to chirch.*                     *church\n"
  "This all and some is, Arcite must die.\n"
  "For which he sendeth after Emily,\n"
  "And Palamon, that was his cousin dear,\n"
  "Then said he thus, as ye shall after hear.\n"
  "\n"
  "\"Nought may the woful spirit in mine heart\n"
  "Declare one point of all my sorrows' smart\n"
  "To you, my lady, that I love the most:\n"
  "But I bequeath  the service of my ghost\n"
  "To you aboven every creature,\n"
  "Since that my life ne may no longer dure.\n"
  "Alas the woe! alas, the paines strong\n"
  "That I for you have suffered and so long!\n"
  "Alas the death,  alas, mine Emily!\n"
  "Alas departing* of our company!                           *the severance\n"
  "Alas, mine hearte's queen! alas, my wife!\n"
  "Mine hearte's lady, ender of my life!\n"
  "What is this world? what aske men to have?\n"
  "Now with his love, now in his colde grave\n"
  "Al one, withouten any company.\n"
  "Farewell, my sweet, farewell, mine Emily,\n"
  "And softly take me in your armes tway,\n"
  "For love of God, and hearken what I say.\n"
  "I have here with my cousin Palamon\n"
  "Had strife and rancour many a day agone,\n"
  "For love of you, and for my jealousy.\n"
  "And Jupiter so *wis my soule gie*,               *surely guides my soul*\n"
  "To speaken of a servant properly,\n"
  "With alle circumstances truely,\n"
  "That is to say, truth, honour, and knighthead,\n"
  "Wisdom, humbless*, estate, and high kindred,                   *humility\n"
  "Freedom, and all that longeth to that art,\n"
  "So Jupiter have of my soul part,\n"
  "As in this world right now I know not one,\n"
  "So worthy to be lov'd as Palamon,\n"
  "That serveth you, and will do all his life.\n"
  "And if that you shall ever be a wife,\n"
  "Forget not Palamon, the gentle man.\"\n"
  "\n"
  "And with that word his speech to fail began.\n"
  "For from his feet up to his breast was come\n"
  "The cold of death, that had him overnome*.                     *overcome\n"
  "And yet moreover in his armes two\n"
  "The vital strength is lost, and all ago*.                          *gone\n"
  "Only the intellect, withoute more,\n"
  "That dwelled in his hearte sick and sore,\n"
  "Gan faile, when the hearte felte death;\n"
  "Dusked* his eyen two, and fail'd his breath.                   *grew dim\n"
  "But on his lady yet he cast his eye;\n"
  "His laste word was; \"Mercy, Emily!\"\n"
  "His spirit changed house, and wente there,\n"
  "As I came never I cannot telle where.<84>\n"
  "Therefore I stent*, I am no divinister**;             *refrain **diviner\n"
  "Of soules find I nought in this register.\n"
  "Ne me list not th' opinions to tell\n"
  "Of them, though that they writen where they dwell;\n"
  "Arcite is cold, there Mars his soule gie.*                        *guide\n"
  "Now will I speake forth of Emily.\n"
  "\n"
  "Shriek'd Emily, and howled Palamon,\n"
  "And Theseus his sister took anon\n"
  "Swooning, and bare her from the corpse away.\n"
  "What helpeth it to tarry forth the day,\n"
  "To telle how she wept both eve and morrow?\n"
  "For in such cases women have such sorrow,\n"
  "When that their husbands be from them y-go*,                       *gone\n"
  "That for the more part they sorrow so,\n"
  "Or elles fall into such malady,\n"
  "That at the laste certainly they die.\n"
  "Infinite be the sorrows and the tears\n"
  "Of olde folk, and folk of tender years,\n"
  "In all the town, for death of this Theban:\n"
  "For him there weepeth bothe child and man.\n"
  "So great a weeping was there none certain,\n"
  "When Hector was y-brought, all fresh y-slain,\n"
  "To Troy: alas! the pity that was there,\n"
  "Scratching of cheeks, and rending eke of hair.\n"
  "\"Why wouldest thou be dead?\" these women cry,\n"
  "\"And haddest gold enough, and Emily.\"\n"
  "No manner man might gladden Theseus,\n"
  "Saving his olde father Egeus,\n"
  "That knew this worlde's transmutatioun,\n"
  "As he had seen it changen up and down,\n"
  "Joy after woe, and woe after gladness;\n"
  "And shewed him example and likeness.\n"
  "\"Right as there died never man,\" quoth he,\n"
  "\"That he ne liv'd in earth in some degree*,             *rank, condition\n"
  "Right so there lived never man,\" he said,\n"
  "\"In all this world, that sometime be not died.\n"
  "This world is but a throughfare full of woe,\n"
  "And we be pilgrims, passing to and fro:\n"
  "Death is an end of every worldly sore.\"\n"
  "And over all this said he yet much more\n"
  "To this effect, full wisely to exhort\n"
  "The people, that they should them recomfort.\n"
  "Duke Theseus, with all his busy cure*,                             *care\n"
  "*Casteth about*, where that the sepulture                  *deliberates*\n"
  "Of good Arcite may best y-maked be,\n"
  "And eke most honourable in his degree.\n"
  "And at the last he took conclusion,\n"
  "That there as first Arcite and Palamon\n"
  "Hadde for love the battle them between,\n"
  "That in that selve* grove, sweet and green,                   *self-same\n"
  "There as he had his amorous desires,\n"
  "His complaint, and for love his hote fires,\n"
  "He woulde make a fire*, in which th' office                *funeral pyre\n"
  "Of funeral he might all accomplice;\n"
  "And *let anon command* to hack and hew         *immediately gave orders*\n"
  "The oakes old, and lay them *on a rew*                        *in a row*\n"
  "In culpons*, well arrayed for to brenne**.                  *logs **burn\n"
  "His officers with swifte feet they renne*                           *run\n"
  "And ride anon at his commandement.\n"
  "And after this, Duke Theseus hath sent\n"
  "After a bier, and it all oversprad\n"
  "With cloth of gold, the richest that he had;\n"
  "And of the same suit he clad Arcite.\n"
  "Upon his handes were his gloves white,\n"
  "Eke on his head a crown of laurel green,\n"
  "And in his hand a sword full bright and keen.\n"
  "He laid him *bare the visage* on the bier,         *with face uncovered*\n"
  "Therewith he wept, that pity was to hear.\n"
  "And, for the people shoulde see him all,\n"
  "When it was day he brought them to the hall,\n"
  "That roareth of the crying and the soun'.\n"
  "Then came this woful Theban, Palamon,\n"
  "With sluttery beard, and ruggy ashy hairs,<85>\n"
  "In clothes black, y-dropped all with tears,\n"
  "And (passing over weeping Emily)\n"
  "The ruefullest of all the company.\n"
  "And *inasmuch as* the service should be                  *in order that*\n"
  "The more noble and rich in its degree,\n"
  "Duke Theseus let forth three steedes bring,\n"
  "That trapped were in steel all glittering.\n"
  "And covered with the arms of Dan Arcite.\n"
  "Upon these steedes, that were great and white,\n"
  "There satte folk, of whom one bare his shield,\n"
  "Another his spear in his handes held;\n"
  "The thirde bare with him his bow Turkeis*,                     *Turkish.\n"
  "Of brent* gold was the case** and the harness:       *burnished **quiver\n"
  "And ride forth *a pace* with sorrowful cheer**          *at a foot pace*\n"
  "Toward the grove, as ye shall after hear.                   **expression\n"
  "\n"
  "The noblest of the Greekes that there were\n"
  "Upon their shoulders carried the bier,\n"
  "With slacke pace, and eyen red and wet,\n"
  "Throughout the city, by the master* street,                   *main <86>\n"
  "That spread was all with black, and wondrous high\n"
  "Right of the same is all the street y-wrie.*               *covered <87>\n"
  "Upon the right hand went old Egeus,\n"
  "And on the other side Duke Theseus,\n"
  "With vessels in their hand of gold full fine,\n"
  "All full of honey, milk, and blood, and wine;\n"
  "Eke Palamon, with a great company;\n"
  "And after that came woful Emily,\n"
  "With fire in hand, as was that time the guise*,                  *custom\n"
  "To do th' office of funeral service.\n"
  "\n"
  "High labour, and full great appareling*                     *preparation\n"
  "Was at the service, and the pyre-making,\n"
  "That with its greene top the heaven raught*,                    *reached\n"
  "And twenty fathom broad its armes straught*:                  *stretched\n"
  "This is to say, the boughes were so broad.\n"
  "Of straw first there was laid many a load.\n"
  "But how the pyre was maked up on height,\n"
  "And eke the names how the trees hight*,                     *were called\n"
  "As oak, fir, birch, asp*, alder, holm, poplere,                   *aspen\n"
  "Willow, elm, plane, ash, box, chestnut, lind*, laurere,    *linden, lime\n"
  "Maple, thorn, beech, hazel, yew, whipul tree,\n"
  "How they were fell'd, shall not be told for me;\n"
  "Nor how the goddes* rannen up and down               *the forest deities\n"
  "Disinherited of their habitatioun,\n"
  "In which they wonned* had in rest and peace,                      *dwelt\n"
  "Nymphes, Faunes, and Hamadryades;\n"
  "Nor how the beastes and the birdes all\n"
  "Fledden for feare, when the wood gan fall;\n"
  "Nor how the ground aghast* was of the light,                  *terrified\n"
  "That was not wont to see the sunne bright;\n"
  "Nor how the fire was couched* first with stre**,           *laid **straw\n"
  "And then with dry stickes cloven in three,\n"
  "And then with greene wood and spicery*,                          *spices\n"
  "And then with cloth of gold and with pierrie*,          *precious stones\n"
  "And garlands hanging with full many a flower,\n"
  "The myrrh, the incense with so sweet odour;\n"
  "Nor how Arcita lay among all this,\n"
  "Nor what richess about his body is;\n"
  "Nor how that Emily, as was the guise*,                           *custom\n"
  "*Put in the fire* of funeral service<88>;           *appplied the torch*\n"
  "Nor how she swooned when she made the fire,\n"
  "Nor what she spake, nor what was her desire;\n"
  "Nor what jewels men in the fire then cast\n"
  "When that the fire was great and burned fast;\n"
  "\n"
  "Nor how some cast their shield, and some their spear,\n"
  "And of their vestiments, which that they wear,\n"
  "And cuppes full of wine, and milk, and blood,\n"
  "Into the fire, that burnt as it were wood*;                         *mad\n"
  "Nor how the Greekes with a huge rout*                        *procession\n"
  "Three times riden all the fire about <89>\n"
  "Upon the left hand, with a loud shouting,\n"
  "And thries with their speares clattering;\n"
  "And thries how the ladies gan to cry;\n"
  "Nor how that led was homeward Emily;\n"
  "Nor how Arcite is burnt to ashes cold;\n"
  "Nor how the lyke-wake* was y-hold                             *wake <90>\n"
  "All thilke* night, nor how the Greekes play                        *that\n"
  "The wake-plays*, ne keep** I not to say:           *funeral games **care\n"
  "Who wrestled best naked, with oil anoint,\n"
  "Nor who that bare him best *in no disjoint*.            *in any contest*\n"
  "I will not tell eke how they all are gone\n"
  "Home to Athenes when the play is done;\n"
  "But shortly to the point now will I wend*,                         *come\n"
  "And maken of my longe tale an end.\n"
  "\n"
  "By process and by length of certain years\n"
  "All stinted* is the mourning and the tears                        *ended\n"
  "Of Greekes, by one general assent.\n"
  "Then seemed me there was a parlement\n"
  "At Athens, upon certain points and cas*:                          *cases\n"
  "Amonge the which points y-spoken was\n"
  "To have with certain countries alliance,\n"
  "And have of Thebans full obeisance.\n"
  "For which this noble Theseus anon\n"
  "Let* send after the gentle Palamon,                              *caused\n"
  "Unwist* of him what was the cause and why:                      *unknown\n"
  "But in his blacke clothes sorrowfully\n"
  "He came at his commandment *on hie*;                          *in haste*\n"
  "Then sente Theseus for Emily.\n"
  "When they were set*, and hush'd was all the place                *seated\n"
  "And Theseus abided* had a space                                  *waited\n"
  "Ere any word came from his wise breast\n"
  "*His eyen set he there as was his lest*,               *he cast his eyes\n"
  "And with a sad visage he sighed still,              wherever he pleased*\n"
  "And after that right thus he said his will.\n"
  "\"The firste mover of the cause above\n"
  "When he first made the faire chain of love,\n"
  "Great was th' effect, and high was his intent;\n"
  "Well wist he why, and what thereof he meant:\n"
  "For with that faire chain of love he bond*                        *bound\n"
  "The fire, the air, the water, and the lond\n"
  "In certain bondes, that they may not flee:<91>\n"
  "That same prince and mover eke,\" quoth he,\n"
  "\"Hath stablish'd, in this wretched world adown,\n"
  "Certain of dayes and duration\n"
  "To all that are engender'd in this place,\n"
  "Over the whiche day they may not pace*,                            *pass\n"
  "All may they yet their dayes well abridge.\n"
  "There needeth no authority to allege\n"
  "For it is proved by experience;\n"
  "But that me list declare my sentence*.                          *opinion\n"
  "Then may men by this order well discern,\n"
  "That thilke* mover stable is and etern.                        *the same\n"
  "Well may men know, but that it be a fool,\n"
  "That every part deriveth from its whole.\n"
  "For nature hath not ta'en its beginning\n"
  "Of no *partie nor cantle* of a thing,                    *part or piece*\n"
  "But of a thing that perfect is and stable,\n"
  "Descending so, till it be corruptable.\n"
  "And therefore of His wise purveyance*                        *providence\n"
  "He hath so well beset* his ordinance,\n"
  "That species of things and progressions\n"
  "Shallen endure by successions,\n"
  "And not etern, withouten any lie:\n"
  "This mayst thou understand and see at eye.\n"
  "Lo th' oak, that hath so long a nourishing\n"
  "From the time that it 'ginneth first to spring,\n"
  "And hath so long a life, as ye may see,\n"
  "Yet at the last y-wasted is the tree.\n"
  "Consider eke, how that the harde stone\n"
  "Under our feet, on which we tread and gon*,                        *walk\n"
  "Yet wasteth, as it lieth by the way.\n"
  "The broade river some time waxeth drey*.                            *dry\n"
  "The greate townes see we wane and wend*.                  *go, disappear\n"
  "Then may ye see that all things have an end.\n"
  "Of man and woman see we well also, --\n"
  "That needes in one of the termes two, --\n"
  "That is to say, in youth or else in age,-\n"
  "He must be dead, the king as shall a page;\n"
  "Some in his bed, some in the deepe sea,\n"
  "Some in the large field, as ye may see:\n"
  "There helpeth nought, all go that ilke* way:                       *same\n"
  "Then may I say that alle thing must die.\n"
  "What maketh this but Jupiter the king?\n"
  "The which is prince, and cause of alle thing,\n"
  "Converting all unto his proper will,\n"
  "From which it is derived, sooth to tell\n"
  "And hereagainst no creature alive,\n"
  "Of no degree, availeth for to strive.\n"
  "Then is it wisdom, as it thinketh me,\n"
  "To make a virtue of necessity,\n"
  "And take it well, that we may not eschew*,                       *escape\n"
  "And namely what to us all is due.\n"
  "And whoso grudgeth* ought, he doth folly,                    *murmurs at\n"
  "And rebel is to him that all may gie*.                    *direct, guide\n"
  "And certainly a man hath most honour\n"
  "To dien in his excellence and flower,\n"
  "When he is sicker* of his goode name.                           *certain\n"
  "Then hath he done his friend, nor him*, no shame                *himself\n"
  "And gladder ought his friend be of his death,\n"
  "When with honour is yielded up his breath,\n"
  "Than when his name *appalled is for age*;           *decayed by old age*\n"
  "For all forgotten is his vassalage*.                    *valour, service\n"
  "Then is it best, as for a worthy fame,\n"
  "To dien when a man is best of name.\n"
  "The contrary of all this is wilfulness.\n"
  "Why grudge we, why have we heaviness,\n"
  "That good Arcite, of chivalry the flower,\n"
  "Departed is, with duty and honour,\n"
  "Out of this foule prison of this life?\n"
  "Why grudge here his cousin and his wife\n"
  "Of his welfare, that loved him so well?\n"
  "Can he them thank? nay, God wot, neverdeal*, --               *not a jot\n"
  "That both his soul and eke themselves offend*,                     *hurt\n"
  "And yet they may their lustes* not amend**.           *desires **control\n"
  "What may I conclude of this longe serie*,             *string of remarks\n"
  "But after sorrow I rede* us to be merry,                        *counsel\n"
  "And thanke Jupiter for all his grace?\n"
  "And ere that we departe from this place,\n"
  "I rede that we make of sorrows two\n"
  "One perfect joye lasting evermo':\n"
  "And look now where most sorrow is herein,\n"
  "There will I first amenden and begin.\n"
  "\"Sister,\" quoth he, \"this is my full assent,\n"
  "With all th' advice here of my parlement,\n"
  "That gentle Palamon, your owen knight,\n"
  "That serveth you with will, and heart, and might,\n"
  "And ever hath, since first time ye him knew,\n"
  "That ye shall of your grace upon him rue*,                    *take pity\n"
  "And take him for your husband and your lord:\n"
  "Lend me your hand, for this is our accord.\n"
  "*Let see* now of your womanly pity.                       *make display*\n"
  "He is a kinge's brother's son, pardie*.                          *by God\n"
  "And though he were a poore bachelere,\n"
  "Since he hath served you so many a year,\n"
  "And had for you so great adversity,\n"
  "It muste be considered, *'lieveth me*.                      *believe me*\n"
  "For gentle mercy *oweth to passen right*.\"          *ought to be rightly\n"
  "Then said he thus to Palamon the knight;                       directed*\n"
  "\"I trow there needeth little sermoning\n"
  "To make you assente to this thing.\n"
  "Come near, and take your lady by the hand.\"\n"
  "Betwixte them was made anon the band,\n"
  "That hight matrimony or marriage,\n"
  "By all the counsel of the baronage.\n"
  "And thus with alle bliss and melody\n"
  "Hath Palamon y-wedded Emily.\n"
  "And God, that all this wide world hath wrought,\n"
  "Send him his love, that hath it dearly bought.\n"
  "For now is Palamon in all his weal,\n"
  "Living in bliss, in riches, and in heal*.                        *health\n"
  "And Emily him loves so tenderly,\n"
  "And he her serveth all so gentilly,\n"
  "That never was there worde them between\n"
  "Of jealousy, nor of none other teen*.                    *cause of anger\n"
  "Thus endeth Palamon and Emily\n"
  "And God save all this faire company.\n"
  "\n"
  "\n"
  "Notes to The Knight's Tale.\n"
  "\n"
  "\n"
  "1. For the plan and principal incidents of the \"Knight's Tale,\"\n"
  "Chaucer was indebted to Boccaccio, who had himself borrowed\n"
  "from some prior poet, chronicler, or romancer.  Boccaccio\n"
  "speaks of the story as \"very ancient;\" and, though that may not\n"
  "be proof of its antiquity, it certainly shows that he took it from\n"
  "an earlier writer. The \"Tale\" is more or less a paraphrase of\n"
  "Boccaccio's \"Theseida;\" but in some points the copy has a\n"
  "distinct dramatic superiority over the original.  The \"Theseida\"\n"
  "contained ten thousand lines; Chaucer has condensed it into less\n"
  "than one-fourth of the number. The \"Knight's Tale\" is supposed\n"
  "to have been at first composed as a separate work; it is\n"
  "undetermined whether Chaucer took it direct from the Italian of\n"
  "Boccaccio, or from a French translation.\n"
  "\n"
  "2. Highte: was called; from the Anglo-Saxon \"hatan\", to bid or\n"
  "call; German, \"Heissen\", \"heisst\".\n"
  "\n"
  "3. Feminie: The \"Royaume des Femmes\" -- kingdom of the\n"
  "Amazons. Gower, in the \"Confessio Amantis,\" styles\n"
  "Penthesilea the \"Queen of Feminie.\"\n"
  "\n"
  "4. Wonnen: Won, conquered; German \"gewonnen.\"\n"
  "\n"
  "5. Ear: To plough; Latin, \"arare.\"  \"I have abundant  matter for\n"
  "discourse.\" The first, and half of the second, of Boccaccio's\n"
  "twelve books are disposed of in the few lines foregoing.\n"
  "\n"
  "6. Waimenting:  bewailing; German, \"wehklagen\"\n"
  "\n"
  "7. Starf: died; German, \"sterben,\" \"starb\".\n"
  "\n"
  "8. The Minotaur: The monster, half-man and half-bull, which\n"
  "yearly devoured a tribute of fourteen Athenian youths and\n"
  "maidens, until it was slain by Theseus.\n"
  "\n"
  "9. Pillers: pillagers, strippers; French, \"pilleurs.\"\n"
  "\n"
  "10. The donjon was originally the central tower or \"keep\" of\n"
  "feudal castles; it was employed to detain prisoners of\n"
  "importance. Hence the modern meaning of the word dungeon.\n"
  "\n"
  "11. Saturn, in the old astrology, was a most unpropitious star to\n"
  "be born under.\n"
  "\n"
  "12. To die in the pain was a proverbial expression in the French,\n"
  "used as an alternative to enforce a resolution or a promise.\n"
  "Edward III., according to Froissart, declared that he would\n"
  "either succeed in the war against France or die in the pain --\n"
  "\"Ou il mourroit en la peine.\" It was the fashion in those times to\n"
  "swear oaths of friendship and brotherhood; and hence, though\n"
  "the fashion has long died out, we still speak of \"sworn friends.\"\n"
  "\n"
  "13. The saying of the old scholar Boethius, in his treatise \"De\n"
  "Consolatione Philosophiae\", which Chaucer translated, and\n"
  "from which he has freely borrowed in his poetry. The words are\n"
  "\"Quis legem det amantibus?\n"
  "Major lex amor est sibi.\"\n"
  "(\"Who can give law to lovers? Love is a law unto himself, and\n"
  "greater\")\n"
  "\n"
  "14. \"Perithous\" and \"Theseus\" must, for the metre, be\n"
  "pronounced as words of four and three syllables respectively --\n"
  "the vowels at the end not being diphthongated, but enunciated\n"
  "separately, as if the words were printed Pe-ri-tho-us, The-se-us.\n"
  "The same rule applies in such words as \"creature\" and\n"
  "\"conscience,\" which are trisyllables.\n"
  "\n"
  "15. Stound: moment, short space of time; from Anglo-Saxon,\n"
  "\"stund;\" akin to which is German, \"Stunde,\" an hour.\n"
  "\n"
  "16. Meinie: servants, or menials, &c., dwelling together in a\n"
  "house; from an Anglo-Saxon word meaning a crowd. Compare\n"
  "German, \"Menge,\" multitude.\n"
  "\n"
  "17. The pure fetters: the very fetters. The Greeks used\n"
  "\"katharos\", the Romans \"purus,\" in the same sense.\n"
  "\n"
  "18. In the medieval courts of Love, to which allusion is\n"
  "probably made forty lines before, in the word \"parlement,\" or\n"
  "\"parliament,\" questions like that here proposed were seriously\n"
  "discussed.\n"
  "\n"
  "19. Gear: behaviour, fashion, dress; but, by another reading, the\n"
  "word is \"gyre,\" and means fit, trance -- from the Latin, \"gyro,\" I\n"
  "turn round.\n"
  "\n"
  "20. Before his head in his cell fantastic: in front of his head in\n"
  "his cell of fantasy. \"The division of the brain into cells,\n"
  "according to the different sensitive faculties,\" says Mr Wright,\n"
  "\"is very ancient, and is found depicted in mediaeval\n"
  "manuscripts.\" In a manuscript in the Harleian Library, it is\n"
  "stated, \"Certum est in prora cerebri esse fantasiam, in medio\n"
  "rationem discretionis, in puppi memoriam\" (it is certain that in\n"
  "the front of the brain is imagination, in the middle reason, in the\n"
  "back memory) -- a classification not materially differing from\n"
  "that of modern phrenologists.\n"
  "\n"
  "21. Dan: Lord; Latin, \"Dominus;\" Spanish, \"Don.\"\n"
  "\n"
  "22. The \"caduceus.\"\n"
  "\n"
  "23. Argus was employed by Juno to watch Io with his hundred\n"
  "eyes but he was sent to sleep by the flute of Mercury, who then\n"
  "cut off his head.\n"
  "\n"
  "24. Next: nearest; German, \"naechste\".\n"
  "\n"
  "25. Clary: hippocras, wine made with spices.\n"
  "\n"
  "26. Warray: make war; French \"guerroyer\", to molest; hence,\n"
  "perhaps, \"to worry.\"\n"
  "\n"
  "27. All day meeten men at unset steven: every day men meet at\n"
  "unexpected time.  \"To  set a steven,\" is to fix a time, make an\n"
  "appointment.\n"
  "\n"
  "28. Roundelay: song coming round again to the words with\n"
  "which it opened.\n"
  "\n"
  "29. Now in the crop and now down in the breres: Now in the\n"
  "tree-top, now down in the briars. \"Crop and root,\" top and\n"
  "bottom, is used to express the perfection or totality of anything.\n"
  "\n"
  "30. Beknow: avow, acknowledge: German, \"bekennen.\"\n"
  "\n"
  "31. Shapen was my death erst than my shert: My death was\n"
  "decreed before my shirt ws shaped -- that is, before any clothes\n"
  "were made for me, before my birth.\n"
  "\n"
  "32. Regne: Queen; French, \"Reine;\" Venus is meant. The\n"
  "common reading, however, is \"regne,\" reign or power.\n"
  "\n"
  "33. Launde: plain. Compare modern English, \"lawn,\" and\n"
  "French, \"Landes\" -- flat, bare marshy tracts in the south of\n"
  "France.\n"
  "\n"
  "34. Mister: manner, kind; German \"muster,\" sample, model.\n"
  "\n"
  "35. In listes:  in the lists, prepared for such single combats\n"
  "between champion and accuser, &c.\n"
  "\n"
  "36. Thilke: that, contracted from \"the ilke,\" the same.\n"
  "\n"
  "37. Mars the Red: referring to the ruddy colour of the planet, to\n"
  "which was doubtless due the transference to it of the name of\n"
  "the God of War. In his \"Republic,\" enumerating the seven\n"
  "planets, Cicero speaks of the propitious and beneficent light of\n"
  "Jupiter: \"Tum (fulgor) rutilis horribilisque terris, quem Martium\n"
  "dicitis\" --  \"Then the red glow, horrible to the nations, which\n"
  "you say to be that of Mars.\" Boccaccio opens the \"Theseida\" by\n"
  "an invocation to \"rubicondo Marte.\"\n"
  "\n"
  "38. Last: lace, leash, noose, snare: from Latin, \"laceus.\"\n"
  "\n"
  "39. \"Round was the shape, in manner of compass,\n"
  "     Full of degrees, the height of sixty pas\"\n"
  "The building was a circle of steps or benches, as in the ancient\n"
  "amphitheatre. Either the building was sixty paces high; or, more\n"
  "probably, there were sixty of the steps or benches.\n"
  "\n"
  "40. Yellow goldes: The sunflower, turnsol, or girasol, which\n"
  "turns with and seems to watch the sun, as a jealous lover his\n"
  "mistress.\n"
  "\n"
  "41. Citheron: The Isle of Venus, Cythera, in the Aegean Sea;\n"
  "now called Cerigo: not, as Chaucer's form of the word might\n"
  "imply, Mount Cithaeron, in the south-west of Boetia, which was\n"
  "appropriated to other deities than Venus -- to Jupiter, to\n"
  "Bacchus, and the Muses.\n"
  "\n"
  "42. It need not be said that Chaucer pays slight heed to\n"
  "chronology in this passage, where the deeds of Turnus, the\n"
  "glory of King Solomon, and the fate of Croesus are made\n"
  "memories of the far past in the time of fabulous Theseus, the\n"
  "Minotaur-slayer.\n"
  "\n"
  "43. Champartie: divided power or possession; an old law-term,\n"
  "signifying the maintenance of a person in a law suit on the\n"
  "condition of receiving part of the property in dispute, if\n"
  "recovered.\n"
  "\n"
  "44. Citole: a kind of dulcimer.\n"
  "\n"
  "45. The picke-purse:  The plunderers that followed armies, and\n"
  "gave to war a horror all their own.\n"
  "\n"
  "46. Shepen: stable;  Anglo-Saxon, \"scypen;\" the word\n"
  "\"sheppon\" still survives in provincial parlance.\n"
  "\n"
  "47. This line, perhaps, refers to the deed of Jael.\n"
  "\n"
  "48. The shippes hoppesteres: The meaning is dubious. We may\n"
  "understand \"the dancing ships,\" \"the ships that hop\" on the\n"
  "waves; \"steres\" being taken as the feminine adjectival\n"
  "termination: or we may, perhaps, read, with one of the\n"
  "manuscripts, \"the ships upon the steres\" -- that is, even as they\n"
  "are being steered, or on the open sea -- a more picturesque\n"
  "notion.\n"
  "\n"
  "49. Freting: devouring; the Germans use \"Fressen\" to mean\n"
  "eating by animals, \"essen\" by men.\n"
  "\n"
  "50. Julius: i.e. Julius Caesar\n"
  "\n"
  "51. Puella and Rubeus were two figures in geomancy,\n"
  "representing two constellations-the one signifying Mars\n"
  "retrograde, the other Mars direct.\n"
  "\n"
  "52. Calistope: or Callisto, daughter of Lycaon, seduced by\n"
  "Jupiter, turned into a bear by Diana, and placed afterwards, with\n"
  "her son, as the Great Bear among the stars.\n"
  "\n"
  "53. Dane: Daphne, daughter of the river-god Peneus, in\n"
  "Thessaly; she was beloved by Apollo, but to avoid his pursuit,\n"
  "she was, at her own prayer, changed into a laurel-tree.\n"
  "\n"
  "54. As the goddess of Light, or the goddess who brings to light,\n"
  "Diana -- as well as Juno -- was invoked by women in childbirth:\n"
  "so Horace, Odes iii. 22, says:--\n"
  "\n"
  "\"Montium custos nemorumque, Virgo,\n"
  "Quae laborantes utero puellas\n"
  "Ter vocata audis adimisque leto,\n"
  "Diva triformis.\"\n"
  "\n"
  "(\"Virgin custodian of hills and groves, three-formed goddess\n"
  "who hears and saves from death young women who call upon\n"
  "her thrice when in childbirth\")\n"
  "\n"
  "55. Every deal:  in every part; \"deal\" corresponds to the\n"
  "German \"Theil\" a portion.\n"
  "\n"
  "56. Sikerly: surely; German, \"sicher;\" Scotch, \"sikkar,\" certain.\n"
  "When Robert Bruce had escaped from England to assume the\n"
  "Scottish crown, he stabbed Comyn before the altar at Dumfries;\n"
  "and, emerging from the church, was asked by his friend\n"
  "Kirkpatrick if he had slain the traitor. \"I doubt it,\" said Bruce.\n"
  "\"Doubt,\" cried Kirkpatrick.  \"I'll mak sikkar;\" and he rushed\n"
  "into the church, and despatched Comyn with repeated thrusts of\n"
  "his dagger.\n"
  "\n"
  "57. Kemped: combed; the word survives in \"unkempt.\"\n"
  "\n"
  "58. Alauns: greyhounds, mastiffs; from the Spanish word\n"
  "\"Alano,\" signifying a mastiff.\n"
  "\n"
  "59. Y-ment: mixed; German, \"mengen,\" to mix.\n"
  "\n"
  "60. Prime: The time of early prayers, between six and nine in\n"
  "the morning.\n"
  "\n"
  "61. On the dais: see note 32 to the Prologue.\n"
  "\n"
  "62. In her hour: in the hour of the day (two hours before\n"
  "daybreak) which after the astrological system that divided the\n"
  "twenty-four among the seven ruling planets, was under the\n"
  "influence of Venus.\n"
  "\n"
  "63. Adon: Adonis, a beautiful youth beloved of Venus, whose\n"
  "death by the tusk of a boar she deeply mourned.\n"
  "\n"
  "64. The third hour unequal: In the third planetary hour;\n"
  "Palamon had gone forth in the hour of Venus, two hours before\n"
  "daybreak; the hour of Mercury intervened; the third hour was\n"
  "that of Luna, or Diana.  \"Unequal\" refers to the astrological\n"
  "division of day and night, whatever their duration, into twelve\n"
  "parts, which of necessity varied in length with the season.\n"
  "\n"
  "65. Smoking: draping; hence the word \"smock;\" \"smokless,\" in\n"
  "Chaucer, means naked.\n"
  "\n"
  "66. Cerrial: of the species of oak which Pliny, in his \"Natural\n"
  "History,\" calls \"cerrus.\"\n"
  "\n"
  "67. Stace of Thebes: Statius, the Roman who embodied in the\n"
  "twelve books of his \"Thebaid\" the ancient legends connected\n"
  "with the war of the seven against Thebes.\n"
  "\n"
  "68. Diana was Luna in heaven, Diana on earth, and Hecate in\n"
  "hell; hence the direction of the eyes of her statue to \"Pluto's\n"
  "dark region.\"  Her statue was set up where three ways met, so\n"
  "that with a different face she looked down each of the three;\n"
  "from which she was called Trivia. See the quotation from\n"
  "Horace, note 54.\n"
  "\n"
  "69. Las: net; the invisible toils in which Hephaestus caught Ares\n"
  "and the faithless Aphrodite, and exposed them to the\n"
  "\"inextinguishable laughter\" of Olympus.\n"
  "\n"
  "70. Saturnus the cold: Here, as in \"Mars the Red\" we have the\n"
  "person of the deity endowed with the supposed quality of the\n"
  "planet called after his name.\n"
  "\n"
  "71. The astrologers ascribed great power to Saturn, and\n"
  "predicted \"much debate\" under his ascendancy; hence it was\n"
  "\"against his kind\" to compose the heavenly strife.\n"
  "\n"
  "72. Ayel: grandfather; French \"Aieul\".\n"
  "\n"
  "73. Testers: Helmets; from the French \"teste\", \"tete\", head.\n"
  "\n"
  "74. Parements: ornamental garb, French \"parer\" to deck.\n"
  "\n"
  "75. Gniding: Rubbing, polishing; Anglo-Saxon \"gnidan\", to rub.\n"
  "\n"
  "76. Nakeres: Drums, used in the cavalry; Boccaccio's word is\n"
  "\"nachere\".\n"
  "\n"
  "77. Made an O: Ho! Ho! to command attention; like \"oyez\", the\n"
  "call for silence in law-courts or before proclamations.\n"
  "\n"
  "78. Sarge: serge, a coarse woollen cloth\n"
  "\n"
  "79. Heart-spoon: The concave part of the breast, where the\n"
  "lower ribs join the cartilago ensiformis.\n"
  "\n"
  "80. To-hewen and to-shred:  \"to\" before a verb implies\n"
  "extraordinary violence in the action denoted.\n"
  "\n"
  "81. He through the thickest of the throng etc.. \"He\" in this\n"
  "passage refers impersonally to any of the combatants.\n"
  "\n"
  "82. Galaphay: Galapha, in Mauritania.\n"
  "\n"
  "83. Belmarie is supposed to have been a Moorish state in\n"
  "Africa; but \"Palmyrie\" has been suggested as the correct\n"
  "reading.\n"
  "\n"
  "84. As I came never I cannot telle where: Where it went I\n"
  "cannot tell you, as I was not there.  Tyrwhitt thinks that\n"
  "Chaucer is sneering at Boccacio's pompous account of the\n"
  "passage of Arcite's soul to heaven. Up to this point, the\n"
  "description of the death-scene is taken literally from the\n"
  "\"Theseida.\"\n"
  "\n"
  "85. With sluttery beard, and ruggy ashy hairs: With neglected\n"
  "beard, and rough hair strewn with ashes. \"Flotery\" is the general\n"
  "reading; but \"sluttery\" seems to be more in keeping with the\n"
  "picture of abandonment to grief.\n"
  "\n"
  "86. Master street: main street; so Froissart speaks of \"le\n"
  "souverain carrefour.\"\n"
  "\n"
  "87. Y-wrie: covered, hid; Anglo-Saxon, \"wrigan,\" to veil.\n"
  "\n"
  "88. Emily applied the funeral torch. The \"guise\" was, among the\n"
  "ancients, for the nearest relative of the deceased to do this, with\n"
  "averted face.\n"
  "\n"
  "89. It was the custom for soldiers to march thrice around the\n"
  "funeral pile of an emperor or general; \"on the left hand\" is\n"
  "added, in reference to the belief that the left hand was\n"
  "propitious -- the Roman augur turning his face southward, and\n"
  "so placing on his left hand the east, whence good omens came.\n"
  "With the Greeks, however, their augurs facing the north, it was\n"
  "just the contrary. The confusion, frequent in classical writers, is\n"
  "complicated here by the fact that Chaucer's description of the\n"
  "funeral of Arcite is taken from Statius' \"Thebaid\" -- from a\n"
  "Roman's account of a Greek solemnity.\n"
  "\n"
  "90. Lyke-wake: watching by the remains of the dead; from\n"
  "Anglo-Saxon, \"lice,\" a corpse; German, \"Leichnam.\"\n"
  "\n"
  "91. Chaucer here borrows from Boethius, who says:\n"
  "\"Hanc rerum seriem ligat,\n"
  "Terras ac pelagus regens,\n"
  "Et coelo imperitans, amor.\"\n"
  "(Love ties these things together: the earth, and the ruling sea,\n"
  "and the imperial heavens)\n"
  "\n"
  "\n"
  "\n"
  "";
// }

const char millersTale0[] PGMSECTION = // { // 21442 bytes
  "THE MILLER'S TALE.\n"
  "\n"
  "\n"
  "THE PROLOGUE.\n"
  "\n"
  "\n"
  "When that the Knight had thus his tale told\n"
  "In all the rout was neither young nor old,\n"
  "That he not said it was a noble story,\n"
  "And worthy to be *drawen to memory*;                          *recorded*\n"
  "And *namely the gentles* every one.          *especially the gentlefolk*\n"
  "Our Host then laugh'd and swore, \"So may I gon,*                *prosper\n"
  "This goes aright; *unbuckled is the mail;*        *the budget is opened*\n"
  "Let see now who shall tell another tale:\n"
  "For truely this game is well begun.\n"
  "Now telleth ye, Sir Monk, if that ye conne*,                       *know\n"
  "Somewhat, to quiten* with the Knighte's tale.\"                    *match\n"
  "The Miller that fordrunken was all pale,\n"
  "So that unnethes* upon his horse he sat,                *with difficulty\n"
  "He would avalen* neither hood nor hat,                          *uncover\n"
  "Nor abide* no man for his courtesy,                         *give way to\n"
  "But in Pilate's voice<1> he gan to cry,\n"
  "And swore by armes, and by blood, and bones,\n"
  "\"I can a noble tale for the nones*                            *occasion,\n"
  "With which I will now quite* the Knighte's tale.\"                 *match\n"
  "Our Host saw well how drunk he was of ale,\n"
  "And said; \"Robin, abide, my leve* brother,                         *dear\n"
  "Some better man shall tell us first another:\n"
  "Abide, and let us worke thriftily.\"\n"
  "By Godde's soul,\" quoth he, \"that will not I,\n"
  "For I will speak, or elles go my way!\"\n"
  "Our Host answer'd; \"*Tell on a devil way*;             *devil take you!*\n"
  "Thou art a fool; thy wit is overcome.\"\n"
  "\"Now hearken,\" quoth the Miller, \"all and some:\n"
  "But first I make a protestatioun.\n"
  "That I am drunk, I know it by my soun':\n"
  "And therefore if that I misspeak or say,\n"
  "*Wite it* the ale of Southwark, I you pray:             *blame it on*<2>\n"
  "For I will tell a legend and a life\n"
  "Both of a carpenter and of his wife,\n"
  "How that a clerk hath *set the wrighte's cap*.\"   *fooled the carpenter*\n"
  "The Reeve answer'd and saide, \"*Stint thy clap*,      *hold your tongue*\n"
  "Let be thy lewed drunken harlotry.\n"
  "It is a sin, and eke a great folly\n"
  "To apeiren* any man, or him defame,                              *injure\n"
  "And eke to bringe wives in evil name.\n"
  "Thou may'st enough of other thinges sayn.\"\n"
  "This drunken Miller spake full soon again,\n"
  "And saide, \"Leve brother Osewold,\n"
  "Who hath no wife, he is no cuckold.\n"
  "But I say not therefore that thou art one;\n"
  "There be full goode wives many one.\n"
  "Why art thou angry with my tale now?\n"
  "I have a wife, pardie, as well as thou,\n"
  "Yet *n'old I*, for the oxen in my plough,                  *I would not*\n"
  "Taken upon me more than enough,\n"
  "To deemen* of myself that I am one;                               *judge\n"
  "I will believe well that I am none.\n"
  "An husband should not be inquisitive\n"
  "Of Godde's privity, nor of his wife.\n"
  "So he may finde Godde's foison* there,                         *treasure\n"
  "Of the remnant needeth not to enquere.\"\n"
  "\n"
  "What should I more say, but that this Millere\n"
  "He would his wordes for no man forbear,\n"
  "But told his churlish* tale in his mannere;               *boorish, rude\n"
  "Me thinketh, that I shall rehearse it here.\n"
  "And therefore every gentle wight I pray,\n"
  "For Godde's love to deem not that I say\n"
  "Of evil intent, but that I must rehearse\n"
  "Their tales all, be they better or worse,\n"
  "Or elles falsen* some of my mattere.                            *falsify\n"
  "And therefore whoso list it not to hear,\n"
  "Turn o'er the leaf, and choose another tale;\n"
  "For he shall find enough, both great and smale,\n"
  "Of storial* thing that toucheth gentiless,             *historical, true\n"
  "And eke morality and holiness.\n"
  "Blame not me, if that ye choose amiss.\n"
  "The Miller is a churl, ye know well this,\n"
  "So was the Reeve, with many other mo',\n"
  "And harlotry* they tolde bothe two.                        *ribald tales\n"
  "*Avise you* now, and put me out of blame;                    *be warned*\n"
  "And eke men should not make earnest of game*.                 *jest, fun\n"
  "\n"
  "\n"
  "Notes to the Prologue to the Miller's Tale\n"
  "\n"
  "1. Pilate, an unpopular personage in the mystery-plays of the\n"
  "middle ages, was probably represented as having a gruff, harsh\n"
  "voice.\n"
  "\n"
  "2. Wite: blame; in Scotland, \"to bear the wyte,\" is to bear the\n"
  "blame.\n"
  "\n"
  "\n"
  "THE TALE.\n"
  "\n"
  "\n"
  "Whilom there was dwelling in Oxenford\n"
  "A riche gnof*, that *guestes held to board*,   *miser *took in boarders*\n"
  "And of his craft he was a carpenter.\n"
  "With him there was dwelling a poor scholer,\n"
  "Had learned art, but all his fantasy\n"
  "Was turned for to learn astrology.\n"
  "He coude* a certain of conclusions                                 *knew\n"
  "To deeme* by interrogations,                                  *determine\n"
  "If that men asked him in certain hours,\n"
  "When that men should have drought or elles show'rs:\n"
  "Or if men asked him what shoulde fall\n"
  "Of everything, I may not reckon all.\n"
  "\n"
  "This clerk was called Hendy* Nicholas;                 *gentle, handsome\n"
  "Of derne* love he knew and of solace;                   *secret, earnest\n"
  "And therewith he was sly and full privy,\n"
  "And like a maiden meek for to see.\n"
  "A chamber had he in that hostelry\n"
  "Alone, withouten any company,\n"
  "Full *fetisly y-dight* with herbes swoot*,            *neatly decorated*\n"
  "And he himself was sweet as is the root                           *sweet\n"
  "Of liquorice, or any setewall*.                                *valerian\n"
  "His Almagest,<1> and bookes great and small,\n"
  "His astrolabe,<2>  belonging to his art,\n"
  "His augrim stones,<3> layed fair apart\n"
  "On shelves couched* at his bedde's head,                      *laid, set\n"
  "His press y-cover'd with a falding* red.                   *coarse cloth\n"
  "And all above there lay a gay psalt'ry\n"
  "On which he made at nightes melody,\n"
  "So sweetely, that all the chamber rang:\n"
  "And Angelus ad virginem<4> he sang.\n"
  "And after that he sung the kinge's note;\n"
  "Full often blessed was his merry throat.\n"
  "And thus this sweete clerk his time spent\n"
  "After *his friendes finding and his rent.*    *Attending to his friends,\n"
  "                                                   and providing for the\n"
  "                                                    cost of his lodging*\n"
  "This carpenter had wedded new a wife,\n"
  "Which that he loved more than his life:\n"
  "Of eighteen year, I guess, she was of age.\n"
  "Jealous he was, and held her narr'w in cage,\n"
  "For she was wild and young, and he was old,\n"
  "And deemed himself belike* a cuckold.                           *perhaps\n"
  "He knew not Cato,<5> for his wit was rude,\n"
  "That bade a man wed his similitude.\n"
  "Men shoulde wedden after their estate,\n"
  "For youth and eld* are often at debate.                             *age\n"
  "But since that he was fallen in the snare,\n"
  "He must endure (as other folk) his care.\n"
  "Fair was this younge wife, and therewithal\n"
  "As any weasel her body gent* and small.                      *slim, neat\n"
  "A seint* she weared, barred all of silk,                         *girdle\n"
  "A barm-cloth* eke as white as morning milk                     *apron<6>\n"
  "Upon her lendes*, full of many a gore**.                  *loins **plait\n"
  "White was her smock*, and broider'd all before,            *robe or gown\n"
  "And eke behind, on her collar about\n"
  "Of coal-black silk, within and eke without.\n"
  "The tapes of her white volupere*                      *head-kerchief <7>\n"
  "Were of the same suit of her collere;\n"
  "Her fillet broad of silk, and set full high:\n"
  "And sickerly* she had a likerous** eye.          *certainly **lascivious\n"
  "Full small y-pulled were her browes two,\n"
  "And they were bent*, and black as any sloe.                      *arched\n"
  "She was well more *blissful on to see*           *pleasant to look upon*\n"
  "Than is the newe perjenete* tree;                       *young pear-tree\n"
  "And softer than the wool is of a wether.\n"
  "And by her girdle hung a purse of leather,\n"
  "Tassel'd with silk, and *pearled with latoun*.   *set with brass pearls*\n"
  "In all this world to seeken up and down\n"
  "There is no man so wise, that coude thenche*            *fancy, think of\n"
  "So gay a popelot*, or such a wench.                          *puppet <8>\n"
  "Full brighter was the shining of her hue,\n"
  "Than in the Tower the noble* forged new.                *a gold coin <9>\n"
  "But of her song, it was as loud and yern*,                  *lively <10>\n"
  "As any swallow chittering on a bern*.                              *barn\n"
  "Thereto* she coulde skip, and *make a game*                 *also *romp*\n"
  "As any kid or calf following his dame.\n"
  "Her mouth was sweet as braket,<11> or as methe*                    *mead\n"
  "Or hoard of apples, laid in hay or heath.\n"
  "Wincing* she was as is a jolly colt,                           *skittish\n"
  "Long as a mast, and upright as a bolt.\n"
  "A brooch she bare upon her low collere,\n"
  "As broad as is the boss of a bucklere.\n"
  "Her shoon were laced on her legges high;\n"
  "She was a primerole,* a piggesnie <12>,                        *primrose\n"
  "For any lord t' have ligging* in his bed,                         *lying\n"
  "Or yet for any good yeoman to wed.\n"
  "\n"
  "Now, sir, and eft* sir, so befell the case,                       *again\n"
  "That on a day this Hendy Nicholas\n"
  "Fell with this younge wife to rage* and play,       *toy, play the rogue\n"
  "While that her husband was at Oseney,<13>\n"
  "As clerkes be full subtle and full quaint.\n"
  "And privily he caught her by the queint,*                          *cunt\n"
  "And said; \"Y-wis,* but if I have my will,                     *assuredly\n"
  "For *derne love of thee, leman, I spill.\"*     *for earnest love of thee\n"
  "And helde her fast by the haunche bones,          my mistress, I perish*\n"
  "And saide \"Leman, love me well at once,\n"
  "Or I will dien, all so God me save.\"\n"
  "And she sprang as a colt doth in the trave<14>:\n"
  "And with her head she writhed fast away,\n"
  "And said; \"I will not kiss thee, by my fay*.                      *faith\n"
  "Why let be,\" quoth she, \"let be, Nicholas,\n"
  "Or I will cry out harow and alas!<15>\n"
  "Do away your handes, for your courtesy.\"\n"
  "This Nicholas gan mercy for to cry,\n"
  "And spake so fair, and proffer'd him so fast,\n"
  "That she her love him granted at the last,\n"
  "And swore her oath by Saint Thomas of Kent,\n"
  "That she would be at his commandement,\n"
  "When that she may her leisure well espy.\n"
  "\"My husband is so full of jealousy,\n"
  "That but* ye waite well, and be privy,                           *unless\n"
  "I wot right well I am but dead,\" quoth she.\n"
  "\"Ye muste be full derne* as in this case.\"                       *secret\n"
  "\"Nay, thereof care thee nought,\" quoth Nicholas:\n"
  "\"A clerk had *litherly beset his while*,            *ill spent his time*\n"
  "*But if* he could a carpenter beguile.\"                          *unless\n"
  "And thus they were accorded and y-sworn\n"
  "To wait a time, as I have said beforn.\n"
  "When Nicholas had done thus every deal*,                           *whit\n"
  "And thwacked her about the lendes* well,                          *loins\n"
  "He kiss'd her sweet, and taketh his psalt'ry\n"
  "And playeth fast, and maketh melody.\n"
  "Then fell it thus, that to the parish church,\n"
  "Of Christe's owen workes for to wirch*,                            *work\n"
  "This good wife went upon a holy day;\n"
  "Her forehead shone as bright as any day,\n"
  "So was it washen, when she left her werk.\n"
  "\n"
  "Now was there of that church a parish clerk,\n"
  "The which that was y-cleped Absolon.\n"
  "Curl'd was his hair, and as the gold it shone,\n"
  "And strutted* as a fanne large and broad;                     *stretched\n"
  "Full straight and even lay his jolly shode*.               *head of hair\n"
  "His rode* was red, his eyen grey as goose,                   *complexion\n"
  "With Paule's windows carven on his shoes <16>\n"
  "In hosen red he went full fetisly*.                    *daintily, neatly\n"
  "Y-clad he was full small and properly,\n"
  "All in a kirtle* of a light waget*;                   *girdle **sky blue\n"
  "Full fair and thicke be the pointes set,\n"
  "And thereupon he had a gay surplice,\n"
  "As white as is the blossom on the rise*.                      *twig <17>\n"
  "A merry child he was, so God me save;\n"
  "Well could he letten blood, and clip, and shave,\n"
  "And make a charter of land, and a quittance.\n"
  "In twenty manners could he trip and dance,\n"
  "After the school of Oxenforde tho*,<18>                            *then\n"
  "And with his legges caste to and fro;\n"
  "And playen songes on a small ribible*;                           *fiddle\n"
  "Thereto he sung sometimes a loud quinible*                       *treble\n"
  "And as well could he play on a gitern.*                          *guitar\n"
  "In all the town was brewhouse nor tavern,\n"
  "That he not visited with his solas*,                       *mirth, sport\n"
  "There as that any *garnard tapstere* was.           *licentious barmaid*\n"
  "But sooth to say he was somedeal squaimous*                   *squeamish\n"
  "Of farting, and of speeche dangerous.\n"
  "This Absolon, that jolly was and gay,\n"
  "Went with a censer on the holy day,\n"
  "Censing* the wives of the parish fast;              *burning incense for\n"
  "And many a lovely look he on them cast,\n"
  "And namely* on this carpenter's wife:                        *especially\n"
  "To look on her him thought a merry life.\n"
  "She was so proper, and sweet, and likerous.\n"
  "I dare well say, if she had been a mouse,\n"
  "And he a cat, he would *her hent anon*.           *have soon caught her*\n"
  "This parish clerk, this jolly Absolon,\n"
  "Hath in his hearte such a love-longing!\n"
  "That of no wife took he none offering;\n"
  "For courtesy he said he woulde none.\n"
  "The moon at night full clear and brighte shone,\n"
  "And Absolon his gitern hath y-taken,\n"
  "For paramours he thoughte for to waken,\n"
  "And forth he went, jolif* and amorous,                           *joyous\n"
  "Till he came to the carpentere's house,\n"
  "A little after the cock had y-crow,\n"
  "And *dressed him* under a shot window <19>,         *stationed himself.*\n"
  "That was upon the carpentere's wall.\n"
  "He singeth in his voice gentle and small;\n"
  "\"Now, dear lady, if thy will be,\n"
  "I pray that ye will rue* on me;\"                              *take pity\n"
  "Full well accordant to his giterning.\n"
  "This carpenter awoke, and heard him sing,\n"
  "And spake unto his wife, and said anon,\n"
  "What Alison, hear'st thou not Absolon,\n"
  "That chanteth thus under our bower* wall?\"                      *chamber\n"
  "And she answer'd her husband therewithal;\n"
  "\"Yes, God wot, John, I hear him every deal.\"\n"
  "This passeth forth; what will ye bet* than well?                 *better\n"
  "\n"
  "From day to day this jolly Absolon\n"
  "So wooeth her, that him is woebegone.\n"
  "He waketh all the night, and all the day,\n"
  "To comb his lockes broad, and make him gay.\n"
  "He wooeth her *by means and by brocage*,     *by presents and by agents*\n"
  "And swore he woulde be her owen page.\n"
  "He singeth brokking* as a nightingale.                        *quavering\n"
  "He sent her piment <20>, mead, and spiced ale,\n"
  "And wafers* piping hot out of the glede**:                *cakes **coals\n"
  "And, for she was of town, he proffer'd meed.<21>\n"
  "For some folk will be wonnen for richess,\n"
  "And some for strokes, and some with gentiless.\n"
  "Sometimes, to show his lightness and mast'ry,\n"
  "He playeth Herod <22> on a scaffold high.\n"
  "But what availeth him as in this case?\n"
  "So loveth she the Hendy Nicholas,\n"
  "That Absolon may *blow the bucke's horn*:                 *\"go whistle\"*\n"
  "He had for all his labour but a scorn.\n"
  "And thus she maketh Absolon her ape,\n"
  "And all his earnest turneth to a jape*.                            *jest\n"
  "Full sooth is this proverb, it is no lie;\n"
  "Men say right thus alway; the nighe sly\n"
  "Maketh oft time the far lief to be loth. <23>\n"
  "For though that Absolon be wood* or wroth                           *mad\n"
  "Because that he far was from her sight,\n"
  "This nigh Nicholas stood still in his light.\n"
  "Now bear thee well, thou Hendy Nicholas,\n"
  "For Absolon may wail and sing \"Alas!\"\n"
  "\n"
  "And so befell, that on a Saturday\n"
  "This carpenter was gone to Oseney,\n"
  "And Hendy Nicholas and Alison\n"
  "Accorded were to this conclusion,\n"
  "That Nicholas shall *shape him a wile*              *devise a stratagem*\n"
  "The silly jealous husband to beguile;\n"
  "And if so were the game went aright,\n"
  "She shoulde sleepen in his arms all night;\n"
  "For this was her desire and his also.\n"
  "And right anon, withoute wordes mo',\n"
  "This Nicholas no longer would he tarry,\n"
  "But doth full soft unto his chamber carry\n"
  "Both meat and drinke for a day or tway.\n"
  "And to her husband bade her for to say,\n"
  "If that he asked after Nicholas,\n"
  "She shoulde say, \"She wist* not where he was;                      *knew\n"
  "Of all the day she saw him not with eye;\n"
  "She trowed* he was in some malady,                             *believed\n"
  "For no cry that her maiden could him call\n"
  "He would answer, for nought that might befall.\"\n"
  "Thus passed forth all thilke* Saturday,                            *that\n"
  "That Nicholas still in his chamber lay,\n"
  "And ate, and slept, and didde what him list\n"
  "Till Sunday, that* the sunne went to rest.                         *when\n"
  "This silly carpenter *had great marvaill*             *wondered greatly*\n"
  "Of Nicholas, or what thing might him ail,\n"
  "And said; \"I am adrad*, by Saint Thomas!               *afraid, in dread\n"
  "It standeth not aright with Nicholas:\n"
  "*God shielde* that he died suddenly.                    *heaven forbid!*\n"
  "This world is now full fickle sickerly*.                      *certainly\n"
  "I saw to-day a corpse y-borne to chirch,\n"
  "That now on Monday last I saw him wirch*.                          *work\n"
  "\"Go up,\" quod he unto his knave*, \"anon;                       *servant.\n"
  "Clepe* at his door, or knocke with a stone:                        *call\n"
  "Look how it is, and tell me boldely.\"\n"
  "This knave went him up full sturdily,\n"
  "And, at the chamber door while that he stood,\n"
  "He cried and knocked as that he were wood:*                         *mad\n"
  "\"What how? what do ye, Master Nicholay?\n"
  "How may ye sleepen all the longe day?\"\n"
  "But all for nought, he hearde not a word.\n"
  "An hole he found full low upon the board,\n"
  "Where as the cat was wont in for to creep,\n"
  "And at that hole he looked in full deep,\n"
  "And at the last he had of him a sight.\n"
  "This Nicholas sat ever gaping upright,\n"
  "As he had kyked* on the newe moon.                          *looked <24>\n"
  "Adown he went, and told his master soon,\n"
  "In what array he saw this ilke* man.                               *same\n"
  "\n"
  "This carpenter to *blissen him* began,            *bless, cross himself*\n"
  "And said: \"Now help us, Sainte Frideswide.<25>\n"
  "A man wot* little what shall him betide.                          *knows\n"
  "This man is fall'n with his astronomy\n"
  "Into some woodness* or some agony.                              *madness\n"
  "I thought aye well how that it shoulde be.\n"
  "Men should know nought of Godde's privity*.                     *secrets\n"
  "Yea, blessed be alway a lewed* man,                           *unlearned\n"
  "That *nought but only his believe can*.                   *knows no more\n"
  "So far'd another clerk with astronomy:                than his \"credo.\"*\n"
  "He walked in the fieldes for to *pry\n"
  "Upon* the starres, what there should befall,             *keep watch on*\n"
  "Till he was in a marle pit y-fall.<26>\n"
  "He saw not that. But yet, by Saint Thomas!\n"
  "*Me rueth sore of*  Hendy Nicholas:                *I am very sorry for*\n"
  "He shall be *rated of* his studying,                       *chidden for*\n"
  "If that I may, by Jesus, heaven's king!\n"
  "Get me a staff, that I may underspore*                         *lever up\n"
  "While that thou, Robin, heavest off the door:\n"
  "He shall out of his studying, as I guess.\"\n"
  "And to the chamber door he gan him dress*                *apply himself.\n"
  "His knave was a strong carl for the nonce,\n"
  "And by the hasp he heav'd it off at once;\n"
  "Into the floor the door fell down anon.\n"
  "This Nicholas sat aye as still as stone,\n"
  "And ever he gap'd upward into the air.\n"
  "The carpenter ween'd* he were in despair,                       *thought\n"
  "And hent* him by the shoulders mightily,                         *caught\n"
  "And shook him hard, and cried spitously;*                       *angrily\n"
  "\"What, Nicholas? what how, man? look adown:\n"
  "Awake, and think on Christe's passioun.\n"
  "I crouche thee<27> from elves, and from wights*.                *witches\n"
  "Therewith the night-spell said he anon rights*,                *properly\n"
  "On the four halves* of the house about,                         *corners\n"
  "And on the threshold of the door without.\n"
  "\"Lord Jesus Christ, and Sainte Benedight,\n"
  "Blesse this house from every wicked wight,\n"
  "From the night mare, the white Pater-noster;\n"
  "Where wonnest* thou now, Sainte Peter's sister?\"               *dwellest\n"
  "And at the last this Hendy Nicholas\n"
  "Gan for to sigh full sore, and said; \"Alas!\n"
  "Shall all time world be lost eftsoones* now?\"                 *forthwith\n"
  "This carpenter answer'd; \"What sayest thou?\n"
  "What? think on God, as we do, men that swink.*\"                  *labour\n"
  "This Nicholas answer'd; \"Fetch me a drink;\n"
  "And after will I speak in privity\n"
  "Of certain thing that toucheth thee and me:\n"
  "I will tell it no other man certain.\"\n"
  "\n"
  "This carpenter went down, and came again,\n"
  "And brought of mighty ale a large quart;\n"
  "And when that each of them had drunk his part,\n"
  "This Nicholas his chamber door fast shet*,                         *shut\n"
  "And down the carpenter by him he set,\n"
  "And saide; \"John, mine host full lief* and dear,                  *loved\n"
  "Thou shalt upon thy truthe swear me here,\n"
  "That to no wight thou shalt my counsel wray*:                    *betray\n"
  "For it is Christes counsel that I say,\n"
  "And if thou tell it man, thou art forlore:*                    *lost<28>\n"
  "For this vengeance thou shalt have therefor,\n"
  "That if thou wraye* me, thou shalt be wood**.\"             *betray **mad\n"
  "\"Nay, Christ forbid it for his holy blood!\"\n"
  "Quoth then this silly man; \"I am no blab,*                       *talker\n"
  "Nor, though I say it, am I *lief to gab*.               *fond of speech*\n"
  "Say what thou wilt, I shall it never tell\n"
  "To child or wife, by him that harried Hell.\"                        <29>\n"
  "\n"
  "";
// }

const char millersTale1[] PGMSECTION = // { // 23070 bytes
  "\"Now, John,\" quoth Nicholas, \"I will not lie,\n"
  "I have y-found in my astrology,\n"
  "As I have looked in the moone bright,\n"
  "That now on Monday next, at quarter night,\n"
  "Shall fall a rain, and that so wild and wood*,                      *mad\n"
  "That never half so great was Noe's flood.\n"
  "This world,\" he said, \"in less than half an hour\n"
  "Shall all be dreint*, so hideous is the shower:                 *drowned\n"
  "Thus shall mankinde drench*, and lose their life.\"                *drown\n"
  "This carpenter answer'd; \"Alas, my wife!\n"
  "And shall she drench? alas, mine Alisoun!\"\n"
  "For sorrow of this he fell almost adown,\n"
  "And said; \"Is there no remedy in this case?\"\n"
  "\"Why, yes, for God,\" quoth Hendy Nicholas;\n"
  "\"If thou wilt worken after *lore and rede*;        *learning and advice*\n"
  "Thou may'st not worken after thine own head.\n"
  "For thus saith Solomon, that was full true:\n"
  "Work all by counsel, and thou shalt not rue*.                    *repent\n"
  "And if thou worke wilt by good counseil,\n"
  "I undertake, withoute mast or sail,\n"
  "Yet shall I save her, and thee, and me.\n"
  "Hast thou not heard how saved was Noe,\n"
  "When that our Lord had warned him beforn,\n"
  "That all the world with water *should be lorn*?\"         *should perish*\n"
  "\"Yes,\" quoth this carpenter,\" *full yore ago*.\"             *long since*\n"
  "\"Hast thou not heard,\" quoth Nicholas, \"also\n"
  "The sorrow of Noe, with his fellowship,\n"
  "That he had ere he got his wife to ship?<30>\n"
  "*Him had been lever, I dare well undertake,\n"
  "At thilke time, than all his wethers black,\n"
  "That she had had a ship herself alone.*                   *see note <31>\n"
  "And therefore know'st thou what is best to be done?\n"
  "This asketh haste, and of an hasty thing\n"
  "Men may not preach or make tarrying.\n"
  "Anon go get us fast into this inn*                                *house\n"
  "A kneading trough, or else a kemelin*,                      *brewing-tub\n"
  "For each of us; but look that they be large,\n"
  "In whiche we may swim* as in a barge:                             *float\n"
  "And have therein vitaille suffisant\n"
  "But for one day; fie on the remenant;\n"
  "The water shall aslake* and go away                      *slacken, abate\n"
  "Aboute prime* upon the nexte day.                         *early morning\n"
  "But Robin may not know of this, thy knave*,                     *servant\n"
  "Nor eke thy maiden Gill I may not save:\n"
  "Ask me not why: for though thou aske me\n"
  "I will not telle Godde's privity.\n"
  "Sufficeth thee, *but if thy wit be mad*,                 *unless thou be\n"
  "To have as great a grace as Noe had;                    out of thy wits*\n"
  "Thy wife shall I well saven out of doubt.\n"
  "Go now thy way, and speed thee hereabout.\n"
  "But when thou hast for her, and thee, and me,\n"
  "Y-gotten us these kneading tubbes three,\n"
  "Then shalt thou hang them in the roof full high,\n"
  "So that no man our purveyance* espy:              *foresight, providence\n"
  "And when thou hast done thus as I have said,\n"
  "And hast our vitaille fair in them y-laid,\n"
  "And eke an axe to smite the cord in two\n"
  "When that the water comes, that we may go,\n"
  "And break an hole on high upon the gable\n"
  "Into the garden-ward, over the stable,\n"
  "That we may freely passe forth our way,\n"
  "When that the greate shower is gone away.\n"
  "Then shalt thou swim as merry, I undertake,\n"
  "As doth the white duck after her drake:\n"
  "Then will I clepe,* 'How, Alison? How, John?                       *call\n"
  "Be merry: for the flood will pass anon.'\n"
  "And thou wilt say, 'Hail, Master Nicholay,\n"
  "Good-morrow, I see thee well, for it is day.'\n"
  "And then shall we be lordes all our life\n"
  "Of all the world, as Noe and his wife.\n"
  "But of one thing I warne thee full right,\n"
  "Be well advised, on that ilke* night,                              *same\n"
  "When we be enter'd into shippe's board,\n"
  "That none of us not speak a single word,\n"
  "Nor clepe nor cry, but be in his prayere,\n"
  "For that is Godde's owen heste* dear.                           *command\n"
  "Thy wife and thou must hangen far atween*,                      *asunder\n"
  "For that betwixte you shall be no sin,\n"
  "No more in looking than there shall in deed.\n"
  "This ordinance is said: go, God thee speed\n"
  "To-morrow night, when men be all asleep,\n"
  "Into our kneading tubbes will we creep,\n"
  "And sitte there, abiding Godde's grace.\n"
  "Go now thy way, I have no longer space\n"
  "To make of this no longer sermoning:\n"
  "Men say thus: Send the wise, and say nothing:\n"
  "Thou art so wise, it needeth thee nought teach.\n"
  "Go, save our lives, and that I thee beseech.\"\n"
  "\n"
  "This silly carpenter went forth his way,\n"
  "Full oft he said, \"Alas! and Well-a-day!,'\n"
  "And to his wife he told his privity,\n"
  "And she was ware, and better knew than he\n"
  "What all this *quainte cast was for to say*.        *strange contrivance\n"
  "But natheless she fear'd as she would dey,                        meant*\n"
  "And said: \"Alas! go forth thy way anon.\n"
  "Help us to scape, or we be dead each one.\n"
  "I am thy true and very wedded wife;\n"
  "Go, deare spouse, and help to save our life.\"\n"
  "Lo, what a great thing is affection!\n"
  "Men may die of imagination,\n"
  "So deeply may impression be take.\n"
  "This silly carpenter begins to quake:\n"
  "He thinketh verily that he may see\n"
  "This newe flood come weltering as the sea\n"
  "To drenchen* Alison, his honey dear.                              *drown\n"
  "He weepeth, waileth, maketh *sorry cheer*;          *dismal countenance*\n"
  "He sigheth, with full many a sorry sough.*                        *groan\n"
  "He go'th, and getteth him a kneading trough,\n"
  "And after that a tub, and a kemelin,\n"
  "And privily he sent them to his inn:\n"
  "And hung them in the roof full privily.\n"
  "With his own hand then made he ladders three,\n"
  "To climbe by *the ranges and the stalks*    *the rungs and the uprights*\n"
  "Unto the tubbes hanging in the balks*;                            *beams\n"
  "And victualed them, kemelin, trough, and tub,\n"
  "With bread and cheese, and good ale in a jub*,                      *jug\n"
  "Sufficing right enough as for a day.\n"
  "But ere that he had made all this array,\n"
  "He sent his knave*, and eke his wench** also,            *servant **maid\n"
  "Upon his need* to London for to go.                            *business\n"
  "And on the Monday, when it drew to night,\n"
  "He shut his door withoute candle light,\n"
  "And dressed* every thing as it should be.                      *prepared\n"
  "And shortly up they climbed all the three.\n"
  "They satte stille well *a furlong way*.          *the time it would take\n"
  "\"Now, Pater noster, clum,\"<32> said Nicholay,         to walk a furlong*\n"
  "And \"clum,\" quoth John; and \"clum,\" said Alison:\n"
  "This carpenter said his devotion,\n"
  "And still he sat and bidded his prayere,\n"
  "Awaking on the rain, if he it hear.\n"
  "The deade sleep, for weary business,\n"
  "Fell on this carpenter, right as I guess,\n"
  "About the curfew-time,<33> or little more,\n"
  "For *travail of his ghost* he groaned sore,          *anguish of spirit*\n"
  "*And eft he routed, for his head mislay.*           *and then he snored,\n"
  "Adown the ladder stalked Nicholay;                for his head lay awry*\n"
  "And Alison full soft adown she sped.\n"
  "Withoute wordes more they went to bed,\n"
  "*There as* the carpenter was wont to lie:                        *where*\n"
  "There was the revel, and the melody.\n"
  "And thus lay Alison and Nicholas,\n"
  "In business of mirth and in solace,\n"
  "Until the bell of laudes* gan to ring,       *morning service, at 3.a.m.\n"
  "And friars in the chancel went to sing.\n"
  "\n"
  "This parish clerk, this amorous Absolon,\n"
  "That is for love alway so woebegone,\n"
  "Upon the Monday was at Oseney\n"
  "With company, him to disport and play;\n"
  "And asked upon cas* a cloisterer**                      *occasion **monk\n"
  "Full privily after John the carpenter;\n"
  "And he drew him apart out of the church,\n"
  "And said, \"I n'ot;* I saw him not here wirch**          *know not **work\n"
  "Since Saturday; I trow that he be went\n"
  "For timber, where our abbot hath him sent.\n"
  "And dwellen at the Grange a day or two:\n"
  "For he is wont for timber for to go,\n"
  "Or else he is at his own house certain.\n"
  "Where that he be, I cannot *soothly sayn.*\"              *say certainly*\n"
  "This Absolon full jolly was and light,\n"
  "And thought, \"Now is the time to wake all night,\n"
  "For sickerly* I saw him not stirring                          *certainly\n"
  "About his door, since day began to spring.\n"
  "So may I thrive, but I shall at cock crow\n"
  "Full privily go knock at his window,\n"
  "That stands full low upon his bower* wall:                      *chamber\n"
  "To Alison then will I tellen all\n"
  "My love-longing; for I shall not miss\n"
  "That at the leaste way I shall her kiss.\n"
  "Some manner comfort shall I have, parfay*,                  *by my faith\n"
  "My mouth hath itched all this livelong day:\n"
  "That is a sign of kissing at the least.\n"
  "All night I mette* eke I was at a feast.                         *dreamt\n"
  "Therefore I will go sleep an hour or tway,\n"
  "And all the night then will I wake and play.\"\n"
  "When that the first cock crowed had, anon\n"
  "Up rose this jolly lover Absolon,\n"
  "And him arrayed gay, *at point devise.*                *with exact care*\n"
  "But first he chewed grains<34> and liquorice,\n"
  "To smelle sweet, ere he had combed his hair.\n"
  "Under his tongue a true love <35>  he bare,\n"
  "For thereby thought he to be gracious.\n"
  "\n"
  "Then came he to the carpentere's house,\n"
  "And still he stood under the shot window;\n"
  "Unto his breast it raught*, it was so low;                      *reached\n"
  "And soft he coughed with a semisoun'.*                         *low tone\n"
  "\"What do ye, honeycomb, sweet Alisoun?\n"
  "My faire bird, my sweet cinamome*,                *cinnamon, sweet spice\n"
  "Awaken, leman* mine, and speak to me.                          *mistress\n"
  "Full little thinke ye upon my woe,\n"
  "That for your love I sweat *there as* I go.                    *wherever\n"
  "No wonder is that I do swelt* and sweat.                          *faint\n"
  "I mourn as doth a lamb after the teat\n"
  "Y-wis*, leman, I have such love-longing,                      *certainly\n"
  "That like a turtle* true is my mourning.                    *turtle-dove\n"
  "I may not eat, no more than a maid.\"\n"
  "\"Go from the window, thou jack fool,\" she said:\n"
  "\"As help me God, it will not be, 'come ba* me.'                    *kiss\n"
  "I love another, else I were to blame\",\n"
  "Well better than thee, by Jesus, Absolon.\n"
  "Go forth thy way, or I will cast a stone;\n"
  "And let me sleep; *a twenty devil way*.         *twenty devils take ye!*\n"
  "\"Alas!\" quoth Absolon, \"and well away!\n"
  "That true love ever was so ill beset:\n"
  "Then kiss me, since that it may be no bet*,                      *better\n"
  "For Jesus' love, and for the love of me.\"\n"
  "\"Wilt thou then go thy way therewith?\" , quoth she.\n"
  "\"Yea, certes, leman,\" quoth this Absolon.\n"
  "\"Then make thee ready,\" quoth she, \"I come anon.\"\n"
  "[And unto Nicholas she said *full still*:               *in a low voice*\n"
  "\"Now peace, and thou shalt laugh anon thy fill.\"]<36>\n"
  "This Absolon down set him on his knees,\n"
  "And said; \"I am a lord at all degrees:\n"
  "For after this I hope there cometh more;\n"
  "Leman, thy grace, and, sweete bird, thine ore.*\"                 *favour\n"
  "The window she undid, and that in haste.\n"
  "\"Have done,\" quoth she, \"come off, and speed thee fast,\n"
  "Lest that our neighebours should thee espy.\"\n"
  "Then Absolon gan wipe his mouth full dry.\n"
  "Dark was the night as pitch or as the coal,\n"
  "And at the window she put out her hole,\n"
  "And Absolon him fell ne bet ne werse,\n"
  "But with his mouth he kiss'd her naked erse\n"
  "Full savourly. When he was ware of this,\n"
  "Aback he start, and thought it was amiss;\n"
  "For well he wist a woman hath no beard.\n"
  "He felt a thing all rough, and long y-hair'd,\n"
  "And saide; \"Fy, alas! what have I do?\"\n"
  "\"Te he!\" quoth she, and clapt the window to;\n"
  "And Absolon went forth at sorry pace.\n"
  "\"A beard, a beard,\" said Hendy Nicholas;\n"
  "\"By God's corpus, this game went fair and well.\"\n"
  "This silly Absolon heard every deal*,                              *word\n"
  "And on his lip he gan for anger bite;\n"
  "And to himself he said, \"I shall thee quite*.     *requite, be even with\n"
  "Who rubbeth now, who frotteth* now his lips                        *rubs\n"
  "With dust, with sand, with straw, with cloth, with chips,\n"
  "But Absolon? that saith full oft, \"Alas!\n"
  "My soul betake I unto Sathanas,\n"
  "But me were lever* than all this town,\" quoth he                 *rather\n"
  "I this despite awroken* for to be.                             *revenged\n"
  "Alas! alas! that I have been y-blent*.\"                        *deceived\n"
  "His hote love is cold, and all y-quent.*                       *quenched\n"
  "For from that time that he had kiss'd her erse,\n"
  "Of paramours he *sette not a kers,*                   *cared not a rush*\n"
  "For he was healed of his malady;\n"
  "Full often paramours he gan defy,\n"
  "And weep as doth a child that hath been beat.\n"
  "A softe pace he went over the street\n"
  "Unto a smith, men callen Dan* Gerveis,                           *master\n"
  "That in his forge smithed plough-harness;\n"
  "He sharped share and culter busily.\n"
  "This Absolon knocked all easily,\n"
  "And said; \"Undo, Gerveis, and that anon.\"\n"
  "\"What, who art thou?\" \"It is I, Absolon.\"\n"
  "\"What? Absolon, what? Christe's sweete tree*,                     *cross\n"
  "Why rise so rath*? hey! Benedicite,                               *early\n"
  "What aileth you? some gay girl,<37> God it wote,\n"
  "Hath brought you thus upon the viretote:<38>\n"
  "By Saint Neot, ye wot well what I mean.\"\n"
  "This Absolon he raughte* not a bean                       *recked, cared\n"
  "Of all his play; no word again he gaf*,                           *spoke\n"
  "For he had more tow on his distaff<39>\n"
  "Than Gerveis knew, and saide; \"Friend so dear,\n"
  "That hote culter in the chimney here\n"
  "Lend it to me, I have therewith to don*:                             *do\n"
  "I will it bring again to thee full soon.\"\n"
  "Gerveis answered; \"Certes, were it gold,\n"
  "Or in a poke* nobles all untold,                                  *purse\n"
  "Thou shouldst it have, as I am a true smith.\n"
  "Hey! Christe's foot, what will ye do therewith?\"\n"
  "\"Thereof,\" quoth Absolon, \"be as be may;\n"
  "I shall well tell it thee another day:\"\n"
  "And caught the culter by the colde stele*.                       *handle\n"
  "Full soft out at the door he gan to steal,\n"
  "And went unto the carpentere's wall\n"
  "He coughed first, and knocked therewithal\n"
  "Upon the window, light as he did ere*.                      *before <40>\n"
  "This Alison answered; \"Who is there\n"
  "That knocketh so? I warrant him a thief.\"\n"
  "\"Nay, nay,\" quoth he, \"God wot, my sweete lefe*,                   *love\n"
  "I am thine Absolon, my own darling.\n"
  "Of gold,\" quoth he, \"I have thee brought a ring,\n"
  "My mother gave it me, so God me save!\n"
  "Full fine it is, and thereto well y-grave*:                    *engraved\n"
  "This will I give to thee, if thou me kiss.\"\n"
  "Now Nicholas was risen up to piss,\n"
  "And thought he would *amenden all the jape*;          *improve the joke*\n"
  "He shoulde kiss his erse ere that he scape:\n"
  "And up the window did he hastily,\n"
  "And out his erse he put full privily\n"
  "Over the buttock, to the haunche bone.\n"
  "And therewith spake this clerk, this Absolon,\n"
  "\"Speak, sweete bird, I know not where thou art.\"\n"
  "This Nicholas anon let fly a fart,\n"
  "As great as it had been a thunder dent*;                     *peal, clap\n"
  "That with the stroke he was well nigh y-blent*;                 *blinded\n"
  "But he was ready with his iron hot,\n"
  "And Nicholas amid the erse he smote.\n"
  "Off went the skin an handbreadth all about.\n"
  "The hote culter burned so his tout*,                             *breech\n"
  "That for the smart he weened* he would die;                     *thought\n"
  "As he were wood*, for woe he gan to cry,                            *mad\n"
  "\"Help! water, water, help for Godde's heart!\"\n"
  "\n"
  "This carpenter out of his slumber start,\n"
  "And heard one cry \"Water,\" as he were wood*,                        *mad\n"
  "And thought, \"Alas! now cometh Noe's flood.\"\n"
  "He sat him up withoute wordes mo'\n"
  "And with his axe he smote the cord in two;\n"
  "And down went all; he found neither to sell\n"
  "Nor bread nor ale, till he came to the sell*,            *threshold <41>\n"
  "Upon the floor, and there in swoon he lay.\n"
  "Up started Alison and Nicholay,\n"
  "And cried out an \"harow!\" <15>  in the street.\n"
  "The neighbours alle, bothe small and great\n"
  "In ranne, for to gauren* on this man,                             *stare\n"
  "That yet in swoone lay, both pale and wan:\n"
  "For with the fall he broken had his arm.\n"
  "But stand he must unto his owen harm,\n"
  "For when he spake, he was anon borne down\n"
  "With Hendy Nicholas and Alisoun.\n"
  "They told to every man that he was wood*;                           *mad\n"
  "He was aghaste* so of Noe's flood,                               *afraid\n"
  "Through phantasy, that of his vanity\n"
  "He had y-bought him kneading-tubbes three,\n"
  "And had them hanged in the roof above;\n"
  "And that he prayed them for Godde's love\n"
  "To sitten in the roof for company.\n"
  "The folk gan laughen at his phantasy.\n"
  "Into the roof they kyken* and they gape,                    *peep, look.\n"
  "And turned all his harm into a jape*.                              *jest\n"
  "For whatsoe'er this carpenter answer'd,\n"
  "It was for nought, no man his reason heard.\n"
  "With oathes great he was so sworn adown,\n"
  "That he was holden wood in all the town.\n"
  "For every clerk anon right held with other;\n"
  "They said, \"The man was wood, my leve* brother;\"                   *dear\n"
  "And every wight gan laughen at his strife.\n"
  "Thus swived* was the carpentere's wife,                         *enjoyed\n"
  "For all his keeping* and his jealousy;                             *care\n"
  "And Absolon hath kiss'd her nether eye;\n"
  "And Nicholas is scalded in the tout.\n"
  "This tale is done, and God save all the rout*.                  *company\n"
  "\n"
  "\n"
  "Notes to the Miller's Tale\n"
  "\n"
  "\n"
  "1. Almagest: The book of Ptolemy the astronomer, which\n"
  "formed the canon of astrological science in the middle ages.\n"
  "\n"
  "2. Astrolabe:  \"Astrelagour,\" \"astrelabore\"; a mathematical\n"
  "instrument for taking the altitude of the sun or stars.\n"
  "\n"
  "3. \"Augrim\" is a corruption of algorithm, the Arabian term for\n"
  "numeration; \"augrim stones,\" therefore were probably marked\n"
  "with numerals, and used as counters.\n"
  "\n"
  "4. Angelus ad virginem: The Angel's salutation to Mary; Luke i.\n"
  "28.  It was the \"Ave Maria\" of the Catholic Church service.\n"
  "\n"
  "5. Cato: Though Chaucer may have referred to the famous\n"
  "Censor, more probably the reference is merely to the \"Moral\n"
  "Distichs,\" which go under his name, though written after his\n"
  "time; and in a supplement to which the quoted passage may be\n"
  "found.\n"
  "\n"
  "6. Barm-cloth: apron; from Anglo-Saxon \"barme,\" bosom or\n"
  "lap.\n"
  "\n"
  "7. Volupere: Head-gear, kerchief; from French, \"envelopper,\"\n"
  "to wrap up.\n"
  "\n"
  "8. Popelet:  Puppet; but chiefly; young wench.\n"
  "\n"
  "9. Noble: nobles were gold coins of especial purity and\n"
  "brightness; \"Ex auro nobilissimi, unde nobilis vocatus,\" (made\n"
  "from the noblest (purest) gold, and therefore called nobles) says\n"
  "Vossius.\n"
  "\n"
  "10. Yern: Shrill, lively; German, \"gern,\" willingly, cheerfully.\n"
  "\n"
  "11. Braket:  bragget, a sweet drink made of honey, spices, &c.\n"
  "In some parts of the country, a drink made from honeycomb,\n"
  "after the honey is extracted, is still called \"bragwort.\"\n"
  "\n"
  "12. Piggesnie: a fond term, like \"my duck;\" from Anglo-Saxon,\n"
  "\"piga,\" a young maid; but Tyrwhitt associates it with the Latin,\n"
  "\"ocellus,\" little eye, a fondling term, and suggests that the \"pigs-\n"
  "eye,\" which is very small, was  applied in the same sense.\n"
  "Davenport and Butler both use the word pigsnie, the first for\n"
  "\"darling,\" the second literally for \"eye;\" and Bishop Gardner,\n"
  "\"On True Obedience,\" in his address to the reader, says: \"How\n"
  "softly she was wont to chirpe him under the chin, and kiss him;\n"
  "how prettily she could talk to him (how doth my sweet heart,\n"
  "what saith now pig's-eye).\"\n"
  "\n"
  "13. Oseney: A once well-known abbey near Oxford.\n"
  "\n"
  "14. Trave: travis; a frame in which unruly  horses were shod.\n"
  "\n"
  "15. Harow and Alas:  Haro! was an old Norman cry for redress\n"
  "or aid. The \"Clameur de Haro\" was lately raised, under peculiar\n"
  "circumstances, as the prelude to a legal protest, in Jersey.\n"
  "\n"
  "16. His shoes were  ornamented like the windows of St. Paul's,\n"
  "especially like the old rose-window.\n"
  "\n"
  "17. Rise: Twig, bush; German, \"Reis,\" a twig; \"Reisig,\" a copse.\n"
  "\n"
  "18. Chaucer satirises the dancing of Oxford as he did the French\n"
  "of Stratford at Bow.\n"
  "\n"
  "19. Shot window: A projecting or bow window, whence it was\n"
  "possible shoot at any one approaching the door.\n"
  "\n"
  "20. Piment: A drink made with wine, honey, and spices.\n"
  "\n"
  "21. Because she was town-bred, he offered wealth, or money\n"
  "reward, for her love.\n"
  "\n"
  "22. Parish-clerks, like Absolon, had leading parts in the\n"
  "mysteries or religious plays; Herod was one of these parts,\n"
  "which may have been an object of competition among the\n"
  "amateurs of the period.\n"
  "\n"
  "23 .\"The nighe sly maketh oft time the far lief to be loth\": a\n"
  "proverb; the cunning one near at hand oft makes the loving one\n"
  "afar off to be odious.\n"
  "\n"
  "24. Kyked: Looked; \"keek\" is still used in some parts in the\n"
  "sense of \"peep.\"\n"
  "\n"
  "25. Saint Frideswide was the patroness of a considerable priory\n"
  "at Oxford, and held there in high repute.\n"
  "\n"
  "26. Plato, in his \"Theatetus,\" tells this story of Thales; but\n"
  "it has since appeared in many other forms.\n"
  "\n"
  "27. Crouche: protect by signing the sign of the cross.\n"
  "\n"
  "28. Forlore: lost; german, \"verloren.\"\n"
  "\n"
  "29. Him that harried Hell: Christ who wasted or subdued hell: in\n"
  "the middle ages, some very active exploits against the prince of\n"
  "darkness and his powers were ascribed by the monkish tale-\n"
  "tellers to the saviour after he had \"descended into hell.\"\n"
  "\n"
  "30. According to the old mysteries, Noah's wife refused to\n"
  "come into the ark, and bade her husband row forth and get him\n"
  "a new wife, because he was leaving her gossips in the town to\n"
  "drown. Shem and his brothers got her shipped by main force;\n"
  "and Noah, coming forward to welcome her, was greeted with a\n"
  "box on the ear.\n"
  "\n"
  "31. \"Him had been lever, I dare well undertake,\n"
  "     At thilke time, than all his wethers black,\n"
  "     That she had had a ship herself alone.\"\n"
  "i.e.\n"
  "\"At that time he would have given all his black wethers, if she\n"
  "had had an ark to herself.\"\n"
  "\n"
  "32. \"Clum,\" like \"mum,\" a note of silence; but otherwise\n"
  "explained as the humming sound made in repeating prayers;\n"
  "from the Anglo-Saxon, \"clumian,\" to mutter, speak in an under-\n"
  "tone, keep silence.\n"
  "\n"
  "33. Curfew-time: Eight in the evening, when, by the law of\n"
  "William the Conqueror, all people were, on ringing of a bell, to\n"
  "extinguish fire and candle, and go to rest; hence the word\n"
  "curfew, from French, \"couvre-feu,\" cover-fire.\n"
  "\n"
  "34. Absolon chewed grains: these were grains of Paris, or\n"
  "Paradise; a favourite spice.\n"
  "\n"
  "35. Under his tongue a true love he bare:  some sweet herb;\n"
  "another reading, however, is \"a true love-knot,\" which may\n"
  "have been of the nature of a charm.\n"
  "\n"
  "36. The two lines within brackets are not in most of the\n"
  "editions: they are taken from Urry; whether he supplied them or\n"
  "not, they serve the purpose of a necessary explanation.\n"
  "\n"
  "37. Gay girl: As applied to a young woman of light manners,\n"
  "this euphemistic phrase has enjoyed a wonderful vitality.\n"
  "\n"
  "38. Viretote: Urry reads \"meritote,\" and explains it from\n"
  "Spelman as a game in which children made themselves giddy by\n"
  "whirling on ropes.  In French, \"virer\" means to turn; and the\n"
  "explanation may, therefore, suit either reading. In modern slang\n"
  "parlance, Gerveis would probably have said, \"on the rampage,\"\n"
  "or \"on the swing\" -- not very far from Spelman's rendering.\n"
  "\n"
  "39. He had more tow on his distaff: a proverbial saying: he was\n"
  "playing a deeper game, had more serious business on hand.\n"
  "\n"
  "40. Ere: before; German, \"eher.\"\n"
  "\n"
  "41. Sell:  sill of the door, threshold; French, \"seuil,\" Latin,\n"
  "\"solum,\" the ground.\n"
  "\n"
  "\n"
  "\n"
  "";
// }

const char reevesTale[] PGMSECTION = // { // 28667 bytes
  "THE REEVE'S TALE.\n"
  "\n"
  "\n"
  "THE PROLOGUE.\n"
  "\n"
  "\n"
  "WHEN folk had laughed all at this nice case\n"
  "Of Absolon and Hendy Nicholas,\n"
  "Diverse folk diversely they said,\n"
  "But for the more part they laugh'd and play'd;*           *were diverted\n"
  "And at this tale I saw no man him grieve,\n"
  "But it were only Osewold the Reeve.\n"
  "Because he was of carpenteres craft,\n"
  "A little ire is in his hearte laft*;                               *left\n"
  "He gan to grudge* and blamed it a lite.**              *murmur **little.\n"
  "\"So the* I,\"  quoth he, \"full well could I him quite**   *thrive **match\n"
  "With blearing* of a proude miller's eye,                    *dimming <1>\n"
  "If that me list to speak of ribaldry.\n"
  "But I am old; me list not play for age; <2>\n"
  "Grass time is done, my fodder is now forage.\n"
  "This white top* writeth mine olde years;                           *head\n"
  "Mine heart is also moulded* as mine hairs;                 *grown mouldy\n"
  "And I do fare as doth an open-erse*;                         *medlar <3>\n"
  "That ilke* fruit is ever longer werse,                             *same\n"
  "Till it be rotten *in mullok or in stre*.    *on the ground or in straw*\n"
  "We olde men, I dread, so fare we;\n"
  "Till we be rotten, can we not be ripe;\n"
  "We hop* away, while that the world will pipe;                     *dance\n"
  "For in our will there sticketh aye a nail,\n"
  "To have an hoary head and a green tail,\n"
  "As hath a leek; for though our might be gone,\n"
  "Our will desireth folly ever-in-one*:                       *continually\n"
  "For when we may not do, then will we speak,\n"
  "Yet in our ashes cold does fire reek.*                         *smoke<4>\n"
  "Four gledes* have we, which I shall devise**,         *coals ** describe\n"
  "Vaunting, and lying, anger, covetise*.                     *covetousness\n"
  "These foure sparks belongen unto eld.\n"
  "Our olde limbes well may be unweld*,                           *unwieldy\n"
  "But will shall never fail us, that is sooth.\n"
  "And yet have I alway a coltes tooth,<5>\n"
  "As many a year as it is passed and gone\n"
  "Since that my tap of life began to run;\n"
  "For sickerly*, when I was born, anon                          *certainly\n"
  "Death drew the tap of life, and let it gon:\n"
  "And ever since hath so the tap y-run,\n"
  "Till that almost all empty is the tun.\n"
  "The stream of life now droppeth on the chimb.<6>\n"
  "The silly tongue well may ring and chime\n"
  "Of wretchedness, that passed is full yore*:                        *long\n"
  "With olde folk, save dotage, is no more. <7>\n"
  "\n"
  "When that our Host had heard this sermoning,\n"
  "He gan to speak as lordly as a king,\n"
  "And said; \"To what amounteth all this wit?\n"
  "What? shall we speak all day of holy writ?\n"
  "The devil made a Reeve for to preach,\n"
  "As of a souter* a shipman, or a leach**.                    *cobbler <8>\n"
  "Say forth thy tale, and tarry not the time:                **surgeon <9>\n"
  "Lo here is Deptford, and 'tis half past prime:<10>\n"
  "Lo Greenwich, where many a shrew is in.\n"
  "It were high time thy tale to begin.\"\n"
  "\n"
  "\"Now, sirs,\" quoth then this Osewold the Reeve,\n"
  "I pray you all that none of you do grieve,\n"
  "Though I answer, and somewhat set his hove*,                  *hood <11>\n"
  "For lawful is *force off with force to shove.*           *to repel force\n"
  "This drunken miller hath y-told us here                        by force*\n"
  "How that beguiled was a carpentere,\n"
  "Paraventure* in scorn, for I am one:                            *perhaps\n"
  "And, by your leave, I shall him quite anon.\n"
  "Right in his churlish termes will I speak,\n"
  "I pray to God his necke might to-break.\n"
  "He can well in mine eye see a stalk,\n"
  "But in his own he cannot see a balk.\"<12>\n"
  "\n"
  "\n"
  "Notes to the Prologue to the Reeves Tale.\n"
  "\n"
  "\n"
  " 1. \"With blearing of a proude miller's eye\": dimming his eye;\n"
  "playing off a joke on him.\n"
  "\n"
  "2. \"Me list not play for age\": age takes away my zest for\n"
  "drollery.\n"
  "\n"
  "3. The medlar, the fruit of the mespilus tree, is only edible when\n"
  "rotten.\n"
  "\n"
  "4. Yet in our ashes cold does fire reek: \"ev'n in our ashes live\n"
  "their wonted fires.\"\n"
  "\n"
  "5. A colt's tooth; a wanton humour, a relish for pleasure.\n"
  "\n"
  "6. Chimb: The rim of a barrel where the staves project beyond\n"
  "the head.\n"
  "\n"
  "7. With olde folk, save dotage, is no more: Dotage is all that is\n"
  "left them; that is, they can only dwell fondly, dote, on the past.\n"
  "\n"
  "8. Souter: cobbler; Scottice, \"sutor;\"' from Latin, \"suere,\" to\n"
  "sew.\n"
  "\n"
  "9. \"Ex sutore medicus\"  (a surgeon from a cobbler) and \"ex\n"
  "sutore nauclerus\" (a  seaman or pilot from a cobbler) were both\n"
  "proverbial expressions in the Middle Ages.\n"
  "\n"
  "10. Half past prime: half-way between prime and tierce; about\n"
  "half-past seven in the morning.\n"
  "\n"
  "11. Set his hove; like \"set their caps;\" as in the description of\n"
  "the Manciple in the Prologue, who \"set their aller cap\".  \"Hove\"\n"
  "or \"houfe,\" means \"hood;\" and the phrase signifies to be even\n"
  "with, outwit.\n"
  "\n"
  "12. The illustration of the mote and the beam, from Matthew.\n"
  "\n"
  "\n"
  "THE TALE.<1>\n"
  "\n"
  "\n"
  "At Trompington, not far from Cantebrig,*                      *Cambridge\n"
  "There goes a brook, and over that a brig,\n"
  "Upon the whiche brook there stands a mill:\n"
  "And this is *very sooth* that I you tell.               *complete truth*\n"
  "A miller was there dwelling many a day,\n"
  "As any peacock he was proud and gay:\n"
  "Pipen he could, and fish, and nettes bete*,                     *prepare\n"
  "And turne cups, and wrestle well, and shete*.                     *shoot\n"
  "Aye by his belt he bare a long pavade*,                         *poniard\n"
  "And of his sword full trenchant was the blade.\n"
  "A jolly popper* bare he in his pouch;                            *dagger\n"
  "There was no man for peril durst him touch.\n"
  "A Sheffield whittle* bare he in his hose.                   *small knife\n"
  "Round was his face, and camuse* was his nose.                  *flat <2>\n"
  "As pilled* as an ape's was his skull.                     *peeled, bald.\n"
  "He was a market-beter* at the full.                             *brawler\n"
  "There durste no wight hand upon him legge*,                         *lay\n"
  "That he ne swore anon he should abegge*.             *suffer the penalty\n"
  "\n"
  "A thief he was, for sooth, of corn and meal,\n"
  "And that a sly, and used well to steal.\n"
  "His name was *hoten deinous Simekin*        *called \"Disdainful Simkin\"*\n"
  "A wife he hadde, come of noble kin:\n"
  "The parson of the town her father was.\n"
  "With her he gave full many a pan of brass,\n"
  "For that Simkin should in his blood ally.\n"
  "She was y-foster'd in a nunnery:\n"
  "For Simkin woulde no wife, as he said,\n"
  "But she were well y-nourish'd, and a maid,\n"
  "To saven his estate and yeomanry:\n"
  "And she was proud, and pert as is a pie*.                        *magpie\n"
  "A full fair sight it was to see them two;\n"
  "On holy days before her would he go\n"
  "With his tippet* y-bound about his head;                           *hood\n"
  "And she came after in a gite* of red,                          *gown <3>\n"
  "And Simkin hadde hosen of the same.\n"
  "There durste no wight call her aught but Dame:\n"
  "None was so hardy, walking by that way,\n"
  "That with her either durste *rage or play*,                *use freedom*\n"
  "*But if* he would be slain by Simekin                            *unless\n"
  "With pavade, or with knife, or bodekin.\n"
  "For jealous folk be per'lous evermo':\n"
  "Algate* they would their wives *wende so*.           *unless *so behave*\n"
  "And eke for she was somewhat smutterlich*,                        *dirty\n"
  "She was as dign* as water in a ditch,                             *nasty\n"
  "And all so full of hoker*, and bismare**.   *ill-nature **abusive speech\n"
  "Her thoughte that a lady should her spare*,        *not judge her hardly\n"
  "What for her kindred, and her nortelrie*           *nurturing, education\n"
  "That she had learned in the nunnery.\n"
  "\n"
  "One daughter hadde they betwixt them two\n"
  "Of twenty year, withouten any mo,\n"
  "Saving a child that was of half year age,\n"
  "In cradle it lay, and was a proper page.*                           *boy\n"
  "This wenche thick and well y-growen was,\n"
  "With camuse* nose, and eyen gray as glass;                         *flat\n"
  "With buttocks broad, and breastes round and high;\n"
  "But right fair was her hair, I will not lie.\n"
  "The parson of the town, for she was fair,\n"
  "In purpose was to make of her his heir\n"
  "Both of his chattels and his messuage,\n"
  "And *strange he made it* of her marriage.           *he made it a matter\n"
  "His purpose was for to bestow her high                    of difficulty*\n"
  "Into some worthy blood of ancestry.\n"
  "For holy Church's good may be dispended*                          *spent\n"
  "On holy Church's blood that is descended.\n"
  "Therefore he would his holy blood honour\n"
  "Though that he holy Churche should devour.\n"
  "\n"
  "Great soken* hath this miller, out of doubt,    *toll taken for grinding\n"
  "With wheat and malt, of all the land about;\n"
  "And namely* there was a great college                        *especially\n"
  "Men call the Soler Hall at Cantebrege,<4>\n"
  "There was their wheat and eke their malt y-ground.\n"
  "And on a day it happed in a stound*,                           *suddenly\n"
  "Sick lay the manciple* of a malady,                         *steward <5>\n"
  "Men *weened wisly* that he shoulde die.              *thought certainly*\n"
  "For which this miller stole both meal and corn\n"
  "An hundred times more than beforn.\n"
  "For theretofore he stole but courteously,\n"
  "But now he was a thief outrageously.\n"
  "For which the warden chid and made fare*,                          *fuss\n"
  "But thereof *set the miller not a tare*;           *he cared not a rush*\n"
  "He *crack'd his boast,* and swore it was not so.            *talked big*\n"
  "\n"
  "Then were there younge poore scholars two,\n"
  "That dwelled in the hall of which I say;\n"
  "Testif* they were, and lusty for to play;                *headstrong <6>\n"
  "And only for their mirth and revelry\n"
  "Upon the warden busily they cry,\n"
  "To give them leave for but a *little stound*,               *short time*\n"
  "To go to mill, and see their corn y-ground:\n"
  "And hardily* they durste lay their neck,                         *boldly\n"
  "The miller should not steal them half a peck\n"
  "Of corn by sleight, nor them by force bereave*                *take away\n"
  "And at the last the warden give them leave:\n"
  "John hight the one, and Alein hight the other,\n"
  "Of one town were they born, that highte Strother,<7>\n"
  "Far in the North, I cannot tell you where.\n"
  "This Alein he made ready all his gear,\n"
  "And on a horse the sack he cast anon:\n"
  "Forth went Alein the clerk, and also John,\n"
  "With good sword and with buckler by their side.\n"
  "John knew the way, him needed not no guide,\n"
  "And at the mill the sack adown he lay'th.\n"
  "\n"
  "Alein spake first; \"All hail, Simon, in faith,\n"
  "How fares thy faire daughter, and thy wife.\"\n"
  "\"Alein, welcome,\" quoth Simkin, \"by my life,\n"
  "And John also: how now, what do ye here?\"\n"
  "\"By God, Simon,\" quoth John, \"need has no peer*.                  *equal\n"
  "Him serve himself behoves that has no swain*,                   *servant\n"
  "Or else he is a fool, as clerkes sayn.\n"
  "Our manciple I hope* he will be dead,                            *expect\n"
  "So workes aye the wanges* in his head:                  *cheek-teeth <8>\n"
  "And therefore is I come, and eke Alein,\n"
  "To grind our corn and carry it home again:\n"
  "I pray you speed us hence as well ye may.\"\n"
  "\"It shall be done,\" quoth Simkin, \"by my fay.\n"
  "What will ye do while that it is in hand?\"\n"
  "\"By God, right by the hopper will I stand,\"\n"
  "Quoth John, \"and see how that the corn goes in.\n"
  "Yet saw I never, by my father's kin,\n"
  "How that the hopper wagges to and fro.\"\n"
  "Alein answered, \"John, and wilt thou so?\n"
  "Then will I be beneathe, by my crown,\n"
  "And see how that the meale falls adown\n"
  "Into the trough, that shall be my disport*:                   *amusement\n"
  "For, John, in faith I may be of your sort;\n"
  "I is as ill a miller as is ye.\"\n"
  "\n"
  "This miller smiled at their nicety*,                         *simplicity\n"
  "And thought, \"All this is done but for a wile.\n"
  "They weenen* that no man may them beguile,                        *think\n"
  "But by my thrift yet shall I blear their eye,<9>\n"
  "For all the sleight in their philosophy.\n"
  "The more *quainte knackes* that they make,           *odd little tricks*\n"
  "The more will I steal when that I take.\n"
  "Instead of flour yet will I give them bren*.                       *bran\n"
  "The greatest clerks are not the wisest men,\n"
  "As whilom to the wolf thus spake the mare: <10>\n"
  "Of all their art ne count I not a tare.\"\n"
  "Out at the door he went full privily,\n"
  "When that he saw his time, softely.\n"
  "He looked up and down, until he found\n"
  "The clerkes' horse, there as he stood y-bound\n"
  "Behind the mill, under a levesell:*                          *arbour<11>\n"
  "And to the horse he went him fair and well,\n"
  "And stripped off the bridle right anon.\n"
  "And when the horse was loose, he gan to gon\n"
  "Toward the fen, where wilde mares run,\n"
  "Forth, with \"Wehee!\" through thick and eke through thin.\n"
  "This miller went again, no word he said,\n"
  "But did his note*, and with these clerkes play'd,         *business <12>\n"
  "Till that their corn was fair and well y-ground.\n"
  "And when the meal was sacked and y-bound,\n"
  "Then John went out, and found his horse away,\n"
  "And gan to cry, \"Harow, and well-away!\n"
  "Our horse is lost: Alein, for Godde's bones,\n"
  "Step on thy feet; come off, man, all at once:\n"
  "Alas! our warden has his palfrey lorn.*\"                           *lost\n"
  "This Alein all forgot, both meal and corn;\n"
  "All was out of his mind his husbandry*.              *careful watch over\n"
  "\"What, which way is he gone?\" he gan to cry.                   the corn*\n"
  "The wife came leaping inward at a renne*,                           *run\n"
  "She said; \"Alas! your horse went to the fen\n"
  "With wilde mares, as fast as he could go.\n"
  "Unthank* come on his hand that bound him so           *ill luck, a curse\n"
  "And his that better should have knit the rein.\"\n"
  "\"Alas!\" quoth John, \"Alein, for Christes pain\n"
  "Lay down thy sword, and I shall mine also.\n"
  "I is full wight*, God wate**, as is a roe.                *swift **knows\n"
  "By Godde's soul he shall not scape us bathe*.                 *both <13>\n"
  "Why n' had thou put the capel* in the lathe**?         *horse<14> **barn\n"
  "Ill hail, Alein, by God thou is a fonne.*\"                         *fool\n"
  "These silly clerkes have full fast y-run\n"
  "Toward the fen, both Alein and eke John;\n"
  "And when the miller saw that they were gone,\n"
  "He half a bushel of their flour did take,\n"
  "And bade his wife go knead it in a cake.\n"
  "He said; I trow, the clerkes were afeard,\n"
  "Yet can a miller *make a clerkes beard,*          *cheat a scholar* <15>\n"
  "For all his art: yea, let them go their way!\n"
  "Lo where they go! yea, let the children play:\n"
  "They get him not so lightly, by my crown.\"\n"
  "These silly clerkes runnen up and down\n"
  "With \"Keep, keep; stand, stand; jossa*, warderere.                 *turn\n"
  "Go whistle thou, and I shall keep* him here.\"                     *catch\n"
  "But shortly, till that it was very night\n"
  "They coulde not, though they did all their might,\n"
  "Their capel catch, he ran alway so fast:\n"
  "Till in a ditch they caught him at the last.\n"
  "\n"
  "Weary and wet, as beastes in the rain,\n"
  "Comes silly John, and with him comes Alein.\n"
  "\"Alas,\" quoth John, \"the day that I was born!\n"
  "Now are we driv'n till hething* and till scorn.                 *mockery\n"
  "Our corn is stol'n, men will us fonnes* call,                     *fools\n"
  "Both the warden, and eke our fellows all,\n"
  "And namely* the miller, well-away!\"                          *especially\n"
  "Thus plained John, as he went by the way\n"
  "Toward the mill, and Bayard* in his hand.                 *the bay horse\n"
  "The miller sitting by the fire he fand*.                          *found\n"
  "For it was night, and forther* might they not,             *go their way\n"
  "But for the love of God they him besought\n"
  "Of herberow* and ease, for their penny.                         *lodging\n"
  "The miller said again,\" If there be any,\n"
  "Such as it is, yet shall ye have your part.\n"
  "Mine house is strait, but ye have learned art;\n"
  "Ye can by arguments maken a place\n"
  "A mile broad, of twenty foot of space.\n"
  "Let see now if this place may suffice,\n"
  "Or make it room with speech, as is your guise.*\"                *fashion\n"
  "\"Now, Simon,\" said this John, \"by Saint Cuthberd\n"
  "Aye is thou merry, and that is fair answer'd.\n"
  "I have heard say, man shall take of two things,\n"
  "Such as he findes, or such as he brings.\n"
  "But specially I pray thee, hoste dear,\n"
  "Gar <16> us have meat and drink, and make us cheer,\n"
  "And we shall pay thee truly at the full:\n"
  "With empty hand men may not hawkes tull*.                        *allure\n"
  "Lo here our silver ready for to spend.\"\n"
  "\n"
  "This miller to the town his daughter send\n"
  "For ale and bread, and roasted them a goose,\n"
  "And bound their horse, he should no more go loose:\n"
  "And them in his own chamber made a bed.\n"
  "With sheetes and with chalons* fair y-spread,              *blankets<17>\n"
  "Not from his owen bed ten foot or twelve:\n"
  "His daughter had a bed all by herselve,\n"
  "Right in the same chamber *by and by*:                    *side by side*\n"
  "It might no better be, and cause why,\n"
  "There was no *roomer herberow* in the place.           *roomier lodging*\n"
  "They suppen, and they speaken of solace,\n"
  "And drinken ever strong ale at the best.\n"
  "Aboute midnight went they all to rest.\n"
  "Well had this miller varnished his head;\n"
  "Full pale he was, fordrunken, and *nought red*.       *without his wits*\n"
  "He yoxed*, and he spake thorough the nose,                     *hiccuped\n"
  "As he were in the quakke*, or in the pose**.         *grunting **catarrh\n"
  "To bed he went, and with him went his wife,\n"
  "As any jay she light was and jolife,*                             *jolly\n"
  "So was her jolly whistle well y-wet.\n"
  "The cradle at her beddes feet was set,\n"
  "To rock, and eke to give the child to suck.\n"
  "And when that drunken was all in the crock*                 *pitcher<18>\n"
  "To bedde went the daughter right anon,\n"
  "To bedde went Alein, and also John.\n"
  "There was no more; needed them no dwale.<19>\n"
  "This miller had, so wisly* bibbed ale,                        *certainly\n"
  "That as a horse he snorted in his sleep,\n"
  "Nor of his tail behind he took no keep*.                           *heed\n"
  "His wife bare him a burdoun*, a full strong;                  *bass <20>\n"
  "Men might their routing* hearen a furlong.                      *snoring\n"
  "\n"
  "The wenche routed eke for company.\n"
  "Alein the clerk, that heard this melody,\n"
  "He poked John, and saide: \"Sleepest thou?\n"
  "Heardest thou ever such a song ere now?\n"
  "Lo what a compline<21> is y-mell* them all.                       *among\n"
  "A wilde fire upon their bodies fall,\n"
  "Who hearken'd ever such a ferly* thing?                    *strange <22>\n"
  "Yea, they shall have the flow'r of ill ending!\n"
  "This longe night there *tides me* no rest.                 *comes to me*\n"
  "But yet no force*, all shall be for the best.                    *matter\n"
  "For, John,\" said he, \"as ever may I thrive,\n"
  "If that I may, yon wenche will I swive*.                 *enjoy carnally\n"
  "Some easement* has law y-shapen** us            *satisfaction **provided\n"
  "For, John, there is a law that sayeth thus,\n"
  "That if a man in one point be aggriev'd,\n"
  "That in another he shall be relievd.\n"
  "Our corn is stol'n, soothly it is no nay,\n"
  "And we have had an evil fit to-day.\n"
  "And since I shall have none amendement\n"
  "Against my loss, I will have easement:\n"
  "By Godde's soul, it shall none, other be.\"\n"
  "This John answer'd;  Alein, *avise thee*:                  *have a care*\n"
  "The miller is a perilous man,\" he said,\n"
  "\"And if that he out of his sleep abraid*,                        *awaked\n"
  "He mighte do us both a villainy*.\"                             *mischief\n"
  "Alein answer'd; \"I count him not a fly.\n"
  "And up he rose, and by the wench he crept.\n"
  "This wenche lay upright, and fast she slept,\n"
  "Till he so nigh was, ere she might espy,\n"
  "That it had been too late for to cry:\n"
  "And, shortly for to say, they were at one.\n"
  "Now play, Alein, for I will speak of John.\n"
  "\n"
  "This John lay still a furlong way <23> or two,\n"
  "And to himself he made ruth* and woe.                              *wail\n"
  "\"Alas!\" quoth he, \"this is a wicked jape*;                        *trick\n"
  "Now may I say, that I is but an ape.\n"
  "Yet has my fellow somewhat for his harm;\n"
  "He has the miller's daughter in his arm:\n"
  "He auntred* him, and hath his needes sped,                   *adventured\n"
  "And I lie as a draff-sack in my bed;\n"
  "And when this jape is told another day,\n"
  "I shall be held a daffe* or a cockenay <24>                      *coward\n"
  "I will arise, and auntre* it, by my fay:                        *attempt\n"
  "Unhardy is unsely, <25> as men say.\"\n"
  "And up he rose, and softely he went\n"
  "Unto the cradle, and in his hand it hent*,                         *took\n"
  "And bare it soft unto his beddes feet.\n"
  "Soon after this the wife *her routing lete*,           *stopped snoring*\n"
  "And gan awake, and went her out to piss\n"
  "And came again and gan the cradle miss\n"
  "And groped here and there, but she found none.\n"
  "\"Alas!\" quoth she, \"I had almost misgone\n"
  "I had almost gone to the clerkes' bed.\n"
  "Ey! Benedicite, then had I foul y-sped.\"\n"
  "And forth she went, till she the cradle fand.\n"
  "She groped alway farther with her hand\n"
  "And found the bed, and *thoughte not but good*        *had no suspicion*\n"
  "Because that the cradle by it stood,\n"
  "And wist not where she was, for it was derk;\n"
  "But fair and well she crept in by the clerk,\n"
  "And lay full still, and would have caught a sleep.\n"
  "Within a while this John the Clerk up leap\n"
  "And on this goode wife laid on full sore;\n"
  "So merry a fit had she not had *full yore*.            *for a long time*\n"
  "He pricked hard and deep, as he were mad.\n"
  "\n"
  "This jolly life have these two clerkes had,\n"
  "Till that the thirde cock began to sing.\n"
  "Alein wax'd weary in the morrowing,\n"
  "For he had swonken* all the longe night,                       *laboured\n"
  "And saide; \"Farewell, Malkin, my sweet wight.\n"
  "The day is come, I may no longer bide,\n"
  "But evermore, where so I go or ride,\n"
  "I is thine owen clerk, so have I hele.*\"                         *health\n"
  "\"Now, deare leman*,\" quoth she, \"go, fare wele:              *sweetheart\n"
  "But ere thou go, one thing I will thee tell.\n"
  "When that thou wendest homeward by the mill,\n"
  "Right at the entry of the door behind\n"
  "Thou shalt a cake of half a bushel find,\n"
  "That was y-maked of thine owen meal,\n"
  "Which that I help'd my father for to steal.\n"
  "And goode leman, God thee save and keep.\"\n"
  "And with that word she gan almost to weep.\n"
  "Alein uprose and thought, \"Ere the day daw\n"
  "I will go creepen in by my fellaw:\"\n"
  "And found the cradle with his hand anon.\n"
  "\"By God!\" thought he, \"all wrong I have misgone:\n"
  "My head is *totty of my swink* to-night,          *giddy from my labour*\n"
  "That maketh me that I go not aright.\n"
  "I wot well by the cradle I have misgo';\n"
  "Here lie the miller and his wife also.\"\n"
  "And forth he went a twenty devil way\n"
  "Unto the bed, there as the miller lay.\n"
  "He ween'd* t' have creeped by his fellow John,                  *thought\n"
  "And by the miller in he crept anon,\n"
  "And caught him by the neck, and gan him shake,\n"
  "And said; \"Thou John, thou swines-head, awake\n"
  "For Christes soul, and hear a noble game!\n"
  "For by that lord that called is Saint Jame,\n"
  "As I have thries in this shorte night\n"
  "Swived the miller's daughter bolt-upright,\n"
  "While thou hast as a coward lain aghast*.\"                       *afraid\n"
  "\"Thou false harlot,\" quoth the miller, \"hast?\n"
  "Ah, false traitor, false clerk,\" quoth he,\n"
  "\"Thou shalt be dead, by Godde's dignity,\n"
  "Who durste be so bold to disparage*                            *disgrace\n"
  "My daughter, that is come of such lineage?\"\n"
  "And by the throate-ball* he caught Alein,                  *Adam's apple\n"
  "And he him hent* dispiteously** again,                 *seized **angrily\n"
  "And on the nose he smote him with his fist;\n"
  "Down ran the bloody stream upon his breast:\n"
  "And in the floor with nose and mouth all broke\n"
  "They wallow, as do two pigs in a poke.\n"
  "And up they go, and down again anon,\n"
  "Till that the miller spurned* on a stone,                      *stumbled\n"
  "And down he backward fell upon his wife,\n"
  "That wiste nothing of this nice strife:\n"
  "For she was fall'n asleep a little wight*                         *while\n"
  "With John the clerk, that waked had all night:\n"
  "And with the fall out of her sleep she braid*.                     *woke\n"
  "\"Help, holy cross of Bromeholm,\" <26> she said;\n"
  "\"In manus tuas! <27> Lord, to thee I call.\n"
  "Awake, Simon, the fiend is on me fall;\n"
  "Mine heart is broken; help; I am but dead:\n"
  "There li'th one on my womb and on mine head.\n"
  "Help, Simkin, for these false clerks do fight\"\n"
  "This John start up as fast as e'er he might,\n"
  "And groped by the walles to and fro\n"
  "To find a staff; and she start up also,\n"
  "And knew the estres* better than this John,                   *apartment\n"
  "And by the wall she took a staff anon:\n"
  "And saw a little shimmering of a light,\n"
  "For at an hole in shone the moone bright,\n"
  "And by that light she saw them both the two,\n"
  "But sickerly* she wist not who was who,                       *certainly\n"
  "But as she saw a white thing in her eye.\n"
  "And when she gan this white thing espy,\n"
  "She ween'd* the clerk had wear'd a volupere**;     *supposed **night-cap\n"
  "And with the staff she drew aye nere* and nere*,                 *nearer\n"
  "And ween'd to have hit this Alein at the full,\n"
  "And smote the miller on the pilled* skull;                         *bald\n"
  "That down he went, and cried,\" Harow! I die.\"\n"
  "These clerkes beat him well, and let him lie,\n"
  "And greithen* them, and take their horse anon,        *make ready, dress\n"
  "And eke their meal, and on their way they gon:\n"
  "And at the mill door eke they took their cake\n"
  "Of half a bushel flour, full well y-bake.\n"
  "\n"
  "Thus is the proude miller well y-beat,\n"
  "And hath y-lost the grinding of the wheat;\n"
  "And payed for the supper *every deal*                         *every bit\n"
  "Of Alein and of John, that beat him well;\n"
  "His wife is swived, and his daughter als*;                         *also\n"
  "Lo, such it is a miller to be false.\n"
  "And therefore this proverb is said full sooth,\n"
  "\"*Him thar not winnen well* that evil do'th,   *he deserves not to gain*\n"
  "A guiler shall himself beguiled be:\"\n"
  "And God that sitteth high in majesty\n"
  "Save all this Company, both great and smale.\n"
  "Thus have I quit* the Miller in my tale.         *made myself quits with\n"
  "\n"
  "\n"
  "Notes to the Reeve's Tale\n"
  "\n"
  "\n"
  "1. The incidents of this tale were much relished in the Middle\n"
  "Ages, and are found under various forms.  Boccaccio has told\n"
  "them in the ninth day of his \"Decameron\".\n"
  "\n"
  "2. Camuse: flat; French \"camuse\", snub-nosed.\n"
  "\n"
  "3. Gite: gown or coat; French \"jupe.\"\n"
  "\n"
  "4. Soler Hall: the hall or college at Cambridge with the gallery\n"
  "or upper storey; supposed to have been Clare Hall.\n"
  "(Transcribers note: later commentators identify it with King's\n"
  "Hall, now merged with Trinity College)\n"
  "\n"
  "5. Manciple:  steward; provisioner of the hall. See also note 47\n"
  "to the prologue to the Tales.\n"
  "\n"
  "6. Testif: headstrong, wild-brained; French, \"entete.\"\n"
  "\n"
  "7. Strother:  Tyrwhitt points to Anstruther, in Fife: Mr Wright\n"
  "to the Vale of Langstroth, in the West Riding of Yorkshire.\n"
  "Chaucer has given the scholars a dialect that may have belonged\n"
  "to either district, although it more immediately suggests the\n"
  "more northern of the two.\n"
  "(Transcribers note: later commentators have identified it with a\n"
  "now vanished village near Kirknewton in Northumberland.\n"
  "There was a well-known Alein of Strother in Chaucer's\n"
  "lifetime.)\n"
  "\n"
  "8. Wanges: grinders, cheek-teeth; Anglo-Saxon, \"Wang,\" the\n"
  "cheek; German, \"Wange.\"\n"
  "\n"
  "9. See note 1 to the Prologue to the Reeves Tale\n"
  "\n"
  "10. In the \"Cento Novelle Antiche,\" the story is told of a mule,\n"
  "which pretends that his name is written on the bottom of his\n"
  "hind foot. The wolf attempts to read it, the mule kills him with a\n"
  "kick in the forehead; and the fox, looking on, remarks that\n"
  "\"every man of letters is not wise.\" A similar story is told in\n"
  "\"Reynard the Fox.\"\n"
  "\n"
  "11. Levesell: an arbour; Anglo-Saxon, \"lefe-setl,\" leafy seat.\n"
  "\n"
  "12. Noth:  business; German, \"Noth,\" necessity.\n"
  "\n"
  "13. Bathe: both; Scottice, \"baith.\"\n"
  "\n"
  "14. Capel:  horse; Gaelic, \"capall;\" French, \"cheval;\" Italian,\n"
  "\"cavallo,\" from Latin, \"caballus.\"\n"
  "\n"
  "15. Make a clerkes beard: cheat a scholar; French, \"faire la\n"
  "barbe;\" and Boccaccio uses the proverb in the same sense.\n"
  "\n"
  "16. \"Gar\" is Scotch for \"cause;\" some editions read, however,\n"
  "\"get us some\".\n"
  "\n"
  "17. Chalons:  blankets, coverlets, made at Chalons in France.\n"
  "\n"
  "18. Crock: pitcher, cruse; Anglo-Saxon, \"crocca;\" German,\n"
  "\"krug;\" hence \"crockery.\"\n"
  "\n"
  "19. Dwale: night-shade, Solanum somniferum, given to cause\n"
  "sleep.\n"
  "\n"
  "20. Burdoun: bass; \"burden\" of a song. It originally means the\n"
  "drone of a bagpipe; French, \"bourdon.\"\n"
  "\n"
  "21. Compline: even-song in the church service; chorus.\n"
  "\n"
  "22. Ferly: strange. In Scotland, a \"ferlie\" is an unwonted or\n"
  "remarkable sight.\n"
  "\n"
  "23. A furlong way: As long as it might take to walk a furlong.\n"
  "\n"
  "24. Cockenay: a term of contempt, probably borrowed from the\n"
  "kitchen; a cook, in base Latin, being termed \"coquinarius.\"\n"
  "compare French \"coquin,\" rascal.\n"
  "\n"
  "25. Unhardy is unsely: the cowardly is unlucky; \"nothing\n"
  "venture, nothing have;\" German, \"unselig,\" unhappy.\n"
  "\n"
  "26. Holy cross of Bromeholm: A common adjuration at that\n"
  "time; the cross or rood of the priory of Bromholm, in Norfolk,\n"
  "was said to contain part of the real cross and therefore held in\n"
  "high esteem.\n"
  "\n"
  "27. In manus tuas: Latin, \"in your hands\".\n"
  "\n"
  "\n"
  "\n"
  "";
// }

const char cooksTale[] PGMSECTION = // { // 6373 bytes
  "THE COOK'S TALE.\n"
  "\n"
  "\n"
  "THE PROLOGUE.\n"
  "\n"
  "\n"
  "THE Cook of London, while the Reeve thus spake,\n"
  "For joy he laugh'd and clapp'd him on the back:\n"
  "\"Aha!\" quoth he, \"for Christes passion,\n"
  "This Miller had a sharp conclusion,\n"
  "Upon this argument of herbergage.*                              *lodging\n"
  "Well saide Solomon in his language,\n"
  "Bring thou not every man into thine house,\n"
  "For harbouring by night is perilous.\n"
  "*Well ought a man avised for to be*        *a man should take good heed*\n"
  "Whom that he brought into his privity.\n"
  "I pray to God to give me sorrow and care\n"
  "If ever, since I highte* Hodge of Ware,                      *was called\n"
  "Heard I a miller better *set a-work*;                           *handled\n"
  "He had a jape* of malice in the derk.                             *trick\n"
  "But God forbid that we should stinte* here,                        *stop\n"
  "And therefore if ye will vouchsafe to hear\n"
  "A tale of me, that am a poore man,\n"
  "I will you tell as well as e'er I can\n"
  "A little jape that fell in our city.\"\n"
  "\n"
  "Our Host answer'd and said; \"I grant it thee.\n"
  "Roger, tell on; and look that it be good,\n"
  "For many a pasty hast thou letten blood,\n"
  "And many a Jack of Dover<1> hast thou sold,\n"
  "That had been twice hot and twice cold.\n"
  "Of many a pilgrim hast thou Christe's curse,\n"
  "For of thy parsley yet fare they the worse.\n"
  "That they have eaten in thy stubble goose:\n"
  "For in thy shop doth many a fly go loose.\n"
  "Now tell on, gentle Roger, by thy name,\n"
  "But yet I pray thee be not *wroth for game*;     *angry with my jesting*\n"
  "A man may say full sooth in game and play.\"\n"
  "\"Thou sayst full sooth,\" quoth Roger, \"by my fay;\n"
  "But sooth play quad play,<2> as the Fleming saith,\n"
  "And therefore, Harry Bailly, by thy faith,\n"
  "Be thou not wroth, else we departe* here,                  *part company\n"
  "Though that my tale be of an hostelere.*                      *innkeeper\n"
  "But natheless, I will not tell it yet,\n"
  "But ere we part, y-wis* thou shalt be quit.\"<3>               *assuredly\n"
  "And therewithal he laugh'd and made cheer,<4>\n"
  "And told his tale, as ye shall after hear.\n"
  "\n"
  "\n"
  "Notes to the Prologue to the Cook's Tale\n"
  "\n"
  "\n"
  "1. Jack of Dover:  an article of cookery. (Transcriber's note:\n"
  "suggested by some commentators to be a kind of pie, and by\n"
  "others to be a fish)\n"
  "\n"
  "2. Sooth play quad play: true jest is no jest.\n"
  "\n"
  "3. It may be remembered that each pilgrim was bound to tell\n"
  "two stories; one on the way to Canterbury, the other returning.\n"
  "\n"
  "4. Made cheer: French, \"fit bonne mine;\" put on a pleasant\n"
  "countenance.\n"
  "\n"
  "\n"
  "\n"
  "THE TALE.\n"
  "\n"
  "\n"
  "A prentice whilom dwelt in our city,\n"
  "And of a craft of victuallers was he:\n"
  "Galliard* he was, as goldfinch in the shaw**,            *lively **grove\n"
  "Brown as a berry, a proper short fellaw:\n"
  "With lockes black, combed full fetisly.*                       *daintily\n"
  "And dance he could so well and jollily,\n"
  "That he was called Perkin Revellour.\n"
  "He was as full of love and paramour,\n"
  "As is the honeycomb of honey sweet;\n"
  "Well was the wenche that with him might meet.\n"
  "At every bridal would he sing and hop;\n"
  "He better lov'd the tavern than the shop.\n"
  "For when there any riding was in Cheap,<1>\n"
  "Out of the shoppe thither would he leap,\n"
  "And, till that he had all the sight y-seen,\n"
  "And danced well, he would not come again;\n"
  "And gather'd him a meinie* of his sort,              *company of fellows\n"
  "To hop and sing, and make such disport:\n"
  "And there they *sette steven* for to meet             *made appointment*\n"
  "To playen at the dice in such a street.\n"
  "For in the towne was there no prentice\n"
  "That fairer coulde cast a pair of dice\n"
  "Than Perkin could; and thereto *he was free    *he spent money liberally\n"
  "Of his dispence, in place of privity.*       where he would not be seen*\n"
  "That found his master well in his chaffare,*                *merchandise\n"
  "For oftentime he found his box full bare.\n"
  "For, soothely, a prentice revellour,\n"
  "That haunteth dice, riot, and paramour,\n"
  "His master shall it in his shop abie*,                       *suffer for\n"
  "All* have he no part of the minstrelsy.                        *although\n"
  "For theft and riot they be convertible,\n"
  "All can they play on *gitern or ribible.*             *guitar or rebeck*\n"
  "Revel and truth, as in a low degree,\n"
  "They be full wroth* all day, as men may see.                *at variance\n"
  "\n"
  "This jolly prentice with his master bode,\n"
  "Till he was nigh out of his prenticehood,\n"
  "All were he snubbed* both early and late,                       *rebuked\n"
  "And sometimes led with revel to Newgate.\n"
  "But at the last his master him bethought,\n"
  "Upon a day when he his paper<2> sought,\n"
  "Of a proverb, that saith this same word;\n"
  "Better is rotten apple out of hoard,\n"
  "Than that it should rot all the remenant:\n"
  "So fares it by a riotous servant;\n"
  "It is well lesse harm to let him pace*,                        *pass, go\n"
  "Than he shend* all the servants in the place.                   *corrupt\n"
  "Therefore his master gave him a quittance,\n"
  "And bade him go, with sorrow and mischance.\n"
  "And thus this jolly prentice had his leve*:                      *desire\n"
  "Now let him riot all the night, or leave*.                      *refrain\n"
  "And, for there is no thief without a louke,<3>\n"
  "That helpeth him to wasten and to souk*                           *spend\n"
  "Of that he bribe* can, or borrow may,                             *steal\n"
  "Anon he sent his bed and his array\n"
  "Unto a compere* of his owen sort,                               *comrade\n"
  "That loved dice, and riot, and disport;\n"
  "And had a wife, that held *for countenance*            *for appearances*\n"
  "A shop, and swived* for her sustenance.             *prostituted herself\n"
  "       .       .       .       .       .       .       . <4>\n"
  "\n"
  "\n"
  "Notes to the Cook's Tale\n"
  "\n"
  "\n"
  "1. Cheapside, where jousts were sometimes held, and which\n"
  "was the great scene of city revels and processions.\n"
  "\n"
  "2. His paper: his certificate of completion of his apprenticeship.\n"
  "\n"
  "3. Louke:  The precise meaning of the word is unknown, but it\n"
  "is doubtless included in the cant term \"pal\".\n"
  "\n"
  "4. The Cook's Tale is unfinished in all the manuscripts; but in\n"
  "some, of minor authority, the Cook is made to break off his\n"
  "tale, because \"it is so foul,\" and to tell the story of Gamelyn, on\n"
  "which Shakespeare's \"As You Like It\" is founded. The story is\n"
  "not Chaucer's, and is different in metre, and inferior in\n"
  "composition to the Tales. It is supposed that Chaucer expunged\n"
  "the Cook's Tale for the same reason that made him on his death-\n"
  "bed lament that he had written so much \"ribaldry.\"\n"
  "\n"
  "\n"
  "\n"
  "";
// }

const char manOfLawsTale0[] PGMSECTION = // { // 31058 bytes
  "THE MAN OF LAW'S TALE.\n"
  "\n"
  "\n"
  "THE PROLOGUE.\n"
  "\n"
  "\n"
  "Our Hoste saw well that the brighte sun\n"
  "Th' arc of his artificial day had run\n"
  "The fourthe part, and half an houre more;\n"
  "And, though he were not deep expert in lore,\n"
  "He wist it was the eight-and-twenty day\n"
  "Of April, that is messenger to May;\n"
  "And saw well that the shadow of every tree\n"
  "Was in its length of the same quantity\n"
  "That was the body erect that caused it;\n"
  "And therefore by the shadow he took his wit*,                 *knowledge\n"
  "That Phoebus, which that shone so clear and bright,\n"
  "Degrees was five-and-forty clomb on height;\n"
  "And for that day, as in that latitude,\n"
  "It was ten of the clock, he gan conclude;\n"
  "And suddenly he plight* his horse about.                     *pulled <1>\n"
  "\n"
  "\"Lordings,\" quoth he, \"I warn you all this rout*,               *company\n"
  "The fourthe partie of this day is gone.\n"
  "Now for the love of God and of Saint John\n"
  "Lose no time, as farforth as ye may.\n"
  "Lordings, the time wasteth night and day,\n"
  "And steals from us, what privily sleeping,\n"
  "And what through negligence in our waking,\n"
  "As doth the stream, that turneth never again,\n"
  "Descending from the mountain to the plain.\n"
  "Well might Senec, and many a philosopher,\n"
  "Bewaile time more than gold in coffer.\n"
  "For loss of chattels may recover'd be,\n"
  "But loss of time shendeth* us, quoth he.                       *destroys\n"
  "\n"
  "It will not come again, withoute dread,*\n"
  "No more than will Malkin's maidenhead,<2>\n"
  "When she hath lost it in her wantonness.\n"
  "Let us not moulde thus in idleness.\n"
  "\"Sir Man of Law,\" quoth he, \"so have ye bliss,\n"
  "Tell us a tale anon, as forword* is.                        *the bargain\n"
  "Ye be submitted through your free assent\n"
  "To stand in this case at my judgement.\n"
  "Acquit you now, and *holde your behest*;             *keep your promise*\n"
  "Then have ye done your devoir* at the least.\"                      *duty\n"
  "\"Hoste,\" quoth he, \"de par dieux jeo asente; <3>\n"
  "To breake forword is not mine intent.\n"
  "Behest is debt, and I would hold it fain,\n"
  "All my behest; I can no better sayn.\n"
  "For such law as a man gives another wight,\n"
  "He should himselfe usen it by right.\n"
  "Thus will our text: but natheless certain\n"
  "I can right now no thrifty* tale sayn,                           *worthy\n"
  "But Chaucer (though he *can but lewedly*         *knows but imperfectly*\n"
  "On metres and on rhyming craftily)\n"
  "Hath said them, in such English as he can,\n"
  "Of olde time, as knoweth many a man.\n"
  "And if he have not said them, leve* brother,                       *dear\n"
  "In one book, he hath said them in another\n"
  "For he hath told of lovers up and down,\n"
  "More than Ovide made of mentioun\n"
  "In his Epistolae, that be full old.\n"
  "Why should I telle them, since they he told?\n"
  "In youth he made of Ceyx and Alcyon,<4>\n"
  "And since then he hath spoke of every one\n"
  "These noble wives, and these lovers eke.\n"
  "Whoso that will his large volume seek\n"
  "Called the Saintes' Legend of Cupid:<5>\n"
  "There may he see the large woundes wide\n"
  "Of Lucrece, and of Babylon Thisbe;\n"
  "The sword of Dido for the false Enee;\n"
  "The tree of Phillis for her Demophon;\n"
  "The plaint of Diane, and of Hermion,\n"
  "Of Ariadne, and Hypsipile;\n"
  "The barren isle standing in the sea;\n"
  "The drown'd Leander for his fair Hero;\n"
  "The teares of Helene, and eke the woe\n"
  "Of Briseis, and Laodamia;\n"
  "The cruelty of thee, Queen Medea,\n"
  "Thy little children hanging by the halse*,                         *neck\n"
  "For thy Jason, that was of love so false.\n"
  "Hypermnestra, Penelop', Alcest',\n"
  "Your wifehood he commendeth with the best.\n"
  "But certainly no worde writeth he\n"
  "Of *thilke wick'* example of Canace,                       *that wicked*\n"
  "That loved her own brother sinfully;\n"
  "(Of all such cursed stories I say, Fy),\n"
  "Or else of Tyrius Apollonius,\n"
  "How that the cursed king Antiochus\n"
  "Bereft his daughter of her maidenhead;\n"
  "That is so horrible a tale to read,\n"
  "When he her threw upon the pavement.\n"
  "And therefore he, *of full avisement*,         *deliberately, advisedly*\n"
  "Would never write in none of his sermons\n"
  "Of such unkind* abominations;                                 *unnatural\n"
  "Nor I will none rehearse, if that I may.\n"
  "But of my tale how shall I do this day?\n"
  "Me were loth to be liken'd doubteless\n"
  "To Muses, that men call Pierides<6>\n"
  "(Metamorphoseos <7> wot what I mean),\n"
  "But natheless I recke not a bean,\n"
  "Though I come after him with hawebake*;                        *lout <8>\n"
  "I speak in prose, and let him rhymes make.\"\n"
  "And with that word, he with a sober cheer\n"
  "Began his tale, and said as ye shall hear.\n"
  "\n"
  "\n"
  "Notes to the Prologue to The Man of Law's Tale\n"
  "\n"
  "\n"
  "1. Plight: pulled; the word is an obsolete past tense from\n"
  "\"pluck.\"\n"
  "\n"
  "2. No more than will Malkin's maidenhead: a proverbial saying;\n"
  "which, however, had obtained fresh point from the Reeve's\n"
  "Tale, to which the host doubtless refers.\n"
  "\n"
  "3. De par dieux jeo asente: \"by God, I agree\".  It is\n"
  "characteristic that the somewhat pompous Sergeant of Law\n"
  "should couch his assent in the semi-barbarous French, then\n"
  "familiar in law procedure.\n"
  "\n"
  "4. Ceyx and Alcyon: Chaucer treats of these in the introduction\n"
  "to the poem called \"The Book of the Duchess.\"  It relates to the\n"
  "death of Blanche, wife of John of Gaunt, Duke of Lancaster, the\n"
  "poet's patron, and afterwards his connexion by marriage.\n"
  "\n"
  "5. The Saintes Legend of Cupid: Now called \"The Legend of\n"
  "Good Women\". The names of eight ladies mentioned here are\n"
  "not in the \"Legend\" as it has come down to us; while those of\n"
  "two ladies in the \"legend\" -- Cleopatra and Philomela -- are her\n"
  "omitted.\n"
  "\n"
  "6. Not the Muses, who had their surname from the place near\n"
  "Mount Olympus where the Thracians first worshipped them; but\n"
  "the nine daughters of Pierus, king of Macedonia, whom he\n"
  "called the nine Muses, and who, being conquered in a contest\n"
  "with the genuine sisterhood, were changed into birds.\n"
  "\n"
  "7. Metamorphoseos:  Ovid's.\n"
  "\n"
  "8. Hawebake: hawbuck, country lout; the common proverbial\n"
  "phrase, \"to put a rogue above a gentleman,\" may throw light on\n"
  "the reading here, which is difficult.\n"
  "\n"
  "\n"
  "THE TALE. <1>\n"
  "\n"
  "\n"
  "O scatheful harm, condition of poverty,\n"
  "With thirst, with cold, with hunger so confounded;\n"
  "To aske help thee shameth in thine hearte;\n"
  "If thou none ask, so sore art thou y-wounded,\n"
  "That very need unwrappeth all thy wound hid.\n"
  "Maugre thine head thou must for indigence\n"
  "Or steal, or beg, or borrow thy dispence*.                      *expense\n"
  "\n"
  "Thou blamest Christ, and sayst full bitterly,\n"
  "He misdeparteth* riches temporal;                          *allots amiss\n"
  "Thy neighebour thou witest* sinfully,                           *blamest\n"
  "And sayst, thou hast too little, and he hath all:\n"
  "\"Parfay (sayst thou) sometime he reckon shall,\n"
  "When that his tail shall *brennen in the glede*,      *burn in the fire*\n"
  "For he not help'd the needful in their need.\"\n"
  "\n"
  "Hearken what is the sentence of the wise:\n"
  "Better to die than to have indigence.\n"
  "*Thy selve* neighebour will thee despise,                    *that same*\n"
  "If thou be poor, farewell thy reverence.\n"
  "Yet of the wise man take this sentence,\n"
  "Alle the days of poore men be wick'*,                      *wicked, evil\n"
  "Beware therefore ere thou come to that prick*.                    *point\n"
  "\n"
  "If thou be poor, thy brother hateth thee,\n"
  "And all thy friendes flee from thee, alas!\n"
  "O riche merchants, full of wealth be ye,\n"
  "O noble, prudent folk, as in this case,\n"
  "Your bagges be not fill'd with *ambes ace,*                   *two aces*\n"
  "But with *six-cinque*, that runneth for your chance;<2>       *six-five*\n"
  "At Christenmass well merry may ye dance.\n"
  "\n"
  "Ye seeke land and sea for your winnings,\n"
  "As wise folk ye knowen all th' estate\n"
  "Of regnes*;  ye be fathers of tidings,                         *kingdoms\n"
  "And tales, both of peace and of debate*:                *contention, war\n"
  "I were right now of tales desolate*,                     *barren, empty.\n"
  "But that a merchant, gone in many a year,\n"
  "Me taught a tale, which ye shall after hear.\n"
  "\n"
  "In Syria whilom dwelt a company\n"
  "Of chapmen rich, and thereto sad* and true,            *grave, steadfast\n"
  "Clothes of gold, and satins rich of hue.\n"
  "That widewhere* sent their spicery,                    *to distant parts\n"
  "Their chaffare* was so thriftly** and so new,      *wares **advantageous\n"
  "That every wight had dainty* to chaffare**              *pleasure **deal\n"
  "With them, and eke to selle them their ware.\n"
  "\n"
  "Now fell it, that the masters of that sort\n"
  "Have *shapen them* to Rome for to wend,           *determined, prepared*\n"
  "Were it for chapmanhood* or for disport,                        *trading\n"
  "None other message would they thither send,\n"
  "But come themselves to Rome, this is the end:\n"
  "And in such place as thought them a vantage\n"
  "For their intent, they took their herbergage.*                  *lodging\n"
  "\n"
  "Sojourned have these merchants in that town\n"
  "A certain time as fell to their pleasance:\n"
  "And so befell, that th' excellent renown\n"
  "Of th' emperore's daughter, Dame Constance,\n"
  "Reported was, with every circumstance,\n"
  "Unto these Syrian merchants in such wise,\n"
  "From day to day, as I shall you devise*                          *relate\n"
  "\n"
  "This was the common voice of every man\n"
  "\"Our emperor of Rome, God him see*,                 *look on with favour\n"
  "A daughter hath, that since the the world began,\n"
  "To reckon as well her goodness and beauty,\n"
  "Was never such another as is she:\n"
  "I pray to God in honour her sustene*,                           *sustain\n"
  "And would she were of all Europe the queen.\n"
  "\n"
  "\"In her is highe beauty without pride,\n"
  "And youth withoute greenhood* or folly:        *childishness, immaturity\n"
  "To all her workes virtue is her guide;\n"
  "Humbless hath slain in her all tyranny:\n"
  "She is the mirror of all courtesy,\n"
  "Her heart a very chamber of holiness,\n"
  "Her hand minister of freedom for almess*.\"                   *almsgiving\n"
  "\n"
  "And all this voice was sooth, as God is true;\n"
  "But now to purpose* let us turn again.                     *our tale <3>\n"
  "These merchants have done freight their shippes new,\n"
  "And when they have this blissful maiden seen,\n"
  "Home to Syria then they went full fain,\n"
  "And did their needes*, as they have done yore,*     *business **formerly\n"
  "And liv'd in weal*; I can you say no more.                   *prosperity\n"
  "\n"
  "Now fell it, that these merchants stood in grace*                *favour\n"
  "Of him that was the Soudan* of Syrie:                            *Sultan\n"
  "For when they came from any strange place\n"
  "He would of his benigne courtesy\n"
  "Make them good cheer, and busily espy*                          *inquire\n"
  "Tidings of sundry regnes*, for to lear**                 *realms **learn\n"
  "The wonders that they mighte see or hear.\n"
  "\n"
  "Amonges other thinges, specially\n"
  "These merchants have him told of Dame Constance\n"
  "So great nobless, in earnest so royally,\n"
  "That this Soudan hath caught so great pleasance*               *pleasure\n"
  "To have her figure in his remembrance,\n"
  "That all his lust*, and all his busy cure**,            *pleasure **care\n"
  "Was for to love her while his life may dure.\n"
  "\n"
  "Paraventure in thilke* large book,                                 *that\n"
  "Which that men call the heaven, y-written was\n"
  "With starres, when that he his birthe took,\n"
  "That he for love should have his death, alas!\n"
  "For in the starres, clearer than is glass,\n"
  "Is written, God wot, whoso could it read,\n"
  "The death of every man withoute dread.*                           *doubt\n"
  "\n"
  "In starres many a winter therebeforn\n"
  "Was writ the death of Hector, Achilles,\n"
  "Of Pompey, Julius, ere they were born;\n"
  "The strife of Thebes; and of Hercules,\n"
  "Of Samson, Turnus, and of Socrates\n"
  "The death; but mennes wittes be so dull,\n"
  "That no wight can well read it at the full.\n"
  "\n"
  "This Soudan for his privy council sent,\n"
  "And, *shortly of this matter for to pace*,          *to pass briefly by*\n"
  "He hath to them declared his intent,\n"
  "And told them certain, but* he might have grace                  *unless\n"
  "To have Constance, within a little space,\n"
  "He was but dead; and charged them in hie*                         *haste\n"
  "To shape* for his life some remedy.                            *contrive\n"
  "\n"
  "Diverse men diverse thinges said;\n"
  "And arguments they casten up and down;\n"
  "Many a subtle reason forth they laid;\n"
  "They speak of magic, and abusion*;                            *deception\n"
  "But finally, as in conclusion,\n"
  "They cannot see in that none avantage,\n"
  "Nor in no other way, save marriage.\n"
  "\n"
  "Then saw they therein such difficulty\n"
  "By way of reason, for to speak all plain,\n"
  "Because that there was such diversity\n"
  "Between their bothe lawes, that they sayn,\n"
  "They trowe* that no Christian prince would fain**   *believe **willingly\n"
  "Wedden his child under our lawe sweet,\n"
  "That us was given by Mahound* our prophete.                     *Mahomet\n"
  "\n"
  "And he answered: \"Rather than I lose\n"
  "Constance, I will be christen'd doubteless\n"
  "I must be hers, I may none other choose,\n"
  "I pray you hold your arguments in peace,<4>\n"
  "Save my life, and be not reckeless\n"
  "To gette her that hath my life in cure,*                        *keeping\n"
  "For in this woe I may not long endure.\"\n"
  "\n"
  "What needeth greater dilatation?\n"
  "I say, by treaty and ambassadry,\n"
  "And by the Pope's mediation,\n"
  "And all the Church, and all the chivalry,\n"
  "That in destruction of Mah'metry,*                         *Mahometanism\n"
  "And in increase of Christe's lawe dear,\n"
  "They be accorded* so as ye may hear;                             *agreed\n"
  "\n"
  "How that the Soudan, and his baronage,\n"
  "And all his lieges, shall y-christen'd be,\n"
  "And he shall have Constance in marriage,\n"
  "And certain gold, I n'ot* what quantity,                       *know not\n"
  "And hereto find they suffisant surety.\n"
  "The same accord is sworn on either side;\n"
  "Now, fair Constance, Almighty God thee guide!\n"
  "\n"
  "Now woulde some men waiten, as I guess,\n"
  "That I should tellen all the purveyance*,                     *provision\n"
  "The which the emperor of his noblesse\n"
  "Hath shapen* for his daughter, Dame Constance.                 *prepared\n"
  "Well may men know that so great ordinance\n"
  "May no man tellen in a little clause,\n"
  "As was arrayed for so high a cause.\n"
  "\n"
  "Bishops be shapen with her for to wend,\n"
  "Lordes, ladies, and knightes of renown,\n"
  "And other folk enough, this is the end.\n"
  "And notified is throughout all the town,\n"
  "That every wight with great devotioun\n"
  "Should pray to Christ, that he this marriage\n"
  "Receive *in gree*, and speede this voyage.      *with good will, favour*\n"
  "\n"
  "The day is comen of her departing, --\n"
  "I say the woful fatal day is come,\n"
  "That there may be no longer tarrying,\n"
  "But forward they them dressen* all and some.        *prepare to set out*\n"
  "Constance, that was with sorrow all o'ercome,\n"
  "Full pale arose, and dressed her to wend,\n"
  "For well she saw there was no other end.\n"
  "\n"
  "Alas! what wonder is it though she wept,\n"
  "That shall be sent to a strange nation\n"
  "From friendes, that so tenderly her kept,\n"
  "And to be bound under subjection\n"
  "of one, she knew not his condition?\n"
  "Husbands be all good, and have been *of yore*,                  *of old*\n"
  "That knowe wives; I dare say no more.\n"
  "\n"
  "\"Father,\" she said, \"thy wretched child Constance,\n"
  "Thy younge daughter, foster'd up so soft,\n"
  "And you, my mother, my sov'reign pleasance\n"
  "Over all thing, out-taken* Christ *on loft*,          *except  *on high*\n"
  "Constance your child her recommendeth oft\n"
  "Unto your grace; for I shall to Syrie,\n"
  "Nor shall I ever see you more with eye.\n"
  "\n"
  "\"Alas! unto the barbarous nation\n"
  "I must anon, since that it is your will:\n"
  "But Christ, that starf* for our redemption,                        *died\n"
  "So give me grace his hestes* to fulfil.                        *commands\n"
  "I, wretched woman, *no force though I spill!*          *no matter though\n"
  "Women are born to thraldom and penance,                        I perish*\n"
  "And to be under mannes governance.\"\n"
  "\n"
  "I trow at Troy when Pyrrhus brake the wall,\n"
  "Or Ilion burnt, or Thebes the city,\n"
  "Nor at Rome for the harm through Hannibal,\n"
  "That Romans hath y-vanquish'd times three,\n"
  "Was heard such tender weeping for pity,\n"
  "As in the chamber was for her parting;\n"
  "But forth she must, whether she weep or sing.\n"
  "\n"
  "O firste moving cruel Firmament,<5>\n"
  "With thy diurnal sway that crowdest* aye,     *pushest together, drivest\n"
  "And hurtlest all from East till Occident\n"
  "That naturally would hold another way;\n"
  "Thy crowding set the heav'n in such array\n"
  "At the beginning of this fierce voyage,\n"
  "That cruel Mars hath slain this marriage.\n"
  "\n"
  "Unfortunate ascendant tortuous,\n"
  "Of which the lord is helpless fall'n, alas!\n"
  "Out of his angle into the darkest house;\n"
  "O Mars, O Atyzar,<6> as in this case;\n"
  "O feeble Moon, unhappy is thy pace.*                           *progress\n"
  "Thou knittest thee where thou art not receiv'd,\n"
  "Where thou wert well, from thennes art thou weiv'd. <7>\n"
  "\n"
  "Imprudent emperor of Rome, alas!\n"
  "Was there no philosopher in all thy town?\n"
  "Is no time bet* than other in such case?                         *better\n"
  "Of voyage is there none election,\n"
  "Namely* to folk of high condition,                           *especially\n"
  "Not *when a root is of a birth y-know?*     *when the nativity is known*\n"
  "Alas! we be too lewed*, or too slow.                           *ignorant\n"
  "\n"
  "To ship was brought this woeful faire maid\n"
  "Solemnely, with every circumstance:\n"
  "\"Now Jesus Christ be with you all,\" she said.\n"
  "There is no more,but \"Farewell, fair Constance.\"\n"
  "She *pained her* to make good countenance.              *made an effort*\n"
  "And forth I let her sail in this manner,\n"
  "And turn I will again to my matter.\n"
  "\n"
  "The mother of the Soudan, well of vices,\n"
  "Espied hath her sone's plain intent,\n"
  "How he will leave his olde sacrifices:\n"
  "And right anon she for her council sent,\n"
  "And they be come, to knowe what she meant,\n"
  "And when assembled was this folk *in fere*,                   *together*\n"
  "She sat her down, and said as ye shall hear.\n"
  "\n"
  "\"Lordes,\" she said, \"ye knowen every one,\n"
  "How that my son in point is for to lete*                        *forsake\n"
  "The holy lawes of our Alkaron*,                                   *Koran\n"
  "Given by God's messenger Mahomete:\n"
  "But one avow to greate God I hete*,                             *promise\n"
  "Life shall rather out of my body start,\n"
  "Than Mahomet's law go out of mine heart.\n"
  "\n"
  "\"What should us tiden* of this newe law,                 *betide, befall\n"
  "But thraldom to our bodies, and penance,\n"
  "And afterward in hell to be y-draw,\n"
  "For we *renied Mahound our creance?*         *denied Mahomet our belief*\n"
  "But, lordes, will ye maken assurance,\n"
  "As I shall say, assenting to my lore*?                           *advice\n"
  "And I shall make us safe for evermore.\"\n"
  "\n"
  "They sworen and assented every man\n"
  "To live with her and die, and by her stand:\n"
  "And every one, in the best wise he can,\n"
  "To strengthen her shall all his friendes fand.*            *endeavour<8>\n"
  "And she hath this emprise taken in hand,\n"
  "Which ye shall heare that I shall devise*;                       *relate\n"
  "And to them all she spake right in this wise.\n"
  "\n"
  "\"We shall first feign us *Christendom to take*;   *embrace Christianity*\n"
  "Cold water shall not grieve us but a lite*:                      *little\n"
  "And I shall such a feast and revel make,\n"
  "That, as I trow, I shall the Soudan quite.*              *requite, match\n"
  "For though his wife be christen'd ne'er so white,\n"
  "She shall have need to wash away the red,\n"
  "Though she a fount of water with her led.\"\n"
  "\n"
  "O Soudaness*, root of iniquity,                               *Sultaness\n"
  "Virago thou, Semiramis the second!\n"
  "O serpent under femininity,\n"
  "Like to the serpent deep in hell y-bound!\n"
  "O feigned woman, all that may confound\n"
  "Virtue and innocence, through thy malice,\n"
  "Is bred in thee, as nest of every vice!\n"
  "\n"
  "O Satan envious! since thilke day\n"
  "That thou wert chased from our heritage,\n"
  "Well knowest thou to woman th' olde way.\n"
  "Thou madest Eve to bring us in servage*:                        *bondage\n"
  "Thou wilt fordo* this Christian marriage:                          *ruin\n"
  "Thine instrument so (well-away the while!)\n"
  "Mak'st thou of women when thou wilt beguile.\n"
  "\n"
  "This Soudaness, whom I thus blame and warray*,          *oppose, censure\n"
  "Let privily her council go their way:\n"
  "Why should I in this tale longer tarry?\n"
  "She rode unto the Soudan on a day,\n"
  "And said him, that she would *reny her lay,*        *renounce her creed*\n"
  "And Christendom of priestes' handes fong*,                      *take<9>\n"
  "Repenting her she heathen was so long;\n"
  "\n"
  "Beseeching him to do her that honour,\n"
  "That she might have the Christian folk to feast:\n"
  "\"To please them I will do my labour.\"\n"
  "The Soudan said, \"I will do at your hest,*\"                      *desire\n"
  "And kneeling, thanked her for that request;\n"
  "So glad he was, he wist* not what to say.                          *knew\n"
  "She kiss'd her son, and home she went her way.\n"
  "\n"
  "Arrived be these Christian folk to land\n"
  "In Syria, with a great solemne rout,\n"
  "And hastily this Soudan sent his sond,*                         *message\n"
  "First to his mother, and all the realm about,\n"
  "And said, his wife was comen out of doubt,\n"
  "And pray'd them for to ride again* the queen,                   *to meet\n"
  "The honour of his regne* to sustene.                              *realm\n"
  "\n"
  "Great was the press, and rich was the array\n"
  "Of Syrians and Romans met *in fere*.                        *in company*\n"
  "The mother of the Soudan rich and gay\n"
  "Received her with all so glad a cheer*                             *face\n"
  "As any mother might her daughter dear\n"
  "And to the nexte city there beside\n"
  "A softe pace solemnely they ride.\n"
  "\n"
  "Nought, trow I, the triumph of Julius\n"
  "Of which that Lucan maketh such a boast,\n"
  "Was royaller, or more curious,\n"
  "Than was th' assembly of this blissful host\n"
  "But O this scorpion, this wicked ghost,*                         *spirit\n"
  "The Soudaness, for all her flattering\n"
  "Cast* under this full mortally to sting.                      *contrived\n"
  "\n"
  "The Soudan came himself soon after this,\n"
  "So royally, that wonder is to tell,\n"
  "And welcomed her with all joy and bliss.\n"
  "And thus in mirth and joy I let them dwell.\n"
  "The fruit of his matter is that I tell;\n"
  "When the time came, men thought it for the best\n"
  "That revel stint,* and men go to their rest.                      *cease\n"
  "\n"
  "The time is come that this old Soudaness\n"
  "Ordained hath the feast of which I told,\n"
  "And to the feast the Christian folk them dress\n"
  "In general, yea, bothe young and old.\n"
  "There may men feast and royalty behold,\n"
  "And dainties more than I can you devise;\n"
  "But all too dear they bought it ere they rise.\n"
  "\n"
  "O sudden woe, that ev'r art successour\n"
  "To worldly bliss! sprent* is with bitterness                  *sprinkled\n"
  "Th' end of our joy, of our worldly labour;\n"
  "Woe *occupies the fine* of our gladness.                *seizes the end*\n"
  "Hearken this counsel, for thy sickerness*:                     *security\n"
  "Upon thy glade days have in thy mind\n"
  "The unware* woe of harm, that comes behind.                  *unforeseen\n"
  "\n"
  "For, shortly for to tell it at a word,\n"
  "The Soudan and the Christians every one\n"
  "Were all *to-hewn and sticked* at the board,             *cut to pieces*\n"
  "But it were only Dame Constance alone.\n"
  "This olde Soudaness, this cursed crone,\n"
  "Had with her friendes done this cursed deed,\n"
  "For she herself would all the country lead.\n"
  "\n"
  "Nor there was Syrian that was converted,\n"
  "That of the counsel of the Soudan wot*,                            *knew\n"
  "That was not all to-hewn, ere he asterted*:                     *escaped\n"
  "And Constance have they ta'en anon foot-hot*,               *immediately\n"
  "And in a ship all steereless,* God wot,                  *without rudder\n"
  "They have her set, and bid her learn to sail\n"
  "Out of Syria *again-ward to Itale.*                      *back to Italy*\n"
  "\n"
  "A certain treasure that she thither lad,*                          *took\n"
  "And, sooth to say, of victual great plenty,\n"
  "They have her giv'n, and clothes eke she had\n"
  "And forth she sailed in the salte sea:\n"
  "O my Constance, full of benignity,\n"
  "O emperores younge daughter dear,\n"
  "He that is lord of fortune be thy steer*!                 *rudder, guide\n"
  "\n"
  "She bless'd herself, and with full piteous voice\n"
  "Unto the cross of Christ thus saide she;\n"
  "\"O dear, O wealful* altar, holy cross,              *blessed, beneficent\n"
  "Red of the Lambes blood, full of pity,\n"
  "That wash'd the world from old iniquity,\n"
  "Me from the fiend and from his clawes keep,\n"
  "That day that I shall drenchen* in the deepe.                     *drown\n"
  "\n"
  "\"Victorious tree, protection of the true,\n"
  "That only worthy were for to bear\n"
  "The King of Heaven, with his woundes new,\n"
  "The white Lamb, that hurt was with a spear;\n"
  "Flemer* of fiendes out of him and her              *banisher, driver out\n"
  "On which thy limbes faithfully extend,<10>\n"
  "Me keep, and give me might my life to mend.\"\n"
  "\n"
  "Yeares and days floated this creature\n"
  "Throughout the sea of Greece, unto the strait\n"
  "Of Maroc*, as it was her a venture:                  *Morocco; Gibraltar\n"
  "On many a sorry meal now may she bait,\n"
  "After her death full often may she wait*,                        *expect\n"
  "Ere that the wilde waves will her drive\n"
  "Unto the place *there as* she shall arrive.                       *where\n"
  "\n"
  "Men mighten aske, why she was not slain?\n"
  "Eke at the feast who might her body save?\n"
  "And I answer to that demand again,\n"
  "Who saved Daniel in the horrible cave,\n"
  "Where every wight, save he, master or knave*,                   *servant\n"
  "Was with the lion frett*, ere he astart?**          *devoured ** escaped\n"
  "No wight but God, that he bare in his heart.\n"
  "\n"
  "God list* to shew his wonderful miracle                      *it pleased\n"
  "In her, that we should see his mighty workes:\n"
  "Christ, which that is to every harm triacle*,             *remedy, salve\n"
  "By certain meanes oft, as knowe clerkes*,                      *scholars\n"
  "Doth thing for certain ende, that full derk is\n"
  "To manne's wit, that for our, ignorance\n"
  "Ne cannot know his prudent purveyance*.                       *foresight\n"
  "\n"
  "Now since she was not at the feast y-slaw,*                       *slain\n"
  "Who kepte her from drowning in the sea?\n"
  "Who kepte Jonas in the fish's maw,\n"
  "Till he was spouted up at Nineveh?\n"
  "Well may men know, it was no wight but he\n"
  "That kept the Hebrew people from drowning,\n"
  "With drye feet throughout the sea passing.\n"
  "\n"
  "Who bade the foure spirits of tempest,<11>\n"
  "That power have t' annoye land and sea,\n"
  "Both north and south, and also west and east,\n"
  "Annoye neither sea, nor land, nor tree?\n"
  "Soothly the commander of that was he\n"
  "That from the tempest aye this woman kept,\n"
  "As well when she awoke as when she slept.\n"
  "\n"
  "Where might this woman meat and drinke have?\n"
  "Three year and more how lasted her vitaille*?                  *victuals\n"
  "Who fed the Egyptian Mary in the cave\n"
  "Or in desert? no wight but Christ *sans faille.*          *without fail*\n"
  "Five thousand folk it was as great marvaille\n"
  "With loaves five and fishes two to feed\n"
  "God sent his foison* at her greate need.                      *abundance\n"
  "\n"
  "She drived forth into our ocean\n"
  "Throughout our wilde sea, till at the last\n"
  "Under an hold*, that nempnen** I not can,                 *castle **name\n"
  "Far in Northumberland, the wave her cast\n"
  "And in the sand her ship sticked so fast\n"
  "That thennes would it not in all a tide: <12>\n"
  "The will of Christ was that she should abide.\n"
  "\n"
  "The Constable of the castle down did fare*                           *go\n"
  "To see this wreck, and all the ship he sought*,                *searched\n"
  "And found this weary woman full of care;\n"
  "He found also the treasure that she brought:\n"
  "In her language mercy she besought,\n"
  "The life out of her body for to twin*,                           *divide\n"
  "Her to deliver of woe that she was in.\n"
  "\n"
  "A manner Latin corrupt <13> was her speech,\n"
  "But algate* thereby was she understond.                    *nevertheless\n"
  "The Constable, when him list no longer seech*,                   *search\n"
  "This woeful woman brought he to the lond.\n"
  "She kneeled down, and thanked *Godde's sond*;        *what God had sent*\n"
  "But what she was she would to no man say\n"
  "For foul nor fair, although that she should dey.*                   *die\n"
  "\n"
  "She said, she was so mazed in the sea,\n"
  "That she forgot her minde, by her truth.\n"
  "The Constable had of her so great pity\n"
  "And eke his wife, that they wept for ruth:*                        *pity\n"
  "She was so diligent withoute slouth\n"
  "To serve and please every one in that place,\n"
  "That all her lov'd, that looked in her face.\n"
  "\n"
  "The Constable and Dame Hermegild his wife\n"
  "Were Pagans, and that country every where;\n"
  "But Hermegild lov'd Constance as her life;\n"
  "And Constance had so long sojourned there\n"
  "In orisons, with many a bitter tear,\n"
  "Till Jesus had converted through His grace\n"
  "Dame Hermegild, Constabless of that place.\n"
  "\n"
  "In all that land no Christians durste rout;*                   *assemble\n"
  "All Christian folk had fled from that country\n"
  "Through Pagans, that conquered all about\n"
  "The plages* of the North by land and sea.               *regions, coasts\n"
  "To Wales had fled the *Christianity                 *the Old Britons who\n"
  "Of olde Britons,* dwelling in this isle;                were Christians*\n"
  "There was their refuge for the meanewhile.\n"
  "\n"
  "But yet n'ere* Christian Britons so exiled,                  *there were\n"
  "That there n'ere* some which in their privity                        not\n"
  "Honoured Christ, and heathen folk beguiled;\n"
  "And nigh the castle such there dwelled three:\n"
  "And one of them was blind, and might not see,\n"
  "But* it were with thilk* eyen of his mind,               *except **those\n"
  "With which men maye see when they be blind.\n"
  "\n"
  "Bright was the sun, as in a summer's day,\n"
  "For which the Constable, and his wife also,\n"
  "And Constance, have y-take the righte way\n"
  "Toward the sea a furlong way or two,\n"
  "To playen, and to roame to and fro;\n"
  "And in their walk this blinde man they met,\n"
  "Crooked and old, with eyen fast y-shet.*                           *shut\n"
  "\n"
  "\"In the name of Christ,\" cried this blind Briton,\n"
  "\"Dame Hermegild, give me my sight again!\"\n"
  "This lady *wax'd afrayed of that soun',*       *was alarmed by that cry*\n"
  "Lest that her husband, shortly for to sayn,\n"
  "Would her for Jesus Christe's love have slain,\n"
  "Till Constance made her hold, and bade her wirch*                  *work\n"
  "The will of Christ, as daughter of holy Church\n"
  "\n"
  "The Constable wax'd abashed* of that sight,                  *astonished\n"
  "And saide; *\"What amounteth all this fare?\"*             *what means all\n"
  "Constance answered; \"Sir, it is Christ's might,               this ado?*\n"
  "That helpeth folk out of the fiendes snare:\"\n"
  "And *so farforth* she gan our law declare,            *with such effect*\n"
  "That she the Constable, ere that it were eve,\n"
  "Converted, and on Christ made him believe.\n"
  "\n"
  "This Constable was not lord of the place\n"
  "Of which I speak, there as he Constance fand,*                    *found\n"
  "But kept it strongly many a winter space,\n"
  "Under Alla, king of Northumberland,\n"
  "That was full wise, and worthy of his hand\n"
  "Against the Scotes, as men may well hear;\n"
  "But turn I will again to my mattere.\n"
  "\n"
  "Satan, that ever us waiteth to beguile,\n"
  "Saw of Constance all her perfectioun,\n"
  "And *cast anon how he might quite her while;*    *considered how to have\n"
  "And made a young knight, that dwelt in that town,        revenge on her*\n"
  "Love her so hot of foul affectioun,\n"
  "That verily him thought that he should spill*                    *perish\n"
  "But* he of her might ones have his will.                         *unless\n"
  "\n"
  "He wooed her, but it availed nought;\n"
  "She woulde do no sinne by no way:\n"
  "And for despite, he compassed his thought\n"
  "To make her a shameful death to dey;*                               *die\n"
  "He waiteth when the Constable is away,\n"
  "And privily upon a night he crept\n"
  "In Hermegilda's chamber while she slept.\n"
  "\n"
  "";
// }

const char manOfLawsTale1[] PGMSECTION = // { // 30787 bytes
  "Weary, forwaked* in her orisons,                 *having been long awake\n"
  "Sleepeth Constance, and Hermegild also.\n"
  "This knight, through Satanas' temptation;\n"
  "All softetly is to the bed y-go,*                                  *gone\n"
  "And cut the throat of Hermegild in two,\n"
  "And laid the bloody knife by Dame Constance,\n"
  "And went his way, there God give him mischance.\n"
  "\n"
  "Soon after came the Constable home again,\n"
  "And eke Alla that king was of that land,\n"
  "And saw his wife dispiteously* slain,                           *cruelly\n"
  "For which full oft he wept and wrung his hand;\n"
  "And ill the bed the bloody knife he fand\n"
  "By Dame Constance: Alas! what might she say?\n"
  "For very woe her wit was all away.\n"
  "\n"
  "To King Alla was told all this mischance\n"
  "And eke the time, and where, and in what wise\n"
  "That in a ship was founden this Constance,\n"
  "As here before ye have me heard devise:*                       *describe\n"
  "The kinges heart for pity *gan agrise,*      *to be grieved, to tremble*\n"
  "When he saw so benign a creature\n"
  "Fall in disease* and in misaventure.                           *distress\n"
  "\n"
  "For as the lamb toward his death is brought,\n"
  "So stood this innocent before the king:\n"
  "This false knight, that had this treason wrought,\n"
  "*Bore her in hand* that she had done this thing:   *accused her falsely*\n"
  "But natheless there was great murmuring\n"
  "Among the people, that say they cannot guess\n"
  "That she had done so great a wickedness.\n"
  "\n"
  "For they had seen her ever virtuous,\n"
  "And loving Hermegild right as her life:\n"
  "Of this bare witness each one in that house,\n"
  "Save he that Hermegild slew with his knife:\n"
  "This gentle king had *caught a great motife*         *been greatly moved\n"
  "Of this witness, and thought he would inquere           by the evidence*\n"
  "Deeper into this case, the truth to lear.*                        *learn\n"
  "\n"
  "Alas! Constance, thou has no champion,\n"
  "Nor fighte canst thou not, so well-away!\n"
  "But he that starf for our redemption,                              *died\n"
  "And bound Satan, and yet li'th where he lay,\n"
  "So be thy stronge champion this day:\n"
  "For, but Christ upon thee miracle kithe,*                          *show\n"
  "Withoute guilt thou shalt be slain *as swithe.*            *immediately*\n"
  "\n"
  "She set her down on knees, and thus she said;\n"
  "\"Immortal God, that savedest Susanne\n"
  "From false blame; and thou merciful maid,\n"
  "Mary I mean, the daughter to Saint Anne,\n"
  "Before whose child the angels sing Osanne,*                     *Hosanna\n"
  "If I be guiltless of this felony,\n"
  "My succour be, or elles shall I die.\"\n"
  "\n"
  "Have ye not seen sometime a pale face\n"
  "(Among a press) of him that hath been lad*                          *led\n"
  "Toward his death, where he getteth no grace,\n"
  "And such a colour in his face hath had,\n"
  "Men mighte know him that was so bestad*                *bested, situated\n"
  "Amonges all the faces in that rout?\n"
  "So stood Constance, and looked her about.\n"
  "\n"
  "O queenes living in prosperity,\n"
  "Duchesses, and ye ladies every one,\n"
  "Have some ruth* on her adversity!                                  *pity\n"
  "An emperor's daughter, she stood alone;\n"
  "She had no wight to whom to make her moan.\n"
  "O blood royal, that standest in this drede,*                     *danger\n"
  "Far be thy friendes in thy greate need!\n"
  "\n"
  "This king Alla had such compassioun,\n"
  "As gentle heart is full filled of pity,\n"
  "That from his eyen ran the water down\n"
  "\"Now hastily do fetch a book,\" quoth he;\n"
  "\"And if this knight will sweare, how that she\n"
  "This woman slew, yet will we us advise*                        *consider\n"
  "Whom that we will that shall be our justice.\"\n"
  "\n"
  "A Briton book, written with Evangiles,*                     *the Gospels\n"
  "Was  fetched, and on this book he swore anon\n"
  "She guilty was; and, in the meanewhiles,\n"
  "An hand him smote upon the necke bone,\n"
  "That down he fell at once right as a stone:\n"
  "And both his eyen burst out of his face\n"
  "In sight of ev'rybody in that place.\n"
  "\n"
  "A voice was heard, in general audience,\n"
  "That said; \"Thou hast deslander'd guilteless\n"
  "The daughter of holy Church in high presence;\n"
  "Thus hast thou done, and yet *hold I my peace?\"*    *shall I be silent?*\n"
  "Of this marvel aghast was all the press,\n"
  "As mazed folk they stood every one\n"
  "For dread of wreake,* save Constance alone.                   *vengeance\n"
  "\n"
  "Great was the dread and eke the repentance\n"
  "Of them that hadde wrong suspicion\n"
  "Upon this sely* innocent Constance;                    *simple, harmless\n"
  "And for this miracle, in conclusion,\n"
  "And by Constance's mediation,\n"
  "The king, and many another in that place,\n"
  "Converted was, thanked be Christe's grace!\n"
  "\n"
  "This false knight was slain for his untruth\n"
  "By judgement of Alla hastily;\n"
  "And yet Constance had of his death great ruth;*              *compassion\n"
  "And after this Jesus of his mercy\n"
  "Made Alla wedde full solemnely\n"
  "This holy woman, that is so bright and sheen,\n"
  "And thus hath Christ y-made Constance a queen.\n"
  "\n"
  "But who was woeful, if I shall not lie,\n"
  "Of this wedding but Donegild, and no mo',\n"
  "The kinge's mother, full of tyranny?\n"
  "Her thought her cursed heart would burst in two;\n"
  "She would not that her son had done so;\n"
  "Her thought it a despite that he should take\n"
  "So strange a creature unto his make.*                     *mate, consort\n"
  "\n"
  "Me list not of the chaff nor of the stre*                         *straw\n"
  "Make so long a tale, as of the corn.\n"
  "What should I tellen of the royalty\n"
  "Of this marriage, or which course goes beforn,\n"
  "Who bloweth in a trump or in an horn?\n"
  "The fruit of every tale is for to say;\n"
  "They eat and drink, and dance, and sing, and play.\n"
  "\n"
  "They go to bed, as it was skill* and right;                  *reasonable\n"
  "For though that wives be full holy things,\n"
  "They muste take in patience at night\n"
  "Such manner* necessaries as be pleasings                        *kind of\n"
  "To folk that have y-wedded them with rings,\n"
  "And lay *a lite* their holiness aside                      *a little of*\n"
  "As for the time, it may no better betide.\n"
  "\n"
  "On her he got a knave* child anon,                            *male <14>\n"
  "And to a Bishop and to his Constable eke\n"
  "He took his wife to keep, when he is gone\n"
  "To Scotland-ward, his foemen for to seek.\n"
  "Now fair Constance, that is so humble and meek,\n"
  "So long is gone with childe till that still\n"
  "She held her chamb'r, abiding Christe's will\n"
  "\n"
  "The time is come, a knave child she bare;\n"
  "Mauricius at the font-stone they him call.\n"
  "This Constable *doth forth come* a messenger,     *caused to come forth*\n"
  "And wrote unto his king that clep'd was All',\n"
  "How that this blissful tiding is befall,\n"
  "And other tidings speedful for to say\n"
  "He* hath the letter, and forth he go'th his way.     *i.e. the messenger\n"
  "\n"
  "This messenger, to *do his avantage,*         *promote his own interest*\n"
  "Unto the kinge's mother rideth swithe,*                         *swiftly\n"
  "And saluteth her full fair in his language.\n"
  "\"Madame,\" quoth he, \"ye may be glad and blithe,\n"
  "And thanke God an hundred thousand sithe;*                        *times\n"
  "My lady queen hath child, withoute doubt,\n"
  "To joy and bliss of all this realm about.\n"
  "\n"
  "\"Lo, here the letter sealed of this thing,\n"
  "That I must bear with all the haste I may:\n"
  "If ye will aught unto your son the king,\n"
  "I am your servant both by night and day.\"\n"
  "Donegild answer'd, \"As now at this time, nay;\n"
  "But here I will all night thou take thy rest,\n"
  "To-morrow will I say thee what me lest.*\"                       *pleases\n"
  "\n"
  "This messenger drank sadly* ale and wine,                      *steadily\n"
  "And stolen were his letters privily\n"
  "Out of his box, while he slept as a swine;\n"
  "And counterfeited was full subtilly\n"
  "Another letter, wrote full sinfully,\n"
  "Unto the king, direct of this mattere\n"
  "From his Constable, as ye shall after hear.\n"
  "\n"
  "This letter said, the queen deliver'd was\n"
  "Of so horrible a fiendlike creature,\n"
  "That in the castle none so hardy* was                             *brave\n"
  "That any while he durst therein endure:\n"
  "The mother was an elf by aventure\n"
  "Become, by charmes or by sorcery,\n"
  "And every man hated her company.\n"
  "\n"
  "Woe was this king when he this letter had seen,\n"
  "But to no wight he told his sorrows sore,\n"
  "But with his owen hand he wrote again,\n"
  "\"Welcome the sond* of Christ for evermore                 *will, sending\n"
  "To me, that am now learned in this lore:\n"
  "Lord, welcome be thy lust* and thy pleasance,            *will, pleasure\n"
  "My lust I put all in thine ordinance.\n"
  "\n"
  "\"Keepe*  this child, albeit foul or fair,                      *preserve\n"
  "And eke my wife, unto mine homecoming:\n"
  "Christ when him list may send to me an heir\n"
  "More agreeable than this to my liking.\"\n"
  "This letter he sealed, privily weeping.\n"
  "Which to the messenger was taken soon,\n"
  "And forth he went, there is no more to do'n.*                        *do\n"
  "\n"
  "O messenger full fill'd of drunkenness,\n"
  "Strong is thy breath, thy limbes falter aye,\n"
  "And thou betrayest alle secretness;\n"
  "Thy mind is lorn,* thou janglest as a jay;                         *lost\n"
  "Thy face is turned in a new array;*                              *aspect\n"
  "Where drunkenness reigneth in any rout,*                        *company\n"
  "There is no counsel hid, withoute doubt.\n"
  "\n"
  "O Donegild, I have no English dign*                              *worthy\n"
  "Unto thy malice, and thy tyranny:\n"
  "And therefore to the fiend I thee resign,\n"
  "Let him indite of all thy treachery\n"
  "'Fy, mannish,* fy! O nay, by God I lie;                 *unwomanly woman\n"
  "Fy, fiendlike spirit! for I dare well tell,\n"
  "Though thou here walk, thy spirit is in hell.\n"
  "\n"
  "This messenger came from the king again,\n"
  "And at the kinge's mother's court he light,*                   *alighted\n"
  "And she was of this messenger full fain,*                          *glad\n"
  "And pleased him in all that e'er she might.\n"
  "He drank, and *well his girdle underpight*;        *stowed away (liquor)\n"
  "He slept, and eke he snored in his guise               under his girdle*\n"
  "All night, until the sun began to rise.\n"
  "\n"
  "Eft* were his letters stolen every one,                           *again\n"
  "And counterfeited letters in this wise:\n"
  "The king commanded his Constable anon,\n"
  "On pain of hanging and of high jewise,*                       *judgement\n"
  "That he should suffer in no manner wise\n"
  "Constance within his regne* for to abide                        *kingdom\n"
  "Three dayes, and a quarter of a tide;\n"
  "\n"
  "But in the same ship as he her fand,\n"
  "Her and her younge son, and all her gear,\n"
  "He shoulde put, and crowd* her from the land,                      *push\n"
  "And charge her, that she never eft come there.\n"
  "O my Constance, well may thy ghost* have fear,                   *spirit\n"
  "And sleeping in thy dream be in penance,*                 *pain, trouble\n"
  "When Donegild cast* all this ordinance.**        *contrived **plan, plot\n"
  "\n"
  "This messenger, on morrow when he woke,\n"
  "Unto the castle held the nexte* way,                            *nearest\n"
  "And to the constable the letter took;\n"
  "And when he this dispiteous* letter sey,**                  *cruel **saw\n"
  "Full oft he said, \"Alas, and well-away!\n"
  "Lord Christ,\" quoth he, \"how may this world endure?\n"
  "So full of sin is many a creature.\n"
  "\n"
  "\"O mighty God, if that it be thy will,\n"
  "Since thou art rightful judge, how may it be\n"
  "That thou wilt suffer innocence to spill,*                 *be destroyed\n"
  "And wicked folk reign in prosperity?\n"
  "Ah! good Constance, alas! so woe is me,\n"
  "That I must be thy tormentor, or dey*                               *die\n"
  "A shameful death, there is no other way.\n"
  "\n"
  "Wept bothe young and old in all that place,\n"
  "When that the king this cursed letter sent;\n"
  "And Constance, with a deadly pale face,\n"
  "The fourthe day toward her ship she went.\n"
  "But natheless she took in good intent\n"
  "The will of Christ, and kneeling on the strond*           *strand, shore\n"
  "She saide, \"Lord, aye welcome be thy sond*        *whatever thou sendest\n"
  "\n"
  "\"He that me kepte from the false blame,\n"
  "While I was in the land amonges you,\n"
  "He can me keep from harm and eke from shame\n"
  "In the salt sea, although I see not how\n"
  "As strong as ever he was, he is yet now,\n"
  "In him trust I, and in his mother dere,\n"
  "That is to me my sail and eke my stere.\"*                 *rudder, guide\n"
  "\n"
  "Her little child lay weeping in her arm\n"
  "And, kneeling, piteously to him she said\n"
  "\"Peace, little son, I will do thee no harm:\"\n"
  "With that her kerchief off her head she braid,*              *took, drew\n"
  "And over his little eyen she it laid,\n"
  "And in her arm she lulled it full fast,\n"
  "And unto heav'n her eyen up she cast.\n"
  "\n"
  "\"Mother,\" quoth she, \"and maiden bright, Mary,\n"
  "Sooth is, that through a woman's eggement*        *incitement, egging on\n"
  "Mankind was lorn,* and damned aye to die;                          *lost\n"
  "For which thy child was on a cross y-rent:*               *torn, pierced\n"
  "Thy blissful eyen saw all his torment,\n"
  "Then is there no comparison between\n"
  "Thy woe, and any woe man may sustene.\n"
  "\n"
  "\"Thou saw'st thy child y-slain before thine eyen,\n"
  "And yet now lives my little child, parfay:*                 *by my faith\n"
  "Now, lady bright, to whom the woeful cryen,\n"
  "Thou glory of womanhood, thou faire may,*                          *maid\n"
  "Thou haven of refuge, bright star of day,\n"
  "Rue* on my child, that of thy gentleness                      *take pity\n"
  "Ruest on every rueful* in distress.                    *sorrowful person\n"
  "\n"
  "\"O little child, alas! what is thy guilt,\n"
  "That never wroughtest sin as yet, pardie?*             *par Dieu; by God\n"
  "Why will thine harde* father have thee spilt?**       *cruel **destroyed\n"
  "O mercy, deare Constable,\" quoth she,\n"
  "\"And let my little child here dwell with thee:\n"
  "And if thou dar'st not save him from blame,\n"
  "So kiss him ones in his father's name.\"\n"
  "\n"
  "Therewith she looked backward to the land,\n"
  "And saide, \"Farewell, husband rutheless!\"\n"
  "And up she rose, and walked down the strand\n"
  "Toward the ship, her following all the press:*                *multitude\n"
  "And ever she pray'd her child to hold his peace,\n"
  "And took her leave, and with an holy intent\n"
  "She blessed her, and to the ship she went.\n"
  "\n"
  "Victualed was the ship, it is no drede,*                          *doubt\n"
  "Abundantly for her a full long space:\n"
  "And other necessaries that should need*                       *be needed\n"
  "She had enough, heried* be Godde's grace:                  *praised <15>\n"
  "For wind and weather, Almighty God purchase,*                   *provide\n"
  "And bring her home; I can no better say;\n"
  "But in the sea she drived forth her way.\n"
  "\n"
  "Alla the king came home soon after this\n"
  "Unto the castle, of the which I told,\n"
  "And asked where his wife and his child is;\n"
  "The Constable gan about his heart feel cold,\n"
  "And plainly all the matter he him told\n"
  "As ye have heard; I can tell it no better;\n"
  "And shew'd the king his seal, and eke his letter\n"
  "\n"
  "And saide; \"Lord, as ye commanded me\n"
  "On pain of death, so have I done certain.\"\n"
  "The messenger tormented* was, till he                          *tortured\n"
  "Muste beknow,* and tell it flat and plain,                 *confess <16>\n"
  "From night to night in what place he had lain;\n"
  "And thus, by wit and subtle inquiring,\n"
  "Imagin'd was by whom this harm gan spring.\n"
  "\n"
  "The hand was known that had the letter wrote,\n"
  "And all the venom of the cursed deed;\n"
  "But in what wise, certainly I know not.\n"
  "Th' effect is this, that Alla, *out of drede,*           *without doubt*\n"
  "His mother slew, that may men plainly read,\n"
  "For that she traitor was to her liegeance:*                  *allegiance\n"
  "Thus ended olde Donegild with mischance.\n"
  "\n"
  "The sorrow that this Alla night and day\n"
  "Made for his wife, and for his child also,\n"
  "There is no tongue that it telle may.\n"
  "But now will I again to Constance go,\n"
  "That floated in the sea in pain and woe\n"
  "Five year and more, as liked Christe's sond,*           *decree, command\n"
  "Ere that her ship approached to the lond.*                         *land\n"
  "\n"
  "Under an heathen castle, at the last,\n"
  "Of which the name in my text I not find,\n"
  "Constance and eke her child the sea upcast.\n"
  "Almighty God, that saved all mankind,\n"
  "Have on Constance and on her child some mind,\n"
  "That fallen is in heathen hand eftsoon*                           *again\n"
  "*In point to spill,* as I shall tell you soon!             *in danger of\n"
  "                                                              perishing*\n"
  "Down from the castle came there many a wight\n"
  "To gauren* on this ship, and on Constance:                  *gaze, stare\n"
  "But shortly from the castle, on a night,\n"
  "The lorde's steward, -- God give him mischance, --\n"
  "A thief that had *renied our creance,*                *denied our faith*\n"
  "Came to the ship alone, and said he would\n"
  "Her leman* be, whether she would or n'ould.               *illicit lover\n"
  "\n"
  "Woe was this wretched woman then begone;\n"
  "Her child cri'd, and she cried piteously:\n"
  "But blissful Mary help'd her right anon,\n"
  "For, with her struggling well and mightily,\n"
  "The thief fell overboard all suddenly,\n"
  "And in the sea he drenched* for vengeance,                      *drowned\n"
  "And thus hath Christ unwemmed* kept Constance.              *unblemished\n"
  "\n"
  "O foul lust of luxury! lo thine end!\n"
  "Not only that thou faintest* manne's mind,                    *weakenest\n"
  "But verily thou wilt his body shend.*                           *destroy\n"
  "Th' end of thy work, or of thy lustes blind,\n"
  "Is complaining: how many may men find,\n"
  "That not for work, sometimes, but for th' intent\n"
  "To do this sin, be either slain or shent?\n"
  "\n"
  "How may this weake woman have the strength\n"
  "Her to defend against this renegate?\n"
  "O Goliath, unmeasurable of length,\n"
  "How mighte David make thee so mate?*                         *overthrown\n"
  "So young, and of armour so desolate,*                            *devoid\n"
  "How durst he look upon thy dreadful face?\n"
  "Well may men see it was but Godde's grace.\n"
  "\n"
  "Who gave Judith courage or hardiness\n"
  "To slay him, Holofernes, in his tent,\n"
  "And to deliver out of wretchedness\n"
  "The people of God? I say for this intent\n"
  "That right as God spirit of vigour sent\n"
  "To them, and saved them out of mischance,\n"
  "So sent he might and vigour to Constance.\n"
  "\n"
  "Forth went her ship throughout the narrow mouth\n"
  "Of *Jubaltare and Septe,* driving alway,           *Gibraltar and Ceuta*\n"
  "Sometime west, and sometime north and south,\n"
  "And sometime east, full many a weary day:\n"
  "Till Christe's mother (blessed be she aye)\n"
  "Had shaped* through her endeless goodness            *resolved, arranged\n"
  "To make an end of all her heaviness.\n"
  "\n"
  "Now let us stint* of Constance but a throw,**            *cease speaking\n"
  "And speak we of the Roman emperor,                          **short time\n"
  "That out of Syria had by letters know\n"
  "The slaughter of Christian folk, and dishonor\n"
  "Done to his daughter by a false traitor,\n"
  "I mean the cursed wicked Soudaness,\n"
  "That at the feast *let slay both more and less.*       *caused both high\n"
  "                                                   and low to be killed*\n"
  "For which this emperor had sent anon\n"
  "His senator, with royal ordinance,\n"
  "And other lordes, God wot, many a one,\n"
  "On Syrians to take high vengeance:\n"
  "They burn and slay, and bring them to mischance\n"
  "Full many a day: but shortly this is th' end,\n"
  "Homeward to Rome they shaped them to wend.\n"
  "\n"
  "This senator repaired with victory\n"
  "To Rome-ward, sailing full royally,\n"
  "And met the ship driving, as saith the story,\n"
  "In which Constance sat full piteously:\n"
  "And nothing knew he what she was, nor why\n"
  "She was in such array; nor she will say\n"
  "Of her estate, although that she should dey.*                       *die\n"
  "\n"
  "He brought her unto Rome, and to his wife\n"
  "He gave her, and her younge son also:\n"
  "And with the senator she led her life.\n"
  "Thus can our Lady bringen out of woe\n"
  "Woeful Constance, and many another mo':\n"
  "And longe time she dwelled in that place,\n"
  "In holy works ever, as was her grace.\n"
  "\n"
  "The senatores wife her aunte was,\n"
  "But for all that she knew her ne'er the more:\n"
  "I will no longer tarry in this case,\n"
  "But to King Alla, whom I spake of yore,\n"
  "That for his wife wept and sighed sore,\n"
  "I will return, and leave I will Constance\n"
  "Under the senatores governance.\n"
  "\n"
  "King Alla, which that had his mother slain,\n"
  "Upon a day fell in such repentance;\n"
  "That, if I shortly tell it shall and plain,\n"
  "To Rome he came to receive his penitance,\n"
  "And put him in the Pope's ordinance\n"
  "In high and low, and Jesus Christ besought\n"
  "Forgive his wicked works that he had wrought.\n"
  "\n"
  "The fame anon throughout the town is borne,\n"
  "How Alla king shall come on pilgrimage,\n"
  "By harbingers that wente him beforn,\n"
  "For which the senator, as was usage,\n"
  "Rode *him again,* and many of his lineage,                 *to meet him*\n"
  "As well to show his high magnificence,\n"
  "As to do any king a reverence.\n"
  "\n"
  "Great cheere* did this noble senator                           *courtesy\n"
  "To King Alla and he to him also;\n"
  "Each of them did the other great honor;\n"
  "And so befell, that in a day or two\n"
  "This senator did to King Alla go\n"
  "To feast, and shortly, if I shall not lie,\n"
  "Constance's son went in his company.\n"
  "\n"
  "Some men would say,<17> at request of Constance\n"
  "This senator had led this child to feast:\n"
  "I may not tellen every circumstance,\n"
  "Be as be may, there was he at the least:\n"
  "But sooth is this, that at his mother's hest*                    *behest\n"
  "Before Alla during *the meates space,*                       *meal time*\n"
  "The child stood, looking in the kinges face.\n"
  "\n"
  "This Alla king had of this child great wonder,\n"
  "And to the senator he said anon,\n"
  "\"Whose is that faire child that standeth yonder?\"\n"
  "\"I n'ot,\"* quoth he, \"by God and by Saint John;                *know not\n"
  "A mother he hath, but father hath he none,\n"
  "That I of wot:\" and shortly in a stound*                *short time <18>\n"
  "He told to Alla how this child was found.\n"
  "\n"
  "\"But God wot,\" quoth this senator also,\n"
  "\"So virtuous a liver in all my life\n"
  "I never saw, as she, nor heard of mo'\n"
  "Of worldly woman, maiden, widow or wife:\n"
  "I dare well say she hadde lever* a knife                         *rather\n"
  "Throughout her breast, than be a woman wick',*                   *wicked\n"
  "There is no man could bring her to that prick.*                   *point\n"
  "\n"
  "Now was this child as like unto Constance\n"
  "As possible is a creature to be:\n"
  "This Alla had the face in remembrance\n"
  "Of Dame Constance, and thereon mused he,\n"
  "If that the childe's mother *were aught she*              *could be she*\n"
  "That was his wife; and privily he sight,*                        *sighed\n"
  "And sped him from the table *that he might.*       *as fast as he could*\n"
  "\n"
  "\"Parfay,\"* thought he, \"phantom** is in mine head.          *by my faith\n"
  "I ought to deem, of skilful judgement,                       **a fantasy\n"
  "That in the salte sea my wife is dead.\"\n"
  "And afterward he made his argument,\n"
  "\"What wot I, if that Christ have hither sent\n"
  "My wife by sea, as well as he her sent\n"
  "To my country, from thennes that she went?\"\n"
  "\n"
  "And, after noon, home with the senator.\n"
  "Went Alla, for to see this wondrous chance.\n"
  "This senator did Alla great honor,\n"
  "And hastily he sent after Constance:\n"
  "But truste well, her liste not to dance.\n"
  "When that she wiste wherefore was that sond,*                   *summons\n"
  "Unneth* upon her feet she mighte stand.                 *with difficulty\n"
  "\n"
  "When Alla saw his wife, fair he her gret,*                      *greeted\n"
  "And wept, that it was ruthe for to see,\n"
  "For at the firste look he on her set\n"
  "He knew well verily that it was she:\n"
  "And she, for sorrow, as dumb stood as a tree:\n"
  "So was her hearte shut in her distress,\n"
  "When she remember'd his unkindeness.\n"
  "\n"
  "Twice she swooned in his owen sight,\n"
  "He wept and him excused piteously:\n"
  "\"Now God,\" quoth he, \"and all his hallows bright*                *saints\n"
  "So wisly* on my soule have mercy,                                *surely\n"
  "That of your harm as guilteless am I,\n"
  "As is Maurice my son, so like your face,\n"
  "Else may the fiend me fetch out of this place.\"\n"
  "\n"
  "Long was the sobbing and the bitter pain,\n"
  "Ere that their woeful heartes mighte cease;\n"
  "Great was the pity for to hear them plain,*                      *lament\n"
  "Through whiche plaintes gan their woe increase.\n"
  "I pray you all my labour to release,\n"
  "I may not tell all their woe till to-morrow,\n"
  "I am so weary for to speak of sorrow.\n"
  "\n"
  "But finally, when that the *sooth is wist,*             *truth is known*\n"
  "That Alla guiltless was of all her woe,\n"
  "I trow an hundred times have they kiss'd,\n"
  "And such a bliss is there betwixt them two,\n"
  "That, save the joy that lasteth evermo',\n"
  "There is none like, that any creature\n"
  "Hath seen, or shall see, while the world may dure.\n"
  "\n"
  "Then prayed she her husband meekely\n"
  "In the relief of her long piteous pine,*                         *sorrow\n"
  "That he would pray her father specially,\n"
  "That of his majesty he would incline\n"
  "To vouchesafe some day with him to dine:\n"
  "She pray'd him eke, that he should by no way\n"
  "Unto her father no word of her say.\n"
  "\n"
  "Some men would say,<17> how that the child Maurice\n"
  "Did this message unto the emperor:\n"
  "But, as I guess, Alla was not so nice,*                         *foolish\n"
  "To him that is so sovereign of honor\n"
  "As he that is of Christian folk the flow'r,\n"
  "Send any child, but better 'tis to deem\n"
  "He went himself; and so it may well seem.\n"
  "\n"
  "This emperor hath granted gentilly\n"
  "To come to dinner, as he him besought:\n"
  "And well rede* I, he looked busily                          *guess, know\n"
  "Upon this child, and on his daughter thought.\n"
  "Alla went to his inn, and as him ought\n"
  "Arrayed* for this feast in every wise,                         *prepared\n"
  "*As farforth as his cunning* may suffice.          *as far as his skill*\n"
  "\n"
  "The morrow came, and Alla gan him dress,*                    *make ready\n"
  "And eke his wife, the emperor to meet:\n"
  "And forth they rode in joy and in gladness,\n"
  "And when she saw her father in the street,\n"
  "She lighted down and fell before his feet.\n"
  "\"Father,\" quoth she, \"your younge child Constance\n"
  "Is now full clean out of your remembrance.\n"
  "\n"
  "\"I am your daughter, your Constance,\" quoth she,\n"
  "\"That whilom ye have sent into Syrie;\n"
  "It am I, father, that in the salt sea\n"
  "Was put alone, and damned* for to die.                        *condemned\n"
  "Now, goode father, I you mercy cry,\n"
  "Send me no more into none heatheness,\n"
  "But thank my lord here of his kindeness.\"\n"
  "\n"
  "Who can the piteous joye tellen all,\n"
  "Betwixt them three, since they be thus y-met?\n"
  "But of my tale make an end I shall,\n"
  "The day goes fast, I will no longer let.*                        *hinder\n"
  "These gladde folk to dinner be y-set;\n"
  "In joy and bliss at meat I let them dwell,\n"
  "A thousand fold well more than I can tell.\n"
  "\n"
  "This child Maurice was since then emperor\n"
  "Made by the Pope, and lived Christianly,\n"
  "To Christe's Churche did he great honor:\n"
  "But I let all his story passe by,\n"
  "Of Constance is my tale especially,\n"
  "In the olde Roman gestes* men may find                    *histories<19>\n"
  "Maurice's life, I bear it not in mind.\n"
  "\n"
  "This King Alla, when he his time sey,*                              *saw\n"
  "With his Constance, his holy wife so sweet,\n"
  "To England are they come the righte way,\n"
  "Where they did live in joy and in quiet.\n"
  "But little while it lasted, I you hete,*                        *promise\n"
  "Joy of this world for time will not abide,\n"
  "From day to night it changeth as the tide.\n"
  "\n"
  "Who liv'd ever in such delight one day,\n"
  "That him not moved either conscience,\n"
  "Or ire, or talent, or *some kind affray,*     *some kind of disturbance*\n"
  "Envy, or pride, or passion, or offence?\n"
  "I say but for this ende this sentence,*              *judgment, opinion*\n"
  "That little while in joy or in pleasance\n"
  "Lasted the bliss of Alla with Constance.\n"
  "\n"
  "For death, that takes of high and low his rent,\n"
  "When passed was a year, even as I guess,\n"
  "Out of this world this King Alla he hent,*                     *snatched\n"
  "For whom Constance had full great heaviness.\n"
  "Now let us pray that God his soule bless:\n"
  "And Dame Constance, finally to say,\n"
  "Toward the town of Rome went her way.\n"
  "\n"
  "To Rome is come this holy creature,\n"
  "And findeth there her friendes whole and sound:\n"
  "Now is she scaped all her aventure:\n"
  "And when that she her father hath y-found,\n"
  "Down on her knees falleth she to ground,\n"
  "Weeping for tenderness in hearte blithe\n"
  "She herieth* God an hundred thousand sithe.**           *praises **times\n"
  "\n"
  "In virtue and in holy almes-deed\n"
  "They liven all, and ne'er asunder wend;\n"
  "Till death departeth them, this life they lead:\n"
  "And fare now well, my tale is at an end\n"
  "Now Jesus Christ, that of his might may send\n"
  "Joy after woe, govern us in his grace\n"
  "And keep us alle that be in this place.\n"
  "\n"
  "\n"
  "Notes to the Man of Law's Tale\n"
  "\n"
  "\n"
  "1. This tale is believed by Tyrwhitt to have been taken, with no\n"
  "material change, from the \"Confessio Amantis\" of John Gower,\n"
  "who was contemporary with Chaucer, though somewhat his\n"
  "senior.  In the prologue, the references to the stories of Canace,\n"
  "and of Apollonius Tyrius, seem to be an attack on Gower, who\n"
  "had given these tales in his book; whence Tyrwhitt concludes\n"
  "that the friendship between the two poets suffered some\n"
  "interruption in the latter part of their lives.  Gower was not the\n"
  "inventor of the story, which he found in old French romances,\n"
  "and it is not improbable that Chaucer may have gone to the\n"
  "same source as Gower, though the latter undoubtedly led the\n"
  "way.\n"
  "(Transcriber's note: later commentators have identified the\n"
  "introduction describing the sorrows of poverty, along with the\n"
  "other moralising interludes in the tale, as translated from \"De\n"
  "Contemptu Mundi\" (\"On the contempt of the world\") by Pope\n"
  "Innocent.)\n"
  "\n"
  "2. Transcriber' note: This refers to the game of hazard, a dice\n"
  "game like craps, in which two  (\"ambes ace\") won,  and eleven\n"
  "(\"six-cinque\") lost.\n"
  "\n"
  "3. Purpose: discourse, tale: French \"propos\".\n"
  "\n"
  "4. \"Peace\" rhymed with \"lese\" and \"chese\", the old forms of\n"
  "\"lose\" and \"choose\".\n"
  "\n"
  "5. According to Middle Age writers there were two motions of\n"
  "the first heaven; one everything always from east to west above\n"
  "the stars; the other moving the stars against the first motion,\n"
  "from west to east, on two other poles.\n"
  "\n"
  "6. Atyzar: the meaning of this word is not known; but \"occifer\",\n"
  "murderer, has been suggested instead by Urry, on the authority\n"
  "of a marginal reading on a manuscript.\n"
  "(Transcriber's note: later commentators explain it as derived\n"
  "from Arabic \"al-ta'thir\", influence - used here in an astrological\n"
  "sense)\n"
  "\n"
  "7. \"Thou knittest thee where thou art not receiv'd,\n"
  "    Where thou wert well, from thennes art thou weiv'd\"\n"
  "i.e.\n"
  "\"Thou joinest thyself where thou art rejected, and art declined\n"
  "or departed from the place where thou wert well.\"  The moon\n"
  "portends the fortunes of Constance.\n"
  "\n"
  "8. Fand: endeavour; from Anglo-Saxon, \"fandian,\" to try\n"
  "\n"
  "9. Feng: take; Anglo-Saxon \"fengian\", German, \"fangen\".\n"
  "\n"
  "10. Him and her on which thy limbes faithfully extend: those\n"
  "who in faith wear the crucifix.\n"
  "\n"
  "11. The four spirits of tempest: the four angels who held the\n"
  "four winds of the earth and to whom it was given to hurt the\n"
  "earth and the sea (Rev. vii. 1, 2).\n"
  "\n"
  "12. Thennes would it not in all a tide: thence would it not move\n"
  "for long, at all.\n"
  "\n"
  "13. A manner Latin corrupt: a kind of bastard Latin.\n"
  "\n"
  "14. Knave child: male child; German \"Knabe\".\n"
  "\n"
  "15. Heried: honoured, praised; from Anglo-Saxon, \"herian.\"\n"
  "Compare German, \"herrlich,\" glorious, honourable.\n"
  "\n"
  "16. Beknow:  confess; German, \"bekennen.\"\n"
  "\n"
  "17. The poet here refers to Gower's version of the story.\n"
  "\n"
  "18. Stound: short time; German, \"stunde\", hour.\n"
  "\n"
  "19. Gestes: histories, exploits; Latin, \"res gestae\".\n"
  "\n"
  "\n"
  "\n"
  "";
// }

const char wifeOfBathsTale0[] PGMSECTION = // { // 23555 bytes
  "THE WIFE OF BATH'S TALE.\n"
  "\n"
  "\n"
  "THE PROLOGUE. <1>\n"
  "\n"
  "\n"
  "Experience, though none authority*                  *authoritative texts\n"
  "Were in this world, is right enough for me\n"
  "To speak of woe that is in marriage:\n"
  "For, lordings, since I twelve year was of age,\n"
  "(Thanked be God that *is etern on live),*              *lives eternally*\n"
  "Husbands at the church door have I had five,<2>\n"
  "For I so often have y-wedded be,\n"
  "And all were worthy men in their degree.\n"
  "But me was told, not longe time gone is\n"
  "That sithen* Christe went never but ones                          *since\n"
  "To wedding, in the Cane* of Galilee,                               *Cana\n"
  "That by that ilk* example taught he me,                            *same\n"
  "That I not wedded shoulde be but once.\n"
  "Lo, hearken eke a sharp word for the nonce,*                   *occasion\n"
  "Beside a welle Jesus, God and man,\n"
  "Spake in reproof of the Samaritan:\n"
  "\"Thou hast y-had five husbandes,\" said he;\n"
  "\"And thilke* man, that now hath wedded thee,                       *that\n"
  "Is not thine husband:\" <3> thus said he certain;\n"
  "What that he meant thereby, I cannot sayn.\n"
  "But that I aske, why the fifthe man\n"
  "Was not husband to the Samaritan?\n"
  "How many might she have in marriage?\n"
  "Yet heard I never tellen *in mine age*                      *in my life*\n"
  "Upon this number definitioun.\n"
  "Men may divine, and glosen* up and down;                        *comment\n"
  "But well I wot, express without a lie,\n"
  "God bade us for to wax and multiply;\n"
  "That gentle text can I well understand.\n"
  "Eke well I wot, he said, that mine husband\n"
  "Should leave father and mother, and take to me;\n"
  "But of no number mention made he,\n"
  "Of bigamy or of octogamy;\n"
  "Why then should men speak of it villainy?*     *as if it were a disgrace\n"
  "\n"
  "Lo here, the wise king Dan* Solomon,                           *Lord <4>\n"
  "I trow that he had wives more than one;\n"
  "As would to God it lawful were to me\n"
  "To be refreshed half so oft as he!\n"
  "What gift* of God had he for all his wives?     *special favour, licence\n"
  "No man hath such, that in this world alive is.\n"
  "God wot, this noble king, *as to my wit,*              *as I understand*\n"
  "The first night had many a merry fit\n"
  "With each of them, so *well was him on live.*         *so well he lived*\n"
  "Blessed be God that I have wedded five!\n"
  "Welcome the sixth whenever that he shall.\n"
  "For since I will not keep me chaste in all,\n"
  "When mine husband is from the world y-gone,\n"
  "Some Christian man shall wedde me anon.\n"
  "For then th' apostle saith that I am free\n"
  "To wed, *a' God's half,* where it liketh me.             *on God's part*\n"
  "He saith, that to be wedded is no sin;\n"
  "Better is to be wedded than to brin.*                              *burn\n"
  "What recketh* me though folk say villainy**                 *care **evil\n"
  "Of shrewed* Lamech, and his bigamy?                     *impious, wicked\n"
  "I wot well Abraham was a holy man,\n"
  "And Jacob eke, as far as ev'r I can.*                              *know\n"
  "And each of them had wives more than two;\n"
  "And many another holy man also.\n"
  "Where can ye see, *in any manner age,*                   *in any period*\n"
  "That highe God defended* marriage                           *forbade <5>\n"
  "By word express? I pray you tell it me;\n"
  "Or where commanded he virginity?\n"
  "I wot as well as you, it is no dread,*                            *doubt\n"
  "Th' apostle, when he spake of maidenhead,\n"
  "He said, that precept thereof had he none:\n"
  "Men may counsel a woman to be one,*                              *a maid\n"
  "But counseling is no commandement;\n"
  "He put it in our owen judgement.\n"
  "For, hadde God commanded maidenhead,\n"
  "Then had he damned* wedding out of dread;**           *condemned **doubt\n"
  "And certes, if there were no seed y-sow,*                          *sown\n"
  "Virginity then whereof should it grow?\n"
  "Paul durste not commanden, at the least,\n"
  "A thing of which his Master gave no hest.*                      *command\n"
  "The dart* is set up for virginity;                             *goal <6>\n"
  "Catch whoso may, who runneth best let see.\n"
  "But this word is not ta'en of every wight,\n"
  "*But there as* God will give it of his might.             *except where*\n"
  "I wot well that th' apostle was a maid,\n"
  "But natheless, although he wrote and said,\n"
  "He would that every wight were such as he,\n"
  "All is but counsel to virginity.\n"
  "And, since to be a wife he gave me leave\n"
  "Of indulgence, so is it no repreve*                   *scandal, reproach\n"
  "To wedde me, if that my make* should die,                 *mate, husband\n"
  "Without exception* of bigamy;                          *charge, reproach\n"
  "*All were it* good no woman for to touch            *though it might be*\n"
  "(He meant as in his bed or in his couch),\n"
  "For peril is both fire and tow t'assemble\n"
  "Ye know what this example may resemble.\n"
  "This is all and some, he held virginity\n"
  "More profit than wedding in frailty:\n"
  "(*Frailty clepe I, but if* that he and she           *frailty I call it,\n"
  "Would lead their lives all in chastity),                         unless*\n"
  "I grant it well, I have of none envy\n"
  "Who maidenhead prefer to bigamy;\n"
  "It liketh them t' be clean in body and ghost;*                     *soul\n"
  "Of mine estate* I will not make a boast.                      *condition\n"
  "\n"
  "For, well ye know, a lord in his household\n"
  "Hath not every vessel all of gold; <7>\n"
  "Some are of tree, and do their lord service.\n"
  "God calleth folk to him in sundry wise,\n"
  "And each one hath of God a proper gift,\n"
  "Some this, some that, as liketh him to shift.*      *appoint, distribute\n"
  "Virginity is great perfection,\n"
  "And continence eke with devotion:\n"
  "But Christ, that of perfection is the well,*                   *fountain\n"
  "Bade not every wight he should go sell\n"
  "All that he had, and give it to the poor,\n"
  "And in such wise follow him and his lore:*                     *doctrine\n"
  "He spake to them that would live perfectly, --\n"
  "And, lordings, by your leave, that am not I;\n"
  "I will bestow the flower of mine age\n"
  "In th' acts and in the fruits of marriage.\n"
  "Tell me also, to what conclusion*                          *end, purpose\n"
  "Were members made of generation,\n"
  "And of so perfect wise a wight* y-wrought?                        *being\n"
  "Trust me right well, they were not made for nought.\n"
  "Glose whoso will, and say both up and down,\n"
  "That they were made for the purgatioun\n"
  "Of urine, and of other thinges smale,\n"
  "And eke to know a female from a male:\n"
  "And for none other cause? say ye no?\n"
  "Experience wot well it is not so.\n"
  "So that the clerkes* be not with me wroth,                     *scholars\n"
  "I say this, that they were made for both,\n"
  "That is to say, *for office, and for ease*                 *for duty and\n"
  "Of engendrure, there we God not displease.                 for pleasure*\n"
  "Why should men elles in their bookes set,\n"
  "That man shall yield unto his wife her debt?\n"
  "Now wherewith should he make his payement,\n"
  "If he us'd not his silly instrument?\n"
  "Then were they made upon a creature\n"
  "To purge urine, and eke for engendrure.\n"
  "But I say not that every wight is hold,*                        *obliged\n"
  "That hath such harness* as I to you told,                     *equipment\n"
  "To go and use them in engendrure;\n"
  "Then should men take of chastity no cure.*                         *care\n"
  "Christ was a maid, and shapen* as a man,                      *fashioned\n"
  "And many a saint, since that this world began,\n"
  "Yet ever liv'd in perfect chastity.\n"
  "I will not vie* with no virginity.                              *contend\n"
  "Let them with bread of pured* wheat be fed,                    *purified\n"
  "And let us wives eat our barley bread.\n"
  "And yet with barley bread, Mark tell us can,<8>\n"
  "Our Lord Jesus refreshed many a man.\n"
  "In such estate as God hath *cleped us,*                    *called us to\n"
  "I'll persevere, I am not precious,*                         *over-dainty\n"
  "In wifehood I will use mine instrument\n"
  "As freely as my Maker hath it sent.\n"
  "If I be dangerous* God give me sorrow;            *sparing of my favours\n"
  "Mine husband shall it have, both eve and morrow,\n"
  "When that him list come forth and pay his debt.\n"
  "A husband will I have, I *will no let,*         *will bear no hindrance*\n"
  "Which shall be both my debtor and my thrall,*                     *slave\n"
  "And have his tribulation withal\n"
  "Upon his flesh, while that I am his wife.\n"
  "I have the power during all my life\n"
  "Upon his proper body, and not he;\n"
  "Right thus th' apostle told it unto me,\n"
  "And bade our husbands for to love us well;\n"
  "All this sentence me liketh every deal.*                           *whit\n"
  "\n"
  "Up start the Pardoner, and that anon;\n"
  "\"Now, Dame,\" quoth he, \"by God and by Saint John,\n"
  "Ye are a noble preacher in this case.\n"
  "I was about to wed a wife, alas!\n"
  "What? should I bie* it on my flesh so dear?                  *suffer for\n"
  "Yet had I lever* wed no wife this year.\"                         *rather\n"
  "\"Abide,\"* quoth she; \"my tale is not begun             *wait in patience\n"
  "Nay, thou shalt drinken of another tun\n"
  "Ere that I go, shall savour worse than ale.\n"
  "And when that I have told thee forth my tale\n"
  "Of tribulation in marriage,\n"
  "Of which I am expert in all mine age,\n"
  "(This is to say, myself hath been the whip),\n"
  "Then mayest thou choose whether thou wilt sip\n"
  "Of *thilke tunne,* that I now shall broach.                   *that tun*\n"
  "Beware of it, ere thou too nigh approach,\n"
  "For I shall tell examples more than ten:\n"
  "Whoso will not beware by other men,\n"
  "By him shall other men corrected be:\n"
  "These same wordes writeth Ptolemy;\n"
  "Read in his Almagest, and take it there.\"\n"
  "\"Dame, I would pray you, if your will it were,\"\n"
  "Saide this Pardoner, \"as ye began,\n"
  "Tell forth your tale, and spare for no man,\n"
  "And teach us younge men of your practique.\"\n"
  "\"Gladly,\" quoth she, \"since that it may you like.\n"
  "But that I pray to all this company,\n"
  "If that I speak after my fantasy,\n"
  "To take nought agrief* what I may say;                         *to heart\n"
  "For mine intent is only for to play.\n"
  "\n"
  "Now, Sirs, then will I tell you forth my tale.\n"
  "As ever may I drinke wine or ale\n"
  "I shall say sooth; the husbands that I had\n"
  "Three of them were good, and two were bad\n"
  "The three were goode men, and rich, and old\n"
  "*Unnethes mighte they the statute hold*      *they could with difficulty\n"
  "In which that they were bounden unto me.                   obey the law*\n"
  "Yet wot well what I mean of this, pardie.*                       *by God\n"
  "As God me help, I laugh when that I think\n"
  "How piteously at night I made them swink,*                       *labour\n"
  "But, *by my fay, I told of it no store:*         *by my faith, I held it\n"
  "They had me giv'n their land and their treasor,           of no account*\n"
  "Me needed not do longer diligence\n"
  "To win their love, or do them reverence.\n"
  "They loved me so well, by God above,\n"
  "That I *tolde no dainty* of their love.              *cared nothing for*\n"
  "A wise woman will busy her ever-in-one*                      *constantly\n"
  "To get their love, where that she hath none.\n"
  "But, since I had them wholly in my hand,\n"
  "And that they had me given all their land,\n"
  "Why should I take keep* them for to please,                        *care\n"
  "But* it were for my profit, or mine ease?                        *unless\n"
  "I set them so a-worke, by my fay,\n"
  "That many a night they sange, well-away!\n"
  "The bacon was not fetched for them, I trow,\n"
  "That some men have in Essex at Dunmow.<9>\n"
  "I govern'd them so well after my law,\n"
  "That each of them full blissful was and fawe*                      *fain\n"
  "To bringe me gay thinges from the fair.\n"
  "They were full glad when that I spake them fair,\n"
  "For, God it wot, I *chid them spiteously.*        *rebuked them angrily*\n"
  "Now hearken how I bare me properly.\n"
  "\n"
  "Ye wise wives, that can understand,\n"
  "Thus should ye speak, and *bear them wrong on hand,*          *make them\n"
  "For half so boldely can there no man                    believe falsely*\n"
  "Swearen and lien as a woman can.\n"
  "(I say not this by wives that be wise,\n"
  "*But if* it be when they them misadvise.)*     *unless* *act unadvisedly\n"
  "A wise wife, if that she can* her good,                           *knows\n"
  "Shall *beare them on hand* the cow is wood,          *make them believe*\n"
  "And take witness of her owen maid\n"
  "Of their assent: but hearken how I said.\n"
  "\"Sir olde  kaynard,<10> is this thine array?\n"
  "Why is my neigheboure's wife so gay?\n"
  "She is honour'd *over all where* she go'th,                 *wheresoever\n"
  "I sit at home, I have no *thrifty cloth.*                 *good clothes*\n"
  "What dost thou at my neigheboure's house?\n"
  "Is she so fair? art thou so amorous?\n"
  "What rown'st* thou with our maid? benedicite,                *whisperest\n"
  "Sir olde lechour, let thy japes* be.                             *tricks\n"
  "And if I have a gossip, or a friend\n"
  "(Withoute guilt), thou chidest as a fiend,\n"
  "If that I walk or play unto his house.\n"
  "Thou comest home as drunken as a mouse,\n"
  "And preachest on thy bench, with evil prefe:*                     *proof\n"
  "Thou say'st to me, it is a great mischief\n"
  "To wed a poore woman, for costage:*                             *expense\n"
  "And if that she be rich, of high parage;*                   * birth <11>\n"
  "Then say'st thou, that it is a tormentry\n"
  "To suffer her pride and melancholy.\n"
  "And if that she be fair, thou very knave,\n"
  "Thou say'st that every holour* will her have;               *whoremonger\n"
  "She may no while in chastity abide,\n"
  "That is assailed upon every side.\n"
  "Thou say'st some folk desire us for richess,\n"
  "Some for our shape, and some for our fairness,\n"
  "And some, for she can either sing or dance,\n"
  "And some for gentiless and dalliance,\n"
  "Some for her handes and her armes smale:\n"
  "Thus goes all to the devil, by thy tale;\n"
  "Thou say'st, men may not keep a castle wall\n"
  "That may be so assailed *over all.*                         *everywhere*\n"
  "And if that she be foul, thou say'st that she\n"
  "Coveteth every man that she may see;\n"
  "For as a spaniel she will on him leap,\n"
  "Till she may finde some man her to cheap;*                          *buy\n"
  "And none so grey goose goes there in the lake,\n"
  "(So say'st thou) that will be without a make.*                     *mate\n"
  "And say'st, it is a hard thing for to weld                *wield, govern\n"
  "A thing that no man will, *his thankes, held.*  *hold with his goodwill*\n"
  "Thus say'st thou, lorel,* when thou go'st to bed,      *good-for-nothing\n"
  "And that no wise man needeth for to wed,\n"
  "Nor no man that intendeth unto heaven.\n"
  "With wilde thunder dint* and fiery leven**          * stroke **lightning\n"
  "Mote* thy wicked necke be to-broke.                                 *may\n"
  "Thou say'st, that dropping houses, and eke smoke,\n"
  "And chiding wives, make men to flee\n"
  "Out of their owne house; ah! ben'dicite,\n"
  "What aileth such an old man for to chide?\n"
  "Thou say'st, we wives will our vices hide,\n"
  "Till we be fast,* and then we will them shew.                    *wedded\n"
  "Well may that be a proverb of a shrew.*             *ill-tempered wretch\n"
  "Thou say'st, that oxen, asses, horses, hounds,\n"
  "They be *assayed at diverse stounds,*                 *tested at various\n"
  "Basons and lavers, ere that men them buy,                        seasons\n"
  "Spoones, stooles, and all such husbandry,\n"
  "And so be pots, and clothes, and array,*                        *raiment\n"
  "But folk of wives make none assay,\n"
  "Till they be wedded, -- olde dotard shrew! --\n"
  "And then, say'st thou, we will our vices shew.\n"
  "Thou say'st also, that it displeaseth me,\n"
  "But if * that thou wilt praise my beauty,                        *unless\n"
  "And but* thou pore alway upon my face,                           *unless\n"
  "And call me faire dame in every place;\n"
  "And but* thou make a feast on thilke** day                *unless **that\n"
  "That I was born, and make me fresh and gay;\n"
  "And but thou do to my norice* honour,                        *nurse <12>\n"
  "And to my chamberere* within my bow'r,                     *chamber-maid\n"
  "And to my father's folk, and mine allies;*                    *relations\n"
  "Thus sayest thou, old barrel full of lies.\n"
  "And yet also of our prentice Jenkin,\n"
  "For his crisp hair, shining as gold so fine,\n"
  "And for he squireth me both up and down,\n"
  "Yet hast thou caught a false suspicioun:\n"
  "I will him not, though thou wert dead to-morrow.\n"
  "But tell me this, why hidest thou, *with sorrow,*      *sorrow on thee!*\n"
  "The keyes of thy chest away from me?\n"
  "It is my good* as well as thine, pardie.                       *property\n"
  "What, think'st to make an idiot of our dame?\n"
  "Now, by that lord that called is Saint Jame,\n"
  "Thou shalt not both, although that thou wert wood,*             *furious\n"
  "Be master of my body, and my good,*                            *property\n"
  "The one thou shalt forego, maugre* thine eyen.              *in spite of\n"
  "What helpeth it of me t'inquire and spyen?\n"
  "I trow thou wouldest lock me in thy chest.\n"
  "Thou shouldest say, 'Fair wife, go where thee lest;\n"
  "Take your disport; I will believe no tales;\n"
  "I know you for a true wife, Dame Ales.'*                          *Alice\n"
  "We love no man, that taketh keep* or charge                        *care\n"
  "Where that we go; we will be at our large.\n"
  "Of alle men most blessed may he be,\n"
  "The wise astrologer Dan* Ptolemy,                                  *Lord\n"
  "That saith this proverb in his Almagest:<13>\n"
  "'Of alle men his wisdom is highest,\n"
  "That recketh not who hath the world in hand.\n"
  "By this proverb thou shalt well understand,\n"
  "Have thou enough, what thar* thee reck or care           *needs, behoves\n"
  "How merrily that other folkes fare?\n"
  "For certes, olde dotard, by your leave,\n"
  "Ye shall have [pleasure] <14> right enough at eve.\n"
  "He is too great a niggard that will werne*                       *forbid\n"
  "A man to light a candle at his lantern;\n"
  "He shall have never the less light, pardie.\n"
  "Have thou enough, thee thar* not plaine** thee          *need **complain\n"
  "Thou say'st also, if that we make us gay\n"
  "With clothing and with precious array,\n"
  "That it is peril of our chastity.\n"
  "And yet, -- with sorrow! -- thou enforcest thee,\n"
  "And say'st these words in the apostle's name:\n"
  "'In habit made with chastity and shame*                         *modesty\n"
  "Ye women shall apparel you,' quoth he,<15>\n"
  "'And not in tressed hair and gay perrie,*                        *jewels\n"
  "As pearles, nor with gold, nor clothes rich.'\n"
  "After thy text nor after thy rubrich\n"
  "I will not work as muchel as a gnat.\n"
  "Thou say'st also, I walk out like a cat;\n"
  "For whoso woulde singe the catte's skin\n"
  "Then will the catte well dwell in her inn;*                       *house\n"
  "And if the catte's skin be sleek and gay,\n"
  "She will not dwell in house half a day,\n"
  "But forth she will, ere any day be daw'd,\n"
  "To shew her skin, and go a caterwaw'd.*                    *caterwauling\n"
  "This is to say, if I be gay, sir shrew,\n"
  "I will run out, my borel* for to shew.            *apparel, fine clothes\n"
  "Sir olde fool, what helpeth thee to spyen?\n"
  "Though thou pray Argus with his hundred eyen\n"
  "To be my wardecorps,* as he can best                         *body-guard\n"
  "In faith he shall not keep me, *but me lest:*          *unless I please*\n"
  "Yet could I *make his beard,* so may I the.         *make a jest of him*\n"
  "\n"
  "\"Thou sayest eke, that there be thinges three,                   *thrive\n"
  "Which thinges greatly trouble all this earth,\n"
  "And that no wighte may endure the ferth:*                        *fourth\n"
  "O lefe* sir shrew, may Jesus short** thy life.       *pleasant **shorten\n"
  "Yet preachest thou, and say'st, a hateful wife\n"
  "Y-reckon'd is for one of these mischances.\n"
  "Be there *none other manner resemblances*              *no other kind of\n"
  "That ye may liken your parables unto,                        comparison*\n"
  "But if a silly wife be one of tho?*                               *those\n"
  "Thou likenest a woman's love to hell;\n"
  "To barren land where water may not dwell.\n"
  "Thou likenest it also to wild fire;\n"
  "The more it burns, the more it hath desire\n"
  "To consume every thing that burnt will be.\n"
  "Thou sayest, right as wormes shend* a tree,                     *destroy\n"
  "Right so a wife destroyeth her husbond;\n"
  "This know they well that be to wives bond.\"\n"
  "\n"
  "Lordings, right thus, as ye have understand,\n"
  "*Bare I stiffly mine old husbands on hand,*          *made them believe*\n"
  "That thus they saiden in their drunkenness;\n"
  "And all was false, but that I took witness\n"
  "On Jenkin, and upon my niece also.\n"
  "O Lord! the pain I did them, and the woe,\n"
  "'Full guilteless, by Godde's sweete pine;*                         *pain\n"
  "For as a horse I coulde bite and whine;\n"
  "I coulde plain,* an'** I was in the guilt,       *complain **even though\n"
  "Or elles oftentime I had been spilt*                             *ruined\n"
  "Whoso first cometh to the nilll, first grint;*                *is ground\n"
  "I plained first, so was our war y-stint.*                       *stopped\n"
  "They were full glad to excuse them full blive*                  *quickly\n"
  "Of things that they never *aguilt their live.*     *were guilty in their\n"
  "                                                                  lives*\n"
  "Of wenches would I *beare them on hand,*           *falsely accuse them*\n"
  "When that for sickness scarcely might they stand,\n"
  "Yet tickled I his hearte for that he\n"
  "Ween'd* that I had of him so great cherte:**     *though **affection<16>\n"
  "I swore that all my walking out by night\n"
  "Was for to espy wenches that he dight:*                         *adorned\n"
  "Under that colour had I many a mirth.\n"
  "For all such wit is given us at birth;\n"
  "Deceit, weeping, and spinning, God doth give\n"
  "To women kindly, while that they may live.                    *naturally\n"
  "And thus of one thing I may vaunte me,\n"
  "At th' end I had the better in each degree,\n"
  "By sleight, or force, or by some manner thing,\n"
  "As by continual murmur or grudging,*                        *complaining\n"
  "Namely* a-bed, there hadde they mischance,                   *especially\n"
  "There would I chide, and do them no pleasance:\n"
  "I would no longer in the bed abide,\n"
  "If that I felt his arm over my side,\n"
  "Till he had made his ransom unto me,\n"
  "Then would I suffer him do his nicety.*                      *folly <17>\n"
  "And therefore every man this tale I tell,\n"
  "Win whoso may, for all is for to sell;\n"
  "With empty hand men may no hawkes lure;\n"
  "For winning would I all his will endure,\n"
  "And make me a feigned appetite,\n"
  "And yet in bacon* had I never delight:               *i.e. of Dunmow <9>\n"
  "That made me that I ever would them chide.\n"
  "For, though the Pope had sitten them beside,\n"
  "I would not spare them at their owen board,\n"
  "For, by my troth, I quit* them word for word                     *repaid\n"
  "As help me very God omnipotent,\n"
  "Though I right now should make my testament\n"
  "I owe them not a word, that is not quit*                         *repaid\n"
  "I brought it so aboute by my wit,\n"
  "That they must give it up, as for the best\n"
  "Or elles had we never been in rest.\n"
  "For, though he looked as a wood* lion,                          *furious\n"
  "Yet should he fail of his conclusion.\n"
  "Then would I say, \"Now, goode lefe* tak keep**              *dear **heed\n"
  "How meekly looketh Wilken oure sheep!\n"
  "Come near, my spouse, and let me ba* thy cheek                *kiss <18>\n"
  "Ye shoulde be all patient and meek,\n"
  "And have a *sweet y-spiced* conscience,                   *tender, nice*\n"
  "Since ye so preach of Jobe's patience.\n"
  "Suffer alway, since ye so well can preach,\n"
  "And but* ye do, certain we shall you teach*                      *unless\n"
  "That it is fair to have a wife in peace.\n"
  "One of us two must bowe* doubteless:                           *give way\n"
  "And since a man is more reasonable\n"
  "Than woman is, ye must be suff'rable.\n"
  "What aileth you to grudge* thus and groan?                     *complain\n"
  "Is it for ye would have my [love] <14> alone?\n"
  "Why, take it all: lo, have it every deal,*                         *whit\n"
  "Peter! <19> shrew* you but ye love it well                        *curse\n"
  "For if I woulde sell my *belle chose*,                 *beautiful thing*\n"
  "I coulde walk as fresh as is a rose,\n"
  "But I will keep it for your owen tooth.\n"
  "Ye be to blame, by God, I say you sooth.\"\n"
  "Such manner wordes hadde we on hand.\n"
  "\n"
  "";
// }

const char wifeOfBathsTale1[] PGMSECTION = // { // 23216 bytes
  "Now will I speaken of my fourth husband.\n"
  "My fourthe husband was a revellour;\n"
  "This is to say, he had a paramour,\n"
  "And I was young and full of ragerie,*                        *wantonness\n"
  "Stubborn and strong, and jolly as a pie.*                        *magpie\n"
  "Then could I dance to a harpe smale,\n"
  "And sing, y-wis,* as any nightingale,                         *certainly\n"
  "When I had drunk a draught of sweete wine.\n"
  "Metellius, the foule churl, the swine,\n"
  "That with a staff bereft his wife of life\n"
  "For she drank wine, though I had been his wife,\n"
  "Never should he have daunted me from drink:\n"
  "And, after wine, of Venus most I think.\n"
  "For all so sure as cold engenders hail,\n"
  "A liquorish mouth must have a liquorish tail.\n"
  "In woman vinolent* is no defence,**            *full of wine *resistance\n"
  "This knowe lechours by experience.\n"
  "But, lord Christ, when that it rememb'reth me\n"
  "Upon my youth, and on my jollity,\n"
  "It tickleth me about mine hearte-root;\n"
  "Unto this day it doth mine hearte boot,*                           *good\n"
  "That I have had my world as in my time.\n"
  "But age, alas! that all will envenime,*                *poison, embitter\n"
  "Hath me bereft my beauty and my pith:*                           *vigour\n"
  "Let go; farewell; the devil go therewith.\n"
  "The flour is gon, there is no more to tell,\n"
  "The bran, as I best may, now must I sell.\n"
  "But yet to be right merry will I fand.*                             *try\n"
  "Now forth to tell you of my fourth husband,\n"
  "I say, I in my heart had great despite,\n"
  "That he of any other had delight;\n"
  "But he was quit,* by God and by Saint Joce:<21>     *requited, paid back\n"
  "I made for him of the same wood a cross;\n"
  "Not of my body in no foul mannere,\n"
  "But certainly I made folk such cheer,\n"
  "That in his owen grease I made him fry\n"
  "For anger, and for very jealousy.\n"
  "By God, in earth I was his purgatory,\n"
  "For which I hope his soul may be in glory.\n"
  "For, God it wot, he sat full oft and sung,\n"
  "When that his shoe full bitterly him wrung.*                    *pinched\n"
  "There was no wight, save God and he, that wist\n"
  "In many wise how sore I did him twist.<20>\n"
  "He died when I came from Jerusalem,\n"
  "And lies in grave under the *roode beam:*                        *cross*\n"
  "Although his tomb is not so curious\n"
  "As was the sepulchre of Darius,\n"
  "Which that Apelles wrought so subtlely.\n"
  "It is but waste to bury them preciously.\n"
  "Let him fare well, God give his soule rest,\n"
  "He is now in his grave and in his chest.\n"
  "\n"
  "Now of my fifthe husband will I tell:\n"
  "God let his soul never come into hell.\n"
  "And yet was he to me the moste shrew;*              *cruel, ill-tempered\n"
  "That feel I on my ribbes all *by rew,*                         *in a row\n"
  "And ever shall, until mine ending day.\n"
  "But in our bed he was so fresh and gay,\n"
  "And therewithal so well he could me glose,*                     *flatter\n"
  "When that he woulde have my belle chose,\n"
  "Though he had beaten me on every bone,\n"
  "Yet could he win again my love anon.\n"
  "I trow, I lov'd him better, for that he\n"
  "Was of his love so dangerous* to me.                 *sparing, difficult\n"
  "We women have, if that I shall not lie,\n"
  "In this matter a quainte fantasy.\n"
  "Whatever thing we may not lightly have,\n"
  "Thereafter will we cry all day and crave.\n"
  "Forbid us thing, and that desire we;\n"
  "Press on us fast, and thenne will we flee.\n"
  "With danger* utter we all our chaffare;**      *difficulty **merchandise\n"
  "Great press at market maketh deare ware,\n"
  "And too great cheap is held at little price;\n"
  "This knoweth every woman that is wise.\n"
  "My fifthe husband, God his soule bless,\n"
  "Which that I took for love and no richess,\n"
  "He some time was *a clerk of Oxenford,*            *a scholar of Oxford*\n"
  "And had left school, and went at home to board\n"
  "With my gossip,* dwelling in oure town:                       *godmother\n"
  "God have her soul, her name was Alisoun.\n"
  "She knew my heart, and all my privity,\n"
  "Bet than our parish priest, so may I the.*                       *thrive\n"
  "To her betrayed I my counsel all;\n"
  "For had my husband pissed on a wall,\n"
  "Or done a thing that should have cost his life,\n"
  "To her, and to another worthy wife,\n"
  "And to my niece, which that I loved well,\n"
  "I would have told his counsel every deal.*                          *jot\n"
  "And so I did full often, God it wot,\n"
  "That made his face full often red and hot\n"
  "For very shame, and blam'd himself, for he\n"
  "Had told to me so great a privity.*                              *secret\n"
  "And so befell that ones in a Lent\n"
  "(So oftentimes I to my gossip went,\n"
  "For ever yet I loved to be gay,\n"
  "And for to walk in March, April, and May\n"
  "From house to house, to heare sundry tales),\n"
  "That Jenkin clerk, and my gossip, Dame Ales,\n"
  "And I myself, into the fieldes went.\n"
  "Mine husband was at London all that Lent;\n"
  "I had the better leisure for to play,\n"
  "And for to see, and eke for to be sey*                             *seen\n"
  "Of lusty folk; what wist I where my grace*                       *favour\n"
  "Was shapen for to be, or in what place?                       *appointed\n"
  "Therefore made I my visitations\n"
  "To vigilies,* and to processions,                     *festival-eves<22>\n"
  "To preachings eke, and to these pilgrimages,\n"
  "To plays of miracles, and marriages,\n"
  "And weared upon me gay scarlet gites.*                            *gowns\n"
  "These wormes, nor these mothes, nor these mites\n"
  "On my apparel frett* them never a deal**                     *fed **whit\n"
  "And know'st thou why? for they were used* well.                    *worn\n"
  "Now will I telle forth what happen'd me:\n"
  "I say, that in the fieldes walked we,\n"
  "Till truely we had such dalliance,\n"
  "This clerk and I, that of my purveyance*                      *foresight\n"
  "I spake to him, and told him how that he,\n"
  "If I were widow, shoulde wedde me.\n"
  "For certainly, I say for no bobance,*                      *boasting<23>\n"
  "Yet was I never without purveyance*                           *foresight\n"
  "Of marriage, nor of other thinges eke:\n"
  "I hold a mouse's wit not worth a leek,\n"
  "That hath but one hole for to starte* to,<24>                    *escape\n"
  "And if that faile, then is all y-do.*                              *done\n"
  "[*I bare him on hand* he had enchanted me          *falsely assured him*\n"
  "(My dame taughte me that subtilty);\n"
  "And eke I said, I mette* of him all night,                      *dreamed\n"
  "He would have slain me, as I lay upright,\n"
  "And all my bed was full of very blood;\n"
  "But yet I hop'd that he should do me good;\n"
  "For blood betoken'd gold, as me was taught.\n"
  "And all was false, I dream'd of him right naught,\n"
  "But as I follow'd aye my dame's lore,\n"
  "As well of that as of other things more.] <25>\n"
  "But now, sir, let me see, what shall I sayn?\n"
  "Aha! by God, I have my tale again.\n"
  "When that my fourthe husband was on bier,\n"
  "I wept algate* and made a sorry cheer,**           *always **countenance\n"
  "As wives must, for it is the usage;\n"
  "And with my kerchief covered my visage;\n"
  "But, for I was provided with a make,*                              *mate\n"
  "I wept but little, that I undertake*                            *promise\n"
  "To churche was mine husband borne a-morrow\n"
  "With neighebours that for him made sorrow,\n"
  "And Jenkin, oure clerk, was one of tho:*                          *those\n"
  "As help me God, when that I saw him go\n"
  "After the bier, methought he had a pair\n"
  "Of legges and of feet so clean and fair,\n"
  "That all my heart I gave unto his hold.*                        *keeping\n"
  "He was, I trow, a twenty winter old,\n"
  "And I was forty, if I shall say sooth,\n"
  "But yet I had always a colte's tooth.\n"
  "Gat-toothed* I was, and that became me well,              *see note <26>\n"
  "I had the print of Sainte Venus' seal.\n"
  "[As help me God, I was a lusty one,\n"
  "And fair, and rich, and young, and *well begone:*        *in a good way*\n"
  "For certes I am all venerian*              *under the influence of Venus\n"
  "In feeling, and my heart is martian;*       *under the influence of Mars\n"
  "Venus me gave my lust and liquorishness,\n"
  "And Mars gave me my sturdy hardiness.] <25>\n"
  "Mine ascendant was Taure,* and Mars therein:                     *Taurus\n"
  "Alas, alas, that ever love was sin!\n"
  "I follow'd aye mine inclination\n"
  "By virtue of my constellation:\n"
  "That made me that I coulde not withdraw\n"
  "My chamber of Venus from a good fellaw.\n"
  "[Yet have I Marte's mark upon my face,\n"
  "And also in another privy place.\n"
  "For God so wisly* be my salvation,                            *certainly\n"
  "I loved never by discretion,\n"
  "But ever follow'd mine own appetite,\n"
  "All* were he short, or long, or black, or white,                *whether\n"
  "I took no keep,* so that he liked me,                              *heed\n"
  "How poor he was, neither of what degree.] <25>\n"
  "What should I say? but that at the month's end\n"
  "This jolly clerk Jenkin, that was so hend,*                   *courteous\n"
  "Had wedded me with great solemnity,\n"
  "And to him gave I all the land and fee\n"
  "That ever was me given therebefore:\n"
  "But afterward repented me full sore.\n"
  "He woulde suffer nothing of my list.*                          *pleasure\n"
  "By God, he smote me ones with his fist,\n"
  "For that I rent out of his book a leaf,\n"
  "That of the stroke mine eare wax'd all deaf.\n"
  "Stubborn I was, as is a lioness,\n"
  "And of my tongue a very jangleress,*                             *prater\n"
  "And walk I would, as I had done beforn,\n"
  "From house to house, although he had it sworn:*            *had sworn to\n"
  "For which he oftentimes woulde preach                         prevent it\n"
  "And me of olde Roman gestes* teach                              *stories\n"
  "How that Sulpitius Gallus left his wife\n"
  "And her forsook for term of all his\n"
  "For nought but open-headed* he her say**              *bare-headed **saw\n"
  "Looking out at his door upon a day.\n"
  "Another Roman <27> told he me by name,\n"
  "That, for his wife was at a summer game\n"
  "Without his knowing, he forsook her eke.\n"
  "And then would he upon his Bible seek\n"
  "That ilke* proverb of Ecclesiast,                                  *same\n"
  "Where he commandeth, and forbiddeth fast,\n"
  "Man shall not suffer his wife go roll about.\n"
  "Then would he say right thus withoute doubt:\n"
  "\"Whoso that buildeth his house all of sallows,*                 *willows\n"
  "And pricketh his blind horse over the fallows,\n"
  "And suff'reth his wife to *go seeke hallows,*         *make pilgrimages*\n"
  "Is worthy to be hanged on the gallows.\"\n"
  "But all for nought; I *sette not a haw*              *cared nothing for*\n"
  "Of his proverbs, nor of his olde saw;\n"
  "Nor would I not of him corrected be.\n"
  "I hate them that my vices telle me,\n"
  "And so do more of us (God wot) than I.\n"
  "This made him wood* with me all utterly;                        *furious\n"
  "I woulde not forbear* him in no case.                            *endure\n"
  "Now will I say you sooth, by Saint Thomas,\n"
  "Why that I rent out of his book a leaf,\n"
  "For which he smote me, so that I was deaf.\n"
  "He had a book, that gladly night and day\n"
  "For his disport he would it read alway;\n"
  "He call'd it Valerie,<28> and Theophrast,\n"
  "And with that book he laugh'd alway full fast.\n"
  "And eke there was a clerk sometime at Rome,\n"
  "A cardinal, that highte Saint Jerome,\n"
  "That made a book against Jovinian,\n"
  "Which book was there; and eke Tertullian,\n"
  "Chrysippus, Trotula, and Heloise,\n"
  "That was an abbess not far from Paris;\n"
  "And eke the Parables* of Solomon,                              *Proverbs\n"
  "Ovide's Art, <29> and bourdes* many one;                          *jests\n"
  "And alle these were bound in one volume.\n"
  "And every night and day was his custume\n"
  "(When he had leisure and vacation\n"
  "From other worldly occupation)\n"
  "To readen in this book of wicked wives.\n"
  "He knew of them more legends and more lives\n"
  "Than be of goodde wives in the Bible.\n"
  "For, trust me well, it is an impossible\n"
  "That any clerk will speake good of wives,\n"
  "(*But if* it be of holy saintes' lives)                          *unless\n"
  "Nor of none other woman never the mo'.\n"
  "Who painted the lion, tell it me, who?\n"
  "By God, if women haddde written stories,\n"
  "As clerkes have within their oratories,\n"
  "They would have writ of men more wickedness\n"
  "Than all the mark of Adam <30> may redress\n"
  "The children of Mercury and of Venus,<31>\n"
  "Be in their working full contrarious.\n"
  "Mercury loveth wisdom and science,\n"
  "And Venus loveth riot and dispence.*                       *extravagance\n"
  "And for their diverse disposition,\n"
  "Each falls in other's exaltation.\n"
  "As thus, God wot, Mercury is desolate\n"
  "In Pisces, where Venus is exaltate,\n"
  "And Venus falls where Mercury is raised. <32>\n"
  "Therefore no woman by no clerk is praised.\n"
  "The clerk, when he is old, and may not do\n"
  "Of Venus' works not worth his olde shoe,\n"
  "Then sits he down, and writes in his dotage,\n"
  "That women cannot keep their marriage.\n"
  "But now to purpose, why I tolde thee\n"
  "That I was beaten for a book, pardie.\n"
  "\n"
  "Upon a night Jenkin, that was our sire,*                        *goodman\n"
  "Read on his book, as he sat by the fire,\n"
  "Of Eva first, that for her wickedness\n"
  "Was all mankind brought into wretchedness,\n"
  "For which that Jesus Christ himself was slain,\n"
  "That bought us with his hearte-blood again.\n"
  "Lo here express of women may ye find\n"
  "That woman was the loss of all mankind.\n"
  "Then read he me how Samson lost his hairs\n"
  "Sleeping, his leman cut them with her shears,\n"
  "Through whiche treason lost he both his eyen.\n"
  "Then read he me, if that I shall not lien,\n"
  "Of Hercules, and of his Dejanire,\n"
  "That caused him to set himself on fire.\n"
  "Nothing forgot he of the care and woe\n"
  "That Socrates had with his wives two;\n"
  "How Xantippe cast piss upon his head.\n"
  "This silly man sat still, as he were dead,\n"
  "He wip'd his head, and no more durst he sayn,\n"
  "But, \"Ere the thunder stint* there cometh rain.\"                 *ceases\n"
  "Of Phasiphae, that was queen of Crete,\n"
  "For shrewedness* he thought the tale sweet.                  *wickedness\n"
  "Fy, speak no more, it is a grisly thing,\n"
  "Of her horrible lust and her liking.\n"
  "Of Clytemnestra, for her lechery\n"
  "That falsely made her husband for to die,\n"
  "He read it with full good devotion.\n"
  "He told me eke, for what occasion\n"
  "Amphiorax at Thebes lost his life:\n"
  "My husband had a legend of his wife\n"
  "Eryphile, that for an ouche* of gold                      *clasp, collar\n"
  "Had privily unto the Greekes told,\n"
  "Where that her husband hid him in a place,\n"
  "For which he had at Thebes sorry grace.\n"
  "Of Luna told he me, and of Lucie;\n"
  "They bothe made their husbands for to die,\n"
  "That one for love, that other was for hate.\n"
  "Luna her husband on an ev'ning late\n"
  "Empoison'd had, for that she was his foe:\n"
  "Lucia liquorish lov'd her husband so,\n"
  "That, for he should always upon her think,\n"
  "She gave him such a manner* love-drink,                         *sort of\n"
  "That he was dead before it were the morrow:\n"
  "And thus algates* husbands hadde sorrow.                         *always\n"
  "Then told he me how one Latumeus\n"
  "Complained to his fellow Arius\n"
  "That in his garden growed such a tree,\n"
  "On which he said how that his wives three\n"
  "Hanged themselves for heart dispiteous.\n"
  "\"O leve* brother,\" quoth this Arius,                               *dear\n"
  "\"Give me a plant of thilke* blessed tree,                          *that\n"
  "And in my garden planted shall it be.\"\n"
  "Of later date of wives hath he read,\n"
  "That some have slain their husbands in their bed,\n"
  "And let their *lechour dight them* all the night,      *lover ride them*\n"
  "While that the corpse lay on the floor upright:\n"
  "And some have driven nails into their brain,\n"
  "While that they slept, and thus they have them slain:\n"
  "Some have them given poison in their drink:\n"
  "He spake more harm than hearte may bethink.\n"
  "And therewithal he knew of more proverbs,\n"
  "Than in this world there groweth grass or herbs.\n"
  "\"Better (quoth he) thine habitation\n"
  "Be with a lion, or a foul dragon,\n"
  "Than with a woman using for to chide.\n"
  "Better (quoth he) high in the roof abide,\n"
  "Than with an angry woman in the house,\n"
  "They be so wicked and contrarious:\n"
  "They hate that their husbands loven aye.\"\n"
  "He said, \"A woman cast her shame away\n"
  "When she cast off her smock;\" and farthermo',\n"
  "\"A fair woman, but* she be chaste also,                          *except\n"
  "Is like a gold ring in a sowe's nose.\n"
  "Who coulde ween,* or who coulde suppose                           *think\n"
  "The woe that in mine heart was, and the pine?*                     *pain\n"
  "And when I saw that he would never fine*                         *finish\n"
  "To readen on this cursed book all night,\n"
  "All suddenly three leaves have I plight*                        *plucked\n"
  "Out of his book, right as he read, and eke\n"
  "I with my fist so took him on the cheek,\n"
  "That in our fire he backward fell adown.\n"
  "And he up start, as doth a wood* lion,                          *furious\n"
  "And with his fist he smote me on the head,\n"
  "That on the floor I lay as I were dead.\n"
  "And when he saw how still that there I lay,\n"
  "He was aghast, and would have fled away,\n"
  "Till at the last out of my swoon I braid,*                         *woke\n"
  "\"Oh, hast thou slain me, thou false thief?\" I said\n"
  "\"And for my land thus hast thou murder'd me?\n"
  "Ere I be dead, yet will I kisse thee.\"\n"
  "And near he came, and kneeled fair adown,\n"
  "And saide\", \"Deare sister Alisoun,\n"
  "As help me God, I shall thee never smite:\n"
  "That I have done it is thyself to wite,*                          *blame\n"
  "Forgive it me, and that I thee beseek.\"*                        *beseech\n"
  "And yet eftsoons* I hit him on the cheek,            *immediately; again\n"
  "And saidde, \"Thief, thus much am I awreak.*                     *avenged\n"
  "Now will I die, I may no longer speak.\"\n"
  "\n"
  "But at the last, with muche care and woe\n"
  "We fell accorded* by ourselves two:                              *agreed\n"
  "He gave me all the bridle in mine hand\n"
  "To have the governance of house and land,\n"
  "And of his tongue, and of his hand also.\n"
  "I made him burn his book anon right tho.*                          *then\n"
  "And when that I had gotten unto me\n"
  "By mast'ry all the sovereignety,\n"
  "And that he said, \"Mine owen true wife,\n"
  "Do *as thee list,* the term of all thy life,           *as pleases thee*\n"
  "Keep thine honour, and eke keep mine estate;\n"
  "After that day we never had debate.\n"
  "God help me so, I was to him as kind\n"
  "As any wife from Denmark unto Ind,\n"
  "And also true, and so was he to me:\n"
  "I pray to God that sits in majesty\n"
  "So bless his soule, for his mercy dear.\n"
  "Now will I say my tale, if ye will hear. --\n"
  "\n"
  "The Friar laugh'd when he had heard all this:\n"
  "\"Now, Dame,\" quoth he, \"so have I joy and bliss,\n"
  "This is a long preamble of a tale.\"\n"
  "And when the Sompnour heard the Friar gale,*                      *speak\n"
  "\"Lo,\" quoth this Sompnour, \"Godde's armes two,\n"
  "A friar will intermete* him evermo':                     *interpose <33>\n"
  "Lo, goode men, a fly and eke a frere\n"
  "Will fall in ev'ry dish and eke mattere.\n"
  "What speak'st thou of perambulation?*                          *preamble\n"
  "What? amble or trot; or peace, or go sit down:\n"
  "Thou lettest* our disport in this mattere.\"                  *hinderesst\n"
  "\"Yea, wilt thou so, Sir Sompnour?\" quoth the Frere;\n"
  "\"Now by my faith I shall, ere that I go,\n"
  "Tell of a Sompnour such a tale or two,\n"
  "That all the folk shall laughen in this place.\"\n"
  "\"Now do, else, Friar, I beshrew* thy face,\"                       *curse\n"
  "Quoth this Sompnour; \"and I beshrewe me,\n"
  "But if* I telle tales two or three                               *unless\n"
  "Of friars, ere I come to Sittingbourne,\n"
  "That I shall make thine hearte for to mourn:\n"
  "For well I wot thy patience is gone.\"\n"
  "Our Hoste cried, \"Peace, and that anon;\"\n"
  "And saide, \"Let the woman tell her tale.\n"
  "Ye fare* as folk that drunken be of ale.                         *behave\n"
  "Do, Dame, tell forth your tale, and that is best.\"\n"
  "\"All ready, sir,\" quoth she, \"right as you lest,*                *please\n"
  "If I have licence of this worthy Frere.\"\n"
  "\"Yes, Dame,\" quoth he, \"tell forth, and I will hear.\"\n"
  "\n"
  "\n"
  "Notes to the Prologue to the Wife of Bath's Tale\n"
  "\n"
  "\n"
  "1. Among the evidences that Chaucer's great work was left\n"
  "incomplete, is the absence of any link of connexion between the\n"
  "Wife of Bath's Prologue and Tale, and what goes before. This\n"
  "deficiency has in some editions caused the Squire's and the\n"
  "Merchant's Tales to be interposed between those of the Man of\n"
  "Law and the Wife of Bath; but in the Merchant's Tale there is\n"
  "internal proof that it was told after the jolly Dame's.  Several\n"
  "manuscripts contain verses designed to serve as a connexion;\n"
  "but they are evidently not Chaucer's, and it is unnecessary to\n"
  "give them here. Of this Prologue, which may fairly be regarded\n"
  "as a distinct autobiographical tale, Tyrwhitt says: \"The\n"
  "extraordinary length of it, as well as the vein of pleasantry that\n"
  "runs through it, is very suitable to the character of the speaker.\n"
  "The greatest part must have been of Chaucer's own invention,\n"
  "though one may plainly see that he had been reading the popular\n"
  "invectives against marriage and women in general; such as the\n"
  "'Roman de la Rose,'  'Valerius ad Rufinum, De non Ducenda\n"
  "Uxore,' ('Valerius to Rufinus, on not being ruled by one's wife')\n"
  "and particularly 'Hieronymus contra Jovinianum.' ('Jerome\n"
  "against Jovinianus')  St Jerome, among other things designed to\n"
  "discourage marriage, has inserted in his treatise a long passage\n"
  "from 'Liber Aureolus Theophrasti de Nuptiis.' ('Theophrastus's\n"
  "Golden Book of Marriage').\"\n"
  "\n"
  "2. A great part of the marriage service used to be performed in\n"
  "the church-porch.\n"
  "\n"
  "3. Jesus and the Samaritan woman: John iv. 13.\n"
  "\n"
  "4. Dan: Lord; Latin, \"dominus.\"  Another reading is \"the wise\n"
  "man, King Solomon.\"\n"
  "\n"
  "5. Defended: forbade; French, \"defendre,\" to prohibit.\n"
  "\n"
  "6. Dart: the goal; a spear or dart was set up to mark the point of\n"
  "victory.\n"
  "\n"
  "7. \"But in a great house there are not only vessels of gold and\n"
  "silver, but also of wood and of earth; and some to honour, and\n"
  "some to dishonour.\" -- 2 Tim. ii 20.\n"
  "\n"
  "8. Jesus feeding the multitude with barley bread: Mark vi. 41,\n"
  "42.\n"
  "\n"
  "9. At Dunmow prevailed the custom of giving, amid much\n"
  "merry making, a flitch of bacon to the married pair who had\n"
  "lived together for a year without quarrel or regret. The same\n"
  "custom prevailed of old in Bretagne.\n"
  "\n"
  "10. \"Cagnard,\" or \"Caignard,\" a French term of reproach,\n"
  "originally derived from \"canis,\" a dog.\n"
  "\n"
  "11. Parage: birth, kindred; from Latin, \"pario,\" I beget.\n"
  "\n"
  "12. Norice: nurse; French, \"nourrice.\"\n"
  "\n"
  "13. This and the previous quotation from Ptolemy are due to\n"
  "the Dame's own fancy.\n"
  "\n"
  "14. (Transcriber's note: Some Victorian censorship here. The\n"
  "word given in [brackets] should be \"queint\" i.e. \"cunt\".)\n"
  "\n"
  "15. Women should not adorn themselves:  see I Tim. ii. 9.\n"
  "\n"
  "16. Cherte: affection; from French, \"cher,\" dear.\n"
  "\n"
  "17. Nicety: folly; French, \"niaiserie.\"\n"
  "\n"
  "18. Ba: kiss; from French, \"baiser.\"\n"
  "\n"
  "19. Peter!: by Saint Peter! a common adjuration, like Marie!\n"
  "from the Virgin's name.\n"
  "\n"
  "20. St. Joce: or Judocus, a saint of Ponthieu, in France.\n"
  "\n"
  "21. \"An allusion,\" says Mr Wright, \"to the story of the Roman\n"
  "sage who, when blamed for divorcing his wife, said that a shoe\n"
  "might appear outwardly to fit well, but no one but the wearer\n"
  "knew where it pinched.\"\n"
  "\n"
  "22. Vigilies: festival-eves; see note 33 to the Prologue to the\n"
  "Tales.\n"
  "\n"
  "23. Bobance: boasting; Ben Jonson's braggart, in \"Every Man in\n"
  "his Humour,\" is named Bobadil.\n"
  "\n"
  "24. \"I hold a mouse's wit not worth a leek,\n"
  "     That hath but one hole for to starte to\"\n"
  " A very old proverb in French, German, and Latin.\n"
  "\n"
  "25. The lines in brackets are only in some of the manuscripts.\n"
  "\n"
  "26. Gat-toothed: gap-toothed; goat-toothed; or cat- or separate\n"
  "toothed. See note 41 to the prologue to the Tales.\n"
  "\n"
  "27. Sempronius Sophus, of whom Valerius Maximus tells in his\n"
  "sixth book.\n"
  "\n"
  "28. The tract of Walter Mapes against marriage, published\n"
  "under the title of \"Epistola Valerii ad Rufinum.\"\n"
  "\n"
  "";
// }

const char wifeOfBathsTale2[] PGMSECTION = // { // 22809 bytes
  "29. \"Ars Amoris.\"\n"
  "\n"
  "30. All the mark of Adam: all who bear the mark of Adam i.e.\n"
  "all men.\n"
  "\n"
  "31. The Children of Mercury and Venus: those born under the\n"
  "influence of the respective planets.\n"
  "\n"
  "32. A planet, according to the old astrologers, was in\n"
  "\"exaltation\" when in the sign of the Zodiac in which it exerted\n"
  "its strongest influence; the opposite sign, in which it was\n"
  "weakest, was called its \"dejection.\"  Venus being strongest in\n"
  "Pisces, was weakest in Virgo; but in Virgo Mercury was in\n"
  "\"exaltation.\"\n"
  "\n"
  "33. Intermete: interpose; French, \"entremettre.\"\n"
  "\n"
  "\n"
  "THE TALE. <1>\n"
  "\n"
  "\n"
  "In olde dayes of the king Arthour,\n"
  "Of which that Britons speake great honour,\n"
  "All was this land full fill'd of faerie;*                       *fairies\n"
  "The Elf-queen, with her jolly company,\n"
  "Danced full oft in many a green mead\n"
  "This was the old opinion, as I read;\n"
  "I speak of many hundred years ago;\n"
  "But now can no man see none elves mo',\n"
  "For now the great charity and prayeres\n"
  "Of limitours,* and other holy freres,                *begging friars <2>\n"
  "That search every land and ev'ry stream\n"
  "As thick as motes in the sunne-beam,\n"
  "Blessing halls, chambers, kitchenes, and  bowers,\n"
  "Cities and burghes, castles high and towers,\n"
  "Thorpes* and barnes, shepens** and dairies,      *villages <3> **stables\n"
  "This makes that there be now no faeries:\n"
  "For *there as* wont to walke was an elf,                         *where*\n"
  "There walketh now the limitour himself,\n"
  "In undermeles* and in morrowings**,             *evenings <4>	**mornings\n"
  "And saith his matins and his holy things,\n"
  "As he goes in his limitatioun.*                        *begging district\n"
  "Women may now go safely up and down,\n"
  "In every bush, and under every tree;\n"
  "There is none other incubus <5> but he;\n"
  "And he will do to them no dishonour.\n"
  "\n"
  "And so befell it, that this king Arthour\n"
  "Had in his house a lusty bacheler,\n"
  "That on a day came riding from river: <6>\n"
  "And happen'd, that, alone as she was born,\n"
  "He saw a maiden walking him beforn,\n"
  "Of which maiden anon, maugre* her head,                     *in spite of\n"
  "By very force he reft her maidenhead:\n"
  "For which oppression was such clamour,\n"
  "And such pursuit unto the king Arthour,\n"
  "That damned* was this knight for to be dead                   *condemned\n"
  "By course of law, and should have lost his head;\n"
  "(Paraventure such was the statute tho),*                           *then\n"
  "But that the queen and other ladies mo'\n"
  "So long they prayed the king of his grace,\n"
  "Till he his life him granted in the place,\n"
  "And gave him to the queen, all at her will\n"
  "To choose whether she would him save or spill*                  *destroy\n"
  "The queen thanked the king with all her might;\n"
  "And, after this, thus spake she to the knight,\n"
  "When that she saw her time upon a day.\n"
  "\"Thou standest yet,\" quoth she, \"in such array,*             *a position\n"
  "That of thy life yet hast thou no surety;\n"
  "I grant thee life, if thou canst tell to me\n"
  "What thing is it that women most desiren:\n"
  "Beware, and keep thy neck-bone from the iron*         *executioner's axe\n"
  "And if thou canst not tell it me anon,\n"
  "Yet will I give thee leave for to gon\n"
  "A twelvemonth and a day, to seek and lear*                        *learn\n"
  "An answer suffisant* in this mattere.                      *satisfactory\n"
  "And surety will I have, ere that thou pace,*                         *go\n"
  "Thy body for to yielden in this place.\"\n"
  "Woe was the knight, and sorrowfully siked;*                      *sighed\n"
  "But what? he might not do all as him liked.\n"
  "And at the last he chose him for to wend,*                       *depart\n"
  "And come again, right at the yeare's end,\n"
  "With such answer as God would him purvey:*                      *provide\n"
  "And took his leave, and wended forth his way.\n"
  "\n"
  "He sought in ev'ry house and ev'ry place,\n"
  "Where as he hoped for to finde grace,\n"
  "To learne what thing women love the most:\n"
  "But he could not arrive in any coast,\n"
  "Where as he mighte find in this mattere\n"
  "Two creatures *according in fere.*                   *agreeing together*\n"
  "Some said that women loved best richess,\n"
  "Some said honour, and some said jolliness,\n"
  "Some rich array, and some said lust* a-bed,                    *pleasure\n"
  "And oft time to be widow and be wed.\n"
  "Some said, that we are in our heart most eased\n"
  "When that we are y-flatter'd and y-praised.\n"
  "He *went full nigh the sooth,* I will not lie;           *came very near\n"
  "A man shall win us best with flattery;                        the truth*\n"
  "And with attendance, and with business\n"
  "Be we y-limed,* bothe more and less.              *caught with bird-lime\n"
  "And some men said that we do love the best\n"
  "For to be free, and do *right as us lest,*          *whatever we please*\n"
  "And that no man reprove us of our vice,\n"
  "But say that we are wise, and nothing nice,*                *foolish <7>\n"
  "For truly there is none among us all,\n"
  "If any wight will *claw us on the gall,*                  *see note <8>*\n"
  "That will not kick, for that he saith us sooth:\n"
  "Assay,* and he shall find it, that so do'th.                        *try\n"
  "For be we never so vicious within,\n"
  "We will be held both wise and clean of sin.\n"
  "And some men said, that great delight have we\n"
  "For to be held stable and eke secre,*                          *discreet\n"
  "And in one purpose steadfastly to dwell,\n"
  "And not bewray* a thing that men us tell.                     *give away\n"
  "But that tale is not worth a rake-stele.*                   *rake-handle\n"
  "Pardie, we women canne nothing hele,*                          *hide <9>\n"
  "Witness on Midas; will ye hear the tale?\n"
  "Ovid, amonges other thinges smale*                                *small\n"
  "Saith, Midas had, under his longe hairs,\n"
  "Growing upon his head two ass's ears;\n"
  "The whiche vice he hid, as best he might,\n"
  "Full subtlely from every man's sight,\n"
  "That, save his wife, there knew of it no mo';\n"
  "He lov'd her most, and trusted her also;\n"
  "He prayed her, that to no creature\n"
  "She woulde tellen of his disfigure.\n"
  "She swore him, nay, for all the world to win,\n"
  "She would not do that villainy or sin,\n"
  "To make her husband have so foul a name:\n"
  "She would not tell it for her owen shame.\n"
  "But natheless her thoughte that she died,\n"
  "That she so longe should a counsel hide;\n"
  "Her thought it swell'd so sore about her heart\n"
  "That needes must some word from her astart\n"
  "And, since she durst not tell it unto man\n"
  "Down to a marish fast thereby she ran,\n"
  "Till she came there, her heart was all afire:\n"
  "And, as a bittern bumbles* in the mire,           *makes a humming noise\n"
  "She laid her mouth unto the water down\n"
  "\"Bewray me not, thou water, with thy soun'\"\n"
  "Quoth she, \"to thee I tell it, and no mo',\n"
  "Mine husband hath long ass's eares two!\n"
  "Now is mine heart all whole; now is it out;\n"
  "I might no longer keep it, out of doubt.\"\n"
  "Here may ye see, though we a time abide,\n"
  "Yet out it must, we can no counsel hide.\n"
  "The remnant of the tale, if ye will hear,\n"
  "Read in Ovid, and there ye may it lear.*                          *learn\n"
  "\n"
  "This knight, of whom my tale is specially,\n"
  "When that he saw he might not come thereby,\n"
  "That is to say, what women love the most,\n"
  "Within his breast full sorrowful was his ghost.*                 *spirit\n"
  "But home he went, for he might not sojourn,\n"
  "The day was come, that homeward he must turn.\n"
  "And in his way it happen'd him to ride,\n"
  "In all his care,* under a forest side,                 *trouble, anxiety\n"
  "Where as he saw upon a dance go\n"
  "Of ladies four-and-twenty, and yet mo',\n"
  "Toward this ilke* dance he drew full yern,**        *same **eagerly <10>\n"
  "The hope that he some wisdom there should learn;\n"
  "But certainly, ere he came fully there,\n"
  "Y-vanish'd was this dance, he knew not where;\n"
  "No creature saw he that bare life,\n"
  "Save on the green he sitting saw a wife,\n"
  "A fouler wight there may no man devise.*                  *imagine, tell\n"
  "Against* this knight this old wife gan to rise,                 *to meet\n"
  "And said, \"Sir Knight, hereforth* lieth no way.               *from here\n"
  "Tell me what ye are seeking, by your fay.\n"
  "Paraventure it may the better be:\n"
  "These olde folk know muche thing.\" quoth she.\n"
  "My leve* mother,\" quoth this knight, \"certain,                     *dear\n"
  "I am but dead, but if* that I can sayn                           *unless\n"
  "What thing it is that women most desire:\n"
  "Could ye me wiss,* I would well *quite your hire.\"*       *instruct <11>\n"
  "\"Plight me thy troth here in mine hand,\" quoth she,         *reward you*\n"
  "\"The nexte thing that I require of thee\n"
  "Thou shalt it do, if it be in thy might,\n"
  "And I will tell it thee ere it be night.\"\n"
  "\"Have here my trothe,\" quoth the knight; \"I grant.\"\n"
  "\"Thenne,\" quoth she, \"I dare me well avaunt,*             *boast, affirm\n"
  "Thy life is safe, for I will stand thereby,\n"
  "Upon my life the queen will say as I:\n"
  "Let see, which is the proudest of them all,\n"
  "That wears either a kerchief or a caul,\n"
  "That dare say nay to that I shall you teach.\n"
  "Let us go forth withoute longer speech\n"
  "Then *rowned she a pistel* in his ear,          *she whispered a secret*\n"
  "And bade him to be glad, and have no fear.\n"
  "\n"
  "When they were come unto the court, this knight\n"
  "Said, he had held his day, as he had hight,*                   *promised\n"
  "And ready was his answer, as he said.\n"
  "Full many a noble wife, and many a maid,\n"
  "And many a widow, for that they be wise, --\n"
  "The queen herself sitting as a justice, --\n"
  "Assembled be, his answer for to hear,\n"
  "And afterward this knight was bid appear.\n"
  "To every wight commanded was silence,\n"
  "And that the knight should tell in audience,\n"
  "What thing that worldly women love the best.\n"
  "This knight he stood not still, as doth a beast,\n"
  "But to this question anon answer'd\n"
  "With manly voice, that all the court it heard,\n"
  "\"My liege lady, generally,\" quoth he,\n"
  "\"Women desire to have the sovereignty\n"
  "As well over their husband as their love\n"
  "And for to be in mast'ry him above.\n"
  "This is your most desire, though ye me kill,\n"
  "Do as you list, I am here at your will.\"\n"
  "In all the court there was no wife nor maid\n"
  "Nor widow, that contraried what he said,\n"
  "But said, he worthy was to have his life.\n"
  "And with that word up start that olde wife\n"
  "Which that the knight saw sitting on the green.\n"
  "\n"
  "\"Mercy,\" quoth she, \"my sovereign lady queen,\n"
  "Ere that your court departe, do me right.\n"
  "I taughte this answer unto this knight,\n"
  "For which he plighted me his trothe there,\n"
  "The firste thing I would of him requere,\n"
  "He would it do, if it lay in his might.\n"
  "Before this court then pray I thee, Sir Knight,\"\n"
  "Quoth she, \"that thou me take unto thy wife,\n"
  "For well thou know'st that I have kept* thy life.             *preserved\n"
  "If I say false, say nay, upon thy fay.\"*                          *faith\n"
  "This knight answer'd, \"Alas, and well-away!\n"
  "I know right well that such was my behest.*                     *promise\n"
  "For Godde's love choose a new request\n"
  "Take all my good, and let my body go.\"\n"
  "\"Nay, then,\" quoth she, \"I shrew* us bothe two,                   *curse\n"
  "For though that I be old, and foul, and poor,\n"
  "I n'ould* for all the metal nor the ore,                      *would not\n"
  "That under earth is grave,* or lies above                        *buried\n"
  "But if thy wife I were and eke thy love.\"\n"
  "\"My love?\" quoth he, \"nay, my damnation,\n"
  "Alas! that any of my nation\n"
  "Should ever so foul disparaged be.\n"
  "But all for nought; the end is this, that he\n"
  "Constrained was, that needs he muste wed,\n"
  "And take this olde wife, and go to bed.\n"
  "\n"
  "Now woulde some men say paraventure\n"
  "That for my negligence I do no cure*                      *take no pains\n"
  "To tell you all the joy and all th' array\n"
  "That at the feast was made that ilke* day.                         *same\n"
  "To which thing shortly answeren I shall:\n"
  "I say there was no joy nor feast at all,\n"
  "There was but heaviness and muche sorrow:\n"
  "For privily he wed her on the morrow;\n"
  "And all day after hid him as an owl,\n"
  "So woe was him, his wife look'd so foul\n"
  "Great was the woe the knight had in his thought\n"
  "When he was with his wife to bed y-brought;\n"
  "He wallow'd, and he turned to and fro.\n"
  "This olde wife lay smiling evermo',\n"
  "And said, \"Dear husband, benedicite,\n"
  "Fares every knight thus with his wife as ye?\n"
  "Is this the law of king Arthoures house?\n"
  "Is every knight of his thus dangerous?*           *fastidious, niggardly\n"
  "I am your owen love, and eke your wife\n"
  "I am she, which that saved hath your life\n"
  "And certes yet did I you ne'er unright.\n"
  "Why fare ye thus with me this firste night?\n"
  "Ye fare like a man had lost his wit.\n"
  "What is my guilt? for God's love tell me it,\n"
  "And it shall be amended, if I may.\"\n"
  "\"Amended!\" quoth this knight; \"alas, nay, nay,\n"
  "It will not be amended, never mo';\n"
  "Thou art so loathly, and so old also,\n"
  "And thereto* comest of so low a kind,                       *in addition\n"
  "That little wonder though I  wallow and wind;*       *writhe, turn about\n"
  "So woulde God, mine hearte woulde brest!\"*                        *burst\n"
  "\"Is this,\" quoth she, \"the cause of your unrest?\"\n"
  "\"Yea, certainly,\" quoth he; \"no wonder is.\"\n"
  "\"Now, Sir,\" quoth she, \"I could amend all this,\n"
  "If that me list, ere it were dayes three,\n"
  "*So well ye mighte bear you unto me.*              *if you could conduct\n"
  "But, for ye speaken of such gentleness                     yourself well\n"
  "As is descended out of old richess,                          towards me*\n"
  "That therefore shalle ye be gentlemen;\n"
  "Such arrogancy is *not worth a hen.*                      *worth nothing\n"
  "Look who that is most virtuous alway,\n"
  "*Prive and apert,* and most intendeth aye        *in private and public*\n"
  "To do the gentle deedes that he can;\n"
  "And take him for the greatest gentleman.\n"
  "Christ will,* we claim of him our gentleness,           *wills, requires\n"
  "Not of our elders* for their old richess.                     *ancestors\n"
  "For though they gave us all their heritage,\n"
  "For which we claim to be of high parage,*                *birth, descent\n"
  "Yet may they not bequeathe, for no thing,\n"
  "To none of us, their virtuous living\n"
  "That made them gentlemen called to be,\n"
  "And bade us follow them in such degree.\n"
  "Well can the wise poet of Florence,\n"
  "That highte Dante, speak of this sentence:*                   *sentiment\n"
  "Lo, in such manner* rhyme is Dante's tale.                      *kind of\n"
  "'Full seld'* upriseth by his branches smale                      *seldom\n"
  "Prowess of man, for God of his goodness\n"
  "Wills that we claim of him our gentleness;' <12>\n"
  "For of our elders may we nothing claim\n"
  "But temp'ral things that man may hurt and maim.\n"
  "Eke every wight knows this as well as I,\n"
  "If gentleness were planted naturally\n"
  "Unto a certain lineage down the line,\n"
  "Prive and apert, then would they never fine*                      *cease\n"
  "To do of gentleness the fair office\n"
  "Then might they do no villainy nor vice.\n"
  "Take fire, and bear it to the darkest house\n"
  "Betwixt this and the mount of Caucasus,\n"
  "And let men shut the doores, and go thenne,*                     *thence\n"
  "Yet will the fire as fair and lighte brenne*                       *burn\n"
  "As twenty thousand men might it behold;\n"
  "*Its office natural aye will it hold,*              *it will perform its\n"
  "On peril of my life, till that it die.                     natural duty*\n"
  "Here may ye see well how that gentery*              *gentility, nobility\n"
  "Is not annexed to possession,\n"
  "Since folk do not their operation\n"
  "Alway, as doth the fire, lo, *in its kind*        *from its very nature*\n"
  "For, God it wot, men may full often find\n"
  "A lorde's son do shame and villainy.\n"
  "And he that will have price* of his gent'ry,             *esteem, honour\n"
  "For* he was boren of a gentle house,                            *because\n"
  "And had his elders noble and virtuous,\n"
  "And will himselfe do no gentle deedes,\n"
  "Nor follow his gentle ancestry, that dead is,\n"
  "He is not gentle, be he duke or earl;\n"
  "For villain sinful deedes make a churl.\n"
  "For gentleness is but the renomee*                               *renown\n"
  "Of thine ancestors, for their high bounte,*             *goodness, worth\n"
  "Which is a strange thing to thy person:\n"
  "Thy gentleness cometh from God alone.\n"
  "Then comes our very* gentleness of grace;                          *true\n"
  "It was no thing bequeath'd us with our place.\n"
  "Think how noble, as saith Valerius,\n"
  "Was thilke* Tullius Hostilius,                                     *that\n"
  "That out of povert' rose to high\n"
  "Read in Senec, and read eke in Boece,\n"
  "There shall ye see express, that it no drede* is,                 *doubt\n"
  "That he is gentle that doth gentle deedes.\n"
  "And therefore, leve* husband, I conclude,                          *dear\n"
  "Albeit that mine ancestors were rude,\n"
  "Yet may the highe God, -- and so hope I, --\n"
  "Grant me His grace to live virtuously:\n"
  "Then am I gentle when that I begin\n"
  "To live virtuously, and waive* sin.                             *forsake\n"
  "\n"
  "\"And whereas ye of povert' me repreve,*                        *reproach\n"
  "The highe God, on whom that we believe,\n"
  "In wilful povert' chose to lead his life:\n"
  "And certes, every man, maiden, or wife\n"
  "May understand that Jesus, heaven's king,\n"
  "Ne would not choose a virtuous living.\n"
  "*Glad povert'* is an honest thing, certain;          *poverty cheerfully\n"
  "This will Senec and other clerkes sayn                          endured*\n"
  "Whoso that *holds him paid of*  his povert',         *is satisfied with*\n"
  "I hold him rich though he hath not a shirt.\n"
  "He that coveteth is a poore wight\n"
  "For he would have what is not in his might\n"
  "But he that nought hath, nor coveteth to have,\n"
  "Is rich, although ye hold him but a knave.*        *slave, abject wretch\n"
  "*Very povert' is sinne,* properly.        *the only true poverty is sin*\n"
  "Juvenal saith of povert' merrily:\n"
  "The poore man, when he goes by the way\n"
  "Before the thieves he may sing and play <13>\n"
  "Povert' is hateful good,<14> and, as I guess,\n"
  "A full great *bringer out of business;*           *deliver from trouble*\n"
  "A great amender eke of sapience\n"
  "To him that taketh it in patience.\n"
  "Povert' is this, although it seem elenge*                  *strange <15>\n"
  "Possession that no wight will challenge\n"
  "Povert' full often, when a man is low,\n"
  "Makes him his God and eke himself to know\n"
  "Povert' a spectacle* is, as thinketh me            *a pair of spectacles\n"
  "Through which he may his very* friendes see.                       *true\n"
  "And, therefore, Sir, since that I you not grieve,\n"
  "Of my povert' no more me repreve.*                             *reproach\n"
  "\"Now, Sir, of elde* ye repreve me:                                  *age\n"
  "And certes, Sir, though none authority*                    *text, dictum\n"
  "Were in no book, ye gentles of honour\n"
  "Say, that men should an olde wight honour,\n"
  "And call him father, for your gentleness;\n"
  "And authors shall I finden, as I guess.\n"
  "Now there ye say that I am foul and old,\n"
  "Then dread ye not to be a cokewold.*                            *cuckold\n"
  "For filth, and elde, all so may I the,*                          *thrive\n"
  "Be greate wardens upon chastity.\n"
  "But natheless, since I know your delight,\n"
  "I shall fulfil your wordly appetite.\n"
  "Choose now,\" quoth she, \"one of these thinges tway,\n"
  "To have me foul and old till that I dey,*                           *die\n"
  "And be to you a true humble wife,\n"
  "And never you displease in all my life:\n"
  "Or elles will ye have me young and fair,\n"
  "And take your aventure of the repair*                            *resort\n"
  "That shall be to your house because of me, --\n"
  "Or in some other place, it may well be?\n"
  "Now choose yourselfe whether that you liketh.\n"
  "\n"
  "This knight adviseth* him and sore he siketh,**     *considered **sighed\n"
  "But at the last he said in this mannere;\n"
  "\"My lady and my love, and wife so dear,\n"
  "I put me in your wise governance,\n"
  "Choose for yourself which may be most pleasance\n"
  "And most honour to you and me also;\n"
  "I *do no force* the whether of the two:                        *care not\n"
  "For as you liketh, it sufficeth me.\"\n"
  "\"Then have I got the mastery,\" quoth she,\n"
  "\"Since I may choose and govern as me lest.\"*                    *pleases\n"
  "\"Yea, certes wife,\" quoth he, \"I hold it best.\"\n"
  "\"Kiss me,\" quoth she, \"we are no longer wroth,*             *at variance\n"
  "For by my troth I will be to you both;\n"
  "This is to say, yea, bothe fair and good.\n"
  "I pray to God that I may *sterve wood,*                        *die mad*\n"
  "But* I to you be all so good and true,                           *unless\n"
  "As ever was wife since the world was new;\n"
  "And but* I be to-morrow as fair to seen,                         *unless\n"
  "As any lady, emperess or queen,\n"
  "That is betwixt the East and eke the West\n"
  "Do with my life and death right as you lest.*                    *please\n"
  "Cast up the curtain, and look how it is.\"\n"
  "\n"
  "And when the knight saw verily all this,\n"
  "That she so fair was, and so young thereto,\n"
  "For joy he hent* her in his armes two:                             *took\n"
  "His hearte bathed in a bath of bliss,\n"
  "A thousand times *on row* he gan her kiss:               *in succession*\n"
  "And she obeyed him in every thing\n"
  "That mighte do him pleasance or liking.\n"
  "And thus they live unto their lives' end\n"
  "In  perfect joy; and Jesus Christ us send\n"
  "Husbandes meek and young, and fresh in bed,\n"
  "And grace to overlive them that we wed.\n"
  "And eke I pray Jesus to short their lives,\n"
  "That will not be governed by their wives.\n"
  "And old and angry niggards of dispence,*                        *expense\n"
  "God send them soon a very pestilence!\n"
  "\n"
  "\n"
  "Notes to the Wife of Bath's Tale\n"
  "\n"
  "\n"
  "1. It is not clear whence Chaucer derived this tale. Tyrwhitt\n"
  "thinks it was taken from the story of Florent, in the first book of\n"
  "Gower's \"Confessio Amantis;\" or perhaps from an older\n"
  "narrative from which Gower himself borrowed. Chaucer has\n"
  "condensed and otherwise improved the fable, especially by\n"
  "laying the scene, not in Sicily, but at the court of our own King\n"
  "Arthur.\n"
  "\n"
  "2. Limitours: begging friars. See note 18 to the prologue to the\n"
  "Tales.\n"
  "\n"
  "3. Thorpes: villages.  Compare German, \"Dorf,\"; Dutch,\n"
  "\"Dorp.\"\n"
  "\n"
  "4. Undermeles: evening-tides, afternoons; \"undern\" signifies the\n"
  "evening; and \"mele,\" corresponds to the German \"Mal\" or\n"
  "\"Mahl,\" time.\n"
  "\n"
  "5. Incubus: an evil spirit supposed to do violence to women; a\n"
  "nightmare.\n"
  "\n"
  "6. Where he had been hawking after waterfowl. Froissart says\n"
  "that any one engaged in this sport \"alloit en riviere.\"\n"
  "\n"
  "7. Nice: foolish; French, \"niais.\"\n"
  "\n"
  "8. Claw us on the gall:  Scratch us on the sore place.  Compare,\n"
  "\"Let the galled jade wince.\" Hamlet iii. 2.\n"
  "\n"
  "9. Hele: hide; from Anglo-Saxon, \"helan,\" to hide, conceal.\n"
  "\n"
  "10. Yern: eagerly; German, \"gern.\"\n"
  "\n"
  "11. Wiss: instruct; German, \"weisen,\" to show or counsel.\n"
  "\n"
  "12. Dante, \"Purgatorio\", vii. 121.\n"
  "\n"
  "13. \"Cantabit vacuus coram latrone viator\" -- \"Satires,\" x. 22.\n"
  "\n"
  "14. In a fabulous conference between the Emperor Adrian and\n"
  "the philosopher Secundus, reported by Vincent of Beauvais,\n"
  "occurs the passage which Chaucer here paraphrases: -- \"Quid\n"
  "est Paupertas? Odibile bonum; sanitas mater; remotio Curarum;\n"
  "sapientae repertrix; negotium sine damno; possessio absque\n"
  "calumnia; sine sollicitudinae felicitas.\" (What is Poverty? A\n"
  "hateful good; a mother of health; a putting away of cares;  a\n"
  "discoverer of wisdom; business without injury; ownership\n"
  "without calumny; happiness without anxiety)\n"
  "\n"
  "15. Elenge: strange; from French \"eloigner,\" to remove.\n"
  "\n"
  "\n"
  "\n"
  "";
// }

const char friarsTale[] PGMSECTION = // { // 22256 bytes
  "THE FRIAR'S TALE.\n"
  "\n"
  "\n"
  "THE PROLOGUE.<1>\n"
  "\n"
  "\n"
  "This worthy limitour, this noble Frere,\n"
  "He made always a manner louring cheer*                      *countenance\n"
  "Upon the Sompnour; but for honesty*                            *courtesy\n"
  "No villain word as yet to him spake he:\n"
  "But at the last he said unto the Wife:\n"
  "\"Dame,\" quoth he, \"God give you right good life,\n"
  "Ye have here touched, all so may I the,*                         *thrive\n"
  "In school matter a greate difficulty.\n"
  "Ye have said muche thing right well, I say;\n"
  "But, Dame, here as we ride by the way,\n"
  "Us needeth not but for to speak of game,\n"
  "And leave authorities, in Godde's name,\n"
  "To preaching, and to school eke of clergy.\n"
  "But if it like unto this company,\n"
  "I will you of a Sompnour tell a game;\n"
  "Pardie, ye may well knowe by the name,\n"
  "That of a Sompnour may no good be said;\n"
  "I pray that none of you be *evil paid;*                   *dissatisfied*\n"
  "A Sompnour is a runner up and down\n"
  "With mandements* for fornicatioun,                 *mandates, summonses*\n"
  "And is y-beat at every towne's end.\"\n"
  "Then spake our Host; \"Ah, sir, ye should be hend*         *civil, gentle\n"
  "And courteous, as a man of your estate;\n"
  "In company we will have no debate:\n"
  "Tell us your tale, and let the Sompnour be.\"\n"
  "\"Nay,\" quoth the Sompnour, \"let him say by me\n"
  "What so him list; when it comes to my lot,\n"
  "By God, I shall him quiten* every groat!                    *pay him off\n"
  "I shall him telle what a great honour\n"
  "It is to be a flattering limitour\n"
  "And his office I shall him tell y-wis\".\n"
  "Our Host answered, \"Peace, no more of this.\"\n"
  "And afterward he said unto the frere,\n"
  "\"Tell forth your tale, mine owen master dear.\"\n"
  "\n"
  "\n"
  "Notes to the Prologue to the Friar's tale\n"
  "\n"
  "\n"
  "1. On the Tale of the Friar, and that of the Sompnour which\n"
  "follows, Tyrwhitt has remarked that they \"are well engrafted\n"
  "upon that of the Wife of Bath. The ill-humour which shows\n"
  "itself between these two characters is quite natural, as no two\n"
  "professions at that time were at more constant variance.  The\n"
  "regular clergy, and particularly the mendicant friars, affected a\n"
  "total exemption from all ecclesiastical jurisdiction,  except that\n"
  "of the Pope, which made them exceedingly obnoxious to the\n"
  "bishops and of course to all the inferior officers of the national\n"
  "hierarchy.\" Both tales, whatever their origin, are bitter satires\n"
  "on the greed and worldliness of the Romish clergy.\n"
  "\n"
  "\n"
  "\n"
  "THE TALE.\n"
  "\n"
  "\n"
  "Whilom* there was dwelling in my country                 *once on a time\n"
  "An archdeacon, a man of high degree,\n"
  "That boldely did execution,\n"
  "In punishing of fornication,\n"
  "Of witchecraft, and eke of bawdery,\n"
  "Of defamation, and adultery,\n"
  "Of churche-reeves,* and of testaments,                    *churchwardens\n"
  "Of contracts, and of lack of sacraments,\n"
  "And eke of many another manner* crime,                          *sort of\n"
  "Which needeth not rehearsen at this time,\n"
  "Of usury, and simony also;\n"
  "But, certes, lechours did he greatest woe;\n"
  "They shoulde singen, if that they were hent;*                    *caught\n"
  "And smale tithers<1> were foul y-shent,*         *troubled, put to shame\n"
  "If any person would on them complain;\n"
  "There might astert them no pecunial pain.<2>\n"
  "For smalle tithes, and small offering,\n"
  "He made the people piteously to sing;\n"
  "For ere the bishop caught them with his crook,\n"
  "They weren in the archedeacon's book;\n"
  "Then had he, through his jurisdiction,\n"
  "Power to do on them correction.\n"
  "\n"
  "He had a Sompnour ready to his hand,\n"
  "A slier boy was none in Engleland;\n"
  "For subtlely he had his espiaille,*                           *espionage\n"
  "That taught him well where it might aught avail.\n"
  "He coulde spare of lechours one or two,\n"
  "To teache him to four and twenty mo'.\n"
  "For, -- though this Sompnour wood* be as a hare, --        *furious, mad\n"
  "To tell his harlotry I will not spare,\n"
  "For we be out of their correction,\n"
  "They have of us no jurisdiction,\n"
  "Ne never shall have, term of all their lives.\n"
  "\n"
  "\"Peter; so be the women of the stives,\"*                          *stews\n"
  "Quoth this Sompnour, \"y-put out of our cure.\"*                     *care\n"
  "\n"
  "\"Peace, with mischance and with misaventure,\"\n"
  "Our Hoste said, \"and let him tell his tale.\n"
  "Now telle forth, and let the Sompnour gale,*              *whistle; bawl\n"
  "Nor spare not, mine owen master dear.\"\n"
  "\n"
  "This false thief, the Sompnour (quoth the Frere),\n"
  "Had always bawdes ready to his hand,\n"
  "As any hawk to lure in Engleland,\n"
  "That told him all the secrets that they knew, --\n"
  "For their acquaintance was not come of new;\n"
  "They were his approvers* privily.                             *informers\n"
  "He took himself at great profit thereby:\n"
  "His master knew not always what he wan.*                            *won\n"
  "Withoute mandement, a lewed* man                               *ignorant\n"
  "He could summon, on pain of Christe's curse,\n"
  "And they were inly glad to fill his purse,\n"
  "And make him greate feastes at the nale.*                      *alehouse\n"
  "And right as Judas hadde purses smale,*                           *small\n"
  "And was a thief, right such a thief was he,\n"
  "His master had but half *his duety.*                *what was owing him*\n"
  "He was (if I shall give him his laud)\n"
  "A thief, and eke a Sompnour, and a bawd.\n"
  "And he had wenches at his retinue,\n"
  "That whether that Sir Robert or Sir Hugh,\n"
  "Or Jack, or Ralph, or whoso that it were\n"
  "That lay by them, they told it in his ear.\n"
  "Thus were the wench and he of one assent;\n"
  "And he would fetch a feigned mandement,\n"
  "And to the chapter summon them both two,\n"
  "And pill* the man, and let the wenche go.                *plunder, pluck\n"
  "Then would he say, \"Friend, I shall for thy sake\n"
  "Do strike thee out of oure letters blake;*                        *black\n"
  "Thee thar* no more as in this case travail;                        *need\n"
  "I am thy friend where I may thee avail.\"\n"
  "Certain he knew of bribers many mo'\n"
  "Than possible is to tell in yeare's two:\n"
  "For in this world is no dog for the bow,<3>\n"
  "That can a hurt deer from a whole know,\n"
  "Bet* than this Sompnour knew a sly lechour,                      *better\n"
  "Or an adult'rer, or a paramour:\n"
  "And, for that was the fruit of all his rent,\n"
  "Therefore on it he set all his intent.\n"
  "\n"
  "And so befell, that once upon a day.\n"
  "This Sompnour, waiting ever on his prey,\n"
  "Rode forth to summon a widow, an old ribibe,<4>\n"
  "Feigning a cause, for he would have a bribe.\n"
  "And happen'd that he saw before him ride\n"
  "A gay yeoman under a forest side:\n"
  "A bow he bare, and arrows bright and keen,\n"
  "He had upon a courtepy* of green,                         *short doublet\n"
  "A hat upon his head with fringes blake.*                          *black\n"
  "\"Sir,\" quoth this Sompnour, \"hail, and well o'ertake.\"\n"
  "\"Welcome,\" quoth he, \"and every good fellaw;\n"
  "Whither ridest thou under this green shaw?\"*                       shade\n"
  "Saide this yeoman; \"wilt thou far to-day?\"\n"
  "This Sompnour answer'd him, and saide, \"Nay.\n"
  "Here faste by,\" quoth he, \"is mine intent\n"
  "To ride, for to raisen up a rent,\n"
  "That longeth to my lorde's duety.\"\n"
  "\"Ah! art thou then a bailiff?\" \"Yea,\" quoth he.\n"
  "He durste not for very filth and shame\n"
  "Say that he was a Sompnour, for the name.\n"
  "\"De par dieux,\" <5> quoth this yeoman, \"leve* brother,             *dear\n"
  "Thou art a bailiff, and I am another.\n"
  "I am unknowen, as in this country.\n"
  "Of thine acquaintance I will praye thee,\n"
  "And eke of brotherhood, if that thee list.*                      *please\n"
  "I have gold and silver lying in my chest;\n"
  "If that thee hap to come into our shire,\n"
  "All shall be thine, right as thou wilt desire.\"\n"
  "\"Grand mercy,\"* quoth this Sompnour, \"by my faith.\"        *great thanks\n"
  "Each in the other's hand his trothe lay'th,\n"
  "For to be sworne brethren till they dey.*                        *die<6>\n"
  "In dalliance they ride forth and play.\n"
  "\n"
  "This Sompnour, which that was as full of jangles,*           *chattering\n"
  "As full of venom be those wariangles,*               * butcher-birds <7>\n"
  "And ev'r inquiring upon every thing,\n"
  "\"Brother,\" quoth he, \"where is now your dwelling,\n"
  "Another day if that I should you seech?\"*                   *seek, visit\n"
  "This yeoman him answered in soft speech;\n"
  "Brother,\" quoth he, \"far in the North country,<8>\n"
  "Where as I hope some time I shall thee see\n"
  "Ere we depart I shall thee so well wiss,*                        *inform\n"
  "That of mine house shalt thou never miss.\"\n"
  "Now, brother,\" quoth this Sompnour, \"I you pray,\n"
  "Teach me, while that we ride by the way,\n"
  "(Since that ye be a bailiff as am I,)\n"
  "Some subtilty, and tell me faithfully\n"
  "For mine office how that I most may win.\n"
  "And *spare not* for conscience or for sin,             *conceal nothing*\n"
  "But, as my brother, tell me how do ye.\"\n"
  "Now by my trothe, brother mine,\" said he,\n"
  "As I shall tell to thee a faithful tale:\n"
  "My wages be full strait and eke full smale;\n"
  "My lord is hard to me and dangerous,*                         *niggardly\n"
  "And mine office is full laborious;\n"
  "And therefore by extortion I live,\n"
  "Forsooth I take all that men will me give.\n"
  "Algate* by sleighte, or by violence,                            *whether\n"
  "From year to year I win all my dispence;\n"
  "I can no better tell thee faithfully.\"\n"
  "Now certes,\" quoth this Sompnour,  \"so fare* I;                      *do\n"
  "I spare not to take, God it wot,\n"
  "*But if* it be too heavy or too hot.                            *unless*\n"
  "What I may get in counsel privily,\n"
  "No manner conscience of that have I.\n"
  "N'ere* mine extortion, I might not live,                *were it not for\n"
  "For of such japes* will I not be shrive.**           *tricks **confessed\n"
  "Stomach nor conscience know I none;\n"
  "I shrew* these shrifte-fathers** every one.          *curse **confessors\n"
  "Well be we met, by God and by St Jame.\n"
  "But, leve brother, tell me then thy name,\"\n"
  "Quoth this Sompnour.  Right in this meane while\n"
  "This yeoman gan a little for to smile.\n"
  "\n"
  "\"Brother,\" quoth he, \"wilt thou that I thee tell?\n"
  "I am a fiend, my dwelling is in hell,\n"
  "And here I ride about my purchasing,\n"
  "To know where men will give me any thing.\n"
  "*My purchase is th' effect of all my rent*        *what I can gain is my\n"
  "Look how thou ridest for the same intent                   sole revenue*\n"
  "To winne good, thou reckest never how,\n"
  "Right so fare I, for ride will I now\n"
  "Into the worlde's ende for a prey.\"\n"
  "\n"
  "\"Ah,\" quoth this Sompnour, \"benedicite! what say y'?\n"
  "I weened ye were a yeoman truly.                                *thought\n"
  "Ye have a manne's shape as well as I\n"
  "Have ye then a figure determinate\n"
  "In helle, where ye be in your estate?\"*                         *at home\n"
  "\"Nay, certainly,\" quoth he, there have we none,\n"
  "But when us liketh we can take us one,\n"
  "Or elles make you seem* that we be shape                        *believe\n"
  "Sometime like a man, or like an ape;\n"
  "Or like an angel can I ride or go;\n"
  "It is no wondrous thing though it be so,\n"
  "A lousy juggler can deceive thee.\n"
  "And pardie, yet can I more craft* than he.\"              *skill, cunning\n"
  "\"Why,\" quoth the Sompnour, \"ride ye then or gon\n"
  "In sundry shapes and not always in one?\"\n"
  "\"For we,\" quoth he, \"will us in such form make.\n"
  "As most is able our prey for to take.\"\n"
  "\"What maketh you to have all this labour?\"\n"
  "\"Full many a cause, leve Sir Sompnour,\"\n"
  "Saide this fiend. \"But all thing hath a time;\n"
  "The day is short and it is passed prime,\n"
  "And yet have I won nothing in this day;\n"
  "I will intend* to winning, if I may,                       *apply myself\n"
  "And not intend our thinges to declare:\n"
  "For, brother mine, thy wit is all too bare\n"
  "To understand, although I told them thee.\n"
  "*But for* thou askest why laboure we:                          *because*\n"
  "For sometimes we be Godde's instruments\n"
  "And meanes to do his commandements,\n"
  "When that him list, upon his creatures,\n"
  "In divers acts and in divers figures:\n"
  "Withoute him we have no might certain,\n"
  "If that him list to stande thereagain.*                      *against it\n"
  "And sometimes, at our prayer have we leave\n"
  "Only the body, not the soul, to grieve:\n"
  "Witness on Job, whom that we did full woe,\n"
  "And sometimes have we might on both the two, --\n"
  "This is to say, on soul and body eke,\n"
  "And sometimes be we suffer'd for to seek\n"
  "Upon a man and do his soul unrest\n"
  "And not his body, and all is for the best,\n"
  "When he withstandeth our temptation,\n"
  "It is a cause of his salvation,\n"
  "Albeit that it was not our intent\n"
  "He should be safe, but that we would him hent.*                   *catch\n"
  "And sometimes be we servants unto man,\n"
  "As to the archbishop Saint Dunstan,\n"
  "And to th'apostle servant eke was I.\"\n"
  "\"Yet tell me,\" quoth this Sompnour, \"faithfully,\n"
  "Make ye you newe bodies thus alway\n"
  "Of th' elements?\" The fiend answered, \"Nay:\n"
  "Sometimes we feign, and sometimes we arise\n"
  "With deade bodies, in full sundry wise,\n"
  "And speak as reas'nably, and fair, and well,\n"
  "As to the Pythoness<9> did Samuel:\n"
  "And yet will some men say it was not he.\n"
  "I *do no force of* your divinity.                    *set no value upon*\n"
  "But one thing warn I thee, I will not jape,*                        jest\n"
  "Thou wilt *algates weet* how we be shape:               *assuredly know*\n"
  "Thou shalt hereafterward, my brother dear,\n"
  "Come, where thee needeth not of me to lear.*                      *learn\n"
  "For thou shalt by thine own experience\n"
  "*Conne in a chair to rede of this sentence,*        *learn to understand\n"
  "Better than Virgil, while he was alive,                what I have said*\n"
  "Or Dante also. <10> Now let us ride blive,*                     *briskly\n"
  "For I will holde company with thee,\n"
  "Till it be so that thou forsake me.\"\n"
  "\"Nay,\" quoth this Sompnour, \"that shall ne'er betide.\n"
  "I am a yeoman, that is known full wide;\n"
  "My trothe will I hold, as in this case;\n"
  "For though thou wert the devil Satanas,\n"
  "My trothe will I hold to thee, my brother,\n"
  "As I have sworn, and each of us to other,\n"
  "For to be true brethren in this case,\n"
  "And both we go *abouten our purchase.*                  *seeking what we\n"
  "Take thou thy part, what that men will thee give,           may pick up*\n"
  "And I shall mine, thus may we bothe live.\n"
  "And if that any of us have more than other,\n"
  "Let him be true, and part it with his brother.\"\n"
  "\"I grante,\" quoth the devil, \"by my fay.\"\n"
  "And with that word they rode forth their way,\n"
  "And right at th'ent'ring of the towne's end,\n"
  "To which this Sompnour shope* him for to wend,**            *shaped **go\n"
  "They saw a cart, that charged was with hay,\n"
  "Which that a carter drove forth on his way.\n"
  "Deep was the way, for which the carte stood:\n"
  "The carter smote, and cried as he were wood,*                       *mad\n"
  "\"Heit Scot! heit Brok! what, spare ye for the stones?\n"
  "The fiend (quoth he) you fetch body and bones,\n"
  "As farforthly* as ever ye were foal'd,                             *sure\n"
  "So muche woe as I have with you tholed.*                   *endured <11>\n"
  "The devil have all, horses, and cart, and hay.\"\n"
  "The Sompnour said, \"Here shall we have a prey,\"\n"
  "And near the fiend he drew, *as nought ne were,*          *as if nothing\n"
  "Full privily, and rowned* in his ear:                   were the matter*\n"
  "\"Hearken, my brother, hearken, by thy faith,                  *whispered\n"
  "Hearest thou not, how that the carter saith?\n"
  "Hent* it anon, for he hath giv'n it thee,                         *seize\n"
  "Both hay and cart, and eke his capels* three.\"              *horses <12>\n"
  "\"Nay,\" quoth the devil, \"God wot, never a deal,*                    whit\n"
  "It is not his intent, trust thou me well;\n"
  "Ask him thyself, if thou not trowest* me,                     *believest\n"
  "Or elles stint* a while and thou shalt see.\"                       *stop\n"
  "The carter thwack'd his horses on the croup,\n"
  "And they began to drawen and to stoop.\n"
  "\"Heit now,\" quoth he; \"there, Jesus Christ you bless,\n"
  "And all his handiwork, both more and less!\n"
  "That was well twight,* mine owen liart,** boy,        *pulled **grey<13>\n"
  "I pray God save thy body, and Saint Loy!\n"
  "Now is my cart out of the slough, pardie.\"\n"
  "\"Lo, brother,\" quoth the fiend, \"what told I thee?\n"
  "Here may ye see, mine owen deare brother,\n"
  "The churl spake one thing, but he thought another.\n"
  "Let us go forth abouten our voyage;\n"
  "Here win I nothing upon this carriage.\"\n"
  "\n"
  "When that they came somewhat out of the town,\n"
  "This Sompnour to his brother gan to rown;\n"
  "\"Brother,\" quoth he, \"here wons* an old rebeck,<14>              *dwells\n"
  "That had almost as lief to lose her neck.\n"
  "As for to give a penny of her good.\n"
  "I will have twelvepence, though that she be wood,*                  *mad\n"
  "Or I will summon her to our office;\n"
  "And yet, God wot, of her know I no vice.\n"
  "But for thou canst not, as in this country,\n"
  "Winne thy cost, take here example of me.\"\n"
  "This Sompnour clapped at the widow's gate:\n"
  "\"Come out,\" he said, \"thou olde very trate;*                  *trot <15>\n"
  "I trow thou hast some friar or priest with thee.\"\n"
  "\"Who clappeth?\" said this wife; \"benedicite,\n"
  "God save you, Sir, what is your sweete will?\"\n"
  "\"I have,\" quoth he, \"of summons here a bill.\n"
  "Up* pain of cursing, looke that thou be                            *upon\n"
  "To-morrow before our archdeacon's knee,\n"
  "To answer to the court of certain things.\"\n"
  "\"Now Lord,\" quoth she, \"Christ Jesus, king of kings,\n"
  "So wis1y* helpe me, *as I not may.*                *surely *as I cannot*\n"
  "I have been sick, and that full many a day.\n"
  "I may not go so far,\" quoth she, \"nor ride,\n"
  "But I be dead, so pricketh it my side.\n"
  "May I not ask a libel, Sir Sompnour,\n"
  "And answer there by my procuratour\n"
  "To such thing as men would appose* me?\"                          *accuse\n"
  "\"Yes,\" quoth this Sompnour, \"pay anon, let see,\n"
  "Twelvepence to me, and I will thee acquit.\n"
  "I shall no profit have thereby but lit:*                         *little\n"
  "My master hath the profit and not I.\n"
  "Come off, and let me ride hastily;\n"
  "Give me twelvepence, I may no longer tarry.\"\n"
  "\n"
  "\"Twelvepence!\" quoth she; \"now lady Sainte Mary\n"
  "So wisly* help me out of care and sin,                           *surely\n"
  "This wide world though that I should it win,\n"
  "No have I not twelvepence within my hold.\n"
  "Ye know full well that I am poor and old;\n"
  "*Kithe your almes* upon me poor wretch.\"             *show your charity*\n"
  "\"Nay then,\" quoth he, \"the foule fiend me fetch,\n"
  "If I excuse thee, though thou should'st be spilt.\"*              *ruined\n"
  "\"Alas!\" quoth she, \"God wot, I have no guilt.\"\n"
  "\"Pay me,\" quoth he, \"or, by the sweet Saint Anne,\n"
  "As I will bear away thy newe pan\n"
  "For debte, which thou owest me of old, --\n"
  "When that thou madest thine husband cuckold, --\n"
  "I paid at home for thy correction.\"\n"
  "\"Thou liest,\" quoth she, \"by my salvation;\n"
  "Never was I ere now, widow or wife,\n"
  "Summon'd unto your court in all my life;\n"
  "Nor never I was but of my body true.\n"
  "Unto the devil rough and black of hue\n"
  "Give I thy body and my pan also.\"\n"
  "And when the devil heard her curse so\n"
  "Upon her knees, he said in this mannere;\n"
  "\"Now, Mabily, mine owen mother dear,\n"
  "Is this your will in earnest that ye say?\"\n"
  "\"The devil,\" quoth she, \"so fetch him ere he dey,*                  *die\n"
  "And pan and all, but* he will him repent.\"                       *unless\n"
  "\"Nay, olde stoat,* that is not mine intent,\"                    *polecat\n"
  "Quoth this Sompnour, \"for to repente me\n"
  "For any thing that I have had of thee;\n"
  "I would I had thy smock and every cloth.\"\n"
  "\"Now, brother,\" quoth the devil, \"be not wroth;\n"
  "Thy body and this pan be mine by right.\n"
  "Thou shalt with me to helle yet tonight,\n"
  "Where thou shalt knowen of our privity*                         *secrets\n"
  "More than a master of divinity.\"\n"
  "\n"
  "And with that word the foule fiend him hent.*                    *seized\n"
  "Body and soul, he with the devil went,\n"
  "Where as the Sompnours have their heritage;\n"
  "And God, that maked after his image\n"
  "Mankinde, save and guide us all and some,\n"
  "And let this Sompnour a good man become.\n"
  "Lordings, I could have told you (quoth this Frere),\n"
  "Had I had leisure for this Sompnour here,\n"
  "After the text of Christ, and Paul, and John,\n"
  "And of our other doctors many a one,\n"
  "Such paines, that your heartes might agrise,*              *be horrified\n"
  "Albeit so, that no tongue may devise,* --                        *relate\n"
  "Though that I might a thousand winters tell, --\n"
  "The pains of thilke* cursed house of hell                          *that\n"
  "But for to keep us from that cursed place\n"
  "Wake we, and pray we Jesus, of his grace,\n"
  "So keep us from the tempter, Satanas.\n"
  "Hearken this word, beware as in this case.\n"
  "The lion sits *in his await* alway                   *on the watch* <16>\n"
  "To slay the innocent, if that he may.\n"
  "Disposen aye your heartes to withstond\n"
  "The fiend that would you make thrall and bond;\n"
  "He may not tempte you over your might,\n"
  "For Christ will be your champion and your knight;\n"
  "And pray, that this our Sompnour him repent\n"
  "Of his misdeeds ere that the fiend him hent.*                     *seize\n"
  "\n"
  "\n"
  "Notes to the Friar's Tale\n"
  "\n"
  "\n"
  "1. Small tithers:  people who did not pay their full tithes.  Mr\n"
  "Wright remarks that \"the sermons of the friars in the fourteenth\n"
  "century were most frequently designed to impress the ahsolute\n"
  "duty of paying full tithes and offerings\".\n"
  "\n"
  "2. There might astert them no pecunial pain: they got off with\n"
  "no mere pecuniary punishment. (Transcriber's note: \"Astert\"\n"
  "means \"escape\".  An alternative reading of this line is \"there\n"
  "might astert him no pecunial pain\" i.e. no fine ever escaped him\n"
  "(the archdeacon))\n"
  "\n"
  "3. A dog for the bow:  a dog attending a huntsman with bow\n"
  "and arrow.\n"
  "\n"
  "4. Ribibe: the name of a musical instrument; applied to an old\n"
  "woman because of the shrillness of her voice.\n"
  "\n"
  "5. De par dieux: by the gods.\n"
  "\n"
  "6. See note 12 to the Knight's Tale.\n"
  "\n"
  "7. Wariangles: butcher-birds; which are very noisy and\n"
  "ravenous, and tear in pieces the birds on which they prey; the\n"
  "thorn on which they do this was said to become poisonous.\n"
  "\n"
  "8. Medieval legends located hell in the North.\n"
  "\n"
  "9. The Pythoness: the witch, or woman, possesed with a\n"
  "prophesying spirit; from the Greek, \"Pythia.\"  Chaucer of\n"
  "course refers to the raising of Samuel's spirit by the witch of\n"
  "Endor.\n"
  "\n"
  "10. Dante and Virgil were both poets who had in fancy visited\n"
  "Hell.\n"
  "\n"
  "11. Tholed: suffered, endured; \"thole\" is still used in Scotland in\n"
  "the same sense.\n"
  "\n"
  "12. Capels: horses. See note 14 to the Reeve's Tale.\n"
  "\n"
  "13. Liart: grey; elsewhere applied by Chaucer to the hairs of an\n"
  "old man. So Burns, in the \"Cotter's Saturday Night,\" speaks of\n"
  "the gray temples of \"the sire\" -- \"His lyart haffets wearing thin\n"
  "and bare.\"\n"
  "\n"
  "14. Rebeck: a kind of fiddle; used like \"ribibe,\" as a nickname\n"
  "for a shrill old scold.\n"
  "\n"
  "15. Trot; a contemptuous term for an old woman who has\n"
  "trotted about much, or who moves with quick short steps.\n"
  "\n"
  "16. In his await: on the watch; French, \"aux aguets.\"\n"
  "\n"
  "\n"
  "\n"
  "";
// }

const char sompnoursTale0[] PGMSECTION = // { // 17516 bytes
  "THE SOMPNOUR'S TALE.\n"
  "\n"
  "\n"
  "THE PROLOGUE.\n"
  "\n"
  "\n"
  "The Sompnour in his stirrups high he stood,\n"
  "Upon this Friar his hearte was so wood,*                        *furious\n"
  "That like an aspen leaf he quoke* for ire:             *quaked, trembled\n"
  "\"Lordings,\" quoth he, \"but one thing I desire;\n"
  "I you beseech, that of your courtesy,\n"
  "Since ye have heard this false Friar lie,\n"
  "As suffer me I may my tale tell\n"
  "This Friar boasteth that he knoweth hell,\n"
  "And, God it wot, that is but little wonder,\n"
  "Friars and fiends be but little asunder.\n"
  "For, pardie, ye have often time heard tell,\n"
  "How that a friar ravish'd was to hell\n"
  "In spirit ones by a visioun,\n"
  "And, as an angel led him up and down,\n"
  "To shew him all the paines that there were,\n"
  "In all the place saw he not a frere;\n"
  "Of other folk he saw enough in woe.\n"
  "Unto the angel spake the friar tho;*                               *then\n"
  "'Now, Sir,' quoth he, 'have friars such a grace,\n"
  "That none of them shall come into this place?'\n"
  "'Yes' quoth the angel; 'many a millioun:'\n"
  "And unto Satanas he led him down.\n"
  "'And now hath Satanas,' said he, 'a tail\n"
  "Broader than of a carrack<1> is the sail.\n"
  "Hold up thy tail, thou Satanas,' quoth he,\n"
  "'Shew forth thine erse, and let the friar see\n"
  "Where is the nest of friars in this place.'\n"
  "And *less than half a furlong way of space*            *immediately* <2>\n"
  "Right so as bees swarmen out of a hive,\n"
  "Out of the devil's erse there gan to drive\n"
  "A twenty thousand friars *on a rout.*                       *in a crowd*\n"
  "And throughout hell they swarmed all about,\n"
  "And came again, as fast as they may gon,\n"
  "And in his erse they creeped every one:\n"
  "He clapt his tail again, and lay full still.\n"
  "This friar, when he looked had his fill\n"
  "Upon the torments of that sorry place,\n"
  "His spirit God restored of his grace\n"
  "Into his body again, and he awoke;\n"
  "But natheless for feare yet he quoke,\n"
  "So was the devil's erse aye in his mind;\n"
  "That is his heritage, *of very kind*                *by his very nature*\n"
  "God save you alle, save this cursed Frere;\n"
  "My prologue will I end in this mannere.\n"
  "\n"
  "\n"
  "Notes to the Prologue to the Sompnour's Tale\n"
  "\n"
  "\n"
  "1. Carrack: A great ship of burden used by the Portuguese; the\n"
  "name is from the Italian, \"cargare,\" to load\n"
  "\n"
  "2. In less than half a furlong way of space: immediately;\n"
  "literally, in less time than it takes to walk half a furlong (110\n"
  "yards).\n"
  "\n"
  "\n"
  "THE TALE.\n"
  "\n"
  "\n"
  "Lordings, there is in Yorkshire, as I guess,\n"
  "A marshy country called Holderness,\n"
  "In which there went a limitour about\n"
  "To preach, and eke to beg, it is no doubt.\n"
  "And so befell that on a day this frere\n"
  "Had preached at a church in his mannere,\n"
  "And specially, above every thing,\n"
  "Excited he the people in his preaching\n"
  "To trentals, <1> and to give, for Godde's sake,\n"
  "Wherewith men mighte holy houses make,\n"
  "There as divine service is honour'd,\n"
  "Not there as it is wasted and devour'd,\n"
  "Nor where it needeth not for to be given,\n"
  "As to possessioners, <2> that may liven,\n"
  "Thanked be God, in wealth and abundance.\n"
  "\"Trentals,\" said he, \"deliver from penance\n"
  "Their friendes' soules, as well old as young,\n"
  "Yea, when that they be hastily y-sung, --\n"
  "Not for to hold a priest jolly and gay,\n"
  "He singeth not but one mass in a day.\n"
  "\"Deliver out,\" quoth he, \"anon the souls.\n"
  "Full hard it is, with flesh-hook or with owls*                     *awls\n"
  "To be y-clawed, or to burn or bake: <3>\n"
  "Now speed you hastily, for Christe's sake.\"\n"
  "And when this friar had said all his intent,\n"
  "With qui cum patre<4> forth his way he went,\n"
  "When folk in church had giv'n him what them lest;*              *pleased\n"
  "He went his way, no longer would he rest,\n"
  "With scrip and tipped staff, *y-tucked high:*      *with his robe tucked\n"
  "In every house he gan to pore* and pry,                   up high* *peer\n"
  "And begged meal and cheese, or elles corn.\n"
  "His fellow had a staff tipped with horn,\n"
  "A pair of tables* all of ivory,                         *writing tablets\n"
  "And a pointel* y-polish'd fetisly,**                  *pencil **daintily\n"
  "And wrote alway the names, as he stood;\n"
  "Of all the folk that gave them any good,\n"
  "Askaunce* that he woulde for them pray.                    *see note <5>\n"
  "\"Give us a bushel wheat, or malt, or rey,*                          *rye\n"
  "A Godde's kichel,* or a trip** of cheese,        *little cake<6> **scrap\n"
  "Or elles what you list, we may not chese;*                       *choose\n"
  "A Godde's halfpenny, <6> or a mass penny;\n"
  "Or give us of your brawn, if ye have any;\n"
  "A dagon* of your blanket, leve dame,                            *remnant\n"
  "Our sister dear, -- lo, here I write your name,--\n"
  "Bacon or beef, or such thing as ye find.\"\n"
  "A sturdy harlot* went them aye behind,                   *manservant <7>\n"
  "That was their hoste's man, and bare a sack,\n"
  "And what men gave them, laid it on his back\n"
  "And when that he was out at door, anon\n"
  "He *planed away* the names every one,                       *rubbed out*\n"
  "That he before had written in his tables:\n"
  "He served them with nifles* and with fables. --             *silly tales\n"
  "\n"
  "\"Nay, there thou liest, thou Sompnour,\" quoth the Frere.\n"
  "\"Peace,\" quoth our Host, \"for Christe's mother dear;\n"
  "Tell forth thy tale, and spare it not at all.\"\n"
  "\"So thrive I,\" quoth this Sompnour, \"so I shall.\" --\n"
  "\n"
  "So long he went from house to house, till he\n"
  "Came to a house, where he was wont to be\n"
  "Refreshed more than in a hundred places\n"
  "Sick lay the husband man, whose that the place is,\n"
  "Bed-rid upon a couche low he lay:\n"
  "*\"Deus hic,\"* quoth he; \"O Thomas friend, good day,\"       *God be here*\n"
  "Said this friar, all courteously and soft.\n"
  "\"Thomas,\" quoth he, \"God *yield it you,* full oft       *reward you for*\n"
  "Have I upon this bench fared full well,\n"
  "Here have I eaten many a merry meal.\"\n"
  "And from the bench he drove away the cat,\n"
  "And laid adown his potent* and his hat,                       *staff <8>\n"
  "And eke his scrip, and sat himself adown:\n"
  "His fellow was y-walked into town\n"
  "Forth with his knave,* into that hostelry                       *servant\n"
  "Where as he shope* him that night to lie.              *shaped, purposed\n"
  "\n"
  "\"O deare master,\" quoth this sicke man,\n"
  "\"How have ye fared since that March began?\n"
  "I saw you not this fortenight and more.\"\n"
  "\"God wot,\" quoth he, \"labour'd have I full sore;\n"
  "And specially for thy salvation\n"
  "Have I said many a precious orison,\n"
  "And for mine other friendes, God them bless.\n"
  "I have this day been at your church at mess,*                      *mass\n"
  "And said sermon after my simple wit,\n"
  "Not all after the text of Holy Writ;\n"
  "For it is hard to you, as I suppose,\n"
  "And therefore will I teach you aye the glose.*           *gloss, comment\n"
  "Glosing is a full glorious thing certain,\n"
  "For letter slayeth, as we clerkes* sayn.                       *scholars\n"
  "There have I taught them to be charitable,\n"
  "And spend their good where it is reasonable.\n"
  "And there I saw our dame; where is she?\"\n"
  "\"Yonder I trow that in the yard she be,\"\n"
  "Saide this man; \"and she will come anon.\"\n"
  "\"Hey master, welcome be ye by Saint John,\"\n"
  "Saide this wife; \"how fare ye heartily?\"\n"
  "\n"
  "This friar riseth up full courteously,\n"
  "And her embraceth *in his armes narrow,*                        *closely\n"
  "And kiss'th her sweet, and chirketh as a sparrow\n"
  "With his lippes: \"Dame,\" quoth he, \"right well,\n"
  "As he that is your servant every deal.*                            *whit\n"
  "Thanked be God, that gave you soul and life,\n"
  "Yet saw I not this day so fair a wife\n"
  "In all the churche, God so save me,\"\n"
  "\"Yea, God amend defaultes, Sir,\" quoth she;\n"
  "\"Algates* welcome be ye, by my fay.\"                             *always\n"
  "\"Grand mercy, Dame; that have I found alway.\n"
  "But of your greate goodness, by your leave,\n"
  "I woulde pray you that ye not you grieve,\n"
  "I will with Thomas speak *a little throw:*              *a little while*\n"
  "These curates be so negligent and slow\n"
  "To grope tenderly a conscience.\n"
  "In shrift* and preaching is my diligence                     *confession\n"
  "And study in Peter's wordes and in Paul's;\n"
  "I walk and fishe Christian menne's souls,\n"
  "To yield our Lord Jesus his proper rent;\n"
  "To spread his word is alle mine intent.\"\n"
  "\"Now by your faith, O deare Sir,\" quoth she,\n"
  "\"Chide him right well, for sainte charity.\n"
  "He is aye angry as is a pismire,*                                   *ant\n"
  "Though that he have all that he can desire,\n"
  "Though I him wrie* at night, and make him warm,                   *cover\n"
  "And ov'r him lay my leg and eke mine arm,\n"
  "He groaneth as our boar that lies in sty:\n"
  "Other disport of him right none have I,\n"
  "I may not please him in no manner case.\"\n"
  "\"O Thomas, *je vous dis,* Thomas, Thomas,                   *I tell you*\n"
  "This *maketh the fiend,* this must be amended.     *is the devil's work*\n"
  "Ire is a thing that high God hath defended,*                  *forbidden\n"
  "And thereof will I speak a word or two.\"\n"
  "\"Now, master,\" quoth the wife, \"ere that I go,\n"
  "What will ye dine? I will go thereabout.\"\n"
  "\"Now, Dame,\" quoth he, \"je vous dis sans doute, <9>\n"
  "Had I not of a capon but the liver,\n"
  "And of your white bread not but a shiver,*                   *thin slice\n"
  "And after that a roasted pigge's head,\n"
  "(But I would that for me no beast were dead,)\n"
  "Then had I with you homely suffisance.\n"
  "I am a man of little sustenance.\n"
  "My spirit hath its fost'ring in the Bible.\n"
  "My body is aye so ready and penible*                        *painstaking\n"
  "To wake,* that my stomach is destroy'd.                           *watch\n"
  "I pray you, Dame, that ye be not annoy'd,\n"
  "Though I so friendly you my counsel shew;\n"
  "By God, I would have told it but to few.\"\n"
  "\"Now, Sir,\" quoth she, \"but one word ere I go;\n"
  "My child is dead within these weeke's two,\n"
  "Soon after that ye went out of this town.\"\n"
  "\n"
  "\"His death saw I by revelatioun,\"\n"
  "Said this friar, \"at home in our dortour.*               *dormitory <10>\n"
  "I dare well say, that less than half an hour\n"
  "Mter his death, I saw him borne to bliss\n"
  "In mine vision, so God me wiss.*                                 *direct\n"
  "So did our sexton, and our fermerere,*                 *infirmary-keeper\n"
  "That have been true friars fifty year, --\n"
  "They may now, God be thanked of his love,\n"
  "Make their jubilee, and walk above.<12>\n"
  "And up I rose, and all our convent eke,\n"
  "With many a teare trilling on my cheek,\n"
  "Withoute noise or clattering of bells,\n"
  "Te Deum was our song, and nothing else,\n"
  "Save that to Christ I bade an orison,\n"
  "Thanking him of my revelation.\n"
  "For, Sir and Dame, truste me right well,\n"
  "Our orisons be more effectuel,\n"
  "And more we see of Christe's secret things,\n"
  "Than *borel folk,* although that they be kings.             *laymen*<13>\n"
  "We live in povert', and in abstinence,\n"
  "And borel folk in riches and dispence\n"
  "Of meat and drink, and in their foul delight.\n"
  "We have this worlde's lust* all in despight**      * pleasure **contempt\n"
  "Lazar and Dives lived diversely,\n"
  "And diverse guerdon* hadde they thereby.                         *reward\n"
  "Whoso will pray, he must fast and be clean,\n"
  "And fat his soul, and keep his body lean\n"
  "We fare as saith th' apostle; cloth* and food                  *clothing\n"
  "Suffice us, although they be not full good.\n"
  "The cleanness and the fasting of us freres\n"
  "Maketh that Christ accepteth our prayeres.\n"
  "Lo, Moses forty days and forty night\n"
  "Fasted, ere that the high God full of might\n"
  "Spake with him in the mountain of Sinai:\n"
  "With empty womb* of fasting many a day                          *stomach\n"
  "Received he the lawe, that was writ\n"
  "With Godde's finger; and Eli,<14> well ye wit,*                    *know\n"
  "In Mount Horeb, ere he had any speech\n"
  "With highe God, that is our live's leech,*            *physician, healer\n"
  "He fasted long, and was in contemplance.\n"
  "Aaron, that had the temple in governance,\n"
  "And eke the other priestes every one,\n"
  "Into the temple when they shoulde gon\n"
  "To praye for the people, and do service,\n"
  "They woulde drinken in no manner wise\n"
  "No drinke, which that might them drunken make,\n"
  "But there in abstinence pray and wake,\n"
  "Lest that they died: take heed what I say --\n"
  "But* they be sober that for the people pray --                   *unless\n"
  "Ware that, I say -- no more: for it sufficeth.\n"
  "Our Lord Jesus, as Holy Writ deviseth,*                        *narrates\n"
  "Gave us example of fasting and prayeres:\n"
  "Therefore we mendicants, we sely* freres,                 *simple, lowly\n"
  "Be wedded to povert' and continence,\n"
  "To charity, humbless, and abstinence,\n"
  "To persecution for righteousness,\n"
  "To weeping, misericorde,* and to cleanness.                  *compassion\n"
  "And therefore may ye see that our prayeres\n"
  "(I speak of us, we mendicants, we freres),\n"
  "Be to the highe God more acceptable\n"
  "Than youres, with your feastes at your table.\n"
  "From Paradise first, if I shall not lie,\n"
  "Was man out chased for his gluttony,\n"
  "And chaste was man in Paradise certain.\n"
  "But hark now, Thomas, what I shall thee sayn;\n"
  "I have no text of it, as I suppose,\n"
  "But I shall find it in *a manner glose;*             *a kind of comment*\n"
  "That specially our sweet Lord Jesus\n"
  "Spake this of friars, when he saide thus,\n"
  "'Blessed be they that poor in spirit be'\n"
  "And so forth all the gospel may ye see,\n"
  "Whether it be liker our profession,\n"
  "Or theirs that swimmen in possession;\n"
  "Fy on their pomp, and on their gluttony,\n"
  "And on their lewedness!  I them defy.\n"
  "Me thinketh they be like Jovinian,<15>\n"
  "Fat as a whale, and walking as a swan;\n"
  "All vinolent* as bottle in the spence;**      *full of wine **store-room\n"
  "Their prayer is of full great reverence;\n"
  "When they for soules say the Psalm of David,\n"
  "Lo, 'Buf' they say, Cor meum eructavit.<16>\n"
  "Who follow Christe's gospel and his lore*                      *doctrine\n"
  "But we, that humble be, and chaste, and pore,*                     *poor\n"
  "Workers of Godde's word, not auditours?*                        *hearers\n"
  "Therefore right as a hawk *upon a sours*                        *rising*\n"
  "Up springs into the air, right so prayeres\n"
  "Of charitable and chaste busy freres\n"
  "*Make their sours* to Godde's eares two.                          *rise*\n"
  "Thomas, Thomas, so may I ride or go,\n"
  "And by that lord that called is Saint Ive,\n"
  "*N'ere thou our brother, shouldest thou not thrive;*    *see note  <17>*\n"
  "In our chapiter pray we day and night\n"
  "To Christ, that he thee sende health and might,\n"
  "Thy body for to *wielde hastily.*          *soon be able to move freely*\n"
  "\n"
  "\"God wot,\" quoth he, \"nothing thereof feel I;\n"
  "So help me Christ, as I in fewe years\n"
  "Have spended upon *divers manner freres*       *friars of various sorts*\n"
  "Full many a pound, yet fare I ne'er the bet;*                    *better\n"
  "Certain my good have I almost beset:*                             *spent\n"
  "Farewell my gold, for it is all ago.\"*                             *gone\n"
  "The friar answer'd, \"O Thomas, dost thou so?\n"
  "What needest thou diverse friars to seech?*                        *seek\n"
  "What needeth him that hath a perfect leech,*                     *healer\n"
  "To seeken other leeches in the town?\n"
  "Your inconstance is your confusioun.\n"
  "Hold ye then me, or elles our convent,\n"
  "To praye for you insufficient?\n"
  "Thomas, that jape* it is not worth a mite;                         *jest\n"
  "Your malady is *for we have too lite.*                  *because we have\n"
  "Ah, give that convent half a quarter oats;                   too little*\n"
  "And give that convent four and twenty groats;\n"
  "And give that friar a penny, and let him go!\n"
  "Nay, nay, Thomas, it may no thing be so.\n"
  "What is a farthing worth parted on twelve?\n"
  "Lo, each thing that is oned* in himselve               *made one, united\n"
  "Is more strong than when it is y-scatter'd.\n"
  "Thomas, of me thou shalt not be y-flatter'd,\n"
  "Thou wouldest have our labour all for nought.\n"
  "The highe God, that all this world hath wrought,\n"
  "Saith, that the workman worthy is his hire\n"
  "Thomas, nought of your treasure I desire\n"
  "As for myself, but that all our convent\n"
  "To pray for you is aye so diligent:\n"
  "And for to builde Christe's owen church.\n"
  "Thomas, if ye will learne for to wirch,*                           *work\n"
  "Of building up of churches may ye find\n"
  "If it be good, in Thomas' life of Ind.<18>\n"
  "Ye lie here full of anger and of ire,\n"
  "With which the devil sets your heart on fire,\n"
  "And chide here this holy innocent\n"
  "Your wife, that is so meek and patient.\n"
  "And therefore trow* me, Thomas, if thee lest,**        *believe **please\n"
  "Ne strive not with thy wife, as for the best.\n"
  "And bear this word away now, by thy faith,\n"
  "Touching such thing, lo, what the wise man saith:\n"
  "'Within thy house be thou no lion;\n"
  "To thy subjects do none oppression;\n"
  "Nor make thou thine acquaintance for to flee.'\n"
  "And yet, Thomas, eftsoones* charge I thee,                        *again\n"
  "Beware from ire that in thy bosom sleeps,\n"
  "Ware from the serpent, that so slily creeps\n"
  "Under the grass, and stingeth subtilly.\n"
  "Beware, my son, and hearken patiently,\n"
  "That twenty thousand men have lost their lives\n"
  "For striving with their lemans* and their wives.             *mistresses\n"
  "Now since ye have so holy and meek a wife,\n"
  "What needeth you, Thomas, to make strife?\n"
  "There is, y-wis,* no serpent so cruel,                        *certainly\n"
  "When men tread on his tail nor half so fell,*                    *fierce\n"
  "As woman is, when she hath caught an ire;\n"
  "Very* vengeance is then all her desire.                      *pure, only\n"
  "Ire is a sin, one of the greate seven,\n"
  "Abominable to the God of heaven,\n"
  "And to himself it is destruction.\n"
  "This every lewed* vicar and parson                             *ignorant\n"
  "Can say, how ire engenders homicide;\n"
  "Ire is in sooth th' executor* of pride.                     *executioner\n"
  "I could of ire you say so muche sorrow,\n"
  "My tale shoulde last until to-morrow.\n"
  "And therefore pray I God both day and ight,\n"
  "An irous* man God send him little might.                     *passionate\n"
  "It is great harm, and certes great pity\n"
  "To set an irous man in high degree.\n"
  "\n"
  "";
// }

const char sompnoursTale1[] PGMSECTION = // { // 17710 bytes
  "\"Whilom* there was an irous potestate,**               *once **judge<19>\n"
  "As saith Senec, that during his estate*                  *term of office\n"
  "Upon a day out rode knightes two;\n"
  "And, as fortune would that it were so,\n"
  "The one of them came home, the other not.\n"
  "Anon the knight before the judge is brought,\n"
  "That saide thus; 'Thou hast thy fellow slain,\n"
  "For which I doom thee to the death certain.'\n"
  "And to another knight commanded he;\n"
  "'Go, lead him to the death, I charge thee.'\n"
  "And happened, as they went by the way\n"
  "Toward the place where as he should dey,*                           *die\n"
  "The knight came, which men weened* had been dead                *thought\n"
  "Then thoughte they it was the beste rede*                       *counsel\n"
  "To lead them both unto the judge again.\n"
  "They saide, 'Lord, the knight hath not y-slain\n"
  "His fellow; here he standeth whole alive.'\n"
  "'Ye shall be dead,' quoth he, 'so may I thrive,\n"
  "That is to say, both one, and two, and three.'\n"
  "And to the firste knight right thus spake he:\n"
  "'I damned thee, thou must algate* be dead:                *at all events\n"
  "And thou also must needes lose thine head,\n"
  "For thou the cause art why thy fellow dieth.'\n"
  "And to the thirde knight right thus he sayeth,\n"
  "'Thou hast not done that I commanded thee.'\n"
  "And thus he did do slay them alle three.\n"
  "\n"
  "Irous Cambyses was eke dronkelew,*                           *a drunkard\n"
  "And aye delighted him to be a shrew.*             *vicious, ill-tempered\n"
  "And so befell, a lord of his meinie,*                             *suite\n"
  "That loved virtuous morality,\n"
  "Said on a day betwixt them two right thus:\n"
  "'A lord is lost, if he be vicious.\n"
  "[An irous man is like a frantic beast,\n"
  "In which there is of wisdom *none arrest*;]                 *no control*\n"
  "And drunkenness is eke a foul record\n"
  "Of any man, and namely* of a lord.                           *especially\n"
  "There is full many an eye and many an ear\n"
  "*Awaiting on* a lord, he knows not where.                      *watching\n"
  "For Godde's love, drink more attemperly:*                   *temperately\n"
  "Wine maketh man to lose wretchedly\n"
  "His mind, and eke his limbes every one.'\n"
  "'The reverse shalt thou see,' quoth he, 'anon,\n"
  "And prove it by thine own experience,\n"
  "That wine doth to folk no such offence.\n"
  "There is no wine bereaveth me my might\n"
  "Of hand, nor foot, nor of mine eyen sight.'\n"
  "And for despite he dranke muche more\n"
  "A hundred part* than he had done before,                          *times\n"
  "And right anon this cursed irous wretch\n"
  "This knighte's sone let* before him fetch,                       *caused\n"
  "Commanding him he should before him stand:\n"
  "And suddenly he took his bow in hand,\n"
  "And up the string he pulled to his ear,\n"
  "And with an arrow slew the child right there.\n"
  "'Now whether have I a sicker* hand or non?'**                *sure **not\n"
  "Quoth he; 'Is all my might and mind agone?\n"
  "Hath wine bereaved me mine eyen sight?'\n"
  "Why should I tell the answer of the knight?\n"
  "His son was slain, there is no more to say.\n"
  "Beware therefore with lordes how ye play,*                  *use freedom\n"
  "Sing placebo;<20> and I shall if I can,\n"
  "*But if* it be unto a poore man:                                 *unless\n"
  "To a poor man men should his vices tell,\n"
  "But not t' a lord, though he should go to hell.\n"
  "Lo, irous Cyrus, thilke* Persian,                                  *that\n"
  "How he destroy'd the river of Gisen,<21>\n"
  "For that a horse of his was drowned therein,\n"
  "When that he wente Babylon to win:\n"
  "He made that the river was so small,\n"
  "That women mighte wade it *over all.*                        *everywhere\n"
  "Lo, what said he, that so well teache can,\n"
  "'Be thou no fellow to an irous man,\n"
  "Nor with no wood* man walke by the way,                         *furious\n"
  "Lest thee repent;' I will no farther say.\n"
  "\n"
  "\"Now, Thomas, leve* brother, leave thine ire,                      *dear\n"
  "Thou shalt me find as just as is as squire;\n"
  "Hold not the devil's knife aye at thine heaat;\n"
  "Thine anger doth thee all too sore smart;*                         *pain\n"
  "But shew to me all thy confession.\"\n"
  "\"Nay,\" quoth the sicke man, \"by Saint Simon\n"
  "I have been shriven* this day of my curate;                   *confessed\n"
  "I have him told all wholly mine estate.\n"
  "Needeth no more to speak of it, saith he,\n"
  "But if me list of mine humility.\"\n"
  "\"Give me then of thy good to make our cloister,\"\n"
  "Quoth he, \"for many a mussel and many an oyster,\n"
  "When other men have been full well at ease,\n"
  "Hath been our food, our cloister for to rese:*             *raise, build\n"
  "And yet, God wot, unneth* the foundement**        *scarcely **foundation\n"
  "Performed is, nor of our pavement\n"
  "Is not a tile yet within our wones:*                         *habitation\n"
  "By God, we owe forty pound for stones.\n"
  "Now help, Thomas, for *him that harrow'd hell,*             *Christ <22>\n"
  "For elles must we oure bookes sell,\n"
  "And if ye lack our predication,\n"
  "Then goes this world all to destruction.\n"
  "For whoso from this world would us bereave,\n"
  "So God me save, Thomas, by your leave,\n"
  "He would bereave out of this world the sun\n"
  "For who can teach and worken as we conne?*               *know how to do\n"
  "And that is not of little time (quoth he),\n"
  "But since Elijah was, and Elisee,*                               *Elisha\n"
  "Have friars been, that find I of record,\n"
  "In charity, y-thanked be our Lord.\n"
  "Now, Thomas, help for sainte charity.\"\n"
  "And down anon he set him on his knee,\n"
  "The sick man waxed well-nigh wood* for ire,                         *mad\n"
  "He woulde that the friar had been a-fire\n"
  "With his false dissimulation.\n"
  "\"Such thing as is in my possession,\"\n"
  "Quoth he, \"that may I give you and none other:\n"
  "Ye say me thus, how that I am your brother.\"\n"
  "\"Yea, certes,\" quoth this friar, \"yea, truste well;\n"
  "I took our Dame the letter of our seal\"<23>\n"
  "\"Now well,\" quoth he, \"and somewhat shall I give\n"
  "Unto your holy convent while I live;\n"
  "And in thine hand thou shalt it have anon,\n"
  "On this condition, and other none,\n"
  "That thou depart* it so, my deare brother,                       *divide\n"
  "That every friar have as much as other:\n"
  "This shalt thou swear on thy profession,\n"
  "Withoute fraud or cavillation.\"*                              *quibbling\n"
  "\"I swear it,\" quoth the friar, \"upon my faith.\"\n"
  "And therewithal his hand in his he lay'th;\n"
  "\"Lo here my faith, in me shall be no lack.\"\n"
  "\"Then put thine hand adown right by my back,\"\n"
  "Saide this man, \"and grope well behind,\n"
  "Beneath my buttock, there thou shalt find\n"
  "A thing, that I have hid in privity.\"\n"
  "\"Ah,\" thought this friar, \"that shall go with me.\"\n"
  "And down his hand he launched to the clift,*                      *cleft\n"
  "In hope for to finde there a gift.\n"
  "And when this sicke man felte this frere\n"
  "About his taile groping there and here,\n"
  "Amid his hand he let the friar a fart;\n"
  "There is no capel* drawing in a cart,                             *horse\n"
  "That might have let a fart of such a soun'.\n"
  "The friar up start, as doth a wood* lioun:                       *fierce\n"
  "\"Ah, false churl,\" quoth he, \"for Godde's bones,\n"
  "This hast thou in despite done for the nones:*               *on purpose\n"
  "Thou shalt abie* this fart, if that I may.\"                  *suffer for\n"
  "His meinie,* which that heard of this affray,                  *servants\n"
  "Came leaping in, and chased out the frere,\n"
  "And forth he went with a full angry cheer*                  *countenance\n"
  "And fetch'd his fellow, there as lay his store:\n"
  "He looked as it were a wilde boar,\n"
  "And grounde with his teeth, so was he wroth.\n"
  "A sturdy pace down to the court he go'th,\n"
  "Where as there wonn'd* a man of great honour,                     *dwelt\n"
  "To whom that he was always confessour:\n"
  "This worthy man was lord of that village.\n"
  "This friar came, as he were in a rage,\n"
  "Where as this lord sat eating at his board:\n"
  "Unnethes* might the friar speak one word,               *with difficulty\n"
  "Till at the last he saide, \"God you see.\"*                         *save\n"
  "\n"
  "This lord gan look, and said, \"Ben'dicite!\n"
  "What? Friar John, what manner world is this?\n"
  "I see well that there something is amiss;\n"
  "Ye look as though the wood were full of thieves.\n"
  "Sit down anon, and tell me what your grieve* is,       *grievance, grief\n"
  "And it shall be amended, if I may.\"\n"
  "\"I have,\" quoth he, \"had a despite to-day,\n"
  "God *yielde you,* adown in your village,                     *reward you\n"
  "That in this world is none so poor a page,\n"
  "That would not have abominatioun\n"
  "Of that I have received in your town:\n"
  "And yet ne grieveth me nothing so sore,\n"
  "As that the olde churl, with lockes hoar,\n"
  "Blasphemed hath our holy convent eke.\"\n"
  "\"Now, master,\" quoth this lord, \"I you beseek\" --\n"
  "\"No master, Sir,\" quoth he, \"but servitour,\n"
  "Though I have had in schoole that honour. <24>\n"
  "God liketh not, that men us Rabbi call\n"
  "Neither in market, nor in your large hall.\"\n"
  "*\"No force,\"* quoth he; \"but tell me all your grief.\"        *no matter*\n"
  "Sir,\" quoth this friar, \"an odious mischief\n"
  "This day betid* is to mine order and me,                       *befallen\n"
  "And so par consequence to each degree\n"
  "Of holy churche, God amend it soon.\"\n"
  "\"Sir,\" quoth the lord, \"ye know what is to doon:*                    *do\n"
  "*Distemp'r you not,* ye be my confessour.             *be not impatient*\n"
  "Ye be the salt of th' earth, and the savour;\n"
  "For Godde's love your patience now hold;\n"
  "Tell me your grief.\" And he anon him told\n"
  "As ye have heard before, ye know well what.\n"
  "The lady of the house aye stiller sat,\n"
  "Till she had hearde what the friar said,\n"
  "\"Hey, Godde's mother;\" quoth she, \"blissful maid,\n"
  "Is there ought elles? tell me faithfully.\"\n"
  "\"Madame,\" quoth he, \"how thinketh you thereby?\"\n"
  "\"How thinketh me?\" quoth she; \"so God me speed,\n"
  "I say, a churl hath done a churlish deed,\n"
  "What should I say?  God let him never the;*                      *thrive\n"
  "His sicke head is full of vanity;\n"
  "I hold him in *a manner phrenesy.\"*                   *a sort of frenzy*\n"
  "\"Madame,\" quoth he, \"by God, I shall not lie,\n"
  "But I in other wise may be awreke,*                            *revenged\n"
  "I shall defame him *ov'r all there* I speak;                   *wherever\n"
  "This false blasphemour, that charged me\n"
  "To parte that will not departed be,\n"
  "To every man alike, with mischance.\"\n"
  "\n"
  "The lord sat still, as he were in a trance,\n"
  "And in his heart he rolled up and down,\n"
  "\"How had this churl imaginatioun\n"
  "To shewe such a problem to the frere.\n"
  "Never ere now heard I of such mattere;\n"
  "I trow* the Devil put it in his mind.                           *believe\n"
  "In all arsmetrik* shall there no man find,                   *arithmetic\n"
  "Before this day, of such a question.\n"
  "Who shoulde make a demonstration,\n"
  "That every man should have alike his part\n"
  "As of the sound and savour of a fart?\n"
  "O nice* proude churl, I shrew** his face.               *foolish **curse\n"
  "Lo, Sires,\" quoth the lord, \"with harde grace,\n"
  "Who ever heard of such a thing ere now?\n"
  "To every man alike? tell me how.\n"
  "It is impossible, it may not be.\n"
  "Hey nice* churl, God let him never the.**              *foolish **thrive\n"
  "The rumbling of a fart, and every soun',\n"
  "Is but of air reverberatioun,\n"
  "And ever wasteth lite* and lite* away;                           *little\n"
  "There is no man can deemen,* by my fay,                   *judge, decide\n"
  "If that it were departed* equally.                              *divided\n"
  "What? lo, my churl, lo yet how shrewedly*           *impiously, wickedly\n"
  "Unto my confessour to-day he spake;\n"
  "I hold him certain a demoniac.\n"
  "Now eat your meat, and let the churl go play,\n"
  "Let him go hang himself a devil way!\"\n"
  "\n"
  "Now stood the lorde's squier at the board,\n"
  "That carv'd his meat, and hearde word by word\n"
  "Of all this thing, which that I have you said.\n"
  "\"My lord,\" quoth he, \"be ye not *evil paid,*                *displeased*\n"
  "I coulde telle, for a gowne-cloth,*                   *cloth for a gown*\n"
  "To you, Sir Friar, so that ye be not wrot,\n"
  "How that this fart should even* dealed be                       *equally\n"
  "Among your convent, if it liked thee.\"\n"
  "\"Tell,\" quoth the lord, \"and thou shalt have anon\n"
  "A gowne-cloth, by God and by Saint John.\"\n"
  "\"My lord,\" quoth he, \"when that the weather is fair,\n"
  "Withoute wind, or perturbing of air,\n"
  "Let* bring a cart-wheel here into this hall,                      cause*\n"
  "But looke that it have its spokes all;\n"
  "Twelve spokes hath a cart-wheel commonly;\n"
  "And bring me then twelve friars, know ye why?\n"
  "For thirteen is a convent as I guess;<25>\n"
  "Your confessor here, for his worthiness,\n"
  "Shall *perform up* the number of his convent.                 *complete*\n"
  "Then shall they kneel adown by one assent,\n"
  "And to each spoke's end, in this mannere,\n"
  "Full sadly* lay his nose shall a frere;             *carefully, steadily\n"
  "Your noble confessor there, God him save,\n"
  "Shall hold his nose upright under the nave.\n"
  "Then shall this churl, with belly stiff and tought*               *tight\n"
  "As any tabour,* hither be y-brought;                               *drum\n"
  "And set him on the wheel right of this cart\n"
  "Upon the nave, and make him let a fart,\n"
  "And ye shall see, on peril of my life,\n"
  "By very proof that is demonstrative,\n"
  "That equally the sound of it will wend,*                             *go\n"
  "And eke the stink, unto the spokes' end,\n"
  "Save that this worthy man, your confessour'\n"
  "(Because he is a man of great honour),\n"
  "Shall have the firste fruit, as reason is;\n"
  "The noble usage of friars yet it is,\n"
  "The worthy men of them shall first be served,\n"
  "And certainly he hath it well deserved;\n"
  "He hath to-day taught us so muche good\n"
  "With preaching in the pulpit where he stood,\n"
  "That I may vouchesafe, I say for me,\n"
  "He had the firste smell of fartes three;\n"
  "And so would all his brethren hardily;\n"
  "He beareth him so fair and holily.\"\n"
  "\n"
  "The lord, the lady, and each man, save the frere,\n"
  "Saide, that Jankin spake in this mattere\n"
  "As well as Euclid, or as Ptolemy.\n"
  "Touching the churl, they said that subtilty\n"
  "And high wit made him speaken as he spake;\n"
  "He is no fool, nor no demoniac.\n"
  "And Jankin hath y-won a newe gown;\n"
  "My tale is done, we are almost at town.\n"
  "\n"
  "\n"
  "Notes to the Sompnour's Tale\n"
  "\n"
  "\n"
  "1. Trentals: The money given to the priests for performing thirty\n"
  "masses for the dead, either in succession or on the anniversaries\n"
  "of their death; also the masses themselves, which were very\n"
  "profitable to the clergy.\n"
  "\n"
  "2. Possessioners: The regular religious orders, who had lands\n"
  "and fixed revenues; while the friars, by their vows, had to\n"
  "depend on voluntary contributions, though their need suggested\n"
  "many modes of evading the prescription.\n"
  "\n"
  "3. In Chaucer's day the most material notions about the tortures\n"
  "of hell prevailed, and were made the most of by the clergy, who\n"
  "preyed on the affection and fear of the survivors, through the\n"
  "ingenious doctrine of purgatory. Old paintings and illuminations\n"
  "represent the dead as torn by hooks, roasted in fires, boiled in\n"
  "pots, and subjected to many other physical torments.\n"
  "\n"
  "4. Qui cum patre: \"Who with the father\"; the closing words of\n"
  "the final benediction pronounced at Mass.\n"
  "\n"
  "5. Askaunce: The word now means sideways or asquint; here it\n"
  "means \"as if;\" and its force is probably to suggest that the\n"
  "second friar, with an ostentatious stealthiness, noted down the\n"
  "names of the liberal, to make them believe that they would be\n"
  "remembered in the holy beggars' orisons.\n"
  "\n"
  "6. A Godde's kichel/halfpenny: a little cake/halfpenny, given for\n"
  "God's sake.\n"
  "\n"
  "7. Harlot: hired servant; from Anglo-Saxon, \"hyran,\" to hire;\n"
  "the word was commonly applied to males.\n"
  "\n"
  "8. Potent: staff; French, \"potence,\" crutch, gibbet.\n"
  "\n"
  "9. Je vous dis sans doute: French; \"I tell you without doubt.\"\n"
  "\n"
  "10. Dortour: dormitory; French, \"dortoir.\"\n"
  "\n"
  "12. The Rules of St Benedict granted peculiar honours and\n"
  "immunities to monks who had lived fifty years -- the jubilee\n"
  "period -- in the order. The usual reading of the words ending\n"
  "the two lines is \"loan\" or \"lone,\" and \"alone;\" but to walk alone\n"
  "does not seem to have been any peculiar privilege of a friar,\n"
  "while the idea of precedence, or higher place at table and in\n"
  "processions, is suggested by the reading in the text.\n"
  "\n"
  "13. Borel folk:  laymen, people who are not learned; \"borel\"\n"
  "was a kind of coarse cloth.\n"
  "\n"
  "14. Eli: Elijah (1 Kings, xix.)\n"
  "\n"
  "15. An emperor Jovinian was famous in the mediaeval  legends\n"
  "for his pride and luxury\n"
  "\n"
  "16. Cor meum eructavit: literally, \"My heart has belched forth;\"\n"
  "in our translation, (i.e. the Authorised \"King James\" Version -\n"
  "Transcriber) \"My heart is inditing a goodly matter.\"  (Ps. xlv.\n"
  "1.). \"Buf\" is meant to represent the sound  of an eructation, and\n"
  "to show the \"great reverence\" with which \"those in possession,\"\n"
  "the monks of the rich monasteries, performed divine service,\n"
  "\n"
  "17. N'ere thou our brother, shouldest thou not thrive: if thou\n"
  "wert not of our  brotherhood, thou shouldst have no hope of\n"
  "recovery.\n"
  "\n"
  "18. Thomas' life of Ind: The life of  Thomas of India - i.e. St.\n"
  "Thomas the Apostle, who was said to have travelled to India.\n"
  "\n"
  "19. Potestate:  chief magistrate or judge; Latin, \"potestas;\"\n"
  "Italian, \"podesta.\"  Seneca relates the story of Cornelius Piso;\n"
  "\"De Ira,\" i. 16.\n"
  "\n"
  "20. Placebo: An anthem of the Roman Church, from Psalm\n"
  "cxvi. 9, which in the Vulgate reads, \"Placebo Domino in regione\n"
  "vivorum\" -- \"I will please the Lord in the land of the living\"\n"
  "\n"
  "21. The Gysen:  Seneca calls it the Gyndes; Sir John Mandeville\n"
  "tells the story of the Euphrates. \"Gihon,\" was the name of one\n"
  "of the four rivers of Eden (Gen. ii, 13).\n"
  "\n"
  "22. Him that harrowed Hell: Christ. See note 14 to the Reeve's\n"
  "Tale.\n"
  "\n"
  "23. Mr. Wright says that \"it was a common practice to grant\n"
  "under the conventual seal to benefactors and others a brotherly\n"
  "participation in the spiritual good works of the convent, and in\n"
  "their expected reward after death.\"\n"
  "\n"
  "24. The friar had received a master's degree.\n"
  "\n"
  "25. The regular number of monks or friars in a convent was\n"
  "fixed at twelve,  with a superior, in imitation of the apostles and\n"
  "their Master; and large religious houses were held to consist of\n"
  "so many convents.\n"
  "\n"
  "\n"
  "\n"
  "";
// }

const char clerksTale0[] PGMSECTION = // { // 31699 bytes
  "THE CLERK'S TALE.\n"
  "\n"
  "\n"
  "THE PROLOGUE.\n"
  "\n"
  "\n"
  "\"SIR Clerk of Oxenford,\" our Hoste said,\n"
  "\"Ye ride as still and coy, as doth a maid\n"
  "That were new spoused, sitting at the board:\n"
  "This day I heard not of your tongue a word.\n"
  "I trow ye study about some sophime:*                            *sophism\n"
  "But Solomon saith, every thing hath time.\n"
  "For Godde's sake, be of *better cheer,*                  *livelier mien*\n"
  "It is no time for to study here.\n"
  "Tell us some merry tale, by your fay;*                            *faith\n"
  "For what man that is entered in a play,\n"
  "He needes must unto that play assent.\n"
  "But preache not, as friars do in Lent,\n"
  "To make us for our olde sinnes weep,\n"
  "Nor that thy tale make us not to sleep.\n"
  "Tell us some merry thing of aventures.\n"
  "Your terms, your coloures, and your figures,\n"
  "Keep them in store, till so be ye indite\n"
  "High style, as when that men to kinges write.\n"
  "Speake so plain at this time, I you pray,\n"
  "That we may understande what ye say.\"\n"
  "\n"
  "This worthy Clerk benignely answer'd;\n"
  "\"Hoste,\" quoth he, \"I am under your yerd,*                      *rod <1>\n"
  "Ye have of us as now the governance,\n"
  "And therefore would I do you obeisance,\n"
  "As far as reason asketh, hardily:*                        *boldly, truly\n"
  "I will you tell a tale, which that I\n"
  "Learn'd at Padova of a worthy clerk,\n"
  "As proved by his wordes and his werk.\n"
  "He is now dead, and nailed in his chest,\n"
  "I pray to God to give his soul good rest.\n"
  "Francis Petrarc', the laureate poet,<2>\n"
  "Highte* this clerk, whose rhetoric so sweet                  *was called\n"
  "Illumin'd all Itale of poetry,\n"
  "As Linian <3> did of philosophy,\n"
  "Or law, or other art particulere:\n"
  "But death, that will not suffer us dwell here\n"
  "But as it were a twinkling of an eye,\n"
  "Them both hath slain, and alle we shall die.\n"
  "\n"
  "\"But forth to tellen of this worthy man,\n"
  "That taughte me this tale, as I began,\n"
  "I say that first he with high style inditeth\n"
  "(Ere he the body of his tale writeth)\n"
  "A proem, in the which describeth he\n"
  "Piedmont, and of Saluces <4> the country,\n"
  "And speaketh of the Pennine hilles high,\n"
  "That be the bounds of all West Lombardy:\n"
  "And of Mount Vesulus in special,\n"
  "Where as the Po out of a welle small\n"
  "Taketh his firste springing and his source,\n"
  "That eastward aye increaseth in his course\n"
  "T'Emilia-ward, <5> to Ferraro, and Venice,\n"
  "The which a long thing were to devise.*                         *narrate\n"
  "And truely, as to my judgement,\n"
  "Me thinketh it a thing impertinent,*                         *irrelevant\n"
  "Save that he would conveye his mattere:\n"
  "But this is the tale, which that ye shall hear.\"\n"
  "\n"
  "\n"
  "Notes to the Prologue to the Clerk's Tale\n"
  "\n"
  "\n"
  "1. Under your yerd: under your rod; as the emblem of\n"
  "government or direction.\n"
  "\n"
  "2. Francesco Petrarca, born 1304, died 1374; for his Latin epic\n"
  "poem on the carer of Scipio, called \"Africa,\" he was solemnly\n"
  "crowned with the poetic laurel in the  Capitol of Rome, on\n"
  "Easter-day of 1341.\n"
  "\n"
  "3. Linian: An eminent jurist and philosopher, now almost\n"
  "forgotten, who died four or five years after Petrarch.\n"
  "\n"
  "4. Saluces: Saluzzo, a district of Savoy; its marquises were\n"
  "celebrated during the Middle Ages.\n"
  "\n"
  "5. Emilia:  The region called Aemilia, across which ran the Via\n"
  "Aemilia -- made by M. Aemilius Lepidus, who was consul at\n"
  "Rome B.C. 187. It continued the Flaminian  Way from\n"
  "Ariminum (Rimini) across the Po at Placentia (Piacenza) to\n"
  "Mediolanum (Milan), traversing Cisalpine Gaul.\n"
  "\n"
  "\n"
  "THE TALE.<1>\n"
  "\n"
  "\n"
  "*Pars Prima.*                                               *First Part*\n"
  "\n"
  "There is, right at the west side of Itale,\n"
  "Down at the root of Vesulus<2> the cold,\n"
  "A lusty* plain, abundant of vitaille;*              *pleasant **victuals\n"
  "There many a town and tow'r thou may'st behold,\n"
  "That founded were in time of fathers old,\n"
  "And many another delectable sight;\n"
  "And Saluces this noble country hight.\n"
  "\n"
  "A marquis whilom lord was of that land,\n"
  "As were his worthy elders* him before,                        *ancestors\n"
  "And obedient, aye ready to his hand,\n"
  "Were all his lieges, bothe less and more:\n"
  "Thus in delight he liv'd, and had done yore,*                      *long\n"
  "Belov'd and drad,* through favour of fortune,         *held in reverence\n"
  "Both of his lordes and of his commune.*                      *commonalty\n"
  "\n"
  "Therewith he was, to speak of lineage,\n"
  "The gentilest y-born of Lombardy,\n"
  "A fair person, and strong, and young of age,\n"
  "And full of honour and of courtesy:\n"
  "Discreet enough his country for to gie,*                    *guide, rule\n"
  "Saving in some things that he was to blame;\n"
  "And Walter was this younge lordes name.\n"
  "\n"
  "I blame him thus, that he consider'd not\n"
  "In time coming what might him betide,\n"
  "But on his present lust* was all his thought,                  *pleasure\n"
  "And for to hawk and hunt on every side;\n"
  "Well nigh all other cares let he slide,\n"
  "And eke he would (that was the worst of all)\n"
  "Wedde no wife for aught that might befall.\n"
  "\n"
  "Only that point his people bare so sore,\n"
  "That flockmel* on a day to him they went,                     *in a body\n"
  "And one of them, that wisest was of lore\n"
  "(Or elles that the lord would best assent\n"
  "That he should tell him what the people meant,\n"
  "Or elles could he well shew such mattere),\n"
  "He to the marquis said as ye shall hear.\n"
  "\n"
  "\"O noble Marquis! your humanity\n"
  "Assureth us and gives us hardiness,\n"
  "As oft as time is of necessity,\n"
  "That we to you may tell our heaviness:\n"
  "Accepte, Lord, now of your gentleness,\n"
  "What we with piteous heart unto you plain,*                 *complain of\n"
  "And let your ears my voice not disdain.\n"
  "\n"
  "\"All* have I nought to do in this mattere                      *although\n"
  "More than another man hath in this place,\n"
  "Yet forasmuch as ye, my Lord so dear,\n"
  "Have always shewed me favour and grace,\n"
  "I dare the better ask of you a space\n"
  "Of audience, to shewen our request,\n"
  "And ye, my Lord, to do right *as you lest.*            *as pleaseth you*\n"
  "\n"
  "\"For certes, Lord, so well us like you\n"
  "And all your work, and ev'r have done, that we\n"
  "Ne coulde not ourselves devise how\n"
  "We mighte live in more felicity:\n"
  "Save one thing, Lord, if that your will it be,\n"
  "That for to be a wedded man you lest;\n"
  "Then were your people *in sovereign hearte's rest.*          *completely\n"
  "\n"
  "\"Bowe your neck under the blissful yoke\n"
  "Of sovereignty, and not of service,\n"
  "Which that men call espousal or wedlock:\n"
  "And thinke, Lord, among your thoughtes wise,\n"
  "How that our dayes pass in sundry wise;\n"
  "For though we sleep, or wake, or roam, or ride,\n"
  "Aye fleeth time, it will no man abide.\n"
  "\n"
  "\"And though your greene youthe flow'r as yet,\n"
  "In creepeth age always as still as stone,\n"
  "And death menaceth every age, and smit*                         *smiteth\n"
  "In each estate, for there escapeth none:\n"
  "And all so certain as we know each one\n"
  "That we shall die, as uncertain we all\n"
  "Be of that day when death shall on us fall.\n"
  "\n"
  "\"Accepte then of us the true intent,*                      *mind, desire\n"
  "That never yet refused youre hest,*                             *command\n"
  "And we will, Lord, if that ye will assent,\n"
  "Choose you a wife, in short time at the lest,*                    *least\n"
  "Born of the gentilest and of the best\n"
  "Of all this land, so that it ought to seem\n"
  "Honour to God and you, as we can deem.\n"
  "\n"
  "\"Deliver us out of all this busy dread,*                          *doubt\n"
  "And take a wife, for highe Godde's sake:\n"
  "For if it so befell, as God forbid,\n"
  "That through your death your lineage should slake,*      *become extinct\n"
  "And that a strange successor shoulde take\n"
  "Your heritage, oh! woe were us on live:*                          *alive\n"
  "Wherefore we pray you hastily to wive.\"\n"
  "\n"
  "Their meeke prayer and their piteous cheer\n"
  "Made the marquis for to have pity.\n"
  "\"Ye will,\" quoth he, \"mine owen people dear,\n"
  "To that I ne'er ere* thought constraine me.                      *before\n"
  "I me rejoiced of my liberty,\n"
  "That seldom time is found in rnarriage;\n"
  "Where I was free, I must be in servage!*                      *servitude\n"
  "\n"
  "\"But natheless I see your true intent,\n"
  "And trust upon your wit, and have done aye:\n"
  "Wherefore of my free will I will assent\n"
  "To wedde me, as soon as e'er I may.\n"
  "But whereas ye have proffer'd me to-day\n"
  "To choose me a wife, I you release\n"
  "That choice, and pray you of that proffer cease.\n"
  "\n"
  "\"For God it wot, that children often been\n"
  "Unlike their worthy elders them before,\n"
  "Bounte* comes all of God, not of the strene**                  *goodness\n"
  "Of which they be engender'd and y-bore:                    **stock, race\n"
  "I trust in Godde's bounte, and therefore\n"
  "My marriage, and mine estate and rest,\n"
  "I *him betake;* he may do as him lest.                   *commend to him\n"
  "\n"
  "\"Let me alone in choosing of my wife;\n"
  "That charge upon my back I will endure:\n"
  "But I you pray, and charge upon your life,\n"
  "That what wife that I take, ye me assure\n"
  "To worship* her, while that her life may dure,                   *honour\n"
  "In word and work both here and elleswhere,\n"
  "As she an emperore's daughter were.\n"
  "\n"
  "\"And farthermore this shall ye swear, that ye\n"
  "Against my choice shall never grudge* nor strive.                *murmur\n"
  "For since I shall forego my liberty\n"
  "At your request, as ever may I thrive,\n"
  "Where as mine heart is set, there will I live\n"
  "And but* ye will assent in such mannere,                         *unless\n"
  "I pray you speak no more of this mattere.\"\n"
  "\n"
  "With heartly will they sworen and assent\n"
  "To all this thing, there said not one wight nay:\n"
  "Beseeching him of grace, ere that they went,\n"
  "That he would grante them a certain day\n"
  "Of his espousal, soon as e'er he rnay,\n"
  "For yet always the people somewhat dread*         *were in fear or doubt\n"
  "Lest that the marquis woulde no wife wed.\n"
  "\n"
  "He granted them a day, such as him lest,\n"
  "On which he would be wedded sickerly,*                        *certainly\n"
  "And said he did all this at their request;\n"
  "And they with humble heart full buxomly,*                *obediently <3>\n"
  "Kneeling upon their knees full reverently,\n"
  "Him thanked all; and thus they have an end\n"
  "Of their intent, and home again they wend.\n"
  "\n"
  "And hereupon he to his officers\n"
  "Commanded for the feaste to purvey.*                            *provide\n"
  "And to his privy knightes and squiers\n"
  "Such charge he gave, as him list on them lay:\n"
  "And they to his commandement obey,\n"
  "And each of them doth all his diligence\n"
  "To do unto the feast all reverence.\n"
  "\n"
  "\n"
  "*Pars Secunda*                                             *Second Part*\n"
  "\n"
  "\n"
  "Not far from thilke* palace honourable,                            *that\n"
  "Where as this marquis shope* his marriage,        *prepared; resolved on\n"
  "There stood a thorp,* of sighte delectable,                      *hamlet\n"
  "In which the poore folk of that village\n"
  "Hadde their beastes and their harbourage,*                     *dwelling\n"
  "And of their labour took their sustenance,\n"
  "After the earthe gave them abundance.\n"
  "\n"
  "Among this poore folk there dwelt a man\n"
  "Which that was holden poorest of them all;\n"
  "But highe God sometimes sende can\n"
  "His grace unto a little ox's stall;\n"
  "Janicola men of that thorp him call.\n"
  "A daughter had he, fair enough to sight,\n"
  "And Griseldis this younge maiden hight.\n"
  "\n"
  "But for to speak of virtuous beauty,\n"
  "Then was she one the fairest under sun:\n"
  "Full poorely y-foster'd up was she;\n"
  "No *likerous lust* was in her heart y-run;          *luxurious pleasure*\n"
  "Well ofter of the well than of the tun\n"
  "She drank, <4> and, for* she woulde virtue please               *because\n"
  "She knew well labour, but no idle ease.\n"
  "\n"
  "But though this maiden tender were of age;\n"
  "Yet in the breast of her virginity\n"
  "There was inclos'd a *sad and ripe corage;*        *steadfast and mature\n"
  "And in great reverence and charity                               spirit*\n"
  "Her olde poore father foster'd she.\n"
  "A few sheep, spinning, on the field she kept,\n"
  "She woulde not be idle till she slept.\n"
  "\n"
  "And when she homeward came, she would bring\n"
  "Wortes,* and other herbes, times oft,                  *plants, cabbages\n"
  "The which she shred and seeth'd for her living,\n"
  "And made her bed full hard, and nothing soft:\n"
  "And aye she kept her father's life on loft*                   *up, aloft\n"
  "With ev'ry obeisance and diligence,\n"
  "That child may do to father's reverence.\n"
  "\n"
  "Upon Griselda, this poor creature,\n"
  "Full often sithes* this marquis set his eye,                      *times\n"
  "As he on hunting rode, paraventure:*                          *by chance\n"
  "And when it fell that he might her espy,\n"
  "He not with wanton looking of folly\n"
  "His eyen cast on her, but in sad* wise                          *serious\n"
  "Upon her cheer* he would him oft advise;**       *countenance **consider\n"
  "\n"
  "Commending in his heart her womanhead,\n"
  "And eke her virtue, passing any wight\n"
  "Of so young age, as well in cheer as deed.\n"
  "For though the people have no great insight\n"
  "In virtue, he considered full right\n"
  "Her bounte,* and disposed that he would                        *goodness\n"
  "Wed only her, if ever wed he should.\n"
  "\n"
  "The day of wedding came, but no wight can\n"
  "Telle what woman that it shoulde be;\n"
  "For which marvail wonder'd many a man,\n"
  "And saide, when they were in privity,\n"
  "\"Will not our lord yet leave his vanity?\n"
  "Will he not wed?  Alas, alas the while!\n"
  "Why will he thus himself and us beguile?\"\n"
  "\n"
  "But natheless this marquis had *done make*           *caused to be made*\n"
  "Of gemmes, set in gold and in azure,\n"
  "Brooches and ringes, for Griselda's sake,\n"
  "And of her clothing took he the measure\n"
  "Of a maiden like unto her stature,\n"
  "And eke of other ornamentes all\n"
  "That unto such a wedding shoulde fall.*                           *befit\n"
  "\n"
  "The time of undern* of the same day                         *evening <5>\n"
  "Approached, that this wedding shoulde be,\n"
  "And all the palace put was in array,\n"
  "Both hall and chamber, each in its degree,\n"
  "Houses of office stuffed with plenty\n"
  "There may'st thou see of dainteous vitaille,*      *victuals, provisions\n"
  "That may be found, as far as lasts Itale.\n"
  "\n"
  "This royal marquis, richely array'd,\n"
  "Lordes and ladies in his company,\n"
  "The which unto the feaste were pray'd,\n"
  "And of his retinue the bach'lery,\n"
  "With many a sound of sundry melody,\n"
  "Unto the village, of the which I told,\n"
  "In this array the right way did they hold.\n"
  "\n"
  "Griseld' of this (God wot) full innocent,\n"
  "That for her shapen* was all this array,                       *prepared\n"
  "To fetche water at a well is went,\n"
  "And home she came as soon as e'er she may.\n"
  "For well she had heard say, that on that day\n"
  "The marquis shoulde wed, and, if she might,\n"
  "She fain would have seen somewhat of that sight.\n"
  "\n"
  "She thought, \"I will with other maidens stand,\n"
  "That be my fellows, in our door, and see\n"
  "The marchioness; and therefore will I fand*                      *strive\n"
  "To do at home, as soon as it may be,\n"
  "The labour which belongeth unto me,\n"
  "And then I may at leisure her behold,\n"
  "If she this way unto the castle hold.\"\n"
  "\n"
  "And as she would over the threshold gon,\n"
  "The marquis came and gan for her to call,\n"
  "And she set down her water-pot anon\n"
  "Beside the threshold, in an ox's stall,\n"
  "And down upon her knees she gan to fall,\n"
  "And with sad* countenance kneeled still,                         *steady\n"
  "Till she had heard what was the lorde's will.\n"
  "\n"
  "The thoughtful marquis spake unto the maid\n"
  "Full soberly, and said in this mannere:\n"
  "\"Where is your father, Griseldis?\" he said.\n"
  "And she with reverence, *in humble cheer,*             *with humble air*\n"
  "Answered, \"Lord, he is all ready here.\"\n"
  "And in she went withoute longer let*                              *delay\n"
  "And to the marquis she her father fet.*                         *fetched\n"
  "\n"
  "He by the hand then took the poore man,\n"
  "And saide thus, when he him had aside:\n"
  "\"Janicola, I neither may nor can\n"
  "Longer the pleasance of mine hearte hide;\n"
  "If that thou vouchesafe, whatso betide,\n"
  "Thy daughter will I take, ere that I wend,*                          *go\n"
  "As for my wife, unto her life's end.\n"
  "\n"
  "\"Thou lovest me, that know I well certain,\n"
  "And art my faithful liegeman y-bore,*                              *born\n"
  "And all that liketh me, I dare well sayn\n"
  "It liketh thee; and specially therefore\n"
  "Tell me that point, that I have said before, --\n"
  "If that thou wilt unto this purpose draw,\n"
  "To take me as for thy son-in-law.\"\n"
  "\n"
  "This sudden case* the man astonied so,                            *event\n"
  "That red he wax'd, abash'd,* and all quaking                     *amazed\n"
  "He stood; unnethes* said he wordes mo',                        *scarcely\n"
  "But only thus; \"Lord,\" quoth he, \"my willing\n"
  "Is as ye will, nor against your liking\n"
  "I will no thing, mine owen lord so dear;\n"
  "Right as you list governe this mattere.\"\n"
  "\n"
  "\"Then will I,\" quoth the marquis softely,\n"
  "\"That in thy chamber I, and thou, and she,\n"
  "Have a collation;* and know'st thou why?                     *conference\n"
  "For I will ask her, if her will it be\n"
  "To be my wife, and rule her after me:\n"
  "And all this shall be done in thy presence,\n"
  "I will not speak out of thine audience.\"*                       *hearing\n"
  "\n"
  "And in the chamber while they were about\n"
  "The treaty, which ye shall hereafter hear,\n"
  "The people came into the house without,\n"
  "And wonder'd them in how honest mannere\n"
  "And tenderly she kept her father dear;\n"
  "But utterly Griseldis wonder might,\n"
  "For never erst* ne saw she such a sight.                         *before\n"
  "\n"
  "No wonder is though that she be astoned,*                    *astonished\n"
  "To see so great a guest come in that place,\n"
  "She never was to no such guestes woned;*               *accustomed, wont\n"
  "For which she looked with full pale face.\n"
  "But shortly forth this matter for to chase,*            *push on, pursue\n"
  "These are the wordes that the marquis said\n"
  "To this benigne, very,* faithful maid.                         *true <6>\n"
  "\n"
  "\"Griseld',\" he said, \"ye shall well understand,\n"
  "It liketh to your father and to me\n"
  "That I you wed, and eke it may so stand,\n"
  "As I suppose ye will that it so be:\n"
  "But these demandes ask I first,\" quoth he,\n"
  "\"Since that it shall be done in hasty wise;\n"
  "Will ye assent, or elles you advise?*                          *consider\n"
  "\n"
  "\"I say this, be ye ready with good heart\n"
  "To all my lust,* and that I freely may,                        *pleasure\n"
  "As me best thinketh, *do you* laugh or smart,             *cause you to*\n"
  "And never ye to grudge,* night nor day,                          *murmur\n"
  "And eke when I say Yea, ye say not Nay,\n"
  "Neither by word, nor frowning countenance?\n"
  "Swear this, and here I swear our alliance.\"\n"
  "\n"
  "Wond'ring upon this word, quaking for dread,\n"
  "She saide; \"Lord, indigne and unworthy\n"
  "Am I to this honour that ye me bede,*                             *offer\n"
  "But as ye will yourself, right so will I:\n"
  "And here I swear, that never willingly\n"
  "In word or thought I will you disobey,\n"
  "For to be dead; though me were loth to dey.\"*                       *die\n"
  "\n"
  "\"This is enough, Griselda mine,\" quoth he.\n"
  "And forth he went with a full sober cheer,\n"
  "Out at the door, and after then came she,\n"
  "And to the people he said in this mannere:\n"
  "\"This is my wife,\" quoth he, \"that standeth here.\n"
  "Honoure her, and love her, I you pray,\n"
  "Whoso me loves; there is no more to say.\"\n"
  "\n"
  "And, for that nothing of her olde gear\n"
  "She shoulde bring into his house, he bade\n"
  "That women should despoile* her right there;                      *strip\n"
  "Of which these ladies were nothing glad\n"
  "To handle her clothes wherein she was clad:\n"
  "But natheless this maiden bright of hue\n"
  "From foot to head they clothed have all new.\n"
  "\n"
  "Her haires have they comb'd that lay untress'd*                   *loose\n"
  "Full rudely, and with their fingers small\n"
  "A crown upon her head they have dress'd,\n"
  "And set her full of nouches <7> great and small:\n"
  "Of her array why should I make a tale?\n"
  "Unneth* the people her knew for her fairness,                  *scarcely\n"
  "When she transmuted was in such richess.\n"
  "\n"
  "The marquis hath her spoused with a ring\n"
  "Brought for the same cause, and then her set\n"
  "Upon a horse snow-white, and well ambling,\n"
  "And to his palace, ere he longer let*                           *delayed\n"
  "With joyful people, that her led and met,\n"
  "Conveyed her; and thus the day they spend\n"
  "In revel, till the sunne gan descend.\n"
  "\n"
  "And, shortly forth this tale for to chase,\n"
  "I say, that to this newe marchioness\n"
  "God hath such favour sent her of his grace,\n"
  "That it ne seemed not by likeliness\n"
  "That she was born and fed in rudeness, --\n"
  "As in a cot, or in an ox's stall, --\n"
  "But nourish'd in an emperore's hall.\n"
  "\n"
  "To every wight she waxen* is so dear                              *grown\n"
  "And worshipful, that folk where she was born,\n"
  "That from her birthe knew her year by year,\n"
  "*Unnethes trowed* they, but durst have sworn,        *scarcely believed*\n"
  "That to Janicol' of whom I spake before,\n"
  "She was not daughter, for by conjecture\n"
  "Them thought she was another creature.\n"
  "\n"
  "For though that ever virtuous was she,\n"
  "She was increased in such excellence\n"
  "Of thewes* good, y-set in high bounte,                        *qualities\n"
  "And so discreet, and fair of eloquence,\n"
  "So benign, and so digne* of reverence,                           *worthy\n"
  "And coulde so the people's heart embrace,\n"
  "That each her lov'd that looked on her face.\n"
  "\n"
  "Not only of Saluces in the town\n"
  "Published was the bounte of her name,\n"
  "But eke besides in many a regioun;\n"
  "If one said well, another said the same:\n"
  "So spread of here high bounte the fame,\n"
  "That men and women, young as well as old,\n"
  "Went to Saluces, her for to behold.\n"
  "\n"
  "Thus Walter lowly, -- nay, but royally,-\n"
  "Wedded with fortn'ate honestete,*                                *virtue\n"
  "In Godde's peace lived full easily\n"
  "At home, and outward grace enough had he:\n"
  "And, for he saw that under low degree\n"
  "Was honest virtue hid, the people him held\n"
  "A prudent man, and that is seen full seld'.*                     *seldom\n"
  "\n"
  "Not only this Griseldis through her wit\n"
  "*Couth all the feat* of wifely homeliness,         *knew all the duties*\n"
  "But eke, when that the case required it,\n"
  "The common profit coulde she redress:\n"
  "There n'as discord, rancour, nor heaviness\n"
  "In all the land, that she could not appease,\n"
  "And wisely bring them all in rest and ease\n"
  "\n"
  "Though that her husband absent were or non,*                        *not\n"
  "If gentlemen or other of that country,\n"
  "Were wroth,* she woulde bringe them at one,                     *at feud\n"
  "So wise and ripe wordes hadde she,\n"
  "And judgement of so great equity,\n"
  "That she from heaven sent was, as men wend,*           *weened, imagined\n"
  "People to save, and every wrong t'amend\n"
  "\n"
  "Not longe time after that this Griseld'\n"
  "Was wedded, she a daughter had y-bore;\n"
  "All she had lever* borne a knave** child,                  *rather **boy\n"
  "Glad was the marquis and his folk therefore;\n"
  "For, though a maiden child came all before,\n"
  "She may unto a knave child attain\n"
  "By likelihood, since she is not barren.\n"
  "\n"
  "\n"
  "*Pars Tertia.*                                              *Third Part*\n"
  "\n"
  "\n"
  "There fell, as falleth many times mo',\n"
  "When that his child had sucked but a throw,*                little while\n"
  "This marquis in his hearte longed so\n"
  "To tempt his wife, her sadness* for to know,              *steadfastness\n"
  "That he might not out of his hearte throw\n"
  "This marvellous desire his wife t'asssay;*                          *try\n"
  "Needless,* God wot, he thought her to affray.**           *without cause\n"
  "                                                        **alarm, disturb\n"
  "He had assayed her anough before,\n"
  "And found her ever good; what needed it\n"
  "Her for to tempt, and always more and more?\n"
  "Though some men praise it for a subtle wit,\n"
  "But as for me, I say that *evil it sit*              *it ill became him*\n"
  "T'assay a wife when that it is no need,\n"
  "And putte her in anguish and in dread.\n"
  "\n"
  "For which this marquis wrought in this mannere:\n"
  "He came at night alone there as she lay,\n"
  "With sterne face and with full troubled cheer,\n"
  "And saide thus; \"Griseld',\" quoth he \"that day\n"
  "That I you took out of your poor array,\n"
  "And put you in estate of high nobless,\n"
  "Ye have it not forgotten, as I guess.\n"
  "\n"
  "\"I say, Griseld', this present dignity,\n"
  "In which that I have put you, as I trow*                        *believe\n"
  "Maketh you not forgetful for to be\n"
  "That I you took in poor estate full low,\n"
  "For any weal you must yourselfe know.\n"
  "Take heed of every word that I you say,\n"
  "There is no wight that hears it but we tway.*                       *two\n"
  "\n"
  "\"Ye know yourself well how that ye came here\n"
  "Into this house, it is not long ago;\n"
  "And though to me ye be right lefe* and dear,                      *loved\n"
  "Unto my gentles* ye be nothing so:                   *nobles, gentlefolk\n"
  "They say, to them it is great shame and woe\n"
  "For to be subject, and be in servage,\n"
  "To thee, that born art of small lineage.\n"
  "\n"
  "\"And namely* since thy daughter was y-bore                   *especially\n"
  "These wordes have they spoken doubteless;\n"
  "But I desire, as I have done before,\n"
  "To live my life with them in rest and peace:\n"
  "I may not in this case be reckeless;\n"
  "I must do with thy daughter for the best,\n"
  "Not as I would, but as my gentles lest.*                         *please\n"
  "\n"
  "\"And yet, God wot, this is full loth* to me:                     *odious\n"
  "But natheless withoute your weeting*                            *knowing\n"
  "I will nought do; but this will I,\" quoth he,\n"
  "\"That ye to me assenten in this thing.\n"
  "Shew now your patience in your working,\n"
  "That ye me hight* and swore in your village                    *promised\n"
  "The day that maked was our marriage.\"\n"
  "\n"
  "When she had heard all this, she not amev'd*                    *changed\n"
  "Neither in word, in cheer, nor countenance\n"
  "(For, as it seemed, she was not aggriev'd);\n"
  "She saide; \"Lord, all lies in your pleasance,\n"
  "My child and I, with hearty obeisance\n"
  "Be youres all, and ye may save or spill*                        *destroy\n"
  "Your owen thing: work then after your will.\n"
  "\n"
  "\"There may no thing, so God my soule save,\n"
  "*Like to* you, that may displease me:                      *be pleasing*\n"
  "Nor I desire nothing for to have,\n"
  "Nor dreade for to lose, save only ye:\n"
  "This will is in mine heart, and aye shall be,\n"
  "No length of time, nor death, may this deface,\n"
  "Nor change my corage* to another place.\"                  *spirit, heart\n"
  "\n"
  "Glad was the marquis for her answering,\n"
  "But yet he feigned as he were not so;\n"
  "All dreary was his cheer and his looking\n"
  "When that he should out of the chamber go.\n"
  "Soon after this, a furlong way or two,<8>\n"
  "He privily hath told all his intent\n"
  "Unto a man, and to his wife him sent.\n"
  "\n"
  "A *manner sergeant* was this private* man,              *kind of squire*\n"
  "The which he faithful often founden had                        *discreet\n"
  "In thinges great, and eke such folk well can\n"
  "Do execution in thinges bad:\n"
  "The lord knew well, that he him loved and drad.*                *dreaded\n"
  "And when this sergeant knew his lorde's will,\n"
  "Into the chamber stalked he full still.\n"
  "\n"
  "\"Madam,\" he said, \"ye must forgive it me,\n"
  "Though I do thing to which I am constrain'd;\n"
  "Ye be so wise, that right well knowe ye\n"
  "*That lordes' hestes may not be y-feign'd;*               *see note <9>*\n"
  "They may well be bewailed and complain'd,\n"
  "But men must needs unto their lust* obey;                      *pleasure\n"
  "And so will I, there is no more to say.\n"
  "\n"
  "\"This child I am commanded for to take.\"\n"
  "And spake no more, but out the child he hent*                    *seized\n"
  "Dispiteously,* and gan a cheer** to make     *unpityingly **show, aspect\n"
  "As though he would have slain it ere he went.\n"
  "Griseldis must all suffer and consent:\n"
  "And as a lamb she sat there meek and still,\n"
  "And let this cruel sergeant do his will\n"
  "\n"
  "Suspicious* was the diffame** of this man,    *ominous **evil reputation\n"
  "Suspect his face, suspect his word also,\n"
  "Suspect the time in which he this began:\n"
  "Alas! her daughter, that she loved so,\n"
  "She weened* he would have it slain right tho,**          *thought **then\n"
  "But natheless she neither wept nor siked,*                       *sighed\n"
  "Conforming her to what the marquis liked.\n"
  "\n"
  "But at the last to speake she began,\n"
  "And meekly she unto the sergeant pray'd,\n"
  "So as he was a worthy gentle man,\n"
  "That she might kiss her child, ere that it died:\n"
  "And in her barme* this little child she laid,                *lap, bosom\n"
  "With full sad face, and gan the child to bless,*                  *cross\n"
  "And lulled it, and after gan it kiss.\n"
  "\n"
  "And thus she said in her benigne voice:\n"
  "Farewell, my child, I shall thee never see;\n"
  "But since I have thee marked with the cross,\n"
  "Of that father y-blessed may'st thou be\n"
  "That for us died upon a cross of tree:\n"
  "Thy soul, my little child, I *him betake,*             *commit unto him*\n"
  "For this night shalt thou dien for my sake.\n"
  "\n"
  "I trow* that to a norice** in this case                 *believe **nurse\n"
  "It had been hard this ruthe* for to see:                  *pitiful sight\n"
  "Well might a mother then have cried, \"Alas!\"\n"
  "But natheless so sad steadfast was she,\n"
  "That she endured all adversity,\n"
  "And to the sergeant meekely she said,\n"
  "\"Have here again your little younge maid.\n"
  "\n"
  "\"Go now,\" quoth she, \"and do my lord's behest.\n"
  "And one thing would I pray you of your grace,\n"
  "*But if* my lord forbade you at the least,                      *unless*\n"
  "Bury this little body in some place,\n"
  "That neither beasts nor birdes it arace.\"*                    *tear <10>\n"
  "But he no word would to that purpose say,\n"
  "But took the child and went upon his way.\n"
  "\n"
  "The sergeant came unto his lord again,\n"
  "And of Griselda's words and of her cheer*                     *demeanour\n"
  "He told him point for point, in short and plain,\n"
  "And him presented with his daughter dear.\n"
  "Somewhat this lord had ruth in his mannere,\n"
  "But natheless his purpose held he still,\n"
  "As lordes do, when they will have their will;\n"
  "\n"
  "And bade this sergeant that he privily\n"
  "Shoulde the child full softly wind and wrap,\n"
  "With alle circumstances tenderly,\n"
  "And carry it in a coffer, or in lap;\n"
  "But, upon pain his head off for to swap,*                        *strike\n"
  "That no man shoulde know of his intent,\n"
  "Nor whence he came, nor whither that he went;\n"
  "\n"
  "But at Bologna, to his sister dear,\n"
  "That at that time of Panic'* was Countess,                       *Panico\n"
  "He should it take, and shew her this mattere,\n"
  "Beseeching her to do her business\n"
  "This child to foster in all gentleness,\n"
  "And whose child it was he bade her hide\n"
  "From every wight, for aught that might betide.\n"
  "\n"
  "The sergeant went, and hath fulfill'd this thing.\n"
  "But to the marquis now returne we;\n"
  "For now went he full fast imagining\n"
  "If by his wife's cheer he mighte see,\n"
  "Or by her wordes apperceive, that she\n"
  "Were changed; but he never could her find,\n"
  "But ever-in-one* alike sad** and kind.           *constantly **steadfast\n"
  "\n"
  "As glad, as humble, as busy in service,\n"
  "And eke in love, as she was wont to be,\n"
  "Was she to him, in every *manner wise;*                    *sort of way*\n"
  "And of her daughter not a word spake she;\n"
  "*No accident for no adversity*            *no change of humour resulting\n"
  "Was seen in her, nor e'er her daughter's name       from her affliction*\n"
  "She named, or in earnest or in game.\n"
  "\n"
  "\n"
  "*Pars Quarta*                                              *Fourth Part*\n"
  "\n"
  "\n"
  "In this estate there passed be four year\n"
  "Ere she with childe was; but, as God wo'ld,\n"
  "A knave* child she bare by this Waltere,                            *boy\n"
  "Full gracious and fair for to behold;\n"
  "And when that folk it to his father told,\n"
  "Not only he, but all his country, merry\n"
  "Were for this child, and God they thank and hery.*               *praise\n"
  "\n"
  "When it was two year old, and from the breast\n"
  "Departed* of the norice, on a day                         *taken, weaned\n"
  "This marquis *caughte yet another lest*               *was seized by yet\n"
  "To tempt his wife yet farther, if he may.                another desire*\n"
  "Oh! needless was she tempted in as say;*                          *trial\n"
  "But wedded men *not connen no measure,*             *know no moderation*\n"
  "When that they find a patient creature.\n"
  "\n"
  "\"Wife,\" quoth the marquis, \"ye have heard ere this\n"
  "My people *sickly bear* our marriage;          *regard with displeasure*\n"
  "And namely* since my son y-boren is,                         *especially\n"
  "Now is it worse than ever in all our age:\n"
  "The murmur slays mine heart and my corage,\n"
  "For to mine ears cometh the voice so smart,*                  *painfully\n"
  "That it well nigh destroyed hath mine heart.\n"
  "\n"
  "";
// }

const char clerksTale1[] PGMSECTION = // { // 31578 bytes
  "\"Now say they thus, 'When Walter is y-gone,\n"
  "Then shall the blood of Janicol' succeed,\n"
  "And be our lord, for other have we none:'\n"
  "Such wordes say my people, out of drede.*                         *doubt\n"
  "Well ought I of such murmur take heed,\n"
  "For certainly I dread all such sentence,*         *expression of opinion\n"
  "Though they not *plainen in mine audience.*     *complain in my hearing*\n"
  "\n"
  "\"I woulde live in peace, if that I might;\n"
  "Wherefore I am disposed utterly,\n"
  "As I his sister served ere* by night,                            *before\n"
  "Right so think I to serve him privily.\n"
  "This warn I you, that ye not suddenly\n"
  "Out of yourself for no woe should outraie;*     *become outrageous, rave\n"
  "Be patient, and thereof I you pray.\"\n"
  "\n"
  "\"I have,\" quoth she, \"said thus, and ever shall,\n"
  "I will no thing, nor n'ill no thing, certain,\n"
  "But as you list; not grieveth me at all\n"
  "Though that my daughter and my son be slain\n"
  "At your commandement; that is to sayn,\n"
  "I have not had no part of children twain,\n"
  "But first sickness, and after woe and pain.\n"
  "\n"
  "\"Ye be my lord, do with your owen thing\n"
  "Right as you list, and ask no rede of me:\n"
  "For, as I left at home all my clothing\n"
  "When I came first to you, right so,\" quoth she,\n"
  "\"Left I my will and all my liberty,\n"
  "And took your clothing: wherefore I you pray,\n"
  "Do your pleasance, I will your lust* obey.                         *will\n"
  "\n"
  "\"And, certes, if I hadde prescience\n"
  "Your will to know, ere ye your lust* me told,                      *will\n"
  "I would it do withoute negligence:\n"
  "But, now I know your lust, and what ye wo'ld,\n"
  "All your pleasance firm and stable I hold;\n"
  "For, wist I that my death might do you ease,\n"
  "Right gladly would I dien you to please.\n"
  "\n"
  "\"Death may not make no comparisoun\n"
  "Unto your love.\" And when this marquis say*                         *saw\n"
  "The constance of his wife,  he cast adown\n"
  "His eyen two, and wonder'd how she may\n"
  "In patience suffer all this array;\n"
  "And forth he went with dreary countenance;\n"
  "But to his heart it was full great pleasance.\n"
  "\n"
  "This ugly sergeant, in the same wise\n"
  "That he her daughter caught, right so hath he\n"
  "(Or worse, if men can any worse devise,)\n"
  "Y-hent* her son, that full was of beauty:                        *seized\n"
  "And ever-in-one* so patient was she,                        *unvaryingly\n"
  "That she no cheere made of heaviness,\n"
  "But kiss'd her son, and after gan him bless.\n"
  "\n"
  "Save this she prayed him, if that he might,\n"
  "Her little son he would in earthe grave,*                          *bury\n"
  "His tender limbes, delicate to sight,\n"
  "From fowles and from beastes for to save.\n"
  "But she none answer of him mighte have;\n"
  "He went his way, as him nothing ne raught,*                       *cared\n"
  "But to Bologna tenderly it brought.\n"
  "\n"
  "The marquis wonder'd ever longer more\n"
  "Upon her patience; and, if that he\n"
  "Not hadde soothly knowen therebefore\n"
  "That perfectly her children loved she,\n"
  "He would have ween'd* that of some subtilty,                    *thought\n"
  "And of malice, or for cruel corage,*                        *disposition\n"
  "She hadde suffer'd this with sad* visage.            *steadfast, unmoved\n"
  "\n"
  "But well he knew, that, next himself, certain\n"
  "She lov'd her children best in every wise.\n"
  "But now of women would I aske fain,\n"
  "If these assayes mighte not suffice?\n"
  "What could a sturdy* husband more devise                          *stern\n"
  "To prove her wifehood and her steadfastness,\n"
  "And he continuing ev'r in sturdiness?\n"
  "\n"
  "But there be folk of such condition,\n"
  "That, when they have a certain purpose take,\n"
  "Thiey cannot stint* of their intention,                           *cease\n"
  "But, right as they were bound unto a stake,\n"
  "They will not of their firste purpose slake:*            *slacken, abate\n"
  "Right so this marquis fully hath purpos'd\n"
  "To tempt his wife, as he was first dispos'd.\n"
  "\n"
  "He waited, if by word or countenance\n"
  "That she to him was changed of corage:*                          *spirit\n"
  "But never could he finde variance,\n"
  "She was aye one in heart and in visage,\n"
  "And aye the farther that she was in age,\n"
  "The more true (if that it were possible)\n"
  "She was to him in love, and more penible.*      *painstaking in devotion\n"
  "\n"
  "For which it seemed thus, that of them two\n"
  "There was but one will; for, as Walter lest,*                   *pleased\n"
  "The same pleasance was her lust* also;                         *pleasure\n"
  "And, God be thanked, all fell for the best.\n"
  "She shewed well, for no worldly unrest,\n"
  "A wife as of herself no thinge should\n"
  "Will, in effect, but as her husbaud would.\n"
  "\n"
  "The sland'r of Walter wondrous wide sprad,\n"
  "That of a cruel heart he wickedly,\n"
  "For* he a poore woman wedded had,                               *because\n"
  "Had murder'd both his children privily:\n"
  "Such murmur was among them commonly.\n"
  "No wonder is: for to the people's ear\n"
  "There came no word, but that they murder'd were.\n"
  "\n"
  "For which, whereas his people therebefore\n"
  "Had lov'd him well, the sland'r of his diffame*                  *infamy\n"
  "Made them that they him hated therefore.\n"
  "To be a murd'rer is a hateful name.\n"
  "But natheless, for earnest or for game,\n"
  "He of his cruel purpose would not stent;\n"
  "To tempt his wife was set all his intent.\n"
  "\n"
  "When that his daughter twelve year was of age,\n"
  "He to the Court of Rome, in subtle wise\n"
  "Informed of his will, sent his message,*                      *messenger\n"
  "Commanding him such bulles to devise\n"
  "As to his cruel purpose may suffice,\n"
  "How that the Pope, for his people's rest,\n"
  "Bade him to wed another, if him lest.*                           *wished\n"
  "\n"
  "I say he bade they shoulde counterfeit\n"
  "The Pope's bulles, making mention\n"
  "That he had leave his firste wife to lete,*                       *leave\n"
  "To stinte* rancour and dissension                         *put an end to\n"
  "Betwixt his people and him: thus spake the bull,\n"
  "The which they have published at full.\n"
  "\n"
  "The rude people, as no wonder is,\n"
  "Weened* full well that it had been right so:          *thought, believed\n"
  "But, when these tidings came to Griseldis.\n"
  "I deeme that her heart was full of woe;\n"
  "But she, alike sad* for evermo',                              *steadfast\n"
  "Disposed was, this humble creature,\n"
  "Th' adversity of fortune all t' endure;\n"
  "\n"
  "Abiding ever his lust and his pleasance,\n"
  "To whom that she was given, heart and all,\n"
  "As *to her very worldly suffisance.*               *to the utmost extent\n"
  "But, shortly if this story tell I shall,                   of her power*\n"
  "The marquis written hath in special\n"
  "A letter, in which he shewed his intent,\n"
  "And secretly it to Bologna sent.\n"
  "\n"
  "To th' earl of Panico, which hadde tho*                           *there\n"
  "Wedded his sister, pray'd he specially\n"
  "To bringe home again his children two\n"
  "In honourable estate all openly:\n"
  "But one thing he him prayed utterly,\n"
  "That he to no wight, though men would inquere,\n"
  "Shoulde not tell whose children that they were,\n"
  "\n"
  "But say, the maiden should y-wedded be\n"
  "Unto the marquis of Saluce anon.\n"
  "And as this earl was prayed, so did he,\n"
  "For, at day set, he on his way is gone\n"
  "Toward Saluce, and lorde's many a one\n"
  "In rich array, this maiden for to guide, --\n"
  "Her younge brother riding her beside.\n"
  "\n"
  "Arrayed was toward* her marriage                              *as if for\n"
  "This freshe maiden, full of gemmes clear;\n"
  "Her brother, which that seven year was of age,\n"
  "Arrayed eke full fresh in his mannere:\n"
  "And thus, in great nobless, and with glad cheer,\n"
  "Toward Saluces shaping their journey,\n"
  "From day to day they rode upon their way.\n"
  "\n"
  "\n"
  "*Pars Quinta.*                                              *Fifth Part*\n"
  "\n"
  "\n"
  "*Among all this,* after his wick' usage,             *while all this was\n"
  "The marquis, yet his wife to tempte more                       going on*\n"
  "To the uttermost proof of her corage,\n"
  "Fully to have experience and lore*                            *knowledge\n"
  "If that she were as steadfast as before,\n"
  "He on a day, in open audience,\n"
  "Full boisterously said her this sentence:\n"
  "\n"
  "\"Certes, Griseld', I had enough pleasance\n"
  "To have you to my wife, for your goodness,\n"
  "And for your truth, and for your obeisance,\n"
  "Not for your lineage, nor for your richess;\n"
  "But now know I, in very soothfastness,\n"
  "That in great lordship, if I well advise,\n"
  "There is great servitude in sundry wise.\n"
  "\n"
  "\"I may not do as every ploughman may:\n"
  "My people me constraineth for to take\n"
  "Another wife, and cryeth day by day;\n"
  "And eke the Pope, rancour for to slake,\n"
  "Consenteth it, that dare I undertake:\n"
  "And truely, thus much I will you say,\n"
  "My newe wife is coming by the way.\n"
  "\n"
  "\"Be strong of heart, and *void anon* her place;     *immediately vacate*\n"
  "And thilke* dower that ye brought to me,                           *that\n"
  "Take it again, I grant it of my grace.\n"
  "Returne to your father's house,\" quoth he;\n"
  "\"No man may always have prosperity;\n"
  "With even heart I rede* you to endure                           *counsel\n"
  "The stroke of fortune or of aventure.\"\n"
  "\n"
  "And she again answer'd in patience:\n"
  "\"My Lord,\" quoth she, \"I know, and knew alway,\n"
  "How that betwixte your magnificence\n"
  "And my povert' no wight nor can nor may\n"
  "Make comparison, it *is no nay;*                      *cannot be denied*\n"
  "I held me never digne* in no mannere                             *worthy\n"
  "To be your wife, nor yet your chamberere.*                 *chamber-maid\n"
  "\n"
  "\"And in this house, where ye me lady made,\n"
  "(The highe God take I for my witness,\n"
  "And all so wisly* he my soule glade),**              *surely **gladdened\n"
  "I never held me lady nor mistress,\n"
  "But humble servant to your worthiness,\n"
  "And ever shall, while that my life may dure,\n"
  "Aboven every worldly creature.\n"
  "\n"
  "\"That ye so long, of your benignity,\n"
  "Have holden me in honour and nobley,*                          *nobility\n"
  "Where as I was not worthy for to be,\n"
  "That thank I God and you, to whom I pray\n"
  "Foryield* it you; there is no more to say:                       *reward\n"
  "Unto my father gladly will I wend,*                                  *go\n"
  "And with him dwell, unto my lifes end,\n"
  "\n"
  "\"Where I was foster'd as a child full small,\n"
  "Till I be dead my life there will I lead,\n"
  "A widow clean in body, heart, and all.\n"
  "For since I gave to you my maidenhead,\n"
  "And am your true wife, it is no dread,*                           *doubt\n"
  "God shielde* such a lordes wife to take                          *forbid\n"
  "Another man to husband or to make.*                                *mate\n"
  "\n"
  "\"And of your newe wife, God of his grace\n"
  "So grant you weal and all prosperity:\n"
  "For I will gladly yield to her my place,\n"
  "In which that I was blissful wont to be.\n"
  "For since it liketh you, my Lord,\" quoth she,\n"
  "\"That whilom weren all mine hearte's rest,\n"
  "That I shall go, I will go when you lest.\n"
  "\n"
  "\"But whereas ye me proffer such dowaire\n"
  "As I first brought, it is well in my mind,\n"
  "It was my wretched clothes, nothing fair,\n"
  "The which to me were hard now for to find.\n"
  "O goode God! how gentle and how kind\n"
  "Ye seemed by your speech and your visage,\n"
  "The day that maked was our marriage!\n"
  "\n"
  "\"But sooth is said, -- algate* I find it true,            *at all events\n"
  "For in effect it proved is on me, --\n"
  "Love is not old as when that it is new.\n"
  "But certes, Lord, for no adversity,\n"
  "To dien in this case, it shall not be\n"
  "That e'er in word or work I shall repent\n"
  "That I you gave mine heart in whole intent.\n"
  "\n"
  "\"My Lord, ye know that in my father's place\n"
  "Ye did me strip out of my poore weed,*                          *raiment\n"
  "And richely ye clad me of your grace;\n"
  "To you brought I nought elles, out of dread,\n"
  "But faith, and nakedness, and maidenhead;\n"
  "And here again your clothing I restore,\n"
  "And eke your wedding ring for evermore.\n"
  "\n"
  "\"The remnant of your jewels ready be\n"
  "Within your chamber, I dare safely sayn:\n"
  "Naked out of my father's house,\" quoth she,\n"
  "\"I came, and naked I must turn again.\n"
  "All your pleasance would I follow fain:*                     *cheerfully\n"
  "But yet I hope it be not your intent\n"
  "That smockless* I out of your palace went.                        *naked\n"
  "\n"
  "\"Ye could not do so dishonest* a thing,                   *dishonourable\n"
  "That thilke* womb, in which your children lay,                     *that\n"
  "Shoulde before the people, in my walking,\n"
  "Be seen all bare: and therefore I you pray,\n"
  "Let me not like a worm go by the way:\n"
  "Remember you, mine owen Lord so dear,\n"
  "I was your wife, though I unworthy were.\n"
  "\n"
  "\"Wherefore, in guerdon* of my maidenhead,                        *reward\n"
  "Which that I brought and not again I bear,\n"
  "As vouchesafe to give me to my meed*                             *reward\n"
  "But such a smock as I was wont to wear,\n"
  "That I therewith may wrie* the womb of her                        *cover\n"
  "That was your wife: and here I take my leave\n"
  "Of you, mine owen Lord, lest I you grieve.\"\n"
  "\n"
  "\"The smock,\" quoth he, \"that thou hast on thy back,\n"
  "Let it be still, and bear it forth with thee.\"\n"
  "But well unnethes* thilke word he spake,                *with difficulty\n"
  "But went his way for ruth and for pity.\n"
  "Before the folk herselfe stripped she,\n"
  "And in her smock, with foot and head all bare,\n"
  "Toward her father's house forth is she fare.*                      *gone\n"
  "\n"
  "The folk her follow'd weeping on her way,\n"
  "And fortune aye they cursed as they gon:*                            *go\n"
  "But she from weeping kept her eyen drey,*                           *dry\n"
  "Nor in this time worde spake she none.\n"
  "Her father, that this tiding heard anon,\n"
  "Cursed the day and time, that nature\n"
  "Shope* him to be a living creature.                    *formed, ordained\n"
  "\n"
  "For, out of doubt, this olde poore man\n"
  "Was ever in suspect of her marriage:\n"
  "For ever deem'd he, since it first began,\n"
  "That when the lord *fulfill'd had his corage,*  *had gratified his whim*\n"
  "He woulde think it were a disparage*                      *disparagement\n"
  "To his estate, so low for to alight,\n"
  "And voide* her as soon as e'er he might.                        *dismiss\n"
  "\n"
  "Against* his daughter hastily went he                           *to meet\n"
  "(For he by noise of folk knew her coming),\n"
  "And with her olde coat, as it might be,\n"
  "He cover'd her, full sorrowfully weeping:\n"
  "But on her body might he it not bring,\n"
  "For rude was the cloth, and more of age\n"
  "By dayes fele* than at her marriage.                          *many <11>\n"
  "\n"
  "Thus with her father for a certain space\n"
  "Dwelled this flow'r of wifely patience,\n"
  "That neither by her words nor by her face,\n"
  "Before the folk nor eke in their absence,\n"
  "Ne shewed she that her was done offence,\n"
  "Nor of her high estate no remembrance\n"
  "Ne hadde she, *as by* her countenance.                   *to judge from*\n"
  "\n"
  "No wonder is, for in her great estate\n"
  "Her ghost* was ever in plein** humility;                  *spirit **full\n"
  "No tender mouth, no hearte delicate,\n"
  "No pomp, and no semblant of royalty;\n"
  "But full of patient benignity,\n"
  "Discreet and prideless, aye honourable,\n"
  "And to her husband ever meek and stable.\n"
  "\n"
  "Men speak of Job, and most for his humbless,\n"
  "As clerkes, when them list, can well indite,\n"
  "Namely* of men; but, as in soothfastness,                  *particularly\n"
  "Though clerkes praise women but a lite,*                         *little\n"
  "There can no man in humbless him acquite\n"
  "As women can, nor can be half so true\n"
  "As women be, *but it be fall of new.*              *unless it has lately\n"
  "                                                           come to pass*\n"
  "\n"
  "*Pars Sexta*                                                *Sixth Part*\n"
  "\n"
  "From Bologn' is the earl of Panic' come,\n"
  "Of which the fame up sprang to more and less;\n"
  "And to the people's eares all and some\n"
  "Was know'n eke, that a newe marchioness\n"
  "He with him brought, in such pomp and richess\n"
  "That never was there seen with manne's eye\n"
  "So noble array in all West Lombardy.\n"
  "\n"
  "The marquis, which that shope* and knew all this,              *arranged\n"
  "Ere that the earl was come, sent his message*                 *messenger\n"
  "For thilke poore sely* Griseldis;                              *innocent\n"
  "And she, with humble heart and glad visage,\n"
  "Nor with no swelling thought in her corage,*                       *mind\n"
  "Came at his hest,* and on her knees her set,                    *command\n"
  "And rev'rently and wisely she him gret.*                        *greeted\n"
  "\n"
  "\"Griseld',\" quoth he, \"my will is utterly,\n"
  "This maiden, that shall wedded be to me,\n"
  "Received be to-morrow as royally\n"
  "As it possible is in my house to be;\n"
  "And eke that every wight in his degree\n"
  "Have *his estate* in sitting and service,               *what befits his\n"
  "And in high pleasance, as I can devise.                       condition*\n"
  "\n"
  "\"I have no women sufficient, certain,\n"
  "The chambers to array in ordinance\n"
  "After my lust;* and therefore would I fain                     *pleasure\n"
  "That thine were all such manner governance:\n"
  "Thou knowest eke of old all my pleasance;\n"
  "Though thine array be bad, and ill besey,*              *poor to look on\n"
  "*Do thou thy devoir at the leaste  way.\"*          * do your duty in the\n"
  "                                                        quickest manner*\n"
  "\"Not only, Lord, that I am glad,\" quoth she,\n"
  "\"To do your lust, but I desire also\n"
  "You for to serve and please in my degree,\n"
  "Withoute fainting, and shall evermo':\n"
  "Nor ever for no weal, nor for no woe,\n"
  "Ne shall the ghost* within mine hearte stent**           *spirit **cease\n"
  "To love you best with all my true intent.\"\n"
  "\n"
  "And with that word she gan the house to dight,*                 *arrange\n"
  "And tables for to set, and beds to make,\n"
  "And *pained her* to do all that she might,              *she took pains*\n"
  "Praying the chambereres* for Godde's sake                 *chamber-maids\n"
  "To hasten them, and faste sweep and shake,\n"
  "And she the most serviceable of all\n"
  "Hath ev'ry chamber arrayed, and his hall.\n"
  "\n"
  "Aboute undern* gan the earl alight,                       *afternoon <5>\n"
  "That with him brought these noble children tway;\n"
  "For which the people ran to see the sight\n"
  "Of their array, so *richely besey;*                     *rich to behold*\n"
  "And then *at erst* amonges them they say,           *for the first time*\n"
  "That Walter was no fool, though that him lest*                  *pleased\n"
  "To change his wife; for it was for the best.\n"
  "\n"
  "For she is fairer, as they deemen* all,                           *think\n"
  "Than is Griseld', and more tender of age,\n"
  "And fairer fruit between them shoulde fall,\n"
  "And more pleasant, for her high lineage:\n"
  "Her brother eke so fair was of visage,\n"
  "That them to see the people hath caught pleasance,\n"
  "Commending now the marquis' governance.\n"
  "\n"
  "\"O stormy people, unsad* and ev'r untrue,                      *variable\n"
  "And undiscreet, and changing as a vane,\n"
  "Delighting ev'r in rumour that is new,\n"
  "For like the moon so waxe ye and wane:\n"
  "Aye full of clapping, *dear enough a jane,*         *worth nothing <12>*\n"
  "Your doom* is false, your constance evil preveth,**  *judgment **proveth\n"
  "A full great fool is he that you believeth.\"\n"
  "\n"
  "Thus saide the sad* folk in that city,                           *sedate\n"
  "When that the people gazed up and down;\n"
  "For they were glad, right for the novelty,\n"
  "To have a newe lady of their town.\n"
  "No more of this now make I mentioun,\n"
  "But to Griseld' again I will me dress,\n"
  "And tell her constancy and business.\n"
  "\n"
  "Full busy was Griseld' in ev'ry thing\n"
  "That to the feaste was appertinent;\n"
  "Right nought was she abash'd* of her clothing,                  *ashamed\n"
  "Though it were rude, and somedeal eke to-rent;*                *tattered\n"
  "But with glad cheer* unto the gate she went                  *expression\n"
  "With other folk, to greet the marchioness,\n"
  "And after that did forth her business.\n"
  "\n"
  "With so glad cheer* his guestes she receiv'd                 *expression\n"
  "And so conningly* each in his degree,               *cleverly, skilfully\n"
  "That no defaulte no man apperceiv'd,\n"
  "But aye they wonder'd what she mighte be\n"
  "That in so poor array was for to see,\n"
  "And coude* such honour and reverence;                  *knew, understood\n"
  "And worthily they praise her prudence.\n"
  "\n"
  "In all this meane while she not stent*                           *ceased\n"
  "This maid, and eke her brother, to commend\n"
  "With all her heart in full benign intent,\n"
  "So well, that no man could her praise amend:\n"
  "But at the last, when that these lordes wend*                        *go\n"
  "To sitte down to meat, he gan to call\n"
  "Griseld', as she was busy in the hall.\n"
  "\n"
  "\"Griseld',\" quoth he, as it were in his play,\n"
  "\"How liketh thee my wife, and her beauty?\"\n"
  "\"Right well, my Lord,\" quoth she, \"for, in good fay,*             *faith\n"
  "A fairer saw I never none than she:\n"
  "I pray to God give you prosperity;\n"
  "And so I hope, that he will to you send\n"
  "Pleasance enough unto your lives end.\n"
  "\n"
  "\"One thing beseech I you, and warn also,\n"
  "That ye not pricke with no tormenting\n"
  "This tender maiden, as ye have done mo:*                        *me <13>\n"
  "For she is foster'd in her nourishing\n"
  "More tenderly, and, to my supposing,\n"
  "She mighte not adversity endure\n"
  "As could a poore foster'd creature.\"\n"
  "\n"
  "And when this Walter saw her patience,\n"
  "Her gladde cheer, and no malice at all,\n"
  "And* he so often had her done offence,                         *although\n"
  "And she aye sad* and constant as a wall,                      *steadfast\n"
  "Continuing ev'r her innocence o'er all,\n"
  "The sturdy marquis gan his hearte dress*                        *prepare\n"
  "To rue upon her wifely steadfastness.\n"
  "\n"
  "\"This is enough, Griselda mine,\" quoth he,\n"
  "\"Be now no more *aghast, nor evil paid,*        *afraid, nor displeased*\n"
  "I have thy faith and thy benignity\n"
  "As well as ever woman was, assay'd,\n"
  "In great estate and poorely array'd:\n"
  "Now know I, deare wife, thy steadfastness;\"\n"
  "And her in arms he took, and gan to kiss.\n"
  "\n"
  "And she for wonder took of it no keep;*                          *notice\n"
  "She hearde not what thing he to her said:\n"
  "She far'd as she had start out of a sleep,\n"
  "Till she out of her mazedness abraid.*                            *awoke\n"
  "\"Griseld',\" quoth he, \"by God that for us died,\n"
  "Thou art my wife, none other I have,\n"
  "Nor ever had, as God my soule save.\n"
  "\n"
  "\"This is thy daughter, which thou hast suppos'd\n"
  "To be my wife; that other faithfully\n"
  "Shall be mine heir, as I have aye dispos'd;\n"
  "Thou bare them of thy body truely:\n"
  "At Bologna kept I them privily:\n"
  "Take them again, for now may'st thou not say\n"
  "That thou hast lorn* none of thy children tway.                    *lost\n"
  "\n"
  "\"And folk, that otherwise have said of me,\n"
  "I warn them well, that I have done this deed\n"
  "For no malice, nor for no cruelty,\n"
  "But to assay in thee thy womanhead:\n"
  "And not to slay my children (God forbid),\n"
  "But for to keep them privily and still,\n"
  "Till I thy purpose knew, and all thy will.\"\n"
  "\n"
  "When she this heard, in swoon adown she falleth\n"
  "For piteous joy; and after her swooning,\n"
  "She both her younge children to her calleth,\n"
  "And in her armes piteously weeping\n"
  "Embraced them, and tenderly kissing,\n"
  "Full like a mother, with her salte tears\n"
  "She bathed both their visage and their hairs.\n"
  "\n"
  "O, what a piteous thing it was to see\n"
  "Her swooning, and her humble voice to hear!\n"
  "\"Grand mercy, Lord, God thank it you,\" quoth she,\n"
  "That ye have saved me my children dear;\n"
  "Now reck* I never to be dead right here;                           *care\n"
  "Since I stand in your love, and in your grace,\n"
  "No *force of* death, nor when my spirit pace.*     *no matter for* *pass\n"
  "\n"
  "\"O tender, O dear, O young children mine,\n"
  "Your woeful mother *weened steadfastly*                *believed firmly*\n"
  "That cruel houndes, or some foul vermine,\n"
  "Had eaten you; but God of his mercy,\n"
  "And your benigne father tenderly\n"
  "Have *done you keep:\"* and in that same stound*           *caused you to\n"
  "All suddenly she swapt** down to the ground.               be preserved*\n"
  "                                                            *hour **fell\n"
  "And in her swoon so sadly* holdeth she                           *firmly\n"
  "Her children two, when she gan them embrace,\n"
  "That with great sleight* and great difficulty                       *art\n"
  "The children from her arm they can arace,*                    *pull away\n"
  "O! many a tear on many a piteous face\n"
  "Down ran of them that stoode her beside,\n"
  "Unneth'* aboute her might they abide.                          *scarcely\n"
  "\n"
  "Walter her gladdeth, and her sorrow slaketh:*                  *assuages\n"
  "She riseth up abashed* from her trance,                      *astonished\n"
  "And every wight her joy and feaste maketh,\n"
  "Till she hath caught again her countenance.\n"
  "Walter her doth so faithfully pleasance,\n"
  "That it was dainty for to see the cheer\n"
  "Betwixt them two, since they be met in fere.*                  *together\n"
  "\n"
  "The ladies, when that they their time sey,*                         *saw\n"
  "Have taken her, and into chamber gone,\n"
  "And stripped her out of her rude array,\n"
  "And in a cloth of gold that brightly shone,\n"
  "And with a crown of many a riche stone\n"
  "Upon her head, they into hall her brought:\n"
  "And there she was honoured as her ought.\n"
  "\n"
  "Thus had this piteous day a blissful end;\n"
  "For every man and woman did his might\n"
  "This day in mirth and revel to dispend,\n"
  "Till on the welkin* shone the starres bright:                 *firmament\n"
  "For more solemn in every mannes sight\n"
  "This feaste was, and greater of costage,*                       *expense\n"
  "Than was the revel of her marriage.\n"
  "\n"
  "Full many a year in high prosperity\n"
  "Lived these two in concord and in rest;\n"
  "And richely his daughter married he\n"
  "Unto a lord, one of the worthiest\n"
  "Of all Itale; and then in peace and rest\n"
  "His wife's father in his court he kept,\n"
  "Till that the soul out of his body crept.\n"
  "\n"
  "His son succeeded in his heritage,\n"
  "In rest and peace, after his father's day:\n"
  "And fortunate was eke in marriage,\n"
  "All* he put not his wife in great assay:                       *although\n"
  "This world is not so strong, it *is no nay,*          *not to be denied*\n"
  "As it hath been in olde times yore;\n"
  "And hearken what this author saith, therefore;\n"
  "\n"
  "This story is said, <14> not for that wives should\n"
  "Follow Griselda in humility,\n"
  "For it were importable* though they would;              *not to be borne\n"
  "But for that every wight in his degree\n"
  "Shoulde be constant in adversity,\n"
  "As was Griselda; therefore Petrarch writeth\n"
  "This story, which with high style he inditeth.\n"
  "\n"
  "For, since a woman was so patient\n"
  "Unto a mortal man, well more we ought\n"
  "Receiven all in gree* that God us sent.                        good-will\n"
  "*For great skill is he proved that he wrought:*          *see note <15>*\n"
  "But he tempteth no man that he hath bought,\n"
  "As saith Saint James, if ye his 'pistle read;\n"
  "He proveth folk all day, it is no dread.*                         *doubt\n"
  "\n"
  "And suffereth us, for our exercise,\n"
  "With sharpe scourges of adversity\n"
  "Full often to be beat in sundry wise;\n"
  "Not for to know our will, for certes he,\n"
  "Ere we were born, knew all our frailty;\n"
  "And for our best is all his governance;\n"
  "Let us then live in virtuous sufferance.\n"
  "\n"
  "But one word, lordings, hearken, ere I go:\n"
  "It were full hard to finde now-a-days\n"
  "In all a town Griseldas three or two:\n"
  "For, if that they were put to such assays,\n"
  "The gold of them hath now so bad allays*                         *alloys\n"
  "With brass, that though the coin be fair *at eye,*              *to see*\n"
  "It woulde rather break in two than ply.*                           *bend\n"
  "\n"
  "For which here, for the Wife's love of Bath, --\n"
  "Whose life and all her sex may God maintain\n"
  "In high mast'ry, and elles were it scath,* --              *damage, pity\n"
  "I will, with lusty hearte fresh and green,\n"
  "Say you a song to gladden you, I ween:\n"
  "And let us stint of earnestful mattere.\n"
  "Hearken my song, that saith in this mannere.\n"
  "\n"
  "\n"
  "L'Envoy of Chaucer.\n"
  "\n"
  "\n"
  "\"Griseld' is dead, and eke her patience,\n"
  "And both at once are buried in Itale:\n"
  "For which I cry in open audience,\n"
  "No wedded man so hardy be t' assail\n"
  "His wife's patience, in trust to find\n"
  "Griselda's, for in certain he shall fail.\n"
  "\n"
  "\"O noble wives, full of high prudence,\n"
  "Let no humility your tongues nail:\n"
  "Nor let no clerk have cause or diligence\n"
  "To write of you a story of such marvail,\n"
  "As of Griselda patient and kind,\n"
  "Lest Chichevache<16> you swallow in her entrail.\n"
  "\n"
  "\"Follow Echo, that holdeth no silence,\n"
  "But ever answereth at the countertail;*              *counter-tally <17>\n"
  "Be not bedaffed* for your innocence,                           *befooled\n"
  "But sharply take on you the governail;*                            *helm\n"
  "Imprinte well this lesson in your mind,\n"
  "For common profit, since it may avail.\n"
  "\n"
  "\"Ye archiwives,* stand aye at defence,                    *wives of rank\n"
  "Since ye be strong as is a great camail,*                         *camel\n"
  "Nor suffer not that men do you offence.\n"
  "And slender wives, feeble in battail,\n"
  "Be eager as a tiger yond in Ind;\n"
  "Aye clapping as a mill, I you counsail.\n"
  "\n"
  "\"Nor dread them not, nor do them reverence;\n"
  "For though thine husband armed be in mail,\n"
  "The arrows of thy crabbed eloquence\n"
  "Shall pierce his breast, and eke his aventail;<18>\n"
  "In jealousy I rede* eke thou him bind,                           *advise\n"
  "And thou shalt make him couch* as doth a quail.          *submit, shrink\n"
  "\n"
  "\"If thou be fair, where folk be in presence\n"
  "Shew thou thy visage and thine apparail:\n"
  "If thou be foul, be free of thy dispence;\n"
  "To get thee friendes aye do thy travail:\n"
  "Be aye of cheer as light as leaf on lind,*            *linden, lime-tree\n"
  "And let him care, and weep, and wring, and wail.\"\n"
  "\n"
  "\n"
  "Notes to the Clerk's Tale\n"
  "\n"
  "\n"
  "1. Petrarch, in his Latin romance, \"De obedientia et fide uxoria\n"
  "Mythologia,\" (Of obedient and faithful wives in Mythology)\n"
  "translated the charming story of \"the patient Grizel\" from the\n"
  "Italian of Bocaccio's \"Decameron;\" and Chaucer has closely\n"
  "followed Petrarch's translation, made in 1373, the year before\n"
  "that in which he died.  The fact that the embassy to Genoa, on\n"
  "which Chaucer was sent, took place in 1372-73, has lent\n"
  "countenance to the opinion that the English poet did actually\n"
  "visit the Italian bard at Padua, and hear the story from his own\n"
  "lips.  This, however, is only a probability; for it is a moot point\n"
  "whether the two poets ever met.\n"
  "\n"
  "2. Vesulus:  Monte Viso, a lofty peak at the junction of the\n"
  "Maritime and Cottian Alps; from two springs on its east side\n"
  "rises the Po.\n"
  "\n"
  "3. Buxomly: obediently; Anglo-Saxon, \"bogsom,\" old English,\n"
  "\"boughsome,\" that can be easily bent or bowed; German,\n"
  "\"biegsam,\" pliant, obedient.\n"
  "\n"
  "4. Well ofter of the well than of the tun she drank: she drank\n"
  "water much more often than wine.\n"
  "\n"
  "5. Undern: afternoon, evening, though by some \"undern\"\n"
  "is understood as dinner-time -- 9 a. m. See note 4 to the Wife of\n"
  "Bath's Tale.\n"
  "\n"
  "6. Very: true; French \"vrai\".\n"
  "\n"
  "7. Nouches: Ornaments of some kind not precisely known;\n"
  "some editions read \"ouches,\" studs, brooches. (Transcriber's\n"
  "note: The OED gives \"nouches\" as a form of \"ouches,\"\n"
  "buckles)\n"
  "\n"
  "8. A furlong way or two: a short time; literally, as long as it\n"
  "takes to walk one or two furlongs (a furlong is 220 yards)\n"
  "\n"
  "9. Lordes' hestes may not be y-feign'd: it will not do merely to\n"
  "feign compliance with a lord's commands.\n"
  "\n"
  "10. Arace: tear; French, \"arracher.\"\n"
  "\n"
  "11. Fele: many; German, \"viel.\"\n"
  "\n"
  "12. Dear enough a jane: worth nothing.  A jane was a small coin\n"
  "of little worth, so the meaning is \"not worth a red cent\".\n"
  "\n"
  "13. Mo: me.  \"This is one of the most licentious corruptions of\n"
  "orthography,\" says Tyrwhitt, \"that I remember to have observed\n"
  "in Chaucer;\" but such liberties were common among the\n"
  "European poets of his time,  when there was an extreme lack of\n"
  "certainty in orthography.\n"
  "\n"
  "14. The fourteen lines that follow are translated almost literally\n"
  "from Petrarch's Latin.\n"
  "\n"
  "15. For great skill is he proved that he wrought: for it is most\n"
  "reasonable that He should prove or test that which he made.\n"
  "\n"
  "16. Chichevache, in old popular fable, was a monster that fed\n"
  "only on good women, and was always very thin from scarcity of\n"
  "such food; a corresponding monster, Bycorne, fed only on\n"
  "obedient and kind husbands, and was always fat. The origin of\n"
  "the fable was French; but Lydgate has a ballad on the subject.\n"
  "\"Chichevache\" literally means \"niggardly\" or \"greedy cow.\"\n"
  "\n"
  "17. Countertail: Counter-tally or counter-foil; something exactly\n"
  "corresponding.\n"
  "\n"
  "18. Aventail: forepart of a helmet, vizor.\n"
  "\n"
  "\n"
  "\n"
  "";
// }

const char merchantsTale0[] PGMSECTION = // { // 32218 bytes
  "THE MERCHANT'S TALE.\n"
  "\n"
  "\n"
  "THE PROLOGUE.<l>\n"
  "\n"
  "\n"
  "\"Weeping and wailing, care and other sorrow,\n"
  "I have enough, on even and on morrow,\"\n"
  "Quoth the Merchant, \"and so have other mo',\n"
  "That wedded be; I trow* that it be so;                          *believe\n"
  "For well I wot it fareth so by me.\n"
  "I have a wife, the worste that may be,\n"
  "For though the fiend to her y-coupled were,\n"
  "She would him overmatch, I dare well swear.\n"
  "Why should I you rehearse in special\n"
  "Her high malice? she is *a shrew at all.*                *thoroughly, in\n"
  "There is a long and large difference                  everything wicked*\n"
  "Betwixt Griselda's greate patience,\n"
  "And of my wife the passing cruelty.\n"
  "Were I unbounden, all so may I the,*                             *thrive\n"
  "I woulde never eft* come in the snare.                            *again\n"
  "We wedded men live in sorrow and care;\n"
  "Assay it whoso will, and he shall find\n"
  "That I say sooth, by Saint Thomas of Ind,<2>\n"
  "As for the more part; I say not all, --\n"
  "God shielde* that it shoulde so befall.                          *forbid\n"
  "Ah! good Sir Host, I have y-wedded be\n"
  "These moneths two, and more not, pardie;\n"
  "And yet I trow* that he that all his life                       *believe\n"
  "Wifeless hath been, though that men would him rive*               *wound\n"
  "Into the hearte, could in no mannere\n"
  "Telle so much sorrow, as I you here\n"
  "Could tellen of my wife's cursedness.\"*                      *wickedness\n"
  "\n"
  "\"Now,\" quoth our Host, \"Merchant, so God you bless,\n"
  "Since ye so muche knowen of that art,\n"
  "Full heartily I pray you tell us part.\"\n"
  "\"Gladly,\" quoth he; \"but of mine owen sore,\n"
  "For sorry heart, I telle may no more.\"\n"
  "\n"
  "\n"
  "Notes to the Prologue to the Merchant's Tale\n"
  "\n"
  "\n"
  "1.  Though the manner in which the Merchant takes up the\n"
  "closing words of the Envoy to the Clerk's Tale, and refers to\n"
  "the patience of Griselda, seems to prove beyond doubt that\n"
  "the order of the Tales in the text is the right one, yet in\n"
  "some manuscripts of good authority the Franklin's Tale\n"
  "follows the Clerk's, and the Envoy is concluded by this\n"
  "stanza: --\n"
  "\"This worthy Clerk when ended was his tale,\n"
  "Our Hoste said, and swore by cocke's bones\n"
  "'Me lever were than a barrel of ale\n"
  "My wife at home had heard this legend once;\n"
  "This is a gentle tale for the nonce;\n"
  "As, to my purpose, wiste ye my will.\n"
  "But thing that will not be, let it be still.'\"\n"
  "\n"
  "In other manuscripts of less authority the Host proceeds, in\n"
  "two similar stanzas, to impose a Tale on the Franklin; but\n"
  "Tyrwhitt is probably right in setting them aside as spurious,\n"
  "and in admitting the genuineness of the first only, if it be\n"
  "supposed that Chaucer forgot to cancel it when he had\n"
  "decided on another mode of connecting the Merchant's with\n"
  "the Clerk's Tale.\n"
  "\n"
  "2. Saint Thomas of Ind: St. Thomas the Apostle, who was\n"
  "believed to have travelled in India.\n"
  "\n"
  "\n"
  "THE TALE.<l>\n"
  "\n"
  "\n"
  "Whilom there was dwelling in Lombardy\n"
  "A worthy knight, that born was at Pavie,\n"
  "In which he liv'd in great prosperity;\n"
  "And forty years a wifeless man was he,\n"
  "And follow'd aye his bodily delight\n"
  "On women, where as was his appetite,\n"
  "As do these fooles that be seculeres.<2>\n"
  "And, when that he was passed sixty years,\n"
  "Were it for holiness, or for dotage,\n"
  "I cannot say, but such a great corage*                      *inclination\n"
  "Hadde this knight to be a wedded man,\n"
  "That day and night he did all that he can\n"
  "To espy where that he might wedded be;\n"
  "Praying our Lord to grante him, that he\n"
  "Mighte once knowen of that blissful life\n"
  "That is betwixt a husband and his wife,\n"
  "And for to live under that holy bond\n"
  "With which God firste man and woman bond.\n"
  "\"None other life,\" said he, \"is worth a bean;\n"
  "For wedlock is so easy, and so clean,\n"
  "That in this world it is a paradise.\"\n"
  "Thus said this olde knight, that was so wise.\n"
  "And certainly, as sooth* as God is king,                           *true\n"
  "To take a wife it is a glorious thing,\n"
  "And namely* when a man is old and hoar,                      *especially\n"
  "Then is a wife the fruit of his treasor;\n"
  "Then should he take a young wife and a fair,\n"
  "On which he might engender him an heir,\n"
  "And lead his life in joy and in solace;*                 *mirth, delight\n"
  "Whereas these bachelors singen \"Alas!\"\n"
  "When that they find any adversity\n"
  "In love, which is but childish vanity.\n"
  "And truely it sits* well to be so,                      *becomes, befits\n"
  "That bachelors have often pain and woe:\n"
  "On brittle ground they build, and brittleness\n"
  "They finde when they *weene sickerness:*               *think that there\n"
  "They live but as a bird or as a beast,                      is security*\n"
  "In liberty, and under no arrest;*                        *check, control\n"
  "Whereas a wedded man in his estate\n"
  "Liveth a life blissful and ordinate,\n"
  "Under the yoke of marriage y-bound;\n"
  "Well may his heart in joy and bliss abound.\n"
  "For who can be so buxom* as a wife?                            *obedient\n"
  "Who is so true, and eke so attentive\n"
  "To keep* him, sick and whole, as is his make?**         *care for **mate\n"
  "For weal or woe she will him not forsake:\n"
  "She is not weary him to love and serve,\n"
  "Though that he lie bedrid until he sterve.*                         *die\n"
  "And yet some clerkes say it is not so;\n"
  "Of which he, Theophrast, is one of tho:*                          *those\n"
  "*What force* though Theophrast list for to lie?            *what matter*\n"
  "\n"
  "\"Take no wife,\" quoth he, <3> \"for husbandry,*                   *thrift\n"
  "As for to spare in household thy dispence;\n"
  "A true servant doth more diligence\n"
  "Thy good to keep, than doth thine owen wife,\n"
  "For she will claim a half part all her life.\n"
  "And if that thou be sick, so God me save,\n"
  "Thy very friendes, or a true knave,*                            *servant\n"
  "Will keep thee bet than she, that *waiteth aye          *ahways waits to\n"
  "After thy good,* and hath done many a day.\"       inherit your property*\n"
  "This sentence, and a hundred times worse,\n"
  "Writeth this man, there God his bones curse.\n"
  "But take no keep* of all such vanity,                            *notice\n"
  "Defy* Theophrast, and hearken to me.                           *distrust\n"
  "\n"
  "A wife is Godde's gifte verily;\n"
  "All other manner giftes hardily,*                                 *truly\n"
  "As handes, rentes, pasture, or commune,*                    *common land\n"
  "Or mebles,* all be giftes of fortune,                     *furniture <4>\n"
  "That passen as a shadow on the wall:\n"
  "But dread* thou not, if plainly speak I shall,                    *doubt\n"
  "A wife will last, and in thine house endure,\n"
  "Well longer than thee list, paraventure.*                       *perhaps\n"
  "Marriage is a full great sacrament;\n"
  "He which that hath no wife, I hold him shent;*                   *ruined\n"
  "He liveth helpless, and all desolate\n"
  "(I speak of folk *in secular estate*):                      *who are not\n"
  "And hearken why, I say not this for nought, --            of the clergy*\n"
  "That woman is for manne's help y-wrought.\n"
  "The highe God, when he had Adam maked,\n"
  "And saw him all alone belly naked,\n"
  "God of his greate goodness saide then,\n"
  "Let us now make a help unto this man\n"
  "Like to himself; and then he made him Eve.\n"
  "Here may ye see, and hereby may ye preve,*                        *prove\n"
  "That a wife is man s help and his comfort,\n"
  "His paradise terrestre and his disport.\n"
  "So buxom* and so virtuous is she,                   *obedient, complying\n"
  "They muste needes live in unity;\n"
  "One flesh they be, and one blood, as I guess,\n"
  "With but one heart in weal and in distress.\n"
  "A wife? Ah! Saint Mary, ben'dicite,\n"
  "How might a man have any adversity\n"
  "That hath a wife? certes I cannot say\n"
  "The bliss the which that is betwixt them tway,\n"
  "There may no tongue it tell, or hearte think.\n"
  "If he be poor, she helpeth him to swink;*                        *labour\n"
  "She keeps his good, and wasteth never a deal;*                     *whit\n"
  "All that her husband list, her liketh* well;                   *pleaseth\n"
  "She saith not ones Nay, when he saith Yea;\n"
  "\"Do this,\" saith he; \"All ready, Sir,\" saith she.\n"
  "O blissful order, wedlock precious!\n"
  "Thou art so merry, and eke so virtuous,\n"
  "And so commended and approved eke,\n"
  "That every man that holds him worth a leek\n"
  "Upon his bare knees ought all his life\n"
  "To thank his God, that him hath sent a wife;\n"
  "Or elles pray to God him for to send\n"
  "A wife, to last unto his life's end.\n"
  "For then his life is set in sickerness,*                       *security\n"
  "He may not be deceived, as I guess,\n"
  "So that he work after his wife's rede;*                         *counsel\n"
  "Then may he boldely bear up his head,\n"
  "They be so true, and therewithal so wise.\n"
  "For which, if thou wilt worken as the wise,\n"
  "Do alway so as women will thee rede. *                          *counsel\n"
  "Lo how that Jacob, as these clerkes read,\n"
  "By good counsel of his mother Rebecc'\n"
  "Bounde the kiddes skin about his neck;\n"
  "For which his father's benison* he wan.                     *benediction\n"
  "Lo Judith, as the story telle can,\n"
  "By good counsel she Godde's people kept,\n"
  "And slew him, Holofernes, while he slept.\n"
  "Lo Abigail, by good counsel, how she\n"
  "Saved her husband Nabal, when that he\n"
  "Should have been slain.  And lo, Esther also\n"
  "By counsel good deliver'd out of woe\n"
  "The people of God, and made him, Mardoche,\n"
  "Of Assuere enhanced* for to be.                     *advanced in dignity\n"
  "There is nothing *in gree superlative*                *of higher esteem*\n"
  "(As saith Senec) above a humble wife.\n"
  "Suffer thy wife's tongue, as Cato bit;*                             *bid\n"
  "She shall command, and thou shalt suffer it,\n"
  "And yet she will obey of courtesy.\n"
  "A wife is keeper of thine husbandry:\n"
  "Well may the sicke man bewail and weep,\n"
  "There as there is no wife the house to keep.\n"
  "I warne thee, if wisely thou wilt wirch,*                          *work\n"
  "Love well thy wife, as Christ loveth his church:\n"
  "Thou lov'st thyself, if thou lovest thy wife.\n"
  "No man hateth his flesh, but in his life\n"
  "He fost'reth it; and therefore bid I thee\n"
  "Cherish thy wife, or thou shalt never the.*                      *thrive\n"
  "Husband and wife, what *so men jape or play,*         *although men joke\n"
  "Of worldly folk holde the sicker* way;               and jeer*  *certain\n"
  "They be so knit there may no harm betide,\n"
  "And namely* upon the wife's side.                           * especially\n"
  "\n"
  "For which this January, of whom I told,\n"
  "Consider'd hath within his dayes old,\n"
  "The lusty life, the virtuous quiet,\n"
  "That is in marriage honey-sweet.\n"
  "And for his friends upon a day he sent\n"
  "To tell them the effect  of his intent.\n"
  "With face sad,* his tale he hath them told:              *grave, earnest\n"
  "He saide, \"Friendes, I am hoar and old,\n"
  "And almost (God wot) on my pitte's* brink,                      *grave's\n"
  "Upon my soule somewhat must I think.\n"
  "I have my body foolishly dispended,\n"
  "Blessed be God that it shall be amended;\n"
  "For I will be certain a wedded man,\n"
  "And that anon in all the haste I can,\n"
  "Unto some maiden, fair and tender of age;\n"
  "I pray you shape* for my marriage                    * arrange, contrive\n"
  "All suddenly, for I will not abide:\n"
  "And I will fond* to espy, on my side,                               *try\n"
  "To whom I may be wedded hastily.\n"
  "But forasmuch as ye be more than,\n"
  "Ye shalle rather* such a thing espy\n"
  "Than I, and where me best were to ally.\n"
  "But one thing warn I you, my friendes dear,\n"
  "I will none old wife have in no mannere:\n"
  "She shall not passe sixteen year certain.\n"
  "Old fish and younge flesh would I have fain.\n"
  "Better,\" quoth he, \"a pike than a pickerel,*                 *young pike\n"
  "And better than old beef is tender veal.\n"
  "I will no woman thirty year of age,\n"
  "It is but beanestraw and great forage.\n"
  "And eke these olde widows (God it wot)\n"
  "They conne* so much craft on Wade's boat,<5>                       *know\n"
  "*So muche brooke harm when that them lest,*         *they can do so much\n"
  "That with them should I never live in rest.         harm when they wish*\n"
  "For sundry schooles make subtle clerkes;\n"
  "Woman of many schooles half a clerk is.\n"
  "But certainly a young thing men may guy,*                         *guide\n"
  "Right as men may warm wax with handes ply.*                  *bend,mould\n"
  "Wherefore I say you plainly in a clause,\n"
  "I will none old wife have, right for this cause.\n"
  "For if so were I hadde such mischance,\n"
  "That I in her could have no pleasance,\n"
  "Then should I lead my life in avoutrie,*                       *adultery\n"
  "And go straight to the devil when I die.\n"
  "Nor children should I none upon her getten:\n"
  "Yet *were me lever* houndes had me eaten                *I would rather*\n"
  "Than that mine heritage shoulde fall\n"
  "In strange hands: and this I tell you all.\n"
  "I doubte not I know the cause why\n"
  "Men shoulde wed: and farthermore know I\n"
  "There speaketh many a man of marriage\n"
  "That knows no more of it than doth my page,\n"
  "For what causes a man should take a wife.\n"
  "If he ne may not live chaste his life,\n"
  "Take him a wife with great devotion,\n"
  "Because of lawful procreation\n"
  "Of children, to th' honour of God above,\n"
  "And not only for paramour or love;\n"
  "And for they shoulde lechery eschew,\n"
  "And yield their debte when that it is due:\n"
  "Or for that each of them should help the other\n"
  "In mischief,* as a sister shall the brother,                    *trouble\n"
  "And live in chastity full holily.\n"
  "But, Sires, by your leave, that am not I,\n"
  "For, God be thanked, I dare make avaunt,*                         *boast\n"
  "I feel my limbes stark* and suffisant                            *strong\n"
  "To do all that a man belongeth to:\n"
  "I wot myselfe best what I may do.\n"
  "Though I be hoar, I fare as doth a tree,\n"
  "That blossoms ere the fruit y-waxen* be;                          *grown\n"
  "The blossomy tree is neither dry nor dead;\n"
  "I feel me now here hoar but on my head.\n"
  "Mine heart and all my limbes are as green\n"
  "As laurel through the year is for to seen.*                         *see\n"
  "And, since that ye have heard all mine intent,\n"
  "I pray you to my will ye would assent.\"\n"
  "\n"
  "Diverse men diversely him told\n"
  "Of marriage many examples old;\n"
  "Some blamed it, some praised it, certain;\n"
  "But at the haste, shortly for to sayn\n"
  "(As all day* falleth altercation                  *constantly, every day\n"
  "Betwixte friends in disputation),\n"
  "There fell a strife betwixt his brethren two,\n"
  "Of which that one was called Placebo,\n"
  "Justinus soothly called was that other.\n"
  "\n"
  "Placebo said; \"O January, brother,\n"
  "Full little need have ye, my lord so dear,\n"
  "Counsel to ask of any that is here:\n"
  "But that ye be so full of sapience,\n"
  "That you not liketh, for your high prudence,\n"
  "To waive* from the word of Solomon.                     *depart, deviate\n"
  "This word said he unto us every one;\n"
  "Work alle thing by counsel, -- thus said he, --\n"
  "And thenne shalt thou not repente thee\n"
  "But though that Solomon spake such a word,\n"
  "Mine owen deare brother and my lord,\n"
  "So wisly* God my soule bring at rest,                            *surely\n"
  "I hold your owen counsel is the best.\n"
  "For, brother mine, take of me this motive; *     *advice, encouragement\n"
  "I have now been a court-man all my life,\n"
  "And, God it wot, though I unworthy be,\n"
  "I have standen in full great degree\n"
  "Aboute lordes of full high estate;\n"
  "Yet had I ne'er with none of them debate;\n"
  "I never them contraried truely.\n"
  "I know well that my lord can* more than I;                        *knows\n"
  "What that he saith I hold it firm and stable,\n"
  "I say the same, or else a thing semblable.\n"
  "A full great fool is any counsellor\n"
  "That serveth any lord of high honour\n"
  "That dare presume, or ones thinken it;\n"
  "That his counsel should pass his lorde's wit.\n"
  "Nay, lordes be no fooles by my fay.\n"
  "Ye have yourselfe shewed here to day\n"
  "So high sentence,* so holily and well               *judgment, sentiment\n"
  "That I consent, and confirm *every deal*                *in every point*\n"
  "Your wordes all, and your opinioun\n"
  "By God, there is no man in all this town\n"
  "Nor in Itale, could better have y-said.\n"
  "Christ holds him of this counsel well apaid.*                 *satisfied\n"
  "And truely it is a high courage\n"
  "Of any man that stopen* is in age,                         *advanced <6>\n"
  "To take a young wife, by my father's kin;\n"
  "Your hearte hangeth on a jolly pin.\n"
  "Do now in this matter right as you lest,\n"
  "For finally I hold it for the best.\"\n"
  "\n"
  "Justinus, that aye stille sat and heard,\n"
  "Right in this wise to Placebo answer'd.\n"
  "\"Now, brother mine, be patient I pray,\n"
  "Since ye have said, and hearken what I say.\n"
  "Senec, among his other wordes wise,\n"
  "Saith, that a man ought him right well advise,*                *consider\n"
  "To whom he gives his hand or his chattel.\n"
  "And since I ought advise me right well\n"
  "To whom I give my good away from me,\n"
  "Well more I ought advise me, pardie,\n"
  "To whom I give my body: for alway\n"
  "I warn you well it is no childe's play\n"
  "To take a wife without advisement.\n"
  "Men must inquire (this is mine assent)\n"
  "Whe'er she be wise, or sober, or dronkelew,*             *given to drink\n"
  "Or proud, or any other ways a shrew,\n"
  "A chidester,* or a waster of thy good,                          *a scold\n"
  "Or rich or poor; or else a man is wood.*                            *mad\n"
  "Albeit so, that no man finde shall\n"
  "None in this world, that *trotteth whole in all,*           *is sound in\n"
  "No man, nor beast, such as men can devise,*     every point*  *describe\n"
  "But nathehess it ought enough suffice\n"
  "With any wife, if so were that she had\n"
  "More goode thewes* than her vices bad:                       * qualities\n"
  "And all this asketh leisure to inquere.\n"
  "For, God it wot, I have wept many a tear\n"
  "Full privily, since I have had a wife.\n"
  "Praise whoso will a wedded manne's life,\n"
  "Certes, I find in it but cost and care,\n"
  "And observances of all blisses bare.\n"
  "And yet, God wot, my neighebours about,\n"
  "And namely* of women many a rout,**                *especially **company\n"
  "Say that I have the moste steadfast wife,\n"
  "And eke the meekest one, that beareth life.\n"
  "But I know best where wringeth* me my shoe,                     *pinches\n"
  "Ye may for me right as you like do\n"
  "Advise you, ye be a man of age,\n"
  "How that ye enter into marriage;\n"
  "And namely* with a young wife and a fair,                   * especially\n"
  "By him that made water, fire, earth, air,\n"
  "The youngest man that is in all this rout*                      *company\n"
  "Is busy enough to bringen it about\n"
  "To have his wife alone, truste me:\n"
  "Ye shall not please her fully yeares three,\n"
  "This is to say, to do her full pleasance.\n"
  "A wife asketh full many an observance.\n"
  "I pray you that ye be not *evil apaid.\"*                    *displeased*\n"
  "\n"
  "\"Well,\" quoth this January, \"and hast thou said?\n"
  "Straw for thy Senec, and for thy proverbs,\n"
  "I counte not a pannier full of herbs\n"
  "Of schoole termes; wiser men than thou,\n"
  "As thou hast heard, assented here right now\n"
  "To my purpose: Placebo, what say ye?\"\n"
  "\"I say it is a cursed* man,\" quoth he,              *ill-natured, wicked\n"
  "\"That letteth* matrimony, sickerly.\"                          *hindereth\n"
  "And with that word they rise up suddenly,\n"
  "And be assented fully, that he should\n"
  "Be wedded when him list, and where he would.\n"
  "\n"
  "High fantasy and curious business\n"
  "From day to day gan in the soul impress*             *imprint themselves\n"
  "Of January about his marriage\n"
  "Many a fair  shape, and many a fair visage\n"
  "There passed through his hearte night by night.\n"
  "As whoso took a mirror polish'd bright,\n"
  "And set it in a common market-place,\n"
  "Then should he see many a figure pace\n"
  "By his mirror; and in the same wise\n"
  "Gan January in his thought devise\n"
  "Of maidens, which that dwelte him beside:\n"
  "He wiste not where that he might abide.*           *stay, fix his choice\n"
  "For if that one had beauty in her face,\n"
  "Another stood so in the people's grace\n"
  "For her sadness* and her benignity,                          *sedateness\n"
  "That of the people greatest voice had she:\n"
  "And some were rich and had a badde name.\n"
  "But natheless, betwixt earnest and game,\n"
  "He at the last appointed him on one,\n"
  "And let all others from his hearte gon,\n"
  "And chose her of his own authority;\n"
  "For love is blind all day, and may not see.\n"
  "And when that he was into bed y-brought,\n"
  "He pourtray'd in his heart and in his thought\n"
  "Her freshe beauty, and her age tender,\n"
  "Her middle small, her armes long and slender,\n"
  "Her wise governance, her gentleness,\n"
  "Her womanly bearing, and her sadness.*                       *sedateness\n"
  "And when that he *on her was condescended,*           *had selected her*\n"
  "He thought his choice might not be amended;\n"
  "For when that he himself concluded had,\n"
  "He thought each other manne' s wit so bad,\n"
  "That impossible it were to reply\n"
  "Against his choice; this was his fantasy.\n"
  "His friendes sent he to, at his instance,\n"
  "And prayed them to do him that pleasance,\n"
  "That hastily they would unto him come;\n"
  "He would abridge their labour all and some:\n"
  "Needed no more for them to go nor ride,<7>\n"
  "*He was appointed where he would abide.*            *he had definitively\n"
  "\n"
  "Placebo came, and eke his friendes soon,                made his choice*\n"
  "And *alderfirst he bade them all a boon,*         *first of all he asked\n"
  "That none of them no arguments would make              a favour of them*\n"
  "Against the purpose that he had y-take:\n"
  "Which purpose was pleasant to God, said he,\n"
  "And very ground of his prosperity.\n"
  "He said, there was a maiden in the town,\n"
  "Which that of beauty hadde great renown;\n"
  "All* were it so she were of small degree,                      *although\n"
  "Sufficed him her youth and her beauty;\n"
  "Which maid, he said, he would have to his wife,\n"
  "To lead in ease and holiness his life;\n"
  "And thanked God, that he might have her all,\n"
  "That no wight with his blisse parte* shall;                *have a share\n"
  "And prayed them to labour in this need,\n"
  "And shape that he faile not to speed:\n"
  "For then, he said, his spirit was at ease.\n"
  "\"Then is,\" quoth he, \"nothing may me displease,\n"
  "Save one thing pricketh in my conscience,\n"
  "The which I will rehearse in your presence.\n"
  "I have,\" quoth he, \"heard said, full yore* ago,                    *long\n"
  "There may no man have perfect blisses two,\n"
  "This is to say, on earth and eke in heaven.\n"
  "For though he keep him from the sinne's seven,\n"
  "And eke from every branch of thilke tree,<8>\n"
  "Yet is there so perfect felicity,\n"
  "And so great *ease and lust,* in marriage,        *comfort and pleasure*\n"
  "That ev'r I am aghast,* now in mine age                 *ashamed, afraid\n"
  "That I shall head now so merry a life,\n"
  "So delicate, withoute woe or strife,\n"
  "That I shall have mine heav'n on earthe here.\n"
  "For since that very heav'n is bought so dear,\n"
  "With tribulation and great penance,\n"
  "How should I then, living in such pleasance\n"
  "As alle wedded men do with their wives,\n"
  "Come to the bliss where Christ *etern on live is?*    *lives eternally*\n"
  "This is my dread;* and ye, my brethren tway,                      *doubt\n"
  "Assoile* me this question, I you pray.\"                 *resolve, answer\n"
  "\n"
  "Justinus, which that hated his folly,\n"
  "Answer'd anon right in his japery;*                *mockery, jesting way\n"
  "And, for he would his longe tale abridge,\n"
  "He woulde no authority* allege,                           *written texts\n"
  "But saide; \"Sir, so there be none obstacle\n"
  "Other than this, God of his high miracle,\n"
  "And of his mercy, may so for you wirch,*                           *work\n"
  "That, ere ye have your rights of holy church,\n"
  "Ye may repent of wedded manne's life,\n"
  "In which ye say there is no woe nor strife:\n"
  "And elles God forbid, *but if* he sent                           *unless\n"
  "A wedded man his grace him to repent\n"
  "Well often, rather than a single man.\n"
  "And therefore, Sir, *the beste rede I can,*   *this is the best counsel\n"
  "Despair you not, but have in your memory,                   that I know*\n"
  "Paraventure she may be your purgatory;\n"
  "She may be Godde's means, and Godde's whip;\n"
  "And then your soul shall up to heaven skip\n"
  "Swifter than doth an arrow from a bow.\n"
  "I hope to God hereafter ye shall know\n"
  "That there is none so great felicity\n"
  "In marriage, nor ever more shall be,\n"
  "That you shall let* of your salvation;                           *hinder\n"
  "So that ye use, as skill is and reason,\n"
  "The lustes* of your wife attemperly,**           *pleasures **moderately\n"
  "And that ye please her not too amorously,\n"
  "And that ye keep you eke from other sin.\n"
  "My tale is done, for my wit is but thin.\n"
  "Be not aghast* hereof, my brother dear,                 *aharmed, afraid\n"
  "But let us waden out of this mattere,\n"
  "The Wife of Bath, if ye have understand,\n"
  "Of marriage, which ye have now in hand,\n"
  "Declared hath full well in little space;\n"
  "Fare ye now well, God have you in his grace.\"\n"
  "\n"
  "And with this word this Justin' and his brother\n"
  "Have ta'en their leave, and each of them of other.\n"
  "And when they saw that it must needes be,\n"
  "They wroughte so, by sleight and wise treaty,\n"
  "That she, this maiden, which that *Maius hight,*         *was named May*\n"
  "As hastily as ever that she might,\n"
  "Shall wedded be unto this January.\n"
  "I trow it were too longe you to tarry,\n"
  "If I told you of every *script and band*                  *written bond*\n"
  "By which she was feoffed in his hand;\n"
  "Or for to reckon of her rich array\n"
  "But finally y-comen is the day\n"
  "That to the churche bothe be they went,\n"
  "For to receive the holy sacrament,\n"
  "Forth came the priest, with stole about his neck,\n"
  "And bade her be like Sarah and Rebecc'\n"
  "In wisdom and in truth of marriage;\n"
  "And said his orisons, as is usage,\n"
  "And crouched* them, and prayed God should them bless,           *crossed\n"
  "And made all sicker* enough with holiness.                      *certain\n"
  "\n"
  "Thus be they wedded with solemnity;\n"
  "And at the feaste sat both he and she,\n"
  "With other worthy folk, upon the dais.\n"
  "All full of joy and bliss is the palace,\n"
  "And full of instruments, and of vitaille, *              *victuals, food\n"
  "The moste dainteous* of all Itale.                             *delicate\n"
  "Before them stood such instruments of soun',\n"
  "That Orpheus, nor of Thebes Amphioun,\n"
  "Ne made never such a melody.\n"
  "At every course came in loud minstrelsy,\n"
  "That never Joab trumped for to hear,\n"
  "Nor he, Theodomas, yet half so clear\n"
  "At Thebes, when the city was in doubt.\n"
  "Bacchus the wine them skinked* all about.                    *poured <9>\n"
  "And Venus laughed upon every wight\n"
  "(For January was become her knight,\n"
  "And woulde both assaye his courage\n"
  "In liberty, and eke in marriage),\n"
  "And with her firebrand in her hand about\n"
  "Danced before the bride and all the rout.\n"
  "And certainly I dare right well say this,\n"
  "Hymeneus, that god of wedding is,\n"
  "Saw never his life so merry a wedded man.\n"
  "Hold thou thy peace, thou poet Marcian,<10>\n"
  "That writest us that ilke* wedding merry                           *same\n"
  "Of her Philology and him Mercury,\n"
  "And of the songes that the Muses sung;\n"
  "Too small is both thy pen, and eke thy tongue\n"
  "For to describen of this marriage.\n"
  "When tender youth hath wedded stooping age,\n"
  "There is such mirth that it may not be writ;\n"
  "Assay it youreself, then may ye wit*                               *know\n"
  "If that I lie or no in this mattere.\n"
  "\n"
  "Maius, that sat with so benign a cheer,*                    *countenance\n"
  "Her to behold it seemed faerie;\n"
  "Queen Esther never look'd with such an eye\n"
  "On Assuere, so meek a look had she;\n"
  "I may you not devise all her beauty;\n"
  "But thus much of her beauty tell I may,\n"
  "That she was hike the bright morrow of May\n"
  "Full filled of all beauty and pleasance.\n"
  "This January is ravish'd in a trance,\n"
  "At every time he looked in her face;\n"
  "But in his heart he gan her to menace,\n"
  "That he that night in armes would her strain\n"
  "Harder than ever Paris did Helene.\n"
  "But natheless yet had he great pity\n"
  "That thilke night offende her must he,\n"
  "And thought, \"Alas, O tender creature,\n"
  "Now woulde God ye mighte well endure\n"
  "All my courage, it is so sharp and keen;\n"
  "I am aghast* ye shall it not sustene.                            *afraid\n"
  "But God forbid that I did all my might.\n"
  "Now woulde God that it were waxen night,\n"
  "And that the night would lasten evermo'.\n"
  "I would that all this people were y-go.\"*                     *gone away\n"
  "And finally he did all his labour,\n"
  "As he best mighte, saving his honour,\n"
  "To haste them from the meat in subtle wise.\n"
  "\n"
  "The time came that reason was to rise;\n"
  "And after that men dance, and drinke fast,\n"
  "And spices all about the house they cast,\n"
  "And full of joy and bliss is every man,\n"
  "All but a squire, that highte Damian,\n"
  "Who carv'd before the knight full many a day;\n"
  "He was so ravish'd on his lady May,\n"
  "That for the very pain he was nigh wood;*                           *mad\n"
  "Almost he swelt* and swooned where he stood,                    *fainted\n"
  "So sore had Venus hurt him with her brand,\n"
  "As that she bare it dancing in her hand.\n"
  "And to his bed he went him hastily;\n"
  "No more of him as at this time speak I;\n"
  "But there I let him weep enough and plain,*                      *bewail\n"
  "Till freshe May will rue upon his pain.\n"
  "O perilous fire, that in the bedstraw breedeth!\n"
  "O foe familiar,* that his service bedeth!**     *domestic <11> **offers\n"
  "O servant traitor, O  false homely hewe,*                  *servant <12>\n"
  "Like to the adder in bosom shy untrue,\n"
  "God shield us alle from your acquaintance!\n"
  "O January, drunken in pleasance\n"
  "Of marriage, see how thy Damian,\n"
  "Thine owen squier and thy boren* man,                         *born <13>\n"
  "Intendeth for to do thee villainy:*                  *dishonour, outrage\n"
  "God grante thee thine *homehy foe* t' espy.     *enemy in the household*\n"
  "For in this world is no worse pestilence\n"
  "Than homely foe, all day in thy presence.\n"
  "\n"
  "Performed hath the sun his arc diurn,*                            *daily\n"
  "No longer may the body of him sojourn\n"
  "On the horizon, in that latitude:\n"
  "Night with his mantle, that is dark and rude,\n"
  "Gan overspread the hemisphere about:\n"
  "For which departed is this *lusty rout*               *pleasant company*\n"
  "From January, with thank on every side.\n"
  "Home to their houses lustily they ride,\n"
  "Where as they do their thinges as them lest,\n"
  "And when they see their time they go to rest.\n"
  "Soon after that this hasty* January                               *eager\n"
  "Will go to bed, he will no longer tarry.\n"
  "He dranke hippocras, clarre, and vernage <14>\n"
  "Of spices hot, to increase his courage;\n"
  "And many a lectuary* had he full fine,                           *potion\n"
  "Such as the cursed monk Dan Constantine<15>\n"
  "Hath written in his book *de Coitu;*             *of sexual intercourse*\n"
  "To eat them all he would nothing eschew:\n"
  "And to his privy friendes thus said he:\n"
  "\"For Godde's love, as soon as it may be,\n"
  "Let *voiden all* this house in courteous wise.\"         *everyone leave*\n"
  "And they have done right as he will devise.\n"
  "Men drinken, and the travers* draw anon;                       *curtains\n"
  "The bride is brought to bed as still as stone;\n"
  "And when the bed was with the priest y-bless'd,\n"
  "Out of the chamber every wight him dress'd,\n"
  "And January hath fast in arms y-take\n"
  "His freshe May, his paradise, his make.*                           *mate\n"
  "He lulled her, he kissed her full oft;\n"
  "With thicke bristles of his beard unsoft,\n"
  "Like to the skin of houndfish,* sharp as brere**        *dogfish **briar\n"
  "(For he was shav'n all new in his mannere),\n"
  "He rubbed her upon her tender face,\n"
  "And saide thus; \"Alas! I must trespace\n"
  "To you, my spouse, and you greatly offend,\n"
  "Ere time come that I will down descend.\n"
  "But natheless consider this,\" quoth he,\n"
  "\"There is no workman, whatsoe'er he be,\n"
  "That may both worke well and hastily:\n"
  "This will be done at leisure perfectly.\n"
  "It is *no force* how longe that we play;                     *no matter*\n"
  "In true wedlock coupled be we tway;\n"
  "And blessed be the yoke that we be in,\n"
  "For in our actes may there be no sin.\n"
  "A man may do no sinne with his wife,\n"
  "Nor hurt himselfe with his owen knife;\n"
  "For we have leave to play us by the law.\"\n"
  "\n"
  "Thus labour'd he, till that the day gan daw,\n"
  "And then he took a sop in fine clarre,\n"
  "And upright in his bedde then sat he.\n"
  "And after that he sang full loud and clear,\n"
  "And kiss'd his wife, and made wanton cheer.\n"
  "He was all coltish, full of ragerie *                        *wantonness\n"
  "And full of jargon as a flecked pie.<16>\n"
  "The slacke skin about his necke shaked,\n"
  "While that he sang, so chanted he and craked.*                 *quavered\n"
  "But God wot what that May thought in her heart,\n"
  "When she him saw up sitting in his shirt\n"
  "In his night-cap, and with his necke lean:\n"
  "She praised not his playing worth a bean.\n"
  "Then said he thus; \"My reste will I take\n"
  "Now day is come, I may no longer wake;\n"
  "And down he laid his head and slept till prime.\n"
  "And afterward, when that he saw his time,\n"
  "Up rose January, but freshe May\n"
  "Helde her chamber till the fourthe day,\n"
  "As usage is of wives for the best.\n"
  "For every labour some time must have rest,\n"
  "Or elles longe may he not endure;\n"
  "This is to say, no life of creature,\n"
  "Be it of fish, or bird, or beast, or man.\n"
  "\n"
  "";
// }

const char merchantsTale1[] PGMSECTION = // { // 32200 bytes
  "Now will I speak of woeful Damian,\n"
  "That languisheth for love, as ye shall hear;\n"
  "Therefore I speak to him in this manneare.\n"
  "I say. \"O silly Damian, alas!\n"
  "Answer to this demand, as in this case,\n"
  "How shalt thou to thy lady, freshe May,\n"
  "Telle thy woe? She will alway say nay;\n"
  "Eke if thou speak, she will thy woe bewray; *                    *betray\n"
  "God be thine help, I can no better say.\n"
  "This sicke Damian in Venus' fire\n"
  "So burned that he died for desire;\n"
  "For which he put his life *in aventure,*                       *at risk*\n"
  "No longer might he in this wise endure;\n"
  "But privily a penner* gan he borrow,                       *writing-case\n"
  "And in a letter wrote he all his sorrow,\n"
  "In manner of a complaint or a lay,\n"
  "Unto his faire freshe lady May.\n"
  "And in a purse of silk, hung on his shirt,\n"
  "He hath it put, and laid it at his heart.\n"
  "\n"
  "The moone, that at noon was thilke* day                            *that\n"
  "That January had wedded freshe May,\n"
  "In ten of Taure, was into Cancer glided;<17>\n"
  "So long had Maius in her chamber abided,\n"
  "As custom is unto these nobles all.\n"
  "A bride shall not eaten in the ball\n"
  "Till dayes four, or three days at the least,\n"
  "Y-passed be; then let her go to feast.\n"
  "The fourthe day complete from noon to noon,\n"
  "When that the highe masse was y-done,\n"
  "In halle sat this January, and May,\n"
  "As fresh as is the brighte summer's day.\n"
  "And so befell, how that this goode man\n"
  "Remember'd him upon this Damian.\n"
  "And saide; \"Saint Mary, how may this be,\n"
  "That Damian attendeth not to me?\n"
  "Is he aye sick? or how may this betide?\"\n"
  "His squiers, which that stoode there beside,\n"
  "Excused him, because of his sickness,\n"
  "Which letted* him to do his business:                          *hindered\n"
  "None other cause mighte make him tarry.\n"
  "\"That me forthinketh,\"* quoth this January              *grieves, causes\n"
  "\"He is a gentle squier, by my truth;                          uneasiness\n"
  "If that he died, it were great harm and ruth.\n"
  "He is as wise, as discreet, and secre',*                 *secret, trusty\n"
  "As any man I know of his degree,\n"
  "And thereto manly and eke serviceble,\n"
  "And for to be a thrifty man right able.\n"
  "But after meat, as soon as ever I may\n"
  "I will myself visit him, and eke May,\n"
  "To do him all the comfort that I can.\"\n"
  "And for that word him blessed every man,\n"
  "That of his bounty and his gentleness\n"
  "He woulde so comforten in sickness\n"
  "His squier, for it was a gentle deed.\n"
  "\n"
  "\"Dame,\" quoth this January, \"take good heed,\n"
  "At after meat, ye with your women all\n"
  "(When that ye be in chamb'r out of this hall),\n"
  "That all ye go to see this Damian:\n"
  "Do him disport, he is a gentle man;\n"
  "And telle him that I will him visite,\n"
  "*Have I nothing but rested me a lite:*          *when only I have rested\n"
  "And speed you faste, for I will abide                       me a little*\n"
  "Till that ye sleepe faste by my side.\"\n"
  "And with that word he gan unto him call\n"
  "A squier, that was marshal of his hall,\n"
  "And told him certain thinges that he wo'ld.\n"
  "This freshe May hath straight her way y-hold,\n"
  "With all her women, unto Damian.\n"
  "Down by his beddes side sat she than,*                             *then\n"
  "Comforting him as goodly as she may.\n"
  "This Damian, when that his time he say,*                            *saw\n"
  "In secret wise his purse, and eke his bill,\n"
  "In which that he y-written had his will,\n"
  "Hath put into her hand withoute more,\n"
  "Save that he sighed wondrous deep and sore,\n"
  "And softely to her right thus said he:\n"
  "\"Mercy, and that ye not discover me:\n"
  "For I am dead if that this thing be kid.\"*              *discovered <18>\n"
  "The purse hath she in her bosom hid,\n"
  "And went her way; ye get no more of me;\n"
  "But unto January come is she,\n"
  "That on his bedde's side sat full soft.\n"
  "He took her, and he kissed her full oft,\n"
  "And laid him down to sleep, and that anon.\n"
  "She feigned her as that she muste gon\n"
  "There as ye know that every wight must need;\n"
  "And when she of this bill had taken heed,\n"
  "She rent it all to cloutes* at the last,                      *fragments\n"
  "And in the privy softely it cast.\n"
  "Who studieth* now but faire freshe May?                   *is thoughtful\n"
  "Adown by olde January she lay,\n"
  "That slepte, till the cough had him awaked:\n"
  "Anon he pray'd her strippe her all naked,\n"
  "He would of her, he said, have some pleasance;\n"
  "And said her clothes did him incumbrance.\n"
  "And she obey'd him, be her *lefe or loth.*        *willing or unwilling*\n"
  "But, lest that precious* folk be with me wroth,          *over-nice <19>\n"
  "How that he wrought I dare not to you tell,\n"
  "Or whether she thought it paradise or hell;\n"
  "But there I let them worken in their wise\n"
  "Till evensong ring, and they must arise.\n"
  "\n"
  "Were it by destiny, or aventure,*                               * chance\n"
  "Were it by influence, or by nature,\n"
  "Or constellation, that in such estate\n"
  "The heaven stood at that time fortunate\n"
  "As for to put a bill of Venus' works\n"
  "(For alle thing hath time, as say these clerks),\n"
  "To any woman for to get her love,\n"
  "I cannot say; but greate God above,\n"
  "That knoweth that none act is causeless,\n"
  "*He deem* of all, for I will hold my peace.              *let him judge*\n"
  "But sooth is this, how that this freshe May\n"
  "Hath taken such impression that day\n"
  "Of pity on this sicke Damian,\n"
  "That from her hearte she not drive can\n"
  "The remembrance for *to do him ease.*                        *to satisfy\n"
  "\"Certain,\" thought she, \"whom that this thing displease      his desire*\n"
  "I recke not, for here I him assure,\n"
  "To love him best of any creature,\n"
  "Though he no more haddee than his shirt.\"\n"
  "Lo, pity runneth soon in gentle heart.\n"
  "Here may ye see, how excellent franchise*                    *generosity\n"
  "In women is when they them *narrow advise.*           *closely consider*\n"
  "Some tyrant is, -- as there be many a one, --\n"
  "That hath a heart as hard as any stone,\n"
  "Which would have let him sterven* in the place                      *die\n"
  "Well rather than have granted him her grace;\n"
  "And then rejoicen in her cruel pride.\n"
  "And reckon not to be a homicide.\n"
  "This gentle May, full filled of pity,\n"
  "Right of her hand a letter maked she,\n"
  "In which she granted him her very grace;\n"
  "There lacked nought, but only day and place,\n"
  "Where that she might unto his lust suffice:\n"
  "For it shall be right as he will devise.\n"
  "And when she saw her time upon a day\n"
  "To visit this Damian went this May,\n"
  "And subtilly this letter down she thrust\n"
  "Under his pillow, read it if him lust.*                         *pleased\n"
  "She took him by the hand, and hard him twist\n"
  "So secretly, that no wight of it wist,\n"
  "And bade him be all whole; and forth she went\n"
  "To January, when he for her sent.\n"
  "Up rose Damian the nexte morrow,\n"
  "All passed was his sickness and his sorrow.\n"
  "He combed him, he proined <20> him and picked,\n"
  "He did all that unto his lady liked;\n"
  "And eke to January he went as low\n"
  "As ever did a dogge for the bow.<21>\n"
  "He is so pleasant unto every man\n"
  "(For craft is all, whoso that do it can),\n"
  "Every wight is fain to speak him good;\n"
  "And fully in his lady's grace he stood.\n"
  "Thus leave I Damian about his need,\n"
  "And in my tale forth I will proceed.\n"
  "\n"
  "Some clerke* holde that felicity                      *writers, scholars\n"
  "Stands in delight; and therefore certain he,\n"
  "This noble January, with all his might\n"
  "In honest wise as longeth* to a knight,                       *belongeth\n"
  "Shope* him to live full deliciously:                 *prepared, arranged\n"
  "His housing, his array, as honestly*               *honourably, suitably\n"
  "To his degree was maked as a king's.\n"
  "Amonges other of his honest things\n"
  "He had a garden walled all with stone;\n"
  "So fair a garden wot I nowhere none.\n"
  "For out of doubt I verily suppose\n"
  "That he that wrote the Romance of the Rose <22>\n"
  "Could not of it the beauty well devise;*                       *describe\n"
  "Nor Priapus <23> mighte not well suffice,\n"
  "Though he be god of gardens, for to tell\n"
  "The beauty of the garden, and the well*                        *fountain\n"
  "That stood under a laurel always green.\n"
  "Full often time he, Pluto, and his queen\n"
  "Proserpina, and all their faerie,\n"
  "Disported them and made melody\n"
  "About that well, and danced, as men told.\n"
  "This noble knight, this January old\n"
  "Such dainty* had in it to walk and play,                       *pleasure\n"
  "That he would suffer no wight to bear the key,\n"
  "Save he himself, for of the small wicket\n"
  "He bare always of silver a cliket,*                                 *key\n"
  "With which, when that him list, he it unshet.*                   *opened\n"
  "And when that he would pay his wife's debt,\n"
  "In summer season, thither would he go,\n"
  "And May his wife, and no wight but they two;\n"
  "And thinges which that were not done in bed,\n"
  "He in the garden them perform'd and sped.\n"
  "And in this wise many a merry day\n"
  "Lived this January and fresh May,\n"
  "But worldly joy may not always endure\n"
  "To January, nor to no creatucere.\n"
  "\n"
  "O sudden hap! O thou fortune unstable!\n"
  "Like to the scorpion so deceivable,*                          *deceitful\n"
  "That fhatt'rest with thy head when thou wilt sting;\n"
  "Thy tail is death, through thine envenoming.\n"
  "O brittle joy! O sweete poison quaint!*                         *strange\n"
  "O monster, that so subtilly canst paint\n"
  "Thy giftes, under hue of steadfastness,\n"
  "That thou deceivest bothe *more and less!*             *great and small*\n"
  "Why hast thou January thus deceiv'd,\n"
  "That haddest him for thy full friend receiv'd?\n"
  "And now thou hast bereft him both his eyen,\n"
  "For sorrow of which desireth he to dien.\n"
  "Alas! this noble January free,\n"
  "Amid his lust* and his prosperity                              *pleasure\n"
  "Is waxen blind, and that all suddenly.\n"
  "He weeped and he wailed piteously;\n"
  "And therewithal the fire of jealousy\n"
  "(Lest that his wife should fall in some folly)\n"
  "So burnt his hearte, that he woulde fain,\n"
  "That some man bothe him and her had slain;\n"
  "For neither after his death, nor in his life,\n"
  "Ne would he that she were no love nor wife,\n"
  "But ever live as widow in clothes black,\n"
  "Sole as the turtle that hath lost her make.*                       *mate\n"
  "But at the last, after a month or tway,\n"
  "His sorrow gan assuage, soothe to say.\n"
  "For, when he wist it might none other be,\n"
  "He patiently took his adversity:\n"
  "Save out of doubte he may not foregon\n"
  "That he was jealous evermore-in-one:*                       *continually\n"
  "Which jealousy was so outrageous,\n"
  "That neither in hall, nor in none other house,\n"
  "Nor in none other place never the mo'\n"
  "He woulde suffer her to ride or go,\n"
  "*But if* that he had hand on her alway.                          *unless\n"
  "For which full often wepte freshe May,\n"
  "That loved Damian so burningly\n"
  "That she must either dien suddenly,\n"
  "Or elles she must have him as her lest:*                        *pleased\n"
  "She waited* when her hearte woulde brest.**            *expected **burst\n"
  "Upon that other side Damian\n"
  "Becomen is the sorrowfullest man\n"
  "That ever was; for neither night nor day\n"
  "He mighte speak a word to freshe May,\n"
  "As to his purpose, of no such mattere,\n"
  "*But if* that January must it hear,                             *unless*\n"
  "That had a hand upon her evermo'.\n"
  "But natheless, by writing to and fro,\n"
  "And privy signes, wist he what she meant,\n"
  "And she knew eke the fine* of his intent.                      *end, aim\n"
  "\n"
  "O January, what might it thee avail,\n"
  "Though thou might see as far as shippes sail?\n"
  "For as good is it blind deceiv'd to be,\n"
  "As be deceived when a man may see.\n"
  "Lo, Argus, which that had a hundred eyen, <24>\n"
  "For all that ever he could pore or pryen,\n"
  "Yet was he blent;* and, God wot, so be mo',                    *deceived\n"
  "That *weene wisly* that it be not so:                *think confidently*\n"
  "Pass over is an ease, I say no more.\n"
  "This freshe May, of which I spake yore,*                     *previously\n"
  "In warm wax hath *imprinted the cliket*             *taken an impression\n"
  "That January bare of the small wicket                        of the key*\n"
  "By which into his garden oft he went;\n"
  "And Damian, that knew all her intent,\n"
  "The cliket counterfeited privily;\n"
  "There is no more to say, but hastily\n"
  "Some wonder by this cliket shall betide,\n"
  "Which ye shall hearen, if ye will abide.\n"
  "\n"
  "O noble Ovid, sooth say'st thou, God wot,\n"
  "What sleight is it, if love be long and hot,\n"
  "That he'll not find it out in some mannere?\n"
  "By Pyramus and Thisbe may men lear;*                              *learn\n"
  "Though they were kept full long and strait o'er all,\n"
  "They be accorded,* rowning** through a wall,        *agreed	**whispering\n"
  "Where no wight could have found out such a sleight.\n"
  "But now to purpose; ere that dayes eight\n"
  "Were passed of the month of July, fill*                       *it befell\n"
  "That January caught so great a will,\n"
  "Through egging* of his wife, him for to play                   *inciting\n"
  "In his garden, and no wight but they tway,\n"
  "That in a morning to this May said he: <25>\n"
  "\"Rise up, my wife, my love, my lady free;\n"
  "The turtle's voice is heard, mine owen sweet;\n"
  "The winter is gone, with all his raines weet.*                      *wet\n"
  "Come forth now with thine *eyen columbine*         *eyes like the doves*\n"
  "Well fairer be thy breasts than any wine.\n"
  "The garden is enclosed all about;\n"
  "Come forth, my white spouse; for, out of doubt,\n"
  "Thou hast me wounded in mine heart, O wife:\n"
  "No spot in thee was e'er in all thy life.\n"
  "Come forth, and let us taken our disport;\n"
  "I choose thee for my wife and my comfort.\"\n"
  "Such olde lewed* wordes used he.                      *foolish, ignorant\n"
  "On Damian a signe made she,\n"
  "That he should go before with his cliket.\n"
  "This Damian then hath opened the wicket,\n"
  "And in he start, and that in such mannere\n"
  "That no wight might him either see or hear;\n"
  "And still he sat under a bush. Anon\n"
  "This January, as blind as is a stone,\n"
  "With Maius in his hand, and no wight mo',\n"
  "Into this freshe garden is y-go,\n"
  "And clapped to the wicket suddenly.\n"
  "\"Now, wife,\" quoth he, \"here is but thou and I;\n"
  "Thou art the creature that I beste love:\n"
  "For, by that Lord that sits in heav'n above,\n"
  "Lever* I had to dien on a knife,                                 *rather\n"
  "Than thee offende, deare true wife.\n"
  "For Godde's sake, think how I thee chees,*                        *chose\n"
  "Not for no covetise* doubteless,                          * covetousness\n"
  "But only for the love I had to thee.\n"
  "And though that I be old, and may not see,\n"
  "Be to me true, and I will tell you why.\n"
  "Certes three thinges shall ye win thereby:\n"
  "First, love of Christ, and to yourself honour,\n"
  "And all mine heritage, town and tow'r.\n"
  "I give it you, make charters as you lest;\n"
  "This shall be done to-morrow ere sun rest,\n"
  "So wisly* God my soule bring to bliss!                           *surely\n"
  "I pray you, on this covenant me kiss.\n"
  "And though that I be jealous, wite* me not;                       *blame\n"
  "Ye be so deep imprinted in my thought,\n"
  "That when that I consider your beauty,\n"
  "And therewithal *th'unlikely eld* of me,                *dissimilar age*\n"
  "I may not, certes, though I shoulde die,\n"
  "Forbear to be out of your company,\n"
  "For very love; this is withoute doubt:\n"
  "Now kiss me, wife, and let us roam about.\"\n"
  "\n"
  "This freshe May, when she these wordes heard,\n"
  "Benignely to January answer'd;\n"
  "But first and forward she began to weep:\n"
  "\"I have,\" quoth she, \"a soule for to keep\n"
  "As well as ye, and also mine honour,\n"
  "And of my wifehood thilke* tender flow'r                      *that same\n"
  "Which that I have assured in your hond,\n"
  "When that the priest to you my body bond:\n"
  "Wherefore I will answer in this mannere,\n"
  "With leave of you mine owen lord so dear.\n"
  "I pray to God, that never dawn the day\n"
  "That I *no sterve,* as foul as woman may,                   *do not die*\n"
  "If e'er I do unto my kin that shame,\n"
  "Or elles I impaire so my name,\n"
  "That I bee false; and if I do that lack,\n"
  "Do strippe me, and put me in a sack,\n"
  "And in the nexte river do me drench:*                             *drown\n"
  "I am a gentle woman, and no wench.\n"
  "Why speak ye thus? but men be e'er untrue,\n"
  "And women have reproof of you aye new.\n"
  "Ye know none other dalliance, I believe,\n"
  "But speak to us of untrust and repreve.\"*                       *reproof\n"
  "\n"
  "And with that word she saw where Damian\n"
  "Sat in the bush, and coughe she began;\n"
  "And with her finger signe made she,\n"
  "That Damian should climb upon a tree\n"
  "That charged was with fruit; and up he went:\n"
  "For verily he knew all her intent,\n"
  "And every signe that she coulde make,\n"
  "Better than January her own make.*                                 *mate\n"
  "For in a letter she had told him all\n"
  "Of this matter, how that he worke shall.\n"
  "And thus I leave him sitting in the perry,*                   *pear-tree\n"
  "And January and May roaming full merry.\n"
  "\n"
  "Bright was the day, and blue the firmament;\n"
  "Phoebus of gold his streames down had sent\n"
  "To gladden every flow'r with his warmness;\n"
  "He was that time in Geminis, I guess,\n"
  "But little from his declination\n"
  "Of Cancer, Jove's exaltation.\n"
  "And so befell, in that bright morning-tide,\n"
  "That in the garden, on the farther side,\n"
  "Pluto, that is the king of Faerie,\n"
  "And many a lady in his company\n"
  "Following his wife, the queen Proserpina, --\n"
  "Which that he ravished out of Ethna,<26>\n"
  "While that she gather'd flowers in the mead\n"
  "(In Claudian ye may the story read,\n"
  "How in his grisly chariot he her fet*), --                      *fetched\n"
  "This king of Faerie adown him set\n"
  "Upon a bank of turfes fresh and green,\n"
  "And right anon thus said he to his queen.\n"
  "\"My wife,\" quoth he, \"there may no wight say nay, --\n"
  "Experience so proves it every day, --\n"
  "The treason which that woman doth to man.\n"
  "Ten hundred thousand stories tell I can\n"
  "Notable of your untruth and brittleness *                   *inconstancy\n"
  "O Solomon, richest of all richess,\n"
  "Full fill'd of sapience and worldly glory,\n"
  "Full worthy be thy wordes of memory\n"
  "To every wight that wit and reason can. *                         *knows\n"
  "Thus praised he yet the bounte* of man:                        *goodness\n"
  "'Among a thousand men yet found I one,\n"
  "But of all women found I never none.' <27>\n"
  "Thus said this king, that knew your wickedness;\n"
  "And Jesus, Filius Sirach, <28> as I guess,\n"
  "He spake of you but seldom reverence.\n"
  "A wilde fire and corrupt pestilence\n"
  "So fall upon your bodies yet to-night!\n"
  "Ne see ye not this honourable knight?\n"
  "Because, alas! that he is blind and old,\n"
  "His owen man shall make him cuckold.\n"
  "Lo, where he sits, the lechour, in the tree.\n"
  "Now will I granten, of my majesty,\n"
  "Unto this olde blinde worthy knight,\n"
  "That he shall have again his eyen sight,\n"
  "When that his wife will do him villainy;\n"
  "Then shall be knowen all her harlotry,\n"
  "Both in reproof of her and other mo'.\"\n"
  "\"Yea, Sir,\" quoth Proserpine,\" and will ye so?\n"
  "Now by my mother Ceres' soul I swear\n"
  "That I shall give her suffisant answer,\n"
  "And alle women after, for her sake;\n"
  "That though they be in any guilt y-take,\n"
  "With face bold they shall themselves excuse,\n"
  "And bear them down that woulde them accuse.\n"
  "For lack of answer, none of them shall dien.\n"
  "\n"
  "All* had ye seen a thing with both your eyen,                  *although\n"
  "Yet shall *we visage it* so hardily,                       *confront it*\n"
  "And weep, and swear, and chide subtilly,\n"
  "That ye shall be as lewed* as be geese.            *ignorant, confounded\n"
  "What recketh me of your authorities?\n"
  "I wot well that this Jew, this Solomon,\n"
  "Found of us women fooles many one:\n"
  "But though that he founde no good woman,\n"
  "Yet there hath found many another man\n"
  "Women full good, and true, and virtuous;\n"
  "Witness on them that dwelt in Christes house;\n"
  "With martyrdom they proved their constance.\n"
  "The Roman gestes <29> make remembrance\n"
  "Of many a very true wife also.\n"
  "But, Sire, be not wroth, albeit so,\n"
  "Though that he said he found no good woman,\n"
  "I pray you take the sentence* of the man:         *opinion, real meaning\n"
  "He meant thus, that in *sovereign bounte*              *perfect goodness\n"
  "Is none but God, no, neither *he nor she.*               *man nor woman*\n"
  "Hey, for the very God that is but one,\n"
  "Why make ye so much of Solomon?\n"
  "What though he made a temple, Godde's house?\n"
  "What though he were rich and glorious?\n"
  "So made he eke a temple of false goddes;\n"
  "How might he do a thing that more forbode* is?                *forbidden\n"
  "Pardie, as fair as ye his name emplaster,*   *plaster over, \"whitewash\"\n"
  "He was a lechour, and an idolaster,*                           *idohater\n"
  "And in his eld he very* God forsook.                           *the true\n"
  "And if that God had not (as saith the book)\n"
  "Spared him for his father's sake, he should\n"
  "Have lost his regne* rather** than he would.           *kingdom **sooner\n"
  "I *sette not of*  all the villainy                           *value not*\n"
  "That he of women wrote, a butterfly.\n"
  "I am a woman, needes must I speak,\n"
  "Or elles swell until mine hearte break.\n"
  "For since he said that we be jangleresses,*                  *chatterers\n"
  "As ever may I brooke* whole my tresses,                        *preserve\n"
  "I shall not spare for no courtesy\n"
  "To speak him harm, that said us villainy.\"\n"
  "\"Dame,\" quoth this Pluto, \"be no longer wroth;\n"
  "I give it up: but, since I swore mine oath\n"
  "That I would grant to him his sight again,\n"
  "My word shall stand, that warn I you certain:\n"
  "I am a king; it sits* me not to lie.\"                   *becomes, befits\n"
  "\"And I,\" quoth she, \"am queen of Faerie.\n"
  "Her answer she shall have, I undertake,\n"
  "Let us no more wordes of it make.\n"
  "Forsooth, I will no longer you contrary.\"\n"
  "\n"
  "Now let us turn again to January,\n"
  "That in the garden with his faire May\n"
  "Singeth well merrier than the popinjay:*                         *parrot\n"
  "\"You love I best, and shall, and other none.\"\n"
  "So long about the alleys is he gone,\n"
  "Till he was come to *that ilke perry,*              *the same pear-tree*\n"
  "Where as this Damian satte full merry\n"
  "On high, among the freshe leaves green.\n"
  "This freshe May, that is so bright and sheen,\n"
  "Gan for to sigh, and said, \"Alas my side!\n"
  "Now, Sir,\" quoth she, \"for aught that may betide,\n"
  "I must have of the peares that I see,\n"
  "Or I must die, so sore longeth me\n"
  "To eaten of the smalle peares green;\n"
  "Help, for her love that is of heaven queen!\n"
  "I tell you well, a woman in my plight <30>\n"
  "May have to fruit so great an appetite,\n"
  "That she may dien, but* she of it have. \"                        *unless\n"
  "\"Alas!\" quoth he, \"that I had here a knave*                     *servant\n"
  "That coulde climb; alas! alas!\" quoth he,\n"
  "\"For I am blind.\"  \"Yea, Sir, *no force,\"* quoth she;        *no matter*\n"
  "\"But would ye vouchesafe, for Godde's sake,\n"
  "The perry in your armes for to take\n"
  "(For well I wot that ye mistruste me),\n"
  "Then would I climbe well enough,\" quoth she,\n"
  "\"So I my foot might set upon your back.\"\n"
  "\"Certes,\" said he, \"therein shall be no lack,\n"
  "Might I you helpe with mine hearte's blood.\"\n"
  "He stooped down, and on his back she stood,\n"
  "And caught her by a twist,* and up she go'th.               *twig, bough\n"
  "(Ladies, I pray you that ye be not wroth,\n"
  "I cannot glose,* I am a rude man):                        *mince matters\n"
  "And suddenly anon this Damian\n"
  "Gan pullen up the smock, and in he throng.*                 *rushed <31>\n"
  "And when that Pluto saw this greate wrong,\n"
  "To January he gave again his sight,\n"
  "And made him see as well as ever he might.\n"
  "And when he thus had caught his sight again,\n"
  "Was never man of anything so fain:\n"
  "But on his wife his thought was evermo'.\n"
  "Up to the tree he cast his eyen two,\n"
  "And saw how Damian his wife had dress'd,\n"
  "In such mannere, it may not be express'd,\n"
  "*But if* I woulde speak uncourteously.                          *unless*\n"
  "And up he gave a roaring and a cry,\n"
  "As doth the mother when the child shall die;\n"
  "\"Out! help! alas! harow!\" he gan to cry;\n"
  "\"O stronge, lady, stowre! <32> what doest thou?\"\n"
  "\n"
  "And she answered: \"Sir, what aileth you?\n"
  "Have patience and reason in your mind,\n"
  "I have you help'd on both your eyen blind.\n"
  "On peril of my soul, I shall not lien,\n"
  "As me was taught to helpe with your eyen,\n"
  "Was nothing better for to make you see,\n"
  "Than struggle with a man upon a tree:\n"
  "God wot, I did it in full good intent.\"\n"
  "\"Struggle!\" quoth he, \"yea, algate* in it went.            *whatever way\n"
  "God give you both one shame's death to dien!\n"
  "He swived* thee; I saw it with mine eyen;              *enjoyed carnally\n"
  "And elles be I hanged by the halse.\"*                              *neck\n"
  "\"Then is,\" quoth she, \"my medicine all false;\n"
  "For certainly, if that ye mighte see,\n"
  "Ye would not say these wordes unto me.\n"
  "Ye have some glimpsing,* and no perfect sight.\"              *glimmering\n"
  "\"I see,\" quoth he, \"as well as ever I might,\n"
  "(Thanked be God!) with both mine eyen two,\n"
  "And by my faith me thought he did thee so.\"\n"
  "\"Ye maze,*  ye maze, goode Sir,\" quoth she;          *rave, are confused\n"
  "\"This thank have I for I have made you see:\n"
  "Alas!\" quoth she, \"that e'er I was so kind.\"\n"
  "\"Now, Dame,\" quoth he, \"let all pass out of mind;\n"
  "Come down, my lefe,* and if I have missaid,                        *love\n"
  "God help me so, as I am *evil apaid.*                     *dissatisfied*\n"
  "But, by my father's soul, I ween'd have seen\n"
  "How that this Damian had by thee lain,\n"
  "And that thy smock had lain upon his breast.\"\n"
  "\"Yea, Sir,\" quoth she, \"ye may *ween as ye lest:*          *think as you\n"
  "But, Sir, a man that wakes out of his sleep,                     please*\n"
  "He may not suddenly well take keep*                              *notice\n"
  "Upon a thing, nor see it perfectly,\n"
  "Till that he be adawed* verily.                                *awakened\n"
  "Right so a man, that long hath blind y-be,\n"
  "He may not suddenly so well y-see,\n"
  "First when his sight is newe come again,\n"
  "As he that hath a day or two y-seen.\n"
  "Till that your sight establish'd be a while,\n"
  "There may full many a sighte you beguile.\n"
  "Beware, I pray you, for, by heaven's king,\n"
  "Full many a man weeneth to see a thing,\n"
  "And it is all another than it seemeth;\n"
  "He which that misconceiveth oft misdeemeth.\"\n"
  "And with that word she leapt down from the tree.\n"
  "This January, who is glad but he?\n"
  "He kissed her, and clipped* her full oft,                      *embraced\n"
  "And on her womb he stroked her full soft;\n"
  "And to his palace home he hath her lad.*                            *led\n"
  "Now, goode men, I pray you to be glad.\n"
  "Thus endeth here my tale of January,\n"
  "God bless us, and his mother, Sainte Mary.\n"
  "\n"
  "\n"
  "Notes to The Merchant's Tale\n"
  "\n"
  "\n"
  "1. If, as is probable, this Tale was translated from the French,\n"
  "the original is not now extant. Tyrwhitt remarks that the scene\n"
  "\"is laid in Italy, but none of the names, except Damian and\n"
  "Justin, seem to be Italian,  but rather made at pleasure; so that I\n"
  "doubt whether the story be really of Italian growth. The\n"
  "adventure of the pear-tree I find in a small collection of Latin\n"
  "fables, written by one Adoiphus, in elegiac verses of his fashion,\n"
  "in the year 1315. . . . Whatever was the real origin of the Tale,\n"
  "the machinery of the fairies, which Chaucer has used so happily,\n"
  "was probably added by himself; and, indeed, I cannot help\n"
  "thinking that his Pluto and Proserpina were the true progenitors\n"
  "of Oberon and Titania; or rather, that they themselves have,\n"
  "once at least, deigned to revisit our poetical system under the\n"
  "latter names.\"\n"
  "\n"
  "2. Seculeres: of the laity; but perhaps, since the word is of two-\n"
  "fold meaning, Chaucer intends a hit at the secular clergy, who,\n"
  "unlike the regular orders, did not live separate from the world,\n"
  "but shared in all its interests and pleasures -- all the more easily\n"
  "and freely, that they had not the civil restraint of marriage.\n"
  "\n"
  "3. This and the next eight lines are taken from the \"Liber\n"
  "aureolus Theophrasti de nuptiis,\" (\"Theophrastus's Golden\n"
  "Book of Marriage\") quoted by Hieronymus, \"Contra\n"
  "Jovinianum,\" (\"Against Jovinian\") and thence again by John of\n"
  "Salisbury.\n"
  "\n"
  "4. Mebles: movables, furniture, &c.; French, \"meubles.\"\n"
  "\n"
  "5. \"Wade's boat\" was called Guingelot; and in it, according to\n"
  "the old romance, the owner underwent a long series of wild\n"
  "adventures, and performed many strange exploits.  The romance\n"
  "is lost, and therefore  the exact force of the phrase in the text is\n"
  "uncertain; but Mr Wright seems to be warranted in supposing\n"
  "that Wade's adventures were cited as examples of craft and\n"
  "cunning -- that the hero, in fact, was a kind of Northern\n"
  "Ulysses,  It is possible that to the same source we may trace the\n"
  "proverbial phrase, found in Chaucer's \"Remedy of Love,\" to\n"
  "\"bear Wattis pack\" signifying to be duped or beguiled.\n"
  "\n"
  "6. Stopen: advanced; past participle of \"step.\" Elsewhere\n"
  "\"y-stept in age\" is used by Chaucer.\n"
  "\n"
  "7. They did not need to go in quest of a wife for him, as they\n"
  "had promised.\n"
  "\n"
  "8. Thilke tree: that tree of original sin, of which the special sins\n"
  "are the branches.\n"
  "\n"
  "9. Skinked:  poured out; from Anglo-Saxon, \"scencan.\"\n"
  "\n"
  "10. Marcianus Capella, who wrote a kind of philosophical\n"
  "romance, \"De Nuptiis Mercurii et Philologiae\" (Of the Marriage\n"
  "of Mercury and Philology) . \"Her\" and \"him,\" two lines after,\n"
  "like \"he\" applied to Theodomas, are prefixed to the proper\n"
  "names for emphasis, according to the Anglo- Saxon usage.\n"
  "\n"
  "11. Familiar: domestic; belonging to the \"familia,\" or household.\n"
  "\n"
  "12. Hewe: domestic servant; from Anglo-Saxon, \"hiwa.\"\n"
  "Tyrwhitt reads \"false of holy hue;\" but Mr Wright has properly\n"
  "restored the reading adopted in the text.\n"
  "\n"
  "13. Boren man: born; owing to January faith and loyalty\n"
  "because born in his household.\n"
  "\n"
  "14. Hippocras: spiced wine. Clarre: also a kind of spiced wine.\n"
  "Vernage: a wine believed to have come from Crete, although its\n"
  "name -- Italian,  \"Vernaccia\" -- seems to be derived from\n"
  "Verona.\n"
  "\n"
  "15. Dan Constantine: a medical author who wrote about 1080;\n"
  "his works were printed at Basle in 1536.\n"
  "\n"
  "16. Full of jargon as a flecked pie: he chattered like a magpie\n"
  "\n"
  "17. Nearly all the manuscripts read \"in two of Taure;\" but\n"
  "Tyrwhitt has shown that, setting out from the second degree of\n"
  "Taurus, the moon, which in the four complete days that Maius\n"
  "spent in her chamber could not have advanced more than fifty-\n"
  "three degrees, would only have been at the twenty-fifth degree\n"
  "of Gemini -- whereas, by reading \"ten,\" she is brought to the\n"
  "third degree of Cancer.\n"
  "\n"
  "18. Kid; or \"kidde,\" past participle of  \"kythe\" or \"kithe,\" to\n"
  "show or discover.\n"
  "\n"
  "19. Precious:  precise, over-nice; French, \"precieux,\" affected.\n"
  "\n"
  "20. Proined: or \"pruned;\" carefully trimmed and dressed\n"
  "himself. The word is used in falconry of a hawk when she picks\n"
  "and trims her feathers.\n"
  "\n"
  "21. A dogge for the bow: a dog attending a hunter with the\n"
  "bow.\n"
  "\n"
  "22  The Romance of the Rose: a very popular mediaeval\n"
  "romance, the English version of which is partly by Chaucer. It\n"
  "opens with a description of a beautiful garden.\n"
  "\n"
  "23. Priapus:  Son of Bacchus and Venus: he was regarded as\n"
  "the promoter of fertility in all agricultural life, vegetable and\n"
  "animal; while not only gardens, but fields, flocks, bees -- and\n"
  "even fisheries -- were supposed to be under his protection.\n"
  "\n"
  "24. Argus was employed by Juno to watch Io with his hundred\n"
  "eyes but he was sent to sleep by the flute of Mercury, who then\n"
  "cut off his head.\n"
  "\n"
  "25. \"My beloved spake, and said unto me, Rise up, my love, my\n"
  "fair one, and come away. For lo, the winter is past, the rain is\n"
  "over and gone: The flowers appear on the earth, the time of the\n"
  "singing of the birds is come, and the voice of the turtle is heard\n"
  "in our land.\"\n"
  "-- Song of Solomon, ii. 10-12.\n"
  "\n"
  "26.                \"That fair field,\n"
  "Of Enna, where Proserpine, gath'ring flowers,\n"
  "Herself a fairer flow'r, by gloomy Dis\n"
  "Was gather'd.\"\n"
  "-- Milton, Paradise Lost, iv. 268\n"
  "\n"
  "27. \"Behold, this have I found, saith the preacher, counting one\n"
  "by one, to find out the account:\n"
  "Which yet my soul seeketh, but I find not: one man amongst a\n"
  "thousand have I found, but a woman among all those I have not\n"
  "found.\n"
  "Lo, this only have I found, that God hath made man upright.\"\n"
  "Ecclesiastes vii. 27-29.\n"
  "\n"
  "28. Jesus, the son of Sirach, to whom is ascribed one of the\n"
  "books of the Apochrypha -- that called the \"Wisdom of Jesus\n"
  "the Son of Sirach, or Ecclesiasticus;\"  in which, especially in the\n"
  "ninth and twenty-fifth chapters, severe cautions are given\n"
  "against women.\n"
  "\n"
  "29. Roman gestes: histories; such as those of Lucretia, Porcia,\n"
  "&c.\n"
  "\n"
  "30. May means January to believe that she is pregnant, and that\n"
  "she has a craving for unripe pears.\n"
  "\n"
  "31. At this point, and again some twenty lines below, several\n"
  "verses of a very coarse character had been inserted in later\n"
  "manuscripts; but they are evidently spurious, and are omitted in\n"
  "the best editions.\n"
  "\n"
  "32. \"Store\" is the general reading here, but its meaning is not\n"
  "obvious.  \"Stowre\" is found in several manuscripts; it signifies\n"
  "\"struggle\" or \"resist;\" and both for its own appropriateness, and\n"
  "for the force which it gives the word \"stronge,\" the reading in\n"
  "the text seems the better.\n"
  "\n"
  "\n"
  "\n"
  "";
// }

const char squiresTale0[] PGMSECTION = // { // 21395 bytes
  "THE SQUIRE'S TALE.\n"
  "\n"
  "\n"
  "THE PROLOGUE.\n"
  "\n"
  "\n"
  "\"HEY! Godde's mercy!\" said our Hoste tho,*                         *then\n"
  "\"Now such a wife I pray God keep me fro'.\n"
  "Lo, suche sleightes and subtilities\n"
  "In women be; for aye as busy as bees\n"
  "Are they us silly men for to deceive,\n"
  "And from the soothe* will they ever weive,**     *truth **swerve, depart\n"
  "As this Merchante's tale it proveth well.\n"
  "But natheless, as true as any steel,\n"
  "I have a wife, though that she poore be;\n"
  "But of her tongue a labbing* shrew is she;                   *chattering\n"
  "And yet* she hath a heap of vices mo'.                         *moreover\n"
  "Thereof *no force;* let all such thinges go.                 *no matter*\n"
  "But wit* ye what? in counsel** be it said,    *know **secret, confidence\n"
  "Me rueth sore I am unto her tied;\n"
  "For, an'* I shoulde reckon every vice                                *if\n"
  "Which that she hath, y-wis* I were too nice;**      *certainly **foolish\n"
  "And cause why, it should reported be\n"
  "And told her by some of this company\n"
  "(By whom, it needeth not for to declare,\n"
  "Since women connen utter such chaffare <1>),\n"
  "And eke my wit sufficeth not thereto\n"
  "To tellen all; wherefore my tale is do.*                           *done\n"
  "Squier, come near, if it your wille be,\n"
  "And say somewhat of love, for certes ye\n"
  "*Conne thereon* as much as any man.\"                     *know about it*\n"
  "\"Nay, Sir,\" quoth he; \"but such thing as I can,\n"
  "With hearty will, -- for I will not rebel\n"
  "Against your lust,* -- a tale will I tell.                     *pleasure\n"
  "Have me excused if I speak amiss;\n"
  "My will is good; and lo, my tale is this.\"\n"
  "\n"
  "\n"
  "Notes to the Prologue to the Squire's Tale\n"
  "\n"
  "\n"
  "1. Women connen utter such chaffare: women are adepts at\n"
  "giving circulation to such wares.  The Host evidently means that\n"
  "his wife would be sure to hear of his confessions from some\n"
  "female member of the company.\n"
  "\n"
  "\n"
  "THE TALE.<1>\n"
  "\n"
  "\n"
  "*Pars Prima.*                                               *First part*\n"
  "\n"
  "At Sarra, in the land of Tartary,\n"
  "There dwelt a king that warrayed* Russie, <2>               *made war on\n"
  "Through which there died many a doughty man;\n"
  "This noble king was called Cambuscan,<3>\n"
  "Which in his time was of so great renown,\n"
  "That there was nowhere in no regioun\n"
  "So excellent a lord in alle thing:\n"
  "Him lacked nought that longeth to a king,\n"
  "As of the sect of which that he was born.\n"
  "He kept his law to which he was y-sworn,\n"
  "And thereto* he was hardy, wise, and rich,            *moreover, besides\n"
  "And piteous and just, always y-lich;*              *alike, even-tempered\n"
  "True of his word, benign and honourable;\n"
  "*Of his corage as any centre stable;*        *firm, immovable of spirit*\n"
  "Young, fresh, and strong, in armes desirous\n"
  "As any bachelor of all his house.\n"
  "A fair person he was, and fortunate,\n"
  "And kept alway so well his royal estate,\n"
  "That there was nowhere such another man.\n"
  "This noble king, this Tartar Cambuscan,\n"
  "Hadde two sons by Elfeta his wife,\n"
  "Of which the eldest highte Algarsife,\n"
  "The other was y-called Camballo.\n"
  "A daughter had this worthy king also,\n"
  "That youngest was, and highte Canace:\n"
  "But for to telle you all her beauty,\n"
  "It lies not in my tongue, nor my conning;*                        *skill\n"
  "I dare not undertake so high a thing:\n"
  "Mine English eke is insufficient,\n"
  "It muste be a rhetor* excellent,                                 *orator\n"
  "*That couth his colours longing for that art,*                * see <4>*\n"
  "If he should her describen any part;\n"
  "I am none such, I must speak as I can.\n"
  "\n"
  "And so befell, that when this Cambuscan\n"
  "Had twenty winters borne his diadem,\n"
  "As he was wont from year to year, I deem,\n"
  "He let *the feast of his nativity*                  *his birthday party*\n"
  "*Do crye,* throughout Sarra his city,                    *be proclaimed*\n"
  "The last Idus of March, after the year.\n"
  "Phoebus the sun full jolly was and clear,\n"
  "For he was nigh his exaltation\n"
  "In Marte's face, and in his mansion <5>\n"
  "In Aries, the choleric hot sign:\n"
  "Full lusty* was the weather and benign;                        *pleasant\n"
  "For which the fowls against the sunne sheen,*                    *bright\n"
  "What for the season and the younge green,\n"
  "Full loude sange their affections:\n"
  "Them seemed to have got protections\n"
  "Against the sword of winter keen and cold.\n"
  "This Cambuscan, of which I have you told,\n"
  "In royal vesture, sat upon his dais,\n"
  "With diadem, full high in his palace;\n"
  "And held his feast so solemn and so rich,\n"
  "That in this worlde was there none it lich.*                       *like\n"
  "Of which if I should tell all the array,\n"
  "Then would it occupy a summer's day;\n"
  "And eke it needeth not for to devise*                          *describe\n"
  "At every course the order of service.\n"
  "I will not tellen of their strange sewes,*                   *dishes <6>\n"
  "Nor of their swannes, nor their heronsews.*            *young herons <7>\n"
  "Eke in that land, as telle knightes old,\n"
  "There is some meat that is full dainty hold,\n"
  "That in this land men *reck of* it full small:                *care for*\n"
  "There is no man that may reporten all.\n"
  "I will not tarry you, for it is prime,\n"
  "And for it is no fruit, but loss of time;\n"
  "Unto my purpose* I will have recourse.                        *story <8>\n"
  "And so befell that, after the third course,\n"
  "While that this king sat thus in his nobley,*               *noble array\n"
  "Hearing his ministreles their thinges play\n"
  "Before him at his board deliciously,\n"
  "In at the halle door all suddenly\n"
  "There came a knight upon a steed of brass,\n"
  "And in his hand a broad mirror of glass;\n"
  "Upon his thumb he had of gold a ring,\n"
  "And by his side a naked sword hanging:\n"
  "And up he rode unto the highe board.\n"
  "In all the hall was there not spoke a word,\n"
  "For marvel of this knight; him to behold\n"
  "Full busily they waited,* young and old.                        *watched\n"
  "\n"
  "This strange knight, that came thus suddenly,\n"
  "All armed, save his head, full richely,\n"
  "Saluted king, and queen, and lordes all,\n"
  "By order as they satten in the hall,\n"
  "With so high reverence and observance,\n"
  "As well in speech as in his countenance,\n"
  "That Gawain <9> with his olde courtesy,\n"
  "Though he were come again out of Faerie,\n"
  "Him *coulde not amende with a word.*               *could not better him\n"
  "And after this, before the highe board,                     by one word*\n"
  "He with a manly voice said his message,\n"
  "After the form used in his language,\n"
  "Withoute vice* of syllable or letter.                             *fault\n"
  "And, for his tale shoulde seem the better,\n"
  "Accordant to his worde's was his cheer,*                      *demeanour\n"
  "As teacheth art of speech them that it lear.*                     *learn\n"
  "Albeit that I cannot sound his style,\n"
  "Nor cannot climb over so high a stile,\n"
  "Yet say I this, as to *commune intent,*       *general sense or meaning*\n"
  "*Thus much amounteth* all that ever he meant,       *this is the sum of*\n"
  "If it so be that I have it in mind.\n"
  "He said; \"The king of Araby and Ind,\n"
  "My liege lord, on this solemne day\n"
  "Saluteth you as he best can and may,\n"
  "And sendeth you, in honour of your feast,\n"
  "By me, that am all ready at your hest,*                         *command\n"
  "This steed of brass, that easily and well\n"
  "Can in the space of one day naturel\n"
  "(This is to say, in four-and-twenty hours),\n"
  "Whereso you list, in drought or else in show'rs,\n"
  "Beare your body into every place\n"
  "To which your hearte willeth for to pace,*                     *pass, go\n"
  "Withoute wem* of you, through foul or fair.                *hurt, injury\n"
  "Or if you list to fly as high in air\n"
  "As doth an eagle, when him list to soar,\n"
  "This same steed shall bear you evermore\n"
  "Withoute harm, till ye be where *you lest*              *it pleases you*\n"
  "(Though that ye sleepen on his back, or rest),\n"
  "And turn again, with writhing* of a pin.                       *twisting\n"
  "He that it wrought, he coude* many a gin;**     *knew **contrivance <10>\n"
  "He waited* in any a constellation,                             *observed\n"
  "Ere he had done this operation,\n"
  "And knew full many a seal <11> and many a bond\n"
  "This mirror eke, that I have in mine hond,\n"
  "Hath such a might, that men may in it see\n"
  "When there shall fall any adversity\n"
  "Unto your realm, or to yourself also,\n"
  "And openly who is your friend or foe.\n"
  "And over all this, if any lady bright\n"
  "Hath set her heart on any manner wight,\n"
  "If he be false, she shall his treason see,\n"
  "His newe love, and all his subtlety,\n"
  "So openly that there shall nothing hide.\n"
  "Wherefore, against this lusty summer-tide,\n"
  "This mirror, and this ring that ye may see,\n"
  "He hath sent to my lady Canace,\n"
  "Your excellente daughter that is here.\n"
  "The virtue of this ring, if ye will hear,\n"
  "Is this, that if her list it for to wear\n"
  "Upon her thumb, or in her purse it bear,\n"
  "There is no fowl that flyeth under heaven,\n"
  "That she shall not well understand his steven,*           *speech, sound\n"
  "And know his meaning openly and plain,\n"
  "And answer him in his language again:\n"
  "And every grass that groweth upon root\n"
  "She shall eke know, to whom it will do boot,*                    *remedy\n"
  "All be his woundes ne'er so deep and wide.\n"
  "This naked sword, that hangeth by my side,\n"
  "Such virtue hath, that what man that it smite,\n"
  "Throughout his armour it will carve and bite,\n"
  "Were it as thick as is a branched oak:\n"
  "And what man is y-wounded with the stroke\n"
  "Shall ne'er be whole, till that you list, of grace,\n"
  "To stroke him with the flat in thilke* place                   *the same\n"
  "Where he is hurt; this is as much to sayn,\n"
  "Ye muste with the flatte sword again\n"
  "Stroke him upon the wound, and it will close.\n"
  "This is the very sooth, withoute glose;*                         *deceit\n"
  "It faileth not, while it is in your hold.\"\n"
  "\n"
  "And when this knight had thus his tale told,\n"
  "He rode out of the hall, and down he light.\n"
  "His steede, which that shone as sunne bright,\n"
  "Stood in the court as still as any stone.\n"
  "The knight is to his chamber led anon,\n"
  "And is unarmed, and to meat y-set.*                              *seated\n"
  "These presents be full richely y-fet,* --                       *fetched\n"
  "This is to say, the sword and the mirrour, --\n"
  "And borne anon into the highe tow'r,\n"
  "With certain officers ordain'd therefor;\n"
  "And unto Canace the ring is bore\n"
  "Solemnely, where she sat at the table;\n"
  "But sickerly, withouten any fable,\n"
  "The horse of brass, that may not be remued.*               *removed <12>\n"
  "It stood as it were to the ground y-glued;\n"
  "There may no man out of the place it drive\n"
  "For no engine of windlass or polive; *                           *pulley\n"
  "And cause why, for they *can not the craft;*       *know not the cunning\n"
  "And therefore in the place they have it laft,          of the mechanism*\n"
  "Till that the knight hath taught them the mannere\n"
  "To voide* him, as ye shall after hear.                           *remove\n"
  "\n"
  "Great was the press, that swarmed to and fro\n"
  "To gauren* on this horse that stoode so:                           *gaze\n"
  "For it so high was, and so broad and long,\n"
  "So well proportioned for to be strong,\n"
  "Right as it were a steed of Lombardy;\n"
  "Therewith so horsely, and so quick of eye,\n"
  "As it a gentle Poileis <13> courser were:\n"
  "For certes, from his tail unto his ear\n"
  "Nature nor art ne could him not amend\n"
  "In no degree, as all the people wend.*                  *weened, thought\n"
  "But evermore their moste wonder was\n"
  "How that it coulde go, and was of brass;\n"
  "It was of Faerie, as the people seem'd.\n"
  "Diverse folk diversely they deem'd;\n"
  "As many heads, as many wittes been.\n"
  "They murmured, as doth a swarm of been,*                           *bees\n"
  "And made skills* after their fantasies,                         *reasons\n"
  "Rehearsing of the olde poetries,\n"
  "And said that it was like the Pegasee,*                         *Pegasus\n"
  "The horse that hadde winges for to flee;*                           *fly\n"
  "Or else it was the Greeke's horse Sinon,<14>\n"
  "That broughte Troye to destruction,\n"
  "As men may in the olde gestes* read.                *tales of adventures\n"
  "Mine heart,\" quoth one, \"is evermore in dread;\n"
  "I trow some men of armes be therein,\n"
  "That shape* them this city for to win:                  *design, prepare\n"
  "It were right good that all such thing were know.\"\n"
  "Another rowned* to his fellow low,                            *whispered\n"
  "And said, \"He lies; for it is rather like\n"
  "An apparence made by some magic,\n"
  "As jugglers playen at these feastes great.\"\n"
  "Of sundry doubts they jangle thus and treat.\n"
  "As lewed* people deeme commonly                                *ignorant\n"
  "Of thinges that be made more subtilly\n"
  "Than they can in their lewdness comprehend;\n"
  "They *deeme gladly to the badder end.*               *are ready to think\n"
  "And some of them wonder'd on the mirrour,                     the worst*\n"
  "That borne was up into the master* tow'r,                    *chief <15>\n"
  "How men might in it suche thinges see.\n"
  "Another answer'd and said, it might well be\n"
  "Naturally by compositions\n"
  "Of angles, and of sly reflections;\n"
  "And saide that in Rome was such a one.\n"
  "They speak of Alhazen and Vitellon,<16>\n"
  "And Aristotle, that wrote in their lives\n"
  "Of quainte* mirrors, and of prospectives,                       *curious\n"
  "As knowe they that have their bookes heard.\n"
  "And other folk have wonder'd on the swerd,*                       *sword\n"
  "That woulde pierce throughout every thing;\n"
  "And fell in speech of Telephus the king,\n"
  "And of Achilles for his quainte spear, <17>\n"
  "For he could with it bothe heal and dere,*                        *wound\n"
  "Right in such wise as men may with the swerd\n"
  "Of which right now ye have yourselves heard.\n"
  "They spake of sundry hard'ning of metal,\n"
  "And spake of medicines therewithal,\n"
  "And how, and when, it shoulde harden'd be,\n"
  "Which is unknowen algate* unto me.                              *however\n"
  "Then spake they of Canacee's ring,\n"
  "And saiden all, that such a wondrous thing\n"
  "Of craft of rings heard they never none,\n"
  "Save that he, Moses, and King Solomon,\n"
  "Hadden *a name of conning* in such art.                *a reputation for\n"
  "Thus said the people, and drew them apart.                    knowledge*\n"
  "Put natheless some saide that it was\n"
  "Wonder to maken of fern ashes glass,\n"
  "And yet is glass nought like ashes of fern;\n"
  "*But for* they have y-knowen it so ferne**        *because **before <18>\n"
  "Therefore ceaseth their jangling and their wonder.\n"
  "As sore wonder some on cause of thunder,\n"
  "On ebb and flood, on gossamer and mist,\n"
  "And on all things, till that the cause is wist.*                  *known\n"
  "Thus jangle they, and deemen and devise,\n"
  "Till that the king gan from his board arise.\n"
  "\n"
  "Phoebus had left the angle meridional,\n"
  "And yet ascending was the beast royal,\n"
  "The gentle Lion, with his Aldrian, <19>\n"
  "When that this Tartar king, this Cambuscan,\n"
  "Rose from the board, there as he sat full high\n"
  "Before him went the loude minstrelsy,\n"
  "Till he came to his chamber of parements,<20>\n"
  "There as they sounded diverse instruments,\n"
  "That it was like a heaven for to hear.\n"
  "Now danced lusty Venus' children dear:\n"
  "For in the Fish* their lady sat full                             *Pisces\n"
  "And looked on them with a friendly eye. <21>\n"
  "This noble king is set upon his throne;\n"
  "This strange knight is fetched to him full sone,*                  *soon\n"
  "And on the dance he goes with Canace.\n"
  "Here is the revel and the jollity,\n"
  "That is not able a dull man to devise:*                        *describe\n"
  "He must have knowen love and his service,\n"
  "And been a feastly* man, as fresh as May,                    *merry, gay\n"
  "That shoulde you devise such array.\n"
  "Who coulde telle you the form of dances\n"
  "So uncouth,* and so freshe countenances**          *unfamliar **gestures\n"
  "Such subtle lookings and dissimulances,\n"
  "For dread of jealous men's apperceivings?\n"
  "No man but Launcelot,<22> and he is dead.\n"
  "Therefore I pass o'er all this lustihead*                  *pleasantness\n"
  "I say no more, but in this jolliness\n"
  "I leave them, till to supper men them dress.\n"
  "The steward bids the spices for to hie*                           *haste\n"
  "And eke the wine, in all this melody;\n"
  "The ushers and the squiers be y-gone,\n"
  "The spices and the wine is come anon;\n"
  "They eat and drink, and when this hath an end,\n"
  "Unto the temple, as reason was, they wend;\n"
  "The service done, they suppen all by day\n"
  "What needeth you rehearse their array?\n"
  "Each man wot well, that at a kinge's feast\n"
  "Is plenty, to the most*, and to the least,                      *highest\n"
  "And dainties more than be in my knowing.\n"
  "\n"
  "At after supper went this noble king\n"
  "To see the horse of brass, with all a rout\n"
  "Of lordes and of ladies him about.\n"
  "Such wond'ring was there on this horse of brass,\n"
  "That, since the great siege of Troye was,\n"
  "There as men wonder'd on a horse also,\n"
  "Ne'er was there such a wond'ring as was tho.*                     *there\n"
  "But finally the king asked the knight\n"
  "The virtue of this courser, and the might,\n"
  "And prayed him to tell his governance.*            *mode of managing him\n"
  "The horse anon began to trip and dance,\n"
  "When that the knight laid hand upon his rein,\n"
  "And saide, \"Sir, there is no more to sayn,\n"
  "But when you list to riden anywhere,\n"
  "Ye muste trill* a pin, stands in his ear,                     *turn <23>\n"
  "Which I shall telle you betwixt us two;\n"
  "Ye muste name him to what place also,\n"
  "Or to what country that you list to ride.\n"
  "And when ye come where you list abide,\n"
  "Bid him descend, and trill another pin\n"
  "(For therein lies th' effect of all the gin*),         *contrivance <10>\n"
  "And he will down descend and do your will,\n"
  "And in that place he will abide still;\n"
  "Though all the world had the contrary swore,\n"
  "He shall not thence be throwen nor be bore.\n"
  "Or, if you list to bid him thennes gon,\n"
  "Trill this pin, and he will vanish anon\n"
  "Out of the sight of every manner wight,\n"
  "And come again, be it by day or night,\n"
  "When that you list to clepe* him again                             *call\n"
  "In such a guise, as I shall to you sayn\n"
  "Betwixte you and me, and that full soon.\n"
  "Ride <24> when you list, there is no more to do'n.'\n"
  "Informed when the king was of the knight,\n"
  "And had conceived in his wit aright\n"
  "The manner and the form of all this thing,\n"
  "Full glad and blithe, this noble doughty king\n"
  "Repaired to his revel as beforn.\n"
  "The bridle is into the tower borne,\n"
  "And kept among his jewels lefe* and dear;                     *cherished\n"
  "The horse vanish'd, I n'ot* in what mannere,                   *know not\n"
  "Out of their sight; ye get no more of me:\n"
  "But thus I leave in lust and jollity\n"
  "This Cambuscan his lordes feastying,*                 *entertaining <25>\n"
  "Until well nigh the day began to spring.\n"
  "\n"
  "\n"
  "*Pars Secunda.*                                            *Second Part*\n"
  "\n"
  "\n"
  "The norice* of digestion, the sleep,                              *nurse\n"
  "Gan on them wink, and bade them take keep,*                        *heed\n"
  "That muche mirth and labour will have rest.\n"
  "And with a gaping* mouth he all them kest,**           *yawning **kissed\n"
  "And said, that it was time to lie down,\n"
  "For blood was in his dominatioun: <26>\n"
  "\"Cherish the blood, nature's friend,\" quoth he.\n"
  "They thanked him gaping, by two and three;\n"
  "And every wight gan draw him to his rest;\n"
  "As sleep them bade, they took it for the best.\n"
  "Their dreames shall not now be told for me;\n"
  "Full are their heades of fumosity,<27>\n"
  "That caused dreams *of which there is no charge:*   *of no significance*\n"
  "They slepte; till that, it was *prime large,*             *late morning*\n"
  "The moste part, but* it was Canace;                              *except\n"
  "She was full measurable,* as women be:                         *moderate\n"
  "For of her father had she ta'en her leave\n"
  "To go to rest, soon after it was eve;\n"
  "Her liste not appalled* for to be;                         *to look pale\n"
  "Nor on the morrow *unfeastly for to see;*       *to look sad, depressed*\n"
  "And slept her firste sleep; and then awoke.\n"
  "For such a joy she in her hearte took\n"
  "Both of her quainte a ring and her mirrour,.\n"
  "That twenty times she changed her colour;\n"
  "And in her sleep, right for th' impression\n"
  "Of her mirror, she had a vision.\n"
  "Wherefore, ere that the sunne gan up glide,\n"
  "She call'd upon her mistress'* her beside,                  *governesses\n"
  "And saide, that her liste for to rise.\n"
  "\n"
  "These olde women, that be gladly wise\n"
  "As are her mistresses answer'd anon,\n"
  "And said; \"Madame, whither will ye gon\n"
  "Thus early? for the folk be all in rest.\"\n"
  "\"I will,\" quoth she, \"arise; for me lest\n"
  "No longer for to sleep, and walk about.\"\n"
  "Her mistresses call'd women a great rout,\n"
  "And up they rose, well a ten or twelve;\n"
  "Up rose freshe Canace herselve,\n"
  "As ruddy and bright as is the yonnge sun\n"
  "That in the Ram is four degrees y-run;\n"
  "No higher was he, when she ready was;\n"
  "And forth she walked easily a pace,\n"
  "Array'd after the lusty* season swoot,**               *pleasant **sweet\n"
  "Lightely for to play, and walk on foot,\n"
  "Nought but with five or six of her meinie;\n"
  "And in a trench* forth in the park went she.                *sunken path\n"
  "The vapour, which up from the earthe glode,*                     *glided\n"
  "Made the sun to seem ruddy and broad:\n"
  "But, natheless, it was so fair a sight\n"
  "That it made all their heartes for to light,*        *be lightened, glad\n"
  "What for the season and the morrowning,\n"
  "And for the fowles that she hearde sing.\n"
  "For right anon she wiste* what they meant                          *knew\n"
  "Right by their song, and knew all their intent.\n"
  "The knotte,* why that every tale is told,         *nucleus, chief matter\n"
  "If it be tarried* till the list* be cold         *delayed  **inclination\n"
  "Of them that have it hearken'd *after yore,*           *for a long time*\n"
  "The savour passeth ever longer more;\n"
  "For fulsomness of the prolixity:\n"
  "And by that same reason thinketh me.\n"
  "I shoulde unto the knotte condescend,\n"
  "And maken of her walking soon an end.\n"
  "\n"
  "";
// }

const char squiresTale1[] PGMSECTION = // { // 19974 bytes
  "Amid a tree fordry*, as white as chalk,             *thoroughly dried up\n"
  "There sat a falcon o'er her head full high,\n"
  "That with a piteous voice so gan to cry;\n"
  "That all the wood resounded of her cry,\n"
  "And beat she had herself so piteously\n"
  "With both her winges, till the redde blood\n"
  "Ran endelong* the tree, there as she stood           *from top to bottom\n"
  "And ever-in-one* alway she cried and shright;**  *incessantly **shrieked\n"
  "And with her beak herselfe she so pight,*                       *wounded\n"
  "That there is no tiger, nor cruel beast,\n"
  "That dwelleth either in wood or in forest;\n"
  "But would have wept, if that he weepe could,\n"
  "For sorrow of her; she shriek'd alway so loud.\n"
  "For there was never yet no man alive,\n"
  "If that he could a falcon well descrive;*                      *describe\n"
  "That heard of such another of fairness\n"
  "As well of plumage, as of gentleness;\n"
  "Of shape, of all that mighte reckon'd be.\n"
  "A falcon peregrine seemed she,\n"
  "Of fremde* land; and ever as she stood                     *foreign <28>\n"
  "She swooned now and now for lack of blood;\n"
  "Till well-nigh is she fallen from the tree.\n"
  "\n"
  "This faire kinge's daughter Canace,\n"
  "That on her finger bare the quainte ring,\n"
  "Through which she understood well every  thing\n"
  "That any fowl may in his leden* sayn,                    **language <29>\n"
  "And could him answer in his leden again;\n"
  "Hath understoode what this falcon said,\n"
  "And well-nigh for the ruth* almost she died;.                      *pity\n"
  "And to the tree she went, full hastily,\n"
  "And on this falcon looked piteously;\n"
  "And held her lap abroad; for well she wist\n"
  "The falcon muste falle from the twist*                      *twig, bough\n"
  "When that she swooned next, for lack of blood.\n"
  "A longe while to waite her she stood;\n"
  "Till at the last she apake in this mannere\n"
  "Unto the hawk, as ye shall after hear:\n"
  "\"What is the cause, if it be for to tell,\n"
  "That ye be in this furial* pain of hell?\"               *raging, furious\n"
  "Quoth Canace unto this hawk above;\n"
  "\"Is this for sorrow of of death; or loss of love?\n"
  "For; as I trow,* these be the causes two;                       *believe\n"
  "That cause most a gentle hearte woe:\n"
  "Of other harm it needeth not to speak.\n"
  "For ye yourself upon yourself awreak;*                          *inflict\n"
  "Which proveth well, that either ire or dread*                      *fear\n"
  "Must be occasion of your cruel deed,\n"
  "Since that I see none other wight you chase:\n"
  "For love of God, as *do yourselfe grace;*                 *have mercy on\n"
  "Or what may be your help? for, west nor east,                  yourself*\n"
  "I never saw ere now no bird nor beast\n"
  "That fared with himself so piteously\n"
  "Ye slay me with your sorrow verily;\n"
  "I have of you so great compassioun.\n"
  "For Godde's love come from the tree adown\n"
  "And, as I am a kinge's daughter true,\n"
  "If that I verily the causes knew\n"
  "Of your disease,* if it lay in my might,                       *distress\n"
  "I would amend it, ere that it were night,\n"
  "So wisly help me the great God of kind.**               *surely **nature\n"
  "And herbes shall I right enoughe find,\n"
  "To heale with your hurtes hastily.\"\n"
  "Then shriek'd this falcon yet more piteously\n"
  "Than ever she did, and fell to ground anon,\n"
  "And lay aswoon, as dead as lies a stone,\n"
  "Till Canace had in her lap her take,\n"
  "Unto that time she gan of swoon awake:\n"
  "And, after that she out of swoon abraid,*                         *awoke\n"
  "Right in her hawke's leden thus she said:\n"
  "\n"
  "\"That pity runneth soon in gentle heart\n"
  "(Feeling his simil'tude in paines smart),\n"
  "Is proved every day, as men may see,\n"
  "As well *by work as by authority;*        *by experience as by doctrine*\n"
  "For gentle hearte kitheth* gentleness.                          *sheweth\n"
  "I see well, that ye have on my distress\n"
  "Compassion, my faire Canace,\n"
  "Of very womanly benignity\n"
  "That nature in your princples hath set.\n"
  "But for no hope for to fare the bet,*                            *better\n"
  "But for t' obey unto your hearte free,\n"
  "And for to make others aware by me,\n"
  "As by the whelp chastis'd* is the lion,           *instructed, corrected\n"
  "Right for that cause and that conclusion,\n"
  "While that I have a leisure and a space,\n"
  "Mine harm I will confessen ere I pace.\"*                         *depart\n"
  "And ever while the one her sorrow told,\n"
  "The other wept, *as she to water wo'ld,*       *as if she would dissolve\n"
  "Till that the falcon bade her to be still,                   into water*\n"
  "And with a sigh right thus she said *her till:*                 *to her*\n"
  "\"Where I was bred (alas that ilke* day!)                           *same\n"
  "And foster'd in a rock of marble gray\n"
  "So tenderly, that nothing ailed me,\n"
  "I wiste* not what was adversity,                                   *knew\n"
  "Till I could flee* full high under the sky.                         *fly\n"
  "Then dwell'd a tercelet <30> me faste by,\n"
  "That seem'd a well of alle gentleness;\n"
  "*All were he* full of treason and falseness,           *although he was*\n"
  "It was so wrapped *under humble cheer,*                 *under an aspect\n"
  "And under hue of truth, in such mannere,                    of humility*\n"
  "Under pleasance, and under busy pain,\n"
  "That no wight weened that he coulde feign,\n"
  "So deep in grain he dyed his colours.\n"
  "Right as a serpent hides him under flow'rs,\n"
  "Till he may see his time for to bite,\n"
  "Right so this god of love's hypocrite\n"
  "Did so his ceremonies and obeisances,\n"
  "And kept in semblance all his observances,\n"
  "That *sounden unto* gentleness of love.               *are consonant to*\n"
  "As on a tomb is all the fair above,\n"
  "And under is the corpse, which that ye wet,\n"
  "Such was this hypocrite, both cold and hot;\n"
  "And in this wise he served his intent,\n"
  "That, save the fiend, none wiste what he meant:\n"
  "Till he so long had weeped and complain'd,\n"
  "And many a year his service to me feign'd,\n"
  "Till that mine heart, too piteous and too nice,*        *foolish, simple\n"
  "All innocent of his crowned malice,\n"
  "*Forfeared of his death,* as thoughte me,           *greatly afraid lest\n"
  "Upon his oathes and his surety                            he should die*\n"
  "Granted him love, on this conditioun,\n"
  "That evermore mine honour and renown\n"
  "Were saved, bothe *privy and apert;*           *privately and in public*\n"
  "This is to say, that, after his desert,\n"
  "I gave him all my heart and all my thought\n"
  "(God wot, and he, that *other wayes nought*),          *in no other way*\n"
  "And took his heart in change of mine for aye.\n"
  "But sooth is said, gone since many a day,\n"
  "A true wight and a thiefe *think not one.*          *do not think alike*\n"
  "And when he saw the thing so far y-gone,\n"
  "That I had granted him fully my love,\n"
  "In such a wise as I have said above,\n"
  "And given him my true heart as free\n"
  "As he swore that he gave his heart to me,\n"
  "Anon this tiger, full of doubleness,\n"
  "Fell on his knees with so great humbleness,\n"
  "With so high reverence, as by his cheer,*                          *mien\n"
  "So like a gentle lover in mannere,\n"
  "So ravish'd, as it seemed, for the joy,\n"
  "That never Jason, nor Paris of Troy, --\n"
  "Jason? certes, nor ever other man,\n"
  "Since Lamech <31> was, that alderfirst* began              *first of all\n"
  "To love two, as write folk beforn,\n"
  "Nor ever since the firste man was born,\n"
  "Coulde no man, by twenty thousand\n"
  "Counterfeit the sophimes* of his art;         *sophistries, beguilements\n"
  "Where doubleness of feigning should approach,\n"
  "Nor worthy were t'unbuckle his galoche,*                      *shoe <32>\n"
  "Nor could so thank a wight, as he did me.\n"
  "His manner was a heaven for to see\n"
  "To any woman, were she ne'er so wise;\n"
  "So painted he and kempt,* *at point devise,*            *combed, studied\n"
  "As well his wordes as his countenance.          *with perfect precision*\n"
  "And I so lov'd him for his obeisance,\n"
  "And for the truth I deemed in his heart,\n"
  "That, if so were that any thing him smart,*                      *pained\n"
  "All were it ne'er so lite,* and I it wist,                       *little\n"
  "Methought I felt death at my hearte twist.\n"
  "And shortly, so farforth this thing is went,*                      *gone\n"
  "That my will was his wille's instrument;\n"
  "That is to say, my will obey'd his will\n"
  "In alle thing, as far as reason fill,*                    *fell; allowed\n"
  "Keeping the boundes of my worship ever;\n"
  "And never had I thing *so lefe, or lever,*          *so dear, or dearer*\n"
  "As him, God wot, nor never shall no mo'.\n"
  "\n"
  "\"This lasted longer than a year or two,\n"
  "That I supposed of him naught but good.\n"
  "But finally, thus at the last it stood,\n"
  "That fortune woulde that he muste twin*                *depart, separate\n"
  "Out of that place which that I was in.\n"
  "Whe'er* me was woe, it is no question;                          *whether\n"
  "I cannot make of it description.\n"
  "For one thing dare I telle boldely,\n"
  "I know what is the pain of death thereby;\n"
  "Such harm I felt, for he might not byleve.*                   *stay <33>\n"
  "So on a day of me he took his leave,\n"
  "So sorrowful eke, that I ween'd verily,\n"
  "That he had felt as muche harm as I,\n"
  "When that I heard him speak, and saw his hue.\n"
  "But natheless, I thought he was so true,\n"
  "And eke that he repaire should again\n"
  "Within a little while, sooth to sayn,\n"
  "And reason would eke that he muste go\n"
  "For his honour, as often happ'neth so,\n"
  "That I made virtue of necessity,\n"
  "And took it well, since that it muste be.\n"
  "As I best might, I hid from him my sorrow,\n"
  "And took him by the hand, Saint John to borrow,*        *witness, pledge\n"
  "And said him thus; 'Lo, I am youres all;\n"
  "Be such as I have been to you, and shall.'\n"
  "What he answer'd, it needs not to rehearse;\n"
  "Who can say bet* than he, who can do worse?                      *better\n"
  "When he had all well said, then had he done.\n"
  "Therefore behoveth him a full long spoon,\n"
  "That shall eat with a fiend; thus heard I say.\n"
  "So at the last he muste forth his way,\n"
  "And forth he flew, till he came where him lest.\n"
  "When it came him to purpose for to rest,\n"
  "I trow that he had thilke text in mind,\n"
  "That alle thing repairing to his kind\n"
  "Gladdeth himself; <34> thus say men, as I guess;\n"
  "*Men love of [proper] kind newfangleness,*               *see note <35>*\n"
  "As birdes do, that men in cages feed.\n"
  "For though thou night and day take of them heed,\n"
  "And strew their cage fair and soft as silk,\n"
  "And give them sugar, honey, bread, and milk,\n"
  "Yet, *right anon as that his door is up,*            *immediately on his\n"
  "He with his feet will spurne down his cup,            door being opened*\n"
  "And to the wood he will, and wormes eat;\n"
  "So newefangle be they of their meat,\n"
  "And love novelties, of proper kind;\n"
  "No gentleness of bloode may them bind.\n"
  "So far'd this tercelet, alas the day!\n"
  "Though he were gentle born, and fresh, and gay,\n"
  "And goodly for to see, and humble, and free,\n"
  "He saw upon a time a kite flee,*                                    *fly\n"
  "And suddenly he loved this kite so,\n"
  "That all his love is clean from me y-go:\n"
  "And hath his trothe falsed in this wise.\n"
  "Thus hath the kite my love in her service,\n"
  "And I am lorn* withoute remedy.\"                           *lost, undone\n"
  "\n"
  "And with that word this falcon gan to cry,\n"
  "And swooned eft* in Canacee's barme**                       *again **lap\n"
  "Great was the sorrow, for that hawke's harm,\n"
  "That Canace and all her women made;\n"
  "They wist not how they might the falcon glade.*                 *gladden\n"
  "But Canace home bare her in her lap,\n"
  "And softely in plasters gan her wrap,\n"
  "There as she with her beak had hurt herselve.\n"
  "Now cannot Canace but herbes delve\n"
  "Out of the ground, and make salves new\n"
  "Of herbes precious and fine of hue,\n"
  "To heale with this hawk; from day to night\n"
  "She did her business, and all her might.\n"
  "And by her bedde's head she made a mew,*                      *bird cage\n"
  "And cover'd it with velouettes* blue,<36>                       *velvets\n"
  "In sign of truth that is in woman seen;\n"
  "And all without the mew is painted green,\n"
  "In which were painted all these false fowls,\n"
  "As be these tidifes,* tercelets, and owls;                      *titmice\n"
  "And pies, on them for to cry and chide,\n"
  "Right for despite were painted them beside.\n"
  "\n"
  "Thus leave I Canace her hawk keeping.\n"
  "I will no more as now speak of her ring,\n"
  "Till it come eft* to purpose for to sayn                          *again\n"
  "How that this falcon got her love again\n"
  "Repentant, as the story telleth us,\n"
  "By mediation of Camballus,\n"
  "The kinge's son of which that I you told.\n"
  "But henceforth I will my process hold\n"
  "To speak of aventures, and of battailes,\n"
  "That yet was never heard so great marvailles.\n"
  "First I will telle you of Cambuscan,\n"
  "That in his time many a city wan;\n"
  "And after will I speak of Algarsife,\n"
  "How he won Theodora to his wife,\n"
  "For whom full oft in great peril he was,\n"
  "*N'had he* been holpen by the horse of brass.               *had he not*\n"
  "And after will I speak of Camballo, <37>\n"
  "That fought in listes with the brethren two\n"
  "For Canace, ere that he might her win;\n"
  "And where I left I will again begin.\n"
  "        .        .        .        .     <38>\n"
  "\n"
  "\n"
  "Notes to the Squire's Tale\n"
  "\n"
  "\n"
  "1. The Squire's Tale has not been found under any other form\n"
  "among the literary remains of the Middle Ages; and it is\n"
  "unknown from what original it was derived, if from any. The\n"
  "Tale is unfinished, not because the conclusion has been lost, but\n"
  "because the author left it so.\n"
  "\n"
  "2. The Russians and Tartars waged constant hostilities between\n"
  "the thirteenth and sixteenth centuries.\n"
  "\n"
  "3. In the best manuscripts the name is \"Cambynskan,\" and thus,\n"
  "no doubt, it should strictly be read. But it is a most pardonable\n"
  "offence against literal accuracy to use the word which Milton\n"
  "has made classical, in \"Il Penseroso,\" speaking of\n"
  "\n"
  "           \"him that left half-told\n"
  "The story of Cambuscan bold,\n"
  "Of Camball, and of Algarsife,\n"
  "And who had Canace to wife,\n"
  "That owned the virtuous Ring and Glass,\n"
  "And of the wondrous Horse of Brass,\n"
  "On which the Tartar King did ride\"\n"
  "\n"
  "Surely the admiration of Milton might well seem to the spirit of\n"
  "Chaucer to condone a much greater transgression on his domain\n"
  "than this verbal change -- which to both eye and ear is an\n"
  "unquestionable improvement on the uncouth original.\n"
  "\n"
  "4. Couth his colours longing for that art: well skilled in using\n"
  "the colours -- the word-painting -- belonging to his art.\n"
  "\n"
  "5. Aries was the mansion of Mars -- to whom \"his\" applies.\n"
  "Leo was the mansion of the Sun.\n"
  "\n"
  "6. Sewes:  Dishes, or soups. The precise force of the word is\n"
  "uncertain; but it may be connected with \"seethe,\" to boil, and it\n"
  "seems to describe a dish in which the flesh was served up amid a\n"
  "kind of broth or gravy. The \"sewer,\" taster or assayer of the\n"
  "viands served at great tables, probably derived his name from\n"
  "the verb to \"say\" or \"assay;\" though Tyrwhitt would connect\n"
  "the two words, by taking both from the French, \"asseoir,\" to\n"
  "place -- making the arrangement of the table the leading duty of\n"
  "the \"sewer,\" rather than the testing of the food.\n"
  "\n"
  "7. Heronsews: young herons; French, \"heronneaux.\"\n"
  "\n"
  "8. Purpose: story, discourse; French, \"propos.\"\n"
  "\n"
  "9. Gawain was celebrated in mediaeval romance as the most\n"
  "courteous among King Arthur's knights.\n"
  "\n"
  "10. Gin: contrivance; trick; snare. Compare Italian, \"inganno,\"\n"
  "deception; and our own \"engine.\"\n"
  "\n"
  "11. Mr Wright remarks that \"the making and arrangement of\n"
  "seals was one of the important operations of mediaeval magic.\"\n"
  "\n"
  "12. Remued: removed; French, \"remuer,\" to stir.\n"
  "\n"
  "13. Polies:  Apulian. The horses of Apulia -- in old French\n"
  "\"Poille,\" in Italian \"Puglia\" -- were held in high value.\n"
  "\n"
  "14. The Greeke's horse Sinon: the wooden horse of the Greek\n"
  "Sinon, introduced  into Troy by the stratagem of its maker.\n"
  "\n"
  "15. Master tower: chief tower; as, in the Knight's Tale, the\n"
  "principal street is called the \"master street.\"  See note 86 to the\n"
  "Knight's Tale.\n"
  "\n"
  "16. Alhazen and Vitellon: two writers on optics -- the first\n"
  "supposed to have lived about 1100, the other about 1270.\n"
  "Tyrwhitt says that their works were printed at Basle in 1572,\n"
  "under the title \"Alhazeni et Vitellonis Opticae.\"\n"
  "\n"
  "17. Telephus, a son of Hercules, reigned over Mysia when the\n"
  "Greeks came to besiege Troy, and he sought to prevent their\n"
  "landing.  But, by the art of Dionysus, he was made to stumble\n"
  "over a vine, and Achilles wounded him with his spear.  The\n"
  "oracle informed Telephus that the hurt could be healed only by\n"
  "him, or by the weapon, that inflicted it; and the king, seeking\n"
  "the Grecian camp, was healed by Achilles with the rust of the\n"
  "charmed spear.\n"
  "\n"
  "18. Ferne: before; a corruption of \"forne,\" from Anglo-Saxon,\n"
  "\"foran.\"\n"
  "\n"
  "19. Aldrian: or Aldebaran; a star in the neck of the constellation\n"
  "Leo.\n"
  "\n"
  "20. Chamber of parements:  Presence-chamber, or chamber of\n"
  "state, full of  splendid furniture and ornaments. The same\n"
  "expression is used in French and Italian.\n"
  "\n"
  "21. In Pisces, Venus was said to be at her exaltation or greatest\n"
  "power. A planet, according to the old astrologers, was in\n"
  "\"exaltation\" when in the sign of the Zodiac in which it exerted\n"
  "its strongest influence; the opposite sign, in which it was\n"
  "weakest, was called its \"dejection.\"\n"
  "\n"
  "22. Launcelot:  Arthur's famous knight, so accomplished and\n"
  "courtly, that he was held the very pink of chivalry.\n"
  "\n"
  "23. Trill: turn;  akin to \"thirl\", \"drill.\"\n"
  "\n"
  "24. Ride: another reading is \"bide,\" alight or remain.\n"
  "\n"
  "25. Feastying: entertaining; French, \"festoyer,\"  to feast.\n"
  "\n"
  "26. The old physicians held that blood dominated in  the human\n"
  "body late at night and in the early morning.  Galen says that the\n"
  "domination lasts for seven hours.\n"
  "\n"
  "27. Fumosity: fumes of wine rising from the stomach to the\n"
  "head.\n"
  "\n"
  "28. Fremde: foreign, strange; German, \"fremd\" in the northern\n"
  "dialects, \"frem,\" or \"fremmed,\" is used in the same sense.\n"
  "\n"
  "29. Leden: Language, dialect; from Anglo-Saxon, \"leden\" or\n"
  "\"laeden,\" a corruption from \"Latin.\"\n"
  "\n"
  "30. Tercelet: the \"tassel,\" or male of any species of hawk; so\n"
  "called, according to Cotgrave, because he is one third (\"tiers\")\n"
  "smaller than the female.\n"
  "\n"
  "31. \"And Lamech took unto him two wives: the name of the\n"
  "one Adah, and the name of the other Zillah\" (Gen. iv. 19).\n"
  "\n"
  "32. Galoche:  shoe; it seems to have been used in France, of a\n"
  "\"sabot,\" or wooden shoe.  The reader cannot fail to recall the\n"
  "same illustration in John i. 27, where the Baptist says of Christ:\n"
  "\"He it is, who coming after me is preferred before me; whose\n"
  "shoe's latchet I am not worthy to unloose.\"\n"
  "\n"
  "33. Byleve; stay; another form is \"bleve;\" from Anglo-Saxon,\n"
  "\"belitan,\" to remain.  Compare German, \"bleiben.\"\n"
  "\n"
  "34. This sentiment, as well as the illustration of the bird which\n"
  "follows, is taken from the third book of Boethius, \"De\n"
  "Consolatione Philosophiae,\" metrum 2. It has thus been\n"
  "rendered in Chaucer's translation: \"All things seek aye to their\n"
  "proper course, and all things rejoice on their returning again to\n"
  "their nature.\"\n"
  "\n"
  "35. Men love of proper kind newfangleness: Men, by their own\n"
  "-- their very -- nature, are fond of novelty, and prone to\n"
  "inconstancy.\n"
  "\n"
  "36. Blue was the colour of truth, as green was that of\n"
  "inconstancy.  In John Stowe's additions to Chaucer's works,\n"
  "printed in 1561, there is \"A balade whiche Chaucer made\n"
  "against women inconstaunt,\" of which the refrain is, \"In stead of\n"
  "blue, thus may ye wear all green.\"\n"
  "\n"
  "37. Unless we suppose this to be a namesake of the Camballo\n"
  "who was Canace's brother -- which is not at all probable -- we\n"
  "must agree with Tyrwhitt that there is a mistake here; which no\n"
  "doubt Chaucer would have rectified, if the tale had not been\n"
  "\"left half-told,\" One manuscript reads \"Caballo;\" and though not\n"
  "much authority need be given to a difference that may be due to\n"
  "mere omission of the mark of contraction over the \"a,\" there is\n"
  "enough in the text to show that another person than the king's\n"
  "younger son is intended.  The Squire promises to tell the\n"
  "adventures that befell each member of Cambuscan's family; and\n"
  "in thorough consistency with this plan, and with the canons of\n"
  "chivalric story, would be \"the marriage of Canace to some\n"
  "knight who was first obliged to fight for her with her two\n"
  "brethren; a method of courtship,\" adds Tyrwhitt, \"very\n"
  "consonant to the spirit of ancient chivalry.\"\n"
  "\n"
  "38. (Trancriber's note) In some manuscripts the following two\n"
  "lines, being the beginning of the third part, are found: -\n"
  "\n"
  "Apollo whirleth up his chair so high,\n"
  "Till that Mercurius' house, the sly...\n"
  "\n"
  "\n"
  "\n"
  "";
// }

const char franklinsTale0[] PGMSECTION = // { // 24958 bytes
  "THE FRANKLIN'S TALE.\n"
  "\n"
  "\n"
  "THE PROLOGUE. <1>\n"
  "\n"
  "\n"
  "\"IN faith, Squier, thou hast thee well acquit,\n"
  "And gentilly; I praise well thy wit,\"\n"
  "Quoth the Franklin; \"considering thy youthe\n"
  "So feelingly thou speak'st, Sir, I aloue* thee,          *allow, approve\n"
  "*As to my doom,* there is none that is here       *so far as my judgment\n"
  "Of eloquence that shall be thy peer,                               goes*\n"
  "If that thou live; God give thee goode chance,\n"
  "And in virtue send thee continuance,\n"
  "For of thy speaking I have great dainty.*                 *value, esteem\n"
  "I have a son, and, by the Trinity;\n"
  "*It were me lever* than twenty pound worth land,        *I would rather*\n"
  "Though it right now were fallen in my hand,\n"
  "He were a man of such discretion\n"
  "As that ye be: fy on possession,\n"
  "*But if* a man be virtuous withal.                               *unless\n"
  "I have my sone snibbed* and yet shall,              *rebuked; \"snubbed.\"\n"
  "For he to virtue *listeth not t'intend,*               *does not wish to\n"
  "But for to play at dice, and to dispend,                  apply himself*\n"
  "And lose all that he hath, is his usage;\n"
  "And he had lever talke with a page,\n"
  "Than to commune with any gentle wight,\n"
  "There he might learen gentilless aright.\"\n"
  "\n"
  "Straw for your gentillesse!\" quoth our Host.\n"
  "\"What? Frankelin, pardie, Sir, well thou wost*                  *knowest\n"
  "That each of you must tellen at the least\n"
  "A tale or two, or breake his behest.\"*                          *promise\n"
  "\"That know I well, Sir,\" quoth the Frankelin;\n"
  "\"I pray you have me not in disdain,\n"
  "Though I to this man speak a word or two.\"\n"
  "\"Tell on thy tale, withoute wordes mo'.\"\n"
  "\"Gladly, Sir Host,\" quoth he, \"I will obey\n"
  "Unto your will; now hearken what I say;\n"
  "I will you not contrary* in no wise,                            *disobey\n"
  "As far as that my wittes may suffice.\n"
  "I pray to God that it may please you,\n"
  "Then wot I well that it is good enow.\n"
  "\n"
  "\"These olde gentle Bretons, in their days,\n"
  "Of divers aventures made lays,<2>\n"
  "Rhymeden in their firste Breton tongue;\n"
  "Which layes with their instruments they sung,\n"
  "Or elles reade them for their pleasance;\n"
  "And one of them have I in remembrance,\n"
  "Which I shall say with good will as I can.\n"
  "But, Sirs, because I am a borel* man,                   *rude, unlearned\n"
  "At my beginning first I you beseech\n"
  "Have me excused of my rude speech.\n"
  "I learned never rhetoric, certain;\n"
  "Thing that I speak, it must be bare and plain.\n"
  "I slept never on the mount of Parnasso,\n"
  "Nor learned Marcus Tullius Cicero.\n"
  "Coloures know I none, withoute dread,*                            *doubt\n"
  "But such colours as growen in the mead,\n"
  "Or elles such as men dye with or paint;\n"
  "Colours of rhetoric be to me quaint;*                           *strange\n"
  "My spirit feeleth not of such mattere.\n"
  "But, if you list, my tale shall ye hear.\"\n"
  "\n"
  "\n"
  "Notes to the Prologue to the Franklin's Tale\n"
  "\n"
  "\n"
  "1. In the older editions, the verses here given as the prologue\n"
  "were prefixed to the Merchant's Tale, and put into his mouth.\n"
  "Tyrwhitt was abundantly justified, by the internal evidence\n"
  "afforded by the lines themselves, in transferring them to their\n"
  "present place.\n"
  "\n"
  "2. The \"Breton Lays\" were an important and curious element in\n"
  "the literature of the Middle Ages; they were originally\n"
  "composed in the Armorican language, and the chief collection\n"
  "of them extant was translated into French verse by a poetess\n"
  "calling herself \"Marie,\" about the middle of the thirteenth\n"
  "century.  But though this collection was the most famous, and\n"
  "had doubtless been read by Chaucer, there were other British or\n"
  "Breton lays, and from one of those the Franklin's Tale is taken.\n"
  "Boccaccio has dealt with the same story in the \"Decameron\"\n"
  "and the \"Philocopo,\"  altering the circumstances to suit the\n"
  "removal of its scene to a southern clime.\n"
  "\n"
  "\n"
  "THE TALE.\n"
  "\n"
  "\n"
  "In Armoric', that called is Bretagne,\n"
  "There was a knight, that lov'd and *did his pain*      *devoted himself,\n"
  "To serve a lady in his beste wise;                               strove*\n"
  "And many a labour, many a great emprise,*                    *enterprise\n"
  "He for his lady wrought, ere she were won:\n"
  "For she was one the fairest under sun,\n"
  "And eke thereto come of so high kindred,\n"
  "That *well unnethes durst this knight for dread,*         *see note <1>*\n"
  "Tell her his woe, his pain, and his distress\n"
  "But, at the last, she for his worthiness,\n"
  "And namely* for his meek obeisance,                          *especially\n"
  "Hath such a pity caught of his penance,*            *suffering, distress\n"
  "That privily she fell of his accord\n"
  "To take him for her husband and her lord\n"
  "(Of such lordship as men have o'er their wives);\n"
  "And, for to lead the more in bliss their lives,\n"
  "Of his free will he swore her as a knight,\n"
  "That never in all his life he day nor night\n"
  "Should take upon himself no mastery\n"
  "Against her will, nor kithe* her jealousy,                         *show\n"
  "But her obey, and follow her will in all,\n"
  "As any lover to his lady shall;\n"
  "Save that the name of sovereignety\n"
  "That would he have, for shame of his degree.\n"
  "She thanked him, and with full great humbless\n"
  "She saide; \"Sir, since of your gentleness\n"
  "Ye proffer me to have so large a reign,\n"
  "*Ne woulde God never betwixt us twain,\n"
  "As in my guilt, were either war or strife:*               *see note <2>*\n"
  "Sir, I will be your humble true wife,\n"
  "Have here my troth, till that my hearte brest.\"*                  *burst\n"
  "Thus be they both in quiet and in rest.\n"
  "\n"
  "For one thing, Sires, safely dare I say,\n"
  "That friends ever each other must obey,\n"
  "If they will longe hold in company.\n"
  "Love will not be constrain'd by mastery.\n"
  "When mast'ry comes, the god of love anon\n"
  "Beateth <3> his wings, and, farewell, he is gone.\n"
  "Love is a thing as any spirit free.\n"
  "Women *of kind* desire liberty,                              *by nature*\n"
  "And not to be constrained as a thrall,*                           *slave\n"
  "And so do men, if soothly I say shall.\n"
  "Look who that is most patient in love,\n"
  "He *is at his advantage all above.*                  *enjoys the highest\n"
  "Patience is a high virtue certain,                    advantages of all*\n"
  "For it vanquisheth, as these clerkes sayn,\n"
  "Thinges that rigour never should attain.\n"
  "For every word men may not chide or plain.\n"
  "Learne to suffer, or, so may I go,*                             *prosper\n"
  "Ye shall it learn whether ye will or no.\n"
  "For in this world certain no wight there is,\n"
  "That he not doth or saith sometimes amiss.\n"
  "Ire, or sickness, or constellation,*                   *the influence of\n"
  "Wine, woe, or changing of complexion,                       the planets*\n"
  "Causeth full oft to do amiss or speaken:\n"
  "On every wrong a man may not be wreaken.*                      *revenged\n"
  "After* the time must be temperance                         *according to\n"
  "To every wight that *can of* governance.                 *is capable of*\n"
  "And therefore hath this worthy wise knight\n"
  "(To live in ease) sufferance her behight;*                     *promised\n"
  "And she to him full wisly* gan to swear                          *surely\n"
  "That never should there be default in her.\n"
  "Here may men see a humble wife accord;\n"
  "Thus hath she ta'en her servant and her lord,\n"
  "Servant in love, and lord in marriage.\n"
  "Then was he both in lordship and servage?\n"
  "Servage? nay, but in lordship all above,\n"
  "Since he had both his lady and his love:\n"
  "His lady certes, and his wife also,\n"
  "The which that law of love accordeth to.\n"
  "And when he was in this prosperrity,\n"
  "Home with his wife he went to his country,\n"
  "Not far from Penmark,<4> where his dwelling was,\n"
  "And there he liv'd in bliss and in solace.*                     *delight\n"
  "Who coulde tell, but* he had wedded be,                          *unless\n"
  "The joy, the ease, and the prosperity,\n"
  "That is betwixt a husband and his wife?\n"
  "A year and more lasted this blissful life,\n"
  "Till that this knight, of whom I spake thus,\n"
  "That of Cairrud <5> was call'd Arviragus,\n"
  "Shope* him to go and dwell a year or twain           *prepared, arranged\n"
  "In Engleland, that call'd was eke Britain,\n"
  "To seek in armes worship and honour\n"
  "(For all his lust* he set in such labour);                     *pleasure\n"
  "And dwelled there two years; the book saith thus.\n"
  "\n"
  "Now will I stint* of this Arviragus,                     *cease speaking\n"
  "And speak I will of Dorigen his wife,\n"
  "That lov'd her husband as her hearte's life.\n"
  "For his absence weepeth she and siketh,*                        *sigheth\n"
  "As do these noble wives when them liketh;\n"
  "She mourneth, waketh, waileth, fasteth, plaineth;\n"
  "Desire of his presence her so distraineth,\n"
  "That all this wide world she set at nought.\n"
  "Her friendes, which that knew her heavy thought,\n"
  "Comforte her in all that ever they may;\n"
  "They preache her, they tell her night and day,\n"
  "That causeless she slays herself, alas!\n"
  "And every comfort possible in this case\n"
  "They do to her, with all their business,*                     *assiduity\n"
  "And all to make her leave her heaviness.\n"
  "By process, as ye knowen every one,\n"
  "Men may so longe graven in a stone,\n"
  "Till some figure therein imprinted be:\n"
  "So long have they comforted her, till she\n"
  "Received hath, by hope and by reason,\n"
  "Th' imprinting of their consolation,\n"
  "Through which her greate sorrow gan assuage;\n"
  "She may not always duren in such rage.\n"
  "And eke Arviragus, in all this care,\n"
  "Hath sent his letters home of his welfare,\n"
  "And that he will come hastily again,\n"
  "Or elles had this sorrow her hearty-slain.\n"
  "Her friendes saw her sorrow gin to slake,*            *slacken, diminish\n"
  "And prayed her on knees for Godde's sake\n"
  "To come and roamen in their company,\n"
  "Away to drive her darke fantasy;\n"
  "And finally she granted that request,\n"
  "For well she saw that it was for the best.\n"
  "\n"
  "Now stood her castle faste by the sea,\n"
  "And often with her friendes walked she,\n"
  "Her to disport upon the bank on high,\n"
  "There as many a ship and barge sigh,*                               *saw\n"
  "Sailing their courses, where them list to go.\n"
  "But then was that a parcel* of her woe,                            *part\n"
  "For to herself full oft, \"Alas!\" said she,\n"
  "Is there no ship, of so many as I see,\n"
  "Will bringe home my lord? then were my heart\n"
  "All warish'd* of this bitter paine's smart.\"                  *cured <6>\n"
  "Another time would she sit and think,\n"
  "And cast her eyen downward from the brink;\n"
  "But when she saw the grisly rockes blake,*                        *black\n"
  "For very fear so would her hearte quake,\n"
  "That on her feet she might her not sustene*                     *sustain\n"
  "Then would she sit adown upon the green,\n"
  "And piteously *into the sea behold,*               *look out on the sea*\n"
  "And say right thus, with *careful sikes* cold:           *painful sighs*\n"
  "\"Eternal God! that through thy purveyance\n"
  "Leadest this world by certain governance,\n"
  "*In idle,* as men say, ye nothing make;                  *idly, in vain*\n"
  "But, Lord, these grisly fiendly rockes blake,\n"
  "That seem rather a foul confusion\n"
  "Of work, than any fair creation\n"
  "Of such a perfect wise God and stable,\n"
  "Why have ye wrought this work unreasonable?\n"
  "For by this work, north, south, or west, or east,\n"
  "There is not foster'd man, nor bird, nor beast:\n"
  "It doth no good, to my wit, but *annoyeth.*         *works mischief* <7>\n"
  "See ye not, Lord, how mankind it destroyeth?\n"
  "A hundred thousand bodies of mankind\n"
  "Have rockes slain, *all be they not in mind;*           *though they are\n"
  "Which mankind is so fair part of thy work,                    forgotten*\n"
  "Thou madest it like to thine owen mark.*                          *image\n"
  "Then seemed it ye had a great cherte*                   *love, affection\n"
  "Toward mankind; but how then may it be\n"
  "That ye such meanes make it to destroy?\n"
  "Which meanes do no good, but ever annoy.\n"
  "I wot well, clerkes will say as them lest,*                      *please\n"
  "By arguments, that all is for the best,\n"
  "Although I can the causes not y-know;\n"
  "But thilke* God that made the wind to blow,                        *that\n"
  "As keep my lord, this is my conclusion:\n"
  "To clerks leave I all disputation:\n"
  "But would to God that all these rockes blake\n"
  "Were sunken into helle for his sake\n"
  "These rockes slay mine hearte for the fear.\"\n"
  "Thus would she say, with many a piteous tear.\n"
  "\n"
  "Her friendes saw that it was no disport\n"
  "To roame by the sea, but discomfort,\n"
  "And shope* them for to playe somewhere else.                   *arranged\n"
  "They leade her by rivers and by wells,\n"
  "And eke in other places delectables;\n"
  "They dancen, and they play at chess and tables.*             *backgammon\n"
  "So on a day, right in the morning-tide,\n"
  "Unto a garden that was there beside,\n"
  "In which that they had made their ordinance*     *provision, arrangement\n"
  "Of victual, and of other purveyance,\n"
  "They go and play them all the longe day:\n"
  "And this was on the sixth morrow of May,\n"
  "Which May had painted with his softe showers\n"
  "This garden full of leaves and of flowers:\n"
  "And craft of manne's hand so curiously\n"
  "Arrayed had this garden truely,\n"
  "That never was there garden of such price,*               *value, praise\n"
  "*But if* it were the very Paradise.                             *unless*\n"
  "Th'odour of flowers, and the freshe sight,\n"
  "Would have maked any hearte light\n"
  "That e'er was born, *but if* too great sickness                 *unless*\n"
  "Or too great sorrow held it in distress;\n"
  "So full it was of beauty and pleasance.\n"
  "And after dinner they began to dance\n"
  "And sing also, save Dorigen alone\n"
  "Who made alway her complaint and her moan,\n"
  "For she saw not him on the dance go\n"
  "That was her husband, and her love also;\n"
  "But natheless she must a time abide\n"
  "And with good hope let her sorrow slide.\n"
  "\n"
  "Upon this dance, amonge other men,\n"
  "Danced a squier before Dorigen\n"
  "That fresher was, and jollier of array\n"
  "*As to my doom,* than is the month of May.              *in my judgment*\n"
  "He sang and danced, passing any man,\n"
  "That is or was since that the world began;\n"
  "Therewith he was, if men should him descrive,\n"
  "One of the *beste faring* men alive,                 *most accomplished*\n"
  "Young, strong, and virtuous, and rich, and wise,\n"
  "And well beloved, and holden in great price.*             *esteem, value\n"
  "And, shortly if the sooth I telle shall,\n"
  "*Unweeting of* this Dorigen at all,                         *unknown to*\n"
  "This lusty squier, servant to Venus,\n"
  "Which that y-called was Aurelius,\n"
  "Had lov'd her best of any creature\n"
  "Two year and more, as was his aventure;*                        *fortune\n"
  "But never durst he tell her his grievance;\n"
  "Withoute cup he drank all his penance.\n"
  "He was despaired, nothing durst he say,\n"
  "Save in his songes somewhat would he wray*                       *betray\n"
  "His woe, as in a general complaining;\n"
  "He said, he lov'd, and was belov'd nothing.\n"
  "Of suche matter made he many lays,\n"
  "Songes, complaintes, roundels, virelays <8>\n"
  "How that he durste not his sorrow tell,\n"
  "But languished, as doth a Fury in hell;\n"
  "And die he must, he said, as did Echo\n"
  "For Narcissus, that durst not tell her woe.\n"
  "In other manner than ye hear me say,\n"
  "He durste not to her his woe bewray,\n"
  "Save that paraventure sometimes at dances,\n"
  "Where younge folke keep their observances,\n"
  "It may well be he looked on her face\n"
  "In such a wise, as man that asketh grace,\n"
  "But nothing wiste she of his intent.\n"
  "Nath'less it happen'd, ere they thennes* went,         *thence (from the\n"
  "Because that he was her neighebour,                             garden)*\n"
  "And was a man of worship and honour,\n"
  "And she had knowen him *of time yore,*                 *for a long time*\n"
  "They fell in speech, and forth aye more and more\n"
  "Unto his purpose drew Aurelius;\n"
  "And when he saw his time, he saide thus:\n"
  "Madam,\" quoth he, \"by God that this world made,\n"
  "So that I wist it might your hearte glade,*                     *gladden\n"
  "I would, that day that your Arviragus\n"
  "Went over sea, that I, Aurelius,\n"
  "Had gone where I should never come again;\n"
  "For well I wot my service is in vain.\n"
  "My guerdon* is but bursting of mine heart.                       *reward\n"
  "Madame, rue upon my paine's smart,\n"
  "For with a word ye may me slay or save.\n"
  "Here at your feet God would that I were grave.\n"
  "I have now no leisure more to say:\n"
  "Have mercy, sweet, or you will *do me dey.\"*           *cause me to die*\n"
  "\n"
  "She gan to look upon Aurelius;\n"
  "\"Is this your will,\" quoth she, \"and say ye thus?\n"
  "Ne'er erst,\"* quoth she, \"I wiste what ye meant:                 *before\n"
  "But now, Aurelius, I know your intent.\n"
  "By thilke* God that gave me soul and life,                         *that\n"
  "Never shall I be an untrue wife\n"
  "In word nor work, as far as I have wit;\n"
  "I will be his to whom that I am knit;\n"
  "Take this for final answer as of me.\"\n"
  "But after that *in play* thus saide she.            *playfully, in jest*\n"
  "\"Aurelius,\" quoth she, \"by high God above,\n"
  "Yet will I grante you to be your love\n"
  "(Since I you see so piteously complain);\n"
  "Looke, what day that endelong* Bretagne              *from end to end of\n"
  "Ye remove all the rockes, stone by stone,\n"
  "That they not lette* ship nor boat to gon,                      *prevent\n"
  "I say, when ye have made this coast so clean\n"
  "Of rockes, that there is no stone seen,\n"
  "Then will I love you best of any man;\n"
  "Have here my troth, in all that ever I can;\n"
  "For well I wot that it shall ne'er betide.\n"
  "Let such folly out of your hearte glide.\n"
  "What dainty* should a man have in his life              *value, pleasure\n"
  "For to go love another manne's wife,\n"
  "That hath her body when that ever him liketh?\"\n"
  "Aurelius full often sore siketh;*                               *sigheth\n"
  "Is there none other grace in you?\" quoth he,\n"
  "\"No, by that Lord,\" quoth she, \"that maked me.\n"
  "Woe was Aurelius when that he this heard,\n"
  "And with a sorrowful heart he thus answer'd.\n"
  "\"Madame, quoth he, \"this were an impossible.\n"
  "Then must I die of sudden death horrible.\"\n"
  "And with that word he turned him anon.\n"
  "\n"
  "Then came her other friends many a one,\n"
  "And in the alleys roamed up and down,\n"
  "And nothing wist of this conclusion,\n"
  "But suddenly began to revel new,\n"
  "Till that the brighte sun had lost his hue,\n"
  "For th' horizon had reft the sun his light\n"
  "(This is as much to say as it was night);\n"
  "And home they go in mirth and in solace;\n"
  "Save only wretch'd Aurelius, alas\n"
  "He to his house is gone with sorrowful heart.\n"
  "He said, he may not from his death astart.*                      *escape\n"
  "Him seemed, that he felt his hearte cold.\n"
  "Up to the heav'n his handes gan he hold,\n"
  "And on his knees bare he set him down.\n"
  "And in his raving said his orisoun.*                             *prayer\n"
  "For very woe out of his wit he braid;*                         *wandered\n"
  "He wist not what he spake, but thus he said;\n"
  "With piteous heart his plaint hath he begun\n"
  "Unto the gods, and first unto the Sun.\n"
  "He said; \"Apollo God and governour\n"
  "Of every plante, herbe, tree, and flower,\n"
  "That giv'st, after thy declination,\n"
  "To each of them his time and his season,\n"
  "As thine herberow* changeth low and high;           *dwelling, situation\n"
  "Lord Phoebus: cast thy merciable eye\n"
  "On wretched Aurelius, which that am but lorn.*                   *undone\n"
  "Lo, lord, my lady hath my death y-sworn,\n"
  "Withoute guilt, but* thy benignity                               *unless\n"
  "Upon my deadly heart have some pity.\n"
  "For well I wot, Lord Phoebus, if you lest,*                      *please\n"
  "Ye may me helpe, save my lady, best.\n"
  "Now vouchsafe, that I may you devise*                     *tell, explain\n"
  "How that I may be holp,* and in what wise.                       *helped\n"
  "Your blissful sister, Lucina the sheen, <9>\n"
  "That of the sea is chief goddess and queen, --\n"
  "Though Neptunus have deity in the sea,\n"
  "Yet emperess above him is she;  --\n"
  "Ye know well, lord, that, right as her desire\n"
  "Is to be quick'd* and lighted of your fire,                   *quickened\n"
  "For which she followeth you full busily,\n"
  "Right so the sea desireth naturally\n"
  "To follow her, as she that is goddess\n"
  "Both in the sea and rivers more and less.\n"
  "Wherefore, Lord Phoebus, this is my request,\n"
  "Do this miracle, or *do mine hearte brest;*              *cause my heart\n"
  "That flow, next at this opposition,                            to burst*\n"
  "Which in the sign shall be of the Lion,\n"
  "As praye her so great a flood to bring,\n"
  "That five fathom at least it overspring\n"
  "The highest rock in Armoric Bretagne,\n"
  "And let this flood endure yeares twain:\n"
  "Then certes to my lady may I say,\n"
  "\"Holde your hest,\" the rockes be away.\n"
  "Lord Phoebus, this miracle do for me,\n"
  "Pray her she go no faster course than ye;\n"
  "I say this, pray your sister that she go\n"
  "No faster course than ye these yeares two:\n"
  "Then shall she be even at full alway,\n"
  "And spring-flood laste bothe night and day.\n"
  "And *but she* vouchesafe in such mannere                 *if she do not*\n"
  "To grante me my sov'reign lady dear,\n"
  "Pray her to sink every rock adown\n"
  "Into her owen darke regioun\n"
  "Under the ground, where Pluto dwelleth in\n"
  "Or nevermore shall I my lady win.\n"
  "Thy temple in Delphos will I barefoot seek.\n"
  "Lord Phoebus! see the teares on my cheek\n"
  "And on my pain have some compassioun.\"\n"
  "And with that word in sorrow he fell down,\n"
  "And longe time he lay forth in a trance.\n"
  "His brother, which that knew of his penance,*                  *distress\n"
  "Up caught him, and to bed he hath him brought,\n"
  "Despaired in this torment and this thought\n"
  "Let I this woeful creature lie;\n"
  "Choose he for me whe'er* he will live or die.                   *whether\n"
  "\n"
  "Arviragus with health and great honour\n"
  "(As he that was of chivalry the flow'r)\n"
  "Is come home, and other worthy men.\n"
  "Oh, blissful art thou now, thou Dorigen!\n"
  "Thou hast thy lusty husband in thine arms,\n"
  "The freshe knight, the worthy man of arms,\n"
  "That loveth thee as his own hearte's life:\n"
  "*Nothing list him to be imaginatif*              *he cared not to fancy*\n"
  "If any wight had spoke, while he was out,\n"
  "To her of love; he had of that no doubt;*               *fear, suspicion\n"
  "He not intended* to no such mattere,              *occupied himself with\n"
  "But danced, jousted, and made merry cheer.\n"
  "And thus in joy and bliss I let them dwell,\n"
  "And of the sick Aurelius will I tell\n"
  "In languor and in torment furious\n"
  "Two year and more lay wretch'd Aurelius,\n"
  "Ere any foot on earth he mighte gon;\n"
  "Nor comfort in this time had he none,\n"
  "Save of his brother, which that was a clerk.*                   *scholar\n"
  "He knew of all this woe and all this work;\n"
  "For to none other creature certain\n"
  "Of this matter he durst no worde sayn;\n"
  "Under his breast he bare it more secree\n"
  "Than e'er did Pamphilus for Galatee.<10>\n"
  "His breast was whole withoute for to seen,\n"
  "But in his heart aye was the arrow keen,\n"
  "And well ye know that of a sursanure <11>\n"
  "In surgery is perilous the cure,\n"
  "But* men might touch the arrow or come thereby.                  *except\n"
  "His brother wept and wailed privily,\n"
  "Till at the last him fell in remembrance,\n"
  "That while he was at Orleans <12> in France, --\n"
  "As younge clerkes, that be likerous* --                           *eager\n"
  "To readen artes that be curious,\n"
  "Seeken in every *halk and every hern*             *nook and corner* <13>\n"
  "Particular sciences for to learn,--\n"
  "He him remember'd, that upon a day\n"
  "At Orleans in study a book he say*                                  *saw\n"
  "Of magic natural, which his fellaw,\n"
  "That was that time a bachelor of law\n"
  "All* were he there to learn another craft,                       *though\n"
  "Had privily upon his desk y-laft;\n"
  "Which book spake much of operations\n"
  "Touching the eight and-twenty mansions\n"
  "That longe to the Moon, and such folly\n"
  "As in our dayes is not worth a fly;\n"
  "For holy church's faith, in our believe,*                 *belief, creed\n"
  "Us suff'reth none illusion to grieve.\n"
  "And when this book was in his remembrance\n"
  "Anon for joy his heart began to dance,\n"
  "And to himself he saide privily;\n"
  "\"My brother shall be warish'd* hastily                            *cured\n"
  "For I am sicker* that there be sciences,                        *certain\n"
  "By which men make divers apparences,\n"
  "Such as these subtle tregetoures play.                  *tricksters <14>\n"
  "For oft at feaste's have I well heard say,\n"
  "That tregetours, within a halle large,\n"
  "Have made come in a water and a barge,\n"
  "And in the halle rowen up and down.\n"
  "Sometimes hath seemed come a grim lioun,\n"
  "And sometimes flowers spring as in a mead;\n"
  "Sometimes a vine, and grapes white and red;\n"
  "Sometimes a castle all of lime and stone;\n"
  "And, when them liked, voided* it anon:                         *vanished\n"
  "Thus seemed it to every manne's sight.\n"
  "Now then conclude I thus; if that I might\n"
  "At Orleans some olde fellow find,\n"
  "That hath these Moone's mansions in mind,\n"
  "Or other magic natural above.\n"
  "He should well make my brother have his love.\n"
  "For with an appearance a clerk* may make,                   *learned man\n"
  "To manne's sight, that all the rockes blake\n"
  "Of Bretagne were voided* every one,                             *removed\n"
  "And shippes by the brinke come and gon,\n"
  "And in such form endure a day or two;\n"
  "Then were my brother warish'd* of his woe,                        *cured\n"
  "Then must she needes *holde her behest,*              *keep her promise*\n"
  "Or elles he shall shame her at the least.\"\n"
  "Why should I make a longer tale of this?\n"
  "Unto his brother's bed he comen is,\n"
  "And such comfort he gave him, for to gon\n"
  "To Orleans, that he upstart anon,\n"
  "And on his way forth-ward then is he fare,*                        *gone\n"
  "In hope for to be lissed* of his care.                    *eased of <15>\n"
  "\n"
  "";
// }

const char franklinsTale1[] PGMSECTION = // { // 25908 bytes
  "When they were come almost to that city,\n"
  "*But if it were* a two furlong or three,                       *all but*\n"
  "A young clerk roaming by himself they met,\n"
  "Which that in Latin *thriftily them gret.*                 *greeted them\n"
  "And after that he said a wondrous thing;                        civilly*\n"
  "I know,\" quoth he, \"the cause of your coming;\"\n"
  "Aud ere they farther any foote went,\n"
  "He told them all that was in their intent.\n"
  "The Breton clerk him asked of fellaws\n"
  "The which he hadde known in olde daws,*                            *days\n"
  "And he answer'd him that they deade were,\n"
  "For which he wept full often many a tear.\n"
  "Down off his horse Aurelius light anon,\n"
  "And forth with this magician is be gone\n"
  "Home to his house, and made him well at ease;\n"
  "Them lacked no vitail* that might them please.           *victuals, food\n"
  "So well-array'd a house as there was one,\n"
  "Aurelius in his life saw never none.\n"
  "He shewed him, ere they went to suppere,\n"
  "Forestes, parkes, full of wilde deer.\n"
  "There saw he hartes with their hornes high,\n"
  "The greatest that were ever seen with eye.\n"
  "He saw of them an hundred slain with hounds,\n"
  "And some with arrows bleed of bitter wounds.\n"
  "He saw, when voided* were the wilde deer,                   *passed away\n"
  "These falconers upon a fair rivere,\n"
  "That with their hawkes have the heron slain.\n"
  "Then saw he knightes jousting in a plain.\n"
  "And after this he did him such pleasance,\n"
  "That he him shew'd his lady on a dance,\n"
  "In which himselfe danced, as him thought.\n"
  "And when this master, that this magic wrought,\n"
  "Saw it was time, he clapp'd his handes two,\n"
  "And farewell, all the revel is y-go.*                     *gone, removed\n"
  "And yet remov'd they never out of the house,\n"
  "While they saw all the sightes marvellous;\n"
  "But in his study, where his bookes be,\n"
  "They satte still, and no wight but they three.\n"
  "To him this master called his squier,\n"
  "\n"
  "And said him thus, \"May we go to supper?\n"
  "Almost an hour it is, I undertake,\n"
  "Since I you bade our supper for to make,\n"
  "When that these worthy men wente with me\n"
  "Into my study, where my bookes be.\"\n"
  "\"Sir,\" quoth this squier, \"when it liketh you.\n"
  "It is all ready, though ye will right now.\"\n"
  "\"Go we then sup,\" quoth he, \"as for the best;\n"
  "These amorous folk some time must have rest.\"\n"
  "At after supper fell they in treaty\n"
  "What summe should this master's guerdon* be,                     *reward\n"
  "To remove all the rockes of Bretagne,\n"
  "And eke from Gironde <16> to the mouth of Seine.\n"
  "He made it strange,* and swore, so God him save,            *a matter of\n"
  "Less than a thousand pound he would not have,                difficulty*\n"
  "*Nor gladly for that sum he would not gon.*              *see note <17>*\n"
  "Aurelius with blissful heart anon\n"
  "Answered thus; \"Fie on a thousand pound!\n"
  "This wide world, which that men say is round,\n"
  "I would it give, if I were lord of it.\n"
  "This bargain is full-driv'n, for we be knit;*                    *agreed\n"
  "Ye shall be payed truly by my troth.\n"
  "But looke, for no negligence or sloth,\n"
  "Ye tarry us here no longer than to-morrow.\"\n"
  "\"Nay,\" quoth the clerk, *\"have here my faith to borrow.\"*   *I pledge my\n"
  "To bed is gone Aurelius when him lest,                      faith on it*\n"
  "And well-nigh all that night he had his rest,\n"
  "What for his labour, and his hope of bliss,\n"
  "His woeful heart *of penance had a liss.*                 *had a respite\n"
  "                                                         from suffering*\n"
  "Upon the morrow, when that it was day,\n"
  "Unto Bretagne they took the righte way,\n"
  "Aurelius and this magician beside,\n"
  "And be descended where they would abide:\n"
  "And this was, as the bookes me remember,\n"
  "The colde frosty season of December.\n"
  "Phoebus wax'd old, and hued like latoun,*                         *brass\n"
  "That in his hote declinatioun\n"
  "Shone as the burned gold, with streames* bright;                  *beams\n"
  "But now in Capricorn adown he light,\n"
  "Where as he shone full pale, I dare well sayn.\n"
  "The bitter frostes, with the sleet and rain,\n"
  "Destroyed have the green in every yard.               *courtyard, garden\n"
  "Janus sits by the fire with double beard,\n"
  "And drinketh of his bugle horn the wine:\n"
  "Before him stands the brawn of tusked swine\n"
  "And \"nowel\"* crieth every lusty man                           *Noel <18>\n"
  "Aurelius, in all that ev'r he can,\n"
  "Did to his master cheer and reverence,\n"
  "And prayed him to do his diligence\n"
  "To bringe him out of his paines smart,\n"
  "Or with a sword that he would slit his heart.\n"
  "This subtle clerk such ruth* had on this man,                      *pity\n"
  "That night and day he sped him, that he can,\n"
  "To wait a time of his conclusion;\n"
  "This is to say, to make illusion,\n"
  "By such an appearance of jugglery\n"
  "(I know no termes of astrology),\n"
  "That she and every wight should ween and say,\n"
  "That of Bretagne the rockes were away,\n"
  "Or else they were sunken under ground.\n"
  "So at the last he hath a time found\n"
  "To make his japes* and his wretchedness                          *tricks\n"
  "Of such a *superstitious cursedness.*              *detestable villainy*\n"
  "His tables Toletanes <19> forth he brought,\n"
  "Full well corrected, that there lacked nought,\n"
  "Neither his collect, nor his expanse years,\n"
  "Neither his rootes, nor his other gears,\n"
  "As be his centres, and his arguments,\n"
  "And his proportional convenients\n"
  "For his equations in everything.\n"
  "And by his eighte spheres in his working,\n"
  "He knew full well how far Alnath <20> was shove\n"
  "From the head of that fix'd Aries above,\n"
  "That in the ninthe sphere consider'd is.\n"
  "Full subtilly he calcul'd all this.\n"
  "When he had found his firste mansion,\n"
  "He knew the remnant by proportion;\n"
  "And knew the rising of his moone well,\n"
  "And in whose face, and term, and every deal;\n"
  "And knew full well the moone's mansion\n"
  "Accordant to his operation;\n"
  "And knew also his other observances,\n"
  "For such illusions and such meschances,*                 *wicked devices\n"
  "As heathen folk used in thilke days.\n"
  "For which no longer made he delays;\n"
  "But through his magic, for a day or tway, <21>\n"
  "It seemed all the rockes were away.\n"
  "\n"
  "Aurelius, which yet despaired is\n"
  "Whe'er* he shall have his love, or fare amiss,                  *whether\n"
  "Awaited night and day on this miracle:\n"
  "And when he knew that there was none obstacle,\n"
  "That voided* were these rockes every one,                       *removed\n"
  "Down at his master's feet he fell anon,\n"
  "And said; \"I, woeful wretch'd Aurelius,\n"
  "Thank you, my Lord, and lady mine Venus,\n"
  "That me have holpen from my cares cold.\"\n"
  "And to the temple his way forth hath he hold,\n"
  "Where as he knew he should his lady see.\n"
  "And when he saw his time, anon right he\n"
  "With dreadful* heart and with full humble cheer**        *fearful **mien\n"
  "Saluteth hath his sovereign lady dear.\n"
  "\"My rightful Lady,\" quoth this woeful man,\n"
  "\"Whom I most dread, and love as I best can,\n"
  "And lothest were of all this world displease,\n"
  "Were't not that I for you have such disease,*      *distress, affliction\n"
  "That I must die here at your foot anon,\n"
  "Nought would I tell how me is woebegone.\n"
  "But certes either must I die or plain;*                          *bewail\n"
  "Ye slay me guilteless for very pain.\n"
  "But of my death though that ye have no ruth,\n"
  "Advise you, ere that ye break your truth:\n"
  "Repente you, for thilke God above,\n"
  "Ere ye me slay because that I you love.\n"
  "For, Madame, well ye wot what ye have hight;*                  *promised\n"
  "Not that I challenge anything of right\n"
  "Of you,  my sovereign lady, but of grace:\n"
  "But in a garden yond', in such a place,\n"
  "Ye wot right well what ye behighte* me,                        *promised\n"
  "And in mine hand your trothe plighted ye,\n"
  "To love me best; God wot ye saide so,\n"
  "Albeit that I unworthy am thereto;\n"
  "Madame, I speak it for th' honour of you,\n"
  "More than to save my hearte's life right now;\n"
  "I have done so as ye commanded me,\n"
  "And if ye vouchesafe, ye may go see.\n"
  "Do as you list, have your behest in mind,\n"
  "For, quick or dead, right there ye shall me find;\n"
  "In you hes all to *do me live or dey;*                      *cause me to\n"
  "But well I wot the rockes be away.\"                         live or die*\n"
  "\n"
  "He took his leave, and she astonish'd stood;\n"
  "In all her face was not one drop of blood:\n"
  "She never ween'd t'have come in such a trap.\n"
  "\"Alas!\" quoth she, \"that ever this should hap!\n"
  "For ween'd I ne'er, by possibility,\n"
  "That such a monster or marvail might be;\n"
  "It is against the process of nature.\"\n"
  "And home she went a sorrowful creature;\n"
  "For very fear unnethes* may she go.                            *scarcely\n"
  "She weeped, wailed, all a day or two,\n"
  "And swooned, that it ruthe was to see:\n"
  "But why it was, to no wight tolde she,\n"
  "For out of town was gone Arviragus.\n"
  "But to herself she spake, and saide thus,\n"
  "With face pale, and full sorrowful cheer,\n"
  "In her complaint, as ye shall after hear.\n"
  "\"Alas!\" quoth she, \"on thee, Fortune, I plain,*                *complain\n"
  "That unware hast me wrapped in thy chain,\n"
  "From which to scape, wot I no succour,\n"
  "Save only death, or elles dishonour;\n"
  "One of these two behoveth me to choose.\n"
  "But natheless, yet had I lever* lose                     *sooner, rather\n"
  "My life, than of my body have shame,\n"
  "Or know myselfe false, or lose my name;\n"
  "And with my death *I may be quit y-wis.*       *I may certainly purchase\n"
  "Hath there not many a noble wife, ere this,                my exemption*\n"
  "And many a maiden, slain herself, alas!\n"
  "Rather than with her body do trespass?\n"
  "Yes, certes; lo, these stories bear witness. <22>\n"
  "When thirty tyrants full of cursedness*                      *wickedness\n"
  "Had slain Phidon in Athens at the feast,\n"
  "They commanded his daughters to arrest,\n"
  "And bringe them before them, in despite,\n"
  "All naked, to fulfil their foul delight;\n"
  "And in their father's blood they made them dance\n"
  "Upon the pavement, -- God give them mischance.\n"
  "For which these woeful maidens, full of dread,\n"
  "Rather than they would lose their maidenhead,\n"
  "They privily *be start* into a well,                    *suddenly leaped\n"
  "And drowned themselves, as the bookes tell.\n"
  "They of Messene let inquire and seek\n"
  "Of Lacedaemon fifty maidens eke,\n"
  "On which they woulde do their lechery:\n"
  "But there was none of all that company\n"
  "That was not slain, and with a glad intent\n"
  "Chose rather for to die, than to assent\n"
  "To be oppressed* of her maidenhead.                     *forcibly bereft\n"
  "Why should I then to dien be in dread?\n"
  "Lo, eke the tyrant Aristoclides,\n"
  "That lov'd a maiden hight Stimphalides,\n"
  "When that her father slain was on a night,\n"
  "Unto Diana's temple went she right,\n"
  "And hent* the image in her handes two,                  *caught, clasped\n"
  "From which image she woulde never go;\n"
  "No wight her handes might off it arace,*            *pluck away by force\n"
  "Till she was slain right in the selfe* place.                      *same\n"
  "Now since that maidens hadde such despite\n"
  "To be defouled with man's foul delight,\n"
  "Well ought a wife rather herself to sle,*                          *slay\n"
  "Than be defouled, as it thinketh me.\n"
  "What shall I say of Hasdrubale's wife,\n"
  "That at Carthage bereft herself of life?\n"
  "For, when she saw the Romans win the town,\n"
  "She took her children all, and skipt adown\n"
  "Into the fire, and rather chose to die,\n"
  "Than any Roman did her villainy.\n"
  "Hath not Lucretia slain herself, alas!\n"
  "At Rome, when that she oppressed* was                          *ravished\n"
  "Of Tarquin? for her thought it was a shame\n"
  "To live, when she hadde lost her name.\n"
  "The seven maidens of Milesie also\n"
  "Have slain themselves for very dread and woe,\n"
  "Rather than folk of Gaul them should oppress.\n"
  "More than a thousand stories, as I guess,\n"
  "Could I now tell as touching this mattere.\n"
  "When Abradate was slain, his wife so dear <23>\n"
  "Herselfe slew, and let her blood to glide\n"
  "In Abradate's woundes, deep and wide,\n"
  "And said, 'My body at the leaste way\n"
  "There shall no wight defoul, if that I may.'\n"
  "Why should I more examples hereof sayn?\n"
  "Since that so many have themselves slain,\n"
  "Well rather than they would defouled be,\n"
  "I will conclude that it is bet* for me                           *better\n"
  "To slay myself, than be defouled thus.\n"
  "I will be true unto Arviragus,\n"
  "Or elles slay myself in some mannere,\n"
  "As did Demotione's daughter dear,\n"
  "Because she woulde not defouled be.\n"
  "O Sedasus, it is full great pity\n"
  "To reade how thy daughters died, alas!\n"
  "That slew themselves *for suche manner cas.*        *in circumstances of\n"
  "As great a pity was it, or well more,                     the same kind*\n"
  "The Theban maiden, that for Nicanor\n"
  "Herselfe slew, right for such manner woe.\n"
  "Another Theban maiden did right so;\n"
  "For one of Macedon had her oppress'd,\n"
  "She with her death her maidenhead redress'd.*                *vindicated\n"
  "What shall I say of Niceratus' wife,\n"
  "That for such case bereft herself her life?\n"
  "How true was eke to Alcibiades\n"
  "His love, that for to dien rather chese,*                         *chose\n"
  "Than for to suffer his body unburied be?\n"
  "Lo, what a wife was Alceste?\" quoth she.\n"
  "\"What saith Homer of good Penelope?\n"
  "All Greece knoweth of her chastity.\n"
  "Pardie, of Laedamia is written thus,\n"
  "That when at Troy was slain Protesilaus, <24>\n"
  "No longer would she live after his day.\n"
  "The same of noble Porcia tell I may;\n"
  "Withoute Brutus coulde she not live,\n"
  "To whom she did all whole her hearte give. <25>\n"
  "The perfect wifehood of Artemisie <26>\n"
  "Honoured is throughout all Barbarie.\n"
  "O Teuta <27> queen, thy wifely chastity\n"
  "To alle wives may a mirror be.\" <28>\n"
  "\n"
  "Thus plained Dorigen a day or tway,\n"
  "Purposing ever that she woulde dey;*                                *die\n"
  "But natheless upon the thirde night\n"
  "Home came Arviragus, the worthy knight,\n"
  "And asked her why that she wept so sore.\n"
  "And she gan weepen ever longer more.\n"
  "\"Alas,\" quoth she, \"that ever I was born!\n"
  "Thus have I said,\" quoth she; \"thus have I sworn. \"\n"
  "And told him all, as ye have heard before:\n"
  "It needeth not rehearse it you no more.\n"
  "This husband with glad cheer,* in friendly wise,              *demeanour\n"
  "Answer'd and said, as I shall you devise.*                       *relate\n"
  "\"Is there aught elles, Dorigen, but this?\"\n"
  "\"Nay, nay,\" quoth she, \"God help me so, *as wis*             *assuredly*\n"
  "This is too much, an* it were Godde's will.\"                         *if\n"
  "\"Yea, wife,\" quoth he, \"let sleepe what is still,\n"
  "It may be well par'venture yet to-day.\n"
  "Ye shall your trothe holde, by my fay.\n"
  "For, God so wisly* have mercy on me,                          *certainly\n"
  "*I had well lever sticked for to be,*            *I had rather be slain*\n"
  "For very love which I to you have,\n"
  "But if ye should your trothe keep and save.\n"
  "Truth is the highest thing that man may keep.\"\n"
  "But with that word he burst anon to weep,\n"
  "And said; \"I you forbid, on pain of death,\n"
  "That never, while you lasteth life or breath,\n"
  "To no wight tell ye this misaventure;\n"
  "As I may best, I will my woe endure,\n"
  "Nor make no countenance of heaviness,\n"
  "That folk of you may deeme harm, or guess.\"\n"
  "And forth he call'd a squier and a maid.\n"
  "\"Go forth anon with Dorigen,\" he said,\n"
  "\"And bringe her to such a place anon.\"\n"
  "They take their leave, and on their way they gon:\n"
  "But they not wiste why she thither went;\n"
  "He would to no wight telle his intent.\n"
  "\n"
  "This squier, which that hight Aurelius,\n"
  "On Dorigen that was so amorous,\n"
  "Of aventure happen'd her to meet\n"
  "Amid the town, right in the quickest* street,                   *nearest\n"
  "As she was bound* to go the way forthright         *prepared, going <29>\n"
  "Toward the garden, there as she had hight.*                    *promised\n"
  "And he was to the garden-ward also;\n"
  "For well he spied when she woulde go\n"
  "Out of her house, to any manner place;\n"
  "But thus they met, of aventure or grace,\n"
  "And he saluted her with glad intent,\n"
  "And asked of her whitherward she went.\n"
  "And she answered, half as she were mad,\n"
  "\"Unto the garden, as my husband bade,\n"
  "My trothe for to hold, alas! alas!\"\n"
  "Aurelius gan to wonder on this case,\n"
  "And in his heart had great compassion\n"
  "Of her, and of her lamentation,\n"
  "And of Arviragus, the worthy knight,\n"
  "That bade her hold all that she hadde hight;\n"
  "So loth him was his wife should break her truth*    *troth, pledged word\n"
  "And in his heart he caught of it great ruth,*                      *pity\n"
  "Considering the best on every side,\n"
  "*That from his lust yet were him lever abide,*           *see note <30>*\n"
  "Than do so high a churlish wretchedness*                     *wickedness\n"
  "Against franchise,* and alle gentleness;                     *generosity\n"
  "For which in fewe words he saide thus;\n"
  "\"Madame, say to your lord Arviragus,\n"
  "That since I see the greate gentleness\n"
  "Of him, and eke I see well your distress,\n"
  "That him were lever* have shame (and that were ruth)**    *rather **pity\n"
  "Than ye to me should breake thus your truth,\n"
  "I had well lever aye* to suffer woe,                            *forever\n"
  "Than to depart* the love betwixt you two.              *sunder, split up\n"
  "I you release, Madame, into your hond,\n"
  "Quit ev'ry surement* and ev'ry bond,                             *surety\n"
  "That ye have made to me as herebeforn,\n"
  "Since thilke time that ye were born.\n"
  "Have here my truth, I shall you ne'er repreve*                 *reproach\n"
  "*Of no behest;* and here I take my leave,             *of no (breach of)\n"
  "As of the truest and the beste wife                             promise*\n"
  "That ever yet I knew in all my life.\n"
  "But every wife beware of her behest;\n"
  "On Dorigen remember at the least.\n"
  "Thus can a squier do a gentle deed,\n"
  "As well as can a knight, withoute drede.\"*                        *doubt\n"
  "\n"
  "She thanked him upon her knees bare,\n"
  "And home unto her husband is she fare,*                            *gone\n"
  "And told him all, as ye have hearde said;\n"
  "And, truste me, he was so *well apaid,*                      *satisfied*\n"
  "That it were impossible me to write.\n"
  "Why should I longer of this case indite?\n"
  "Arviragus and Dorigen his wife\n"
  "In sov'reign blisse ledde forth their life;\n"
  "Ne'er after was there anger them between;\n"
  "He cherish'd her as though she were a queen,\n"
  "And she was to him true for evermore;\n"
  "Of these two folk ye get of me no more.\n"
  "\n"
  "Aurelius, that his cost had *all forlorn,*                *utterly lost*\n"
  "Cursed the time that ever he was born.\n"
  "\"Alas!\" quoth he, \"alas that I behight*                        *promised\n"
  "Of pured* gold a thousand pound of weight                       *refined\n"
  "To this philosopher! how shall I do?\n"
  "I see no more, but that I am fordo.*                     *ruined, undone\n"
  "Mine heritage must I needes sell,\n"
  "And be a beggar; here I will not dwell,\n"
  "And shamen all my kindred in this place,\n"
  "But* I of him may gette better grace.                            *unless\n"
  "But natheless I will of him assay\n"
  "At certain dayes year by year to pay,\n"
  "And thank him of his greate courtesy.\n"
  "My trothe will I keep, I will not he.\"\n"
  "With hearte sore he went unto his coffer,\n"
  "And broughte gold unto this philosopher,\n"
  "The value of five hundred pound, I guess,\n"
  "And him beseeched, of his gentleness,\n"
  "To grant him *dayes of* the remenant;                   *time to pay up*\n"
  "And said; \"Master, I dare well make avaunt,\n"
  "I failed never of my truth as yet.\n"
  "For sickerly my debte shall be quit\n"
  "Towardes you how so that e'er I fare\n"
  "To go a-begging in my kirtle bare:\n"
  "But would ye vouchesafe, upon surety,\n"
  "Two year, or three, for to respite me,\n"
  "Then were I well, for elles must I sell\n"
  "Mine heritage; there is no more to tell.\"\n"
  "\n"
  "This philosopher soberly* answer'd,                             *gravely\n"
  "And saide thus, when he these wordes heard;\n"
  "\"Have I not holden covenant to thee?\"\n"
  "\"Yes, certes, well and truely,\" quoth he.\n"
  "\"Hast thou not had thy lady as thee liked?\"\n"
  "\"No, no,\" quoth he, and sorrowfully siked.*                      *sighed\n"
  "\"What was the cause? tell me if thou can.\"\n"
  "Aurelius his tale anon began,\n"
  "And told him all as ye have heard before,\n"
  "It needeth not to you rehearse it more.\n"
  "He said, \"Arviragus of gentleness\n"
  "Had lever* die in sorrow and distress,                           *rather\n"
  "Than that his wife were of her trothe false.\"\n"
  "The sorrow of Dorigen he told him als',*                           *also\n"
  "How loth her was to be a wicked wife,\n"
  "And that she lever had lost that day her life;\n"
  "And that her troth she swore through innocence;\n"
  "She ne'er erst* had heard speak of apparence**   *before **see note <31>\n"
  "That made me have of her so great pity,\n"
  "And right as freely as he sent her to me,\n"
  "As freely sent I her to him again:\n"
  "This is all and some, there is no more to sayn.\"\n"
  "\n"
  "The philosopher answer'd; \"Leve* brother,                          *dear\n"
  "Evereach of you did gently to the other;\n"
  "Thou art a squier, and he is a knight,\n"
  "But God forbidde, for his blissful might,\n"
  "But if a clerk could do a gentle deed\n"
  "As well as any of you, it is no drede*                            *doubt\n"
  "Sir, I release thee thy thousand pound,\n"
  "As thou right now were crept out of the ground,\n"
  "Nor ever ere now haddest knowen me.\n"
  "For, Sir, I will not take a penny of thee\n"
  "For all my craft, nor naught for my travail;*             *labour, pains\n"
  "Thou hast y-payed well for my vitaille;\n"
  "It is enough; and farewell, have good day.\"\n"
  "And took his horse, and forth he went his way.\n"
  "Lordings, this question would I aske now,\n"
  "Which was the moste free,* as thinketh you?               *generous <32>\n"
  "Now telle me, ere that ye farther wend.\n"
  "I can* no more, my tale is at an end.                    *know, can tell\n"
  "\n"
  "\n"
  "Notes to The Franklin's Tale\n"
  "\n"
  "\n"
  "1. Well unnethes durst this knight for dread: This knight hardly\n"
  "dared,  for fear (that she would not entertain his suit.)\n"
  "\n"
  "2. \"Ne woulde God never betwixt us twain,\n"
  "    As in my guilt, were either war or strife\"\n"
  "Would to God there may never be war or strife between us,\n"
  "through my fault.\n"
  "\n"
  "3. Perhaps the true reading is \"beteth\" -- prepares, makes ready,\n"
  "his wings for flight.\n"
  "\n"
  "4. Penmark: On the west coast of Brittany, between Brest and\n"
  "L'Orient.  The name is composed of two British words, \"pen,\"\n"
  "mountain, and \"mark,\" region; it therefore means the\n"
  "mountainous country\n"
  "\n"
  "5. Cairrud: \"The red city;\" it is not known where it was\n"
  "situated.\n"
  "\n"
  "6. Warished: cured; French, \"guerir,\" to heal, or recover from\n"
  "sickness.\n"
  "\n"
  "7. Annoyeth: works mischief; from Latin, \"nocco,\" I hurt.\n"
  "\n"
  "8. Virelays:  ballads; the \"virelai\" was an ancient French poem\n"
  "of two rhymes.\n"
  "\n"
  "9. Lucina the sheen:  Diana the bright. See note 54 to the\n"
  "Knight's Tale.\n"
  "\n"
  "10. In a Latin poem, very popular in Chaucer's time, Pamphilus\n"
  "relates his amour with Galatea, setting out with the idea\n"
  "adopted by our poet in the lines that follow.\n"
  "\n"
  "11. Sursanure:  A wound healed on the surface, but festering\n"
  "beneath.\n"
  "\n"
  "12. Orleans:  Where there was a celebrated and very famous\n"
  "university, afterwards eclipsed by that of Paris.  It was founded\n"
  "by Philip le Bel in 1312.\n"
  "\n"
  "13. Every  halk and every hern: Every nook and corner, Anglo-\n"
  "Saxon, \"healc,\" a nook; \"hyrn,\" a corner.\n"
  "\n"
  "14. Tregetoures: tricksters, jugglers. The word is probably\n"
  "derived -- in \"treget,\" deceit or imposture -- from the French\n"
  "\"trebuchet,\" a military machine; since it is evident that much and\n"
  "elaborate machinery must have been employed to produce the\n"
  "effects afterwards described. Another derivation is from the\n"
  "Low Latin, \"tricator,\" a deceiver.\n"
  "\n"
  "15. Lissed of: eased of; released from; another form of \"less\" or\n"
  "\"lessen.\"\n"
  "\n"
  "16. Gironde:  The river, formed by the union of the Dordogne\n"
  "and Garonne, on which Bourdeaux stands.\n"
  "\n"
  "17. Nor gladly for that sum he would not gon: And even for\n"
  "that sum he would not willingly go to work.\n"
  "\n"
  "18. \"Noel,\" the French for Christmas -- derived from \"natalis,\"\n"
  "and signifying that on that day Christ was born -- came to be\n"
  "used as a festive cry by the people on solemn occasions.\n"
  "\n"
  "19. Tables Toletanes: Toledan tables; the astronomical tables\n"
  "composed by order Of Alphonso II, King of Castile, about 1250\n"
  "and so called because they were adapted to the city of Toledo.\n"
  "\n"
  "20. \"Alnath,\" Says Mr Wright, was \"the first star in the horns of\n"
  "Aries, whence the first mansion of the moon is named.\"\n"
  "\n"
  "21. Another and better reading is \"a week or two.\"\n"
  "\n"
  "22. These stories are all taken from the book of St Jerome\n"
  "\"Contra Jovinianum,\" from which the Wife of Bath drew so\n"
  "many of her ancient instances. See note 1 to the prologue to the\n"
  "Wife of Bath's Tale.\n"
  "\n"
  "23. Panthea.  Abradatas, King of Susa, was an ally of the\n"
  "Assyrians against Cyrus; and his wife was taken at the conquest\n"
  "of the Assyrian camp.  Struck by the honourable treatment she\n"
  "received at the captors hands, Abradatas joined Cyrus, and fell\n"
  "in battle against his former alhes.  His wife, inconsolable at his\n"
  "loss, slew herself immediately.\n"
  "\n"
  "24. Protesilaus was the husband of Laedamia.  She begged the\n"
  "gods, after his death, that but three hours' converse with him\n"
  "might be allowed her; the request was granted; and when her\n"
  "dead husband, at the expiry of the time, returned to the world of\n"
  "shades, she bore him company.\n"
  "\n"
  "25. The daughter of Cato of Utica, Porcia married Marcus\n"
  "Brutus, the friend and the assassin of Julius Caesar; when her\n"
  "husband died by his own hand after the battle of Philippi, she\n"
  "committed suicide, it is said, by swallowing live coals -- all\n"
  "other means having been removed by her friends.\n"
  "\n"
  "26. Artemisia, Queen of Caria, who built to her husband\n"
  "Mausolus, the splendid monument which was accounted among\n"
  "the wonders of the world; and who mingled her husband's ashes\n"
  "with her daily drink. \"Barbarie\" is used in the Greek sense, to\n"
  "designate the non-Hellenic peoples of Asia.\n"
  "\n"
  "27. Teuta:  Queen of Illyria, who, after her husband's death,\n"
  "made war on and was conquered by the Romans, B.C 228.\n"
  "\n"
  "28. At this point, in some manuscripts, occur thefollowing two\n"
  "lines: --\n"
  "\"The same thing I say of Bilia,\n"
  "Of Rhodegone and of Valeria.\"\n"
  "\n"
  "29. Bound:  prepared; going. To \"boun\" or \"bown\" is a good\n"
  "old word, whence comes our word \"bound,\" in the sense of \"on\n"
  "the way.\"\n"
  "\n"
  "30. That from his lust yet were him lever abide: He would\n"
  "rather do without his pleasure.\n"
  "\n"
  "31. Such apparence: such an ocular deception, or apparition --\n"
  "more properly, disappearance -- as the removal of the rocks.\n"
  "\n"
  "32. The same question is stated a the end of Boccaccio's version\n"
  "of the story in the \"Philocopo,\" where the queen determines in\n"
  "favour of Aviragus. The question is evidently one of those\n"
  "which it was the fashion to propose for debate in the mediaeval\n"
  "\"courts of love.\"\n"
  "\n"
  "\n"
  "\n"
  "";
// }

const char doctorsTale[] PGMSECTION = // { // 15256 bytes
  "THE DOCTOR'S TALE.\n"
  "\n"
  "\n"
  "THE PROLOGUE. <1>\n"
  "\n"
  "\n"
  "[\"YEA, let that passe,\" quoth our Host, \"as now.\n"
  "Sir Doctor of Physik, I praye you,\n"
  "Tell us a tale of some honest mattere.\"\n"
  "\"It shall be done, if that ye will it hear,\"\n"
  "Said this Doctor; and his tale gan anon.\n"
  "\"Now, good men,\" quoth he, \"hearken everyone.\"]\n"
  "\n"
  "\n"
  "Notes to the Prologue to the Doctor's Tale\n"
  "\n"
  "\n"
  "1. The authenticity of the prologue is questionable. It is found in\n"
  "one manuscript only; other manuscripts give other prologues,\n"
  "more plainly not Chaucer's than this; and some manuscripts\n"
  "have merely a colophon to the effect that \"Here endeth the\n"
  "Franklin's Tale and beginneth the Physician's Tale without a\n"
  "prologue.\" The Tale itself is the well-known story of Virginia,\n"
  "with several departures from the text of Livy. Chaucer probably\n"
  "followed the \"Romance of the Rose\" and Gower's \"Confessio\n"
  "Amantis,\" in both of which the story is found.\n"
  "\n"
  "\n"
  "THE TALE.\n"
  "\n"
  "\n"
  "There was, as telleth Titus Livius, <1>\n"
  "A knight, that called was Virginius,\n"
  "Full filled of honour and worthiness,\n"
  "And strong of friendes, and of great richess.\n"
  "This knight one daughter hadde by his wife;\n"
  "No children had he more in all his life.\n"
  "Fair was this maid in excellent beauty\n"
  "Aboven ev'ry wight that man may see:\n"
  "For nature had with sov'reign diligence\n"
  "Y-formed her in so great excellence,\n"
  "As though she woulde say, \"Lo, I, Nature,\n"
  "Thus can I form and paint a creature,\n"
  "When that me list; who can me counterfeit?\n"
  "Pygmalion? not though he aye forge and beat,\n"
  "Or grave or painte: for I dare well sayn,\n"
  "Apelles, Zeuxis, shoulde work in vain,\n"
  "Either to grave, or paint, or forge, or beat,\n"
  "If they presumed me to counterfeit.\n"
  "For he that is the former principal,\n"
  "Hath made me his vicar-general\n"
  "To form and painten earthly creatures\n"
  "Right as me list, and all thing in my cure* is,                    *care\n"
  "Under the moone, that may wane and wax.\n"
  "And for my work right nothing will I ax*                            *ask\n"
  "My lord and I be full of one accord.\n"
  "I made her to the worship* of my lord;\n"
  "So do I all mine other creatures,\n"
  "What colour that they have, or what figures.\"\n"
  "Thus seemeth me that Nature woulde say.\n"
  "\n"
  "This maiden was of age twelve year and tway,*                       *two\n"
  "In which that Nature hadde such delight.\n"
  "For right as she can paint a lily white,\n"
  "And red a rose, right with such painture\n"
  "She painted had this noble creature,\n"
  "Ere she was born, upon her limbes free,\n"
  "Where as by right such colours shoulde be:\n"
  "And Phoebus dyed had her tresses great,\n"
  "Like to the streames* of his burned heat.                   *beams, rays\n"
  "And if that excellent was her beauty,\n"
  "A thousand-fold more virtuous was she.\n"
  "In her there lacked no condition,\n"
  "That is to praise, as by discretion.\n"
  "As well in ghost* as body chaste was she:                  *mind, spirit\n"
  "For which she flower'd in virginity,\n"
  "With all humility and abstinence,\n"
  "With alle temperance and patience,\n"
  "With measure* eke of bearing and array.                      *moderation\n"
  "Discreet she was in answering alway,\n"
  "Though she were wise as Pallas, dare I sayn;\n"
  "Her faconde* eke full womanly and plain,                     *speech <2>\n"
  "No counterfeited termes hadde she\n"
  "To seeme wise; but after her degree\n"
  "She spake, and all her worde's more and less\n"
  "Sounding in virtue and in gentleness.\n"
  "Shamefast she was in maiden's shamefastness,\n"
  "Constant in heart, and ever *in business*              *diligent, eager*\n"
  "To drive her out of idle sluggardy:\n"
  "Bacchus had of her mouth right no mast'ry.\n"
  "For wine and slothe <3> do Venus increase,\n"
  "As men in fire will casten oil and grease.\n"
  "And of her owen virtue, unconstrain'd,\n"
  "She had herself full often sick y-feign'd,\n"
  "For that she woulde flee the company,\n"
  "Where likely was to treaten of folly,\n"
  "As is at feasts, at revels, and at dances,\n"
  "That be occasions of dalliances.\n"
  "Such thinges make children for to be\n"
  "Too soone ripe and bold, as men may see,\n"
  "Which is full perilous, and hath been yore;*                     *of old\n"
  "For all too soone may she learne lore\n"
  "Of boldeness, when that she is a wife.\n"
  "\n"
  "And ye mistresses,* in your olde life              *governesses, duennas\n"
  "That lordes' daughters have in governance,\n"
  "Take not of my wordes displeasance\n"
  "Thinke that ye be set in governings\n"
  "Of lordes' daughters only for two things;\n"
  "Either for ye have kept your honesty,\n"
  "Or else for ye have fallen in frailty\n"
  "And knowe well enough the olde dance,\n"
  "And have forsaken fully such meschance*                  *wickedness <4>\n"
  "For evermore; therefore, for Christe's sake,\n"
  "To teach them virtue look that ye not slake.*            *be slack, fail\n"
  "A thief of venison, that hath forlaft*                   *forsaken, left\n"
  "His lik'rousness,* and all his olde craft,                     *gluttony\n"
  "Can keep a forest best of any man;\n"
  "Now keep them well, for if ye will ye can.\n"
  "Look well, that ye unto no vice assent,\n"
  "Lest ye be damned for your wick'*  intent,                 *wicked, evil\n"
  "For whoso doth, a traitor is certain;\n"
  "And take keep* of that I shall you sayn;                           *heed\n"
  "Of alle treason, sov'reign pestilence\n"
  "Is when a wight betrayeth innocence.\n"
  "Ye fathers, and ye mothers eke also,\n"
  "Though ye have children, be it one or mo',\n"
  "Yours is the charge of all their surveyance,*               *supervision\n"
  "While that they be under your governance.\n"
  "Beware, that by example of your living,\n"
  "Or by your negligence in chastising,\n"
  "That they not perish for I dare well say,\n"
  "If that they do, ye shall it dear abeye.*           *pay for, suffer for\n"
  "Under a shepherd soft and negligent\n"
  "The wolf hath many a sheep and lamb to-rent.\n"
  "Suffice this example now as here,\n"
  "For I must turn again to my mattere.\n"
  "\n"
  "This maid, of which I tell my tale express,\n"
  "She kept herself, her needed no mistress;\n"
  "For in her living maidens mighte read,\n"
  "As in a book, ev'ry good word and deed\n"
  "That longeth to a maiden virtuous;\n"
  "She was so prudent and so bounteous.\n"
  "For which the fame out sprang on every side\n"
  "Both of her beauty and her bounte* wide:                       *goodness\n"
  "That through the land they praised her each one\n"
  "That loved virtue, save envy alone,\n"
  "That sorry is of other manne's weal,\n"
  "And glad is of his sorrow and unheal* --                     *misfortune\n"
  "The Doctor maketh this descriptioun. -- <5>\n"
  "This maiden on a day went in the town\n"
  "Toward a temple, with her mother dear,\n"
  "As is of younge maidens the mannere.\n"
  "Now was there then a justice in that town,\n"
  "That governor was of that regioun:\n"
  "And so befell, this judge his eyen cast\n"
  "Upon this maid, avising* her full fast,                       *observing\n"
  "As she came forth by where this judge stood;\n"
  "Anon his hearte changed and his mood,\n"
  "So was he caught with beauty of this maid\n"
  "And to himself full privily he said,\n"
  "\"This maiden shall be mine *for any man.\"*             *despite what any\n"
  "Anon the fiend into his hearte ran,                          man may do*\n"
  "And taught him suddenly, that he by sleight\n"
  "This maiden to his purpose winne might.\n"
  "For certes, by no force, nor by no meed,*                 *bribe, reward\n"
  "Him thought he was not able for to speed;\n"
  "For she was strong of friendes, and eke she\n"
  "Confirmed was in such sov'reign bounte,\n"
  "That well he wist he might her never win,\n"
  "As for to make her with her body sin.\n"
  "For which, with great deliberatioun,\n"
  "He sent after a clerk <6>  was in the town,\n"
  "The which he knew for subtle and for bold.\n"
  "This judge unto this clerk his tale told\n"
  "In secret wise, and made him to assure\n"
  "He shoulde tell it to no creature,\n"
  "And if he did, he shoulde lose his head.\n"
  "And when assented was this cursed rede,*                  *counsel, plot\n"
  "Glad was the judge, and made him greate cheer,\n"
  "And gave him giftes precious and dear.\n"
  "When shapen* was all their conspiracy                          *arranged\n"
  "From point to point, how that his lechery\n"
  "Performed shoulde be full subtilly,\n"
  "As ye shall hear it after openly,\n"
  "Home went this clerk, that highte Claudius.\n"
  "This false judge, that highte Appius, --\n"
  "(So was his name, for it is no fable,\n"
  "But knowen for a storial*  thing notable;         *historical, authentic\n"
  "The sentence* of it sooth** is out of doubt); --         *account **true\n"
  "This false judge went now fast about\n"
  "To hasten his delight all that he may.\n"
  "And so befell, soon after on a day,\n"
  "This false judge, as telleth us the story,\n"
  "As he was wont, sat in his consistory,\n"
  "And gave his doomes* upon sundry case';                       *judgments\n"
  "This false clerk came forth *a full great pace,*               *in haste\n"
  "And saide; Lord, if that it be your will,\n"
  "As do me right upon this piteous bill,*                        *petition\n"
  "In which I plain upon Virginius.\n"
  "And if that he will say it is not thus,\n"
  "I will it prove, and finde good witness,\n"
  "That sooth is what my bille will express.\"\n"
  "The judge answer'd, \"Of this, in his absence,\n"
  "I may not give definitive sentence.\n"
  "Let do* him call, and I will gladly hear;                         *cause\n"
  "Thou shalt have alle right, and no wrong here.\"\n"
  "Virginius came to weet* the judge's will,                   *know, learn\n"
  "And right anon was read this cursed bill;\n"
  "The sentence of it was as ye shall hear\n"
  "\"To you, my lord, Sir Appius so clear,\n"
  "Sheweth your poore servant Claudius,\n"
  "How that a knight called Virginius,\n"
  "Against the law, against all equity,\n"
  "Holdeth, express against the will of me,\n"
  "My servant, which that is my thrall* by right,                    *slave\n"
  "Which from my house was stolen on a night,\n"
  "While that she was full young; I will it preve*                   *prove\n"
  "By witness, lord, so that it you *not grieve;*      *be not displeasing*\n"
  "She is his daughter not, what so he say.\n"
  "Wherefore to you, my lord the judge, I pray,\n"
  "Yield me my thrall, if that it be your will.\"\n"
  "Lo, this was all the sentence of the bill.\n"
  "Virginius gan upon the clerk behold;\n"
  "But hastily, ere he his tale told,\n"
  "And would have proved it, as should a knight,\n"
  "And eke by witnessing of many a wight,\n"
  "That all was false that said his adversary,\n"
  "This cursed judge would no longer tarry,\n"
  "Nor hear a word more of Virginius,\n"
  "But gave his judgement, and saide thus:\n"
  "\"I deem* anon this clerk his servant have;         *pronounce, determine\n"
  "Thou shalt no longer in thy house her save.\n"
  "Go, bring her forth, and put her in our ward\n"
  "The clerk shall have his thrall: thus I award.\"\n"
  "\n"
  "And when this worthy knight, Virginius,\n"
  "Through sentence of this justice Appius,\n"
  "Muste by force his deare daughter give\n"
  "Unto the judge, in lechery to live,\n"
  "He went him home, and sat him in his hall,\n"
  "And let anon his deare daughter call;\n"
  "And with a face dead as ashes cold\n"
  "Upon her humble face he gan behold,\n"
  "With father's pity sticking* through his heart,                *piercing\n"
  "All* would he from his purpose not convert.**     *although **turn aside\n"
  "\"Daughter,\" quoth he, \"Virginia by name,\n"
  "There be two wayes, either death or shame,\n"
  "That thou must suffer, -- alas that I was bore!*                   *born\n"
  "For never thou deservedest wherefore\n"
  "To dien with a sword or with a knife,\n"
  "O deare daughter, ender of my life,\n"
  "Whom I have foster'd up with such pleasance\n"
  "That thou were ne'er out of my remembrance;\n"
  "O daughter, which that art my laste woe,\n"
  "And in this life my laste joy also,\n"
  "O gem of chastity, in patience\n"
  "Take thou thy death, for this is my sentence:\n"
  "For love and not for hate thou must be dead;\n"
  "My piteous hand must smiten off thine head.\n"
  "Alas, that ever Appius thee say!*                                   *saw\n"
  "Thus hath he falsely judged thee to-day.\"\n"
  "And told her all the case, as ye before\n"
  "Have heard; it needeth not to tell it more.\n"
  "\n"
  "\"O mercy, deare father,\" quoth the maid.\n"
  "And with that word she both her armes laid\n"
  "About his neck, as she was wont to do,\n"
  "(The teares burst out of her eyen two),\n"
  "And said, \"O goode father, shall I die?\n"
  "Is there no grace? is there no remedy?\"\n"
  "\"No, certes, deare daughter mine,\" quoth he.\n"
  "\"Then give me leisure, father mine, quoth she,\n"
  "\"My death for to complain* a little space                        *bewail\n"
  "For, pardie, Jephthah gave his daughter grace\n"
  "For to complain, ere he her slew, alas! <7>\n"
  "And, God it wot, nothing was her trespass,*                     *offence\n"
  "But for she ran her father first to see,\n"
  "To welcome him with great solemnity.\"\n"
  "And with that word she fell a-swoon anon;\n"
  "And after, when her swooning was y-gone,\n"
  "She rose up, and unto her father said:\n"
  "\"Blessed be God, that I shall die a maid.\n"
  "Give me my death, ere that I have shame;\n"
  "Do with your child your will, in Godde's name.\"\n"
  "And with that word she prayed him full oft\n"
  "That with his sword he woulde smite her soft;\n"
  "And with that word, a-swoon again she fell.\n"
  "Her father, with full sorrowful heart and fell,*           *stern, cruel\n"
  "Her head off smote, and by the top it hent,*                       *took\n"
  "And to the judge he went it to present,\n"
  "As he sat yet in doom* in consistory.                          *judgment\n"
  "\n"
  "And when the judge it saw, as saith the story,\n"
  "He bade to take him, and to hang him fast.\n"
  "But right anon a thousand people *in thrast*                 *rushed in*\n"
  "To save the knight, for ruth and for pity\n"
  "For knowen was the false iniquity.\n"
  "The people anon had suspect* in this thing,                   *suspicion\n"
  "By manner of the clerke's challenging,\n"
  "That it was by th'assent of Appius;\n"
  "They wiste well that he was lecherous.\n"
  "For which unto this Appius they gon,\n"
  "And cast him in a prison right anon,\n"
  "Where as he slew himself: and Claudius,\n"
  "That servant was unto this Appius,\n"
  "Was doomed for to hang upon a tree;\n"
  "But that Virginius, of his pity,\n"
  "So prayed for him, that he was exil'd;\n"
  "And elles certes had he been beguil'd;*                    *see note <8>\n"
  "The remenant were hanged, more and less,\n"
  "That were consenting to this cursedness.*                      *villainy\n"
  "Here men may see how sin hath his merite:*                      *deserts\n"
  "Beware, for no man knows how God will smite\n"
  "In no degree, nor in which manner wise\n"
  "The worm of conscience may agrise*                     frighten, horrify\n"
  "Of  wicked life, though it so privy be,\n"
  "That no man knows thereof, save God and he;\n"
  "For be he lewed* man or elles lear'd,**              *ignorant **learned\n"
  "He knows not how soon he shall be afear'd;\n"
  "Therefore I rede* you this counsel take,                         *advise\n"
  "Forsake sin, ere sinne you forsake.\n"
  "\n"
  "\n"
  "Notes to the Doctor's Tale\n"
  "\n"
  "\n"
  "1. Livy, Book iii. cap. 44, et seqq.\n"
  "\n"
  "2. Faconde: utterance, speech; from Latin, \"facundia,\"\n"
  "eloquence.\n"
  "\n"
  "3. Slothe: other readings are \"thought\" and \"youth.\"\n"
  "\n"
  "4. Meschance: wickedness; French, \"mechancete.\"\n"
  "\n"
  "5. This line seems to be a kind of aside thrown in by Chaucer\n"
  "himself.\n"
  "\n"
  "6. The various readings of this word are \"churl,\" or \"cherl,\" in\n"
  "the best manuscripts; \"client\" in the common editions, and\n"
  "\"clerk\" supported by two important manuscripts. \"Client\"\n"
  "would perhaps be the best reading, if it were not awkward for\n"
  "the metre; but between \"churl\" and ''clerk\" there can be little\n"
  "doubt that Mr Wright chose wisely when he preferred the\n"
  "second.\n"
  "\n"
  "7. Judges xi. 37, 38.  \"And she said unto her father,\n"
  "Let .  . . me alone two months, that I may go up and down upon\n"
  "the mountains, and bewail my virginity, I and my fellows.  And\n"
  "he said, go.\"\n"
  "\n"
  "8. Beguiled: \"cast into gaol,\" according to Urry's explanation;\n"
  "though we should probably understand that, if Claudius had not\n"
  "been sent out of the country, his death would have been secretly\n"
  "contrived through private detestation.\n"
  "\n"
  "\n"
  "\n"
  "";
// }

const char pardonersTale0[] PGMSECTION = // { // 18989 bytes
  "THE PARDONER'S TALE.\n"
  "\n"
  "\n"
  "THE PROLOGUE.\n"
  "\n"
  "\n"
  "OUR Hoste gan to swear as he were wood;\n"
  "\"Harow!\" quoth he, \"by nailes and by blood, <1>\n"
  "This was a cursed thief, a false justice.\n"
  "As shameful death as hearte can devise\n"
  "Come to these judges and their advoca's.*        *advocates, counsellors\n"
  "Algate* this sely** maid is slain, alas!        *nevertheless **innocent\n"
  "Alas! too deare bought she her beauty.\n"
  "Wherefore I say, that all day man may see\n"
  "That giftes of fortune and of nature\n"
  "Be cause of death to many a creature.\n"
  "Her beauty was her death, I dare well sayn;\n"
  "Alas! so piteously as she was slain.\n"
  "[Of bothe giftes, that I speak of now\n"
  "Men have full often more harm than prow,*]                       *profit\n"
  "But truely, mine owen master dear,\n"
  "This was a piteous tale for to hear;\n"
  "But natheless, pass over; 'tis *no force.*                   *no matter*\n"
  "I pray to God to save thy gentle corse,*                           *body\n"
  "And eke thine urinals, and thy jordans,\n"
  "Thine Hippocras, and eke thy Galliens, <2>\n"
  "And every boist* full of thy lectuary,                          *box <3>\n"
  "God bless them, and our lady Sainte Mary.\n"
  "So may I the',* thou art a proper man,                           *thrive\n"
  "And like a prelate, by Saint Ronian;\n"
  "Said I not well? Can I not speak *in term?*                *in set form*\n"
  "But well I wot thou dost* mine heart to erme,**      *makest **grieve<4>\n"
  "That I have almost caught a cardiacle:*                   *heartache <5>\n"
  "By corpus Domini <6>, but* I have triacle,**          *unless **a remedy\n"
  "Or else a draught of moist and corny <7> ale,\n"
  "Or but* I hear anon a merry tale,                                *unless\n"
  "Mine heart is brost* for pity of this maid.               *burst, broken\n"
  "Thou *bel ami,*  thou Pardoner,\" he said,                  *good friend*\n"
  "\"Tell us some mirth of japes* right anon.\"                        *jokes\n"
  "\"It shall be done,\" quoth he, \"by Saint Ronion.\n"
  "But first,\" quoth he, \"here at this ale-stake*       *ale-house sign <8>\n"
  "I will both drink, and biten on a cake.\"\n"
  "But right anon the gentles gan to cry,\n"
  "\"Nay, let him tell us of no ribaldry.\n"
  "Tell us some moral thing, that we may lear*                       *learn\n"
  "Some wit,* and thenne will we gladly hear.\"               *wisdom, sense\n"
  "\"I grant y-wis,\"* quoth he; \"but I must think                    *surely\n"
  "Upon some honest thing while that I drink.\"\n"
  "\n"
  "\n"
  "Notes to the Prologue to the Pardoner's Tale\n"
  "\n"
  "\n"
  "1. The nails and blood of Christ, by which it was then a fashion\n"
  "to swear.\n"
  "\n"
  "2. Mediaeval medical writers; see note 36 to the Prologue to the\n"
  "Tales.\n"
  "\n"
  "3. Boist: box; French  \"boite,\" old form \"boiste.\"\n"
  "\n"
  "4. Erme: grieve; from Anglo-Saxon, \"earme,\" wretched.\n"
  "\n"
  "5. Cardiacle:  heartache; from Greek, \"kardialgia.\"\n"
  "\n"
  "6. Corpus Domini: God's body.\n"
  "\n"
  "7. Corny ale:  New and strong, nappy. As to \"moist,\" see note\n"
  "39 to the Prologue to the Tales.\n"
  "\n"
  "8. (Transcriber's Note)In this scene the pilgrims are refreshing\n"
  "themselves at tables in front of an inn.  The pardoner is drunk,\n"
  "which explains his boastful and revealing confession of his\n"
  "deceits.\n"
  "\n"
  "\n"
  "THE TALE <1>\n"
  "\n"
  "\n"
  "Lordings (quoth he), in churche when I preach,\n"
  "I paine me to have an hautein* speech,            *take pains **loud <2>\n"
  "And ring it out, as round as doth a bell,\n"
  "For I know all by rote that I tell.\n"
  "My theme is always one, and ever was;\n"
  "Radix malorum est cupiditas.<3>\n"
  "First I pronounce whence that I come,\n"
  "And then my bulles shew I all and some;\n"
  "Our liege lorde's seal on my patent,\n"
  "That shew I first, *my body to warrent,*             *for the protection\n"
  "That no man be so hardy, priest nor clerk,                 of my person*\n"
  "Me to disturb of Christe's holy werk.\n"
  "And after that then tell I forth my tales.\n"
  "Bulles of popes, and of cardinales,\n"
  "Of patriarchs, and of bishops I shew,\n"
  "And in Latin I speak a wordes few,\n"
  "To savour with my predication,\n"
  "And for to stir men to devotion\n"
  "Then show I forth my longe crystal stones,\n"
  "Y-crammed fall of cloutes* and of bones;                *rags, fragments\n"
  "Relics they be, as *weene they* each one.        *as my listeners think*\n"
  "Then have I in latoun* a shoulder-bone                            *brass\n"
  "Which that was of a holy Jewe's sheep.\n"
  "\"Good men,\" say I, \"take of my wordes keep;*                       *heed\n"
  "If that this bone be wash'd in any well,\n"
  "If cow, or calf, or sheep, or oxe swell,\n"
  "That any worm hath eat, or worm y-stung,\n"
  "Take water of that well, and wash his tongue,\n"
  "And it is whole anon; and farthermore\n"
  "Of pockes, and of scab, and every sore\n"
  "Shall every sheep be whole, that of this well\n"
  "Drinketh a draught; take keep* of that I tell.                     *heed\n"
  "\n"
  "\"If that the goodman, that the beastes oweth,*                   *owneth\n"
  "Will every week, ere that the cock him croweth,\n"
  "Fasting, y-drinken of this well a draught,\n"
  "As thilke holy Jew our elders taught,\n"
  "His beastes and his store shall multiply.\n"
  "And, Sirs, also it healeth jealousy;\n"
  "For though a man be fall'n in jealous rage,\n"
  "Let make with this water his pottage,\n"
  "And never shall he more his wife mistrist,*                    *mistrust\n"
  "*Though he the sooth of her defaulte wist;*             *though he truly\n"
  "All had she taken priestes two or three. <4>               knew her sin*\n"
  "Here is a mittain* eke, that ye may see;                  *glove, mitten\n"
  "He that his hand will put in this mittain,\n"
  "He shall have multiplying of his grain,\n"
  "When he hath sowen, be it wheat or oats,\n"
  "So that he offer pence, or elles groats.\n"
  "And, men and women, one thing warn I you;\n"
  "If any wight be in this churche now\n"
  "That hath done sin horrible, so that he\n"
  "Dare not for shame of it y-shriven* be;                       *confessed\n"
  "Or any woman, be she young or old,\n"
  "That hath y-made her husband cokewold,*                         *cuckold\n"
  "Such folk shall have no power nor no grace\n"
  "To offer to my relics in this place.\n"
  "And whoso findeth him out of such blame,\n"
  "He will come up and offer in God's name;\n"
  "And I assoil* him by the authority                              *absolve\n"
  "Which that by bull y-granted was to me.\"\n"
  "\n"
  "By this gaud* have I wonne year by year                     *jest, trick\n"
  "A hundred marks, since I was pardonere.\n"
  "I stande like a clerk in my pulpit,\n"
  "And when the lewed* people down is set,                        *ignorant\n"
  "I preache so as ye have heard before,\n"
  "And telle them a hundred japes* more.                    *jests, deceits\n"
  "Then pain I me to stretche forth my neck,\n"
  "And east and west upon the people I beck,\n"
  "As doth a dove, sitting on a bern;*                                *barn\n"
  "My handes and my tongue go so yern,*                            *briskly\n"
  "That it is joy to see my business.\n"
  "Of avarice and of such cursedness*                           *wickedness\n"
  "Is all my preaching, for to make them free\n"
  "To give their pence, and namely* unto me.                    *especially\n"
  "For mine intent is not but for to win,\n"
  "And nothing for correction of sin.\n"
  "I recke never, when that they be buried,\n"
  "Though that their soules go a blackburied.<5>\n"
  "For certes *many a predication              *preaching is often inspired\n"
  "Cometh oft-time of evil intention;*                     by evil motives*\n"
  "Some for pleasance of folk, and flattery,\n"
  "To be advanced by hypocrisy;\n"
  "And some for vainglory, and some for hate.\n"
  "For, when I dare not otherwise debate,\n"
  "Then will I sting him with my tongue smart*                     *sharply\n"
  "In preaching, so that he shall not astart*                       *escape\n"
  "To be defamed falsely, if that he\n"
  "Hath trespass'd* to my brethren or to me.                      *offended\n"
  "For, though I telle not his proper name,\n"
  "Men shall well knowe that it is the same\n"
  "By signes, and by other circumstances.\n"
  "Thus *quite I* folk that do us displeasances:         *I am revenged on*\n"
  "Thus spit I out my venom, under hue\n"
  "Of holiness, to seem holy and true.\n"
  "But, shortly mine intent I will devise,\n"
  "I preach of nothing but of covetise.\n"
  "Therefore my theme is yet, and ever was, --\n"
  "Radix malorum est cupiditas. <3>\n"
  "Thus can I preach against the same vice\n"
  "Which that I use, and that is avarice.\n"
  "But though myself be guilty in that sin,\n"
  "Yet can I maken other folk to twin*                              *depart\n"
  "From avarice, and sore them repent.\n"
  "But that is not my principal intent;\n"
  "I preache nothing but for covetise.\n"
  "Of this mattere it ought enough suffice.\n"
  "Then tell I them examples many a one,\n"
  "Of olde stories longe time gone;\n"
  "For lewed* people love tales old;                             *unlearned\n"
  "Such thinges can they well report and hold.\n"
  "What? trowe ye, that whiles I may preach\n"
  "And winne gold and silver for* I teach,                         *because\n"
  "That I will live in povert' wilfully?\n"
  "Nay, nay, I thought it never truely.\n"
  "For I will preach and beg in sundry lands;\n"
  "I will not do no labour with mine hands,\n"
  "Nor make baskets for to live thereby,\n"
  "Because I will not beggen idlely.\n"
  "I will none of the apostles counterfeit;*          *imitate (in poverty)\n"
  "I will have money, wool, and cheese, and wheat,\n"
  "All* were it given of the poorest page,                         *even if\n"
  "Or of the pooreste widow in a village:\n"
  "All should her children sterve* for famine.                         *die\n"
  "Nay, I will drink the liquor of the vine,\n"
  "And have a jolly wench in every town.\n"
  "But hearken, lordings, in conclusioun;\n"
  "Your liking is, that I shall tell a tale\n"
  "Now I have drunk a draught of corny ale,\n"
  "By God, I hope I shall you tell a thing\n"
  "That shall by reason be to your liking;\n"
  "For though myself be a full vicious man,\n"
  "A moral tale yet I you telle can,\n"
  "Which I am wont to preache, for to win.\n"
  "Now hold your peace, my tale I will begin.\n"
  "\n"
  "\n"
  "In Flanders whilom was a company\n"
  "Of younge folkes, that haunted folly,\n"
  "As riot, hazard, stewes,* and taverns;                         *brothels\n"
  "Where as with lutes, harpes, and giterns,*                      *guitars\n"
  "They dance and play at dice both day and night,\n"
  "And eat also, and drink over their might;\n"
  "Through which they do the devil sacrifice\n"
  "Within the devil's temple, in cursed wise,\n"
  "By superfluity abominable.\n"
  "Their oathes be so great and so damnable,\n"
  "That it is grisly* for to hear them swear.                 *dreadful <6>\n"
  "Our blissful Lorde's body they to-tear;*             *tore to pieces <7>\n"
  "Them thought the Jewes rent him not enough,\n"
  "And each of them at other's sinne lough.*                       *laughed\n"
  "And right anon in come tombesteres <8>\n"
  "Fetis* and small, and younge fruitesteres.**       *dainty **fruit-girls\n"
  "Singers with harpes, baudes,* waferers,**      *revellers **cake-sellers\n"
  "Which be the very devil's officers,\n"
  "To kindle and blow the fire of lechery,\n"
  "That is annexed unto gluttony.\n"
  "The Holy Writ take I to my witness,\n"
  "That luxury is in wine and drunkenness. <9>\n"
  "Lo, how that drunken Lot unkindely*                         *unnaturally\n"
  "Lay by his daughters two unwittingly,\n"
  "So drunk he was he knew not what he wrought.\n"
  "Herodes, who so well the stories sought, <10>\n"
  "When he of wine replete was at his feast,\n"
  "Right at his owen table gave his hest*                          *command\n"
  "To slay the Baptist John full guilteless.\n"
  "Seneca saith a good word, doubteless:\n"
  "He saith he can no difference find\n"
  "Betwixt a man that is out of his mind,\n"
  "And a man whiche that is drunkelew:*                    *a drunkard <11>\n"
  "But that woodness,* y-fallen in a shrew,*   *madness **one evil-tempered\n"
  "Persevereth longer than drunkenness.\n"
  "\n"
  "O gluttony, full of all cursedness;\n"
  "O cause first of our confusion,\n"
  "Original of our damnation,\n"
  "Till Christ had bought us with his blood again!\n"
  "Looke, how deare, shortly for to sayn,\n"
  "Abought* was first this cursed villainy:                     *atoned for\n"
  "Corrupt was all this world for gluttony.\n"
  "Adam our father, and his wife also,\n"
  "From Paradise, to labour and to woe,\n"
  "Were driven for that vice, it is no dread.*                       *doubt\n"
  "For while that Adam fasted, as I read,\n"
  "He was in Paradise; and when that he\n"
  "Ate of the fruit defended* of the tree,                  *forbidden <12>\n"
  "Anon he was cast out to woe and pain.\n"
  "O gluttony! well ought us on thee plain.\n"
  "Oh! wist a man how many maladies\n"
  "Follow of excess and of gluttonies,\n"
  "He woulde be the more measurable*                              *moderate\n"
  "Of his diete, sitting at his table.\n"
  "Alas! the shorte throat, the tender mouth,\n"
  "Maketh that east and west, and north and south,\n"
  "In earth, in air, in water, men do swink*                        *labour\n"
  "To get a glutton dainty meat and drink.\n"
  "Of this mattere, O Paul! well canst thou treat\n"
  "Meat unto womb,* and womb eke unto meat,                          *belly\n"
  "Shall God destroye both, as Paulus saith. <13>\n"
  "Alas! a foul thing is it, by my faith,\n"
  "To say this word, and fouler is the deed,\n"
  "When man so drinketh of the *white and red,*                 *i.e. wine*\n"
  "That of his throat he maketh his privy\n"
  "Through thilke cursed superfluity\n"
  "The apostle saith, <14> weeping full piteously,\n"
  "There walk many, of which you told have I, --\n"
  "I say it now weeping with piteous voice, --\n"
  "That they be enemies of Christe's crois;*                         *cross\n"
  "Of which the end is death; womb* is their God.                    *belly\n"
  "O womb, O belly, stinking is thy cod,*                         *bag <15>\n"
  "Full fill'd of dung and of corruptioun;\n"
  "At either end of thee foul is the soun.\n"
  "How great labour and cost is thee to find!*                      *supply\n"
  "These cookes how they stamp, and strain, and grind,\n"
  "And turne substance into accident,\n"
  "To fulfill all thy likerous talent!\n"
  "Out of the harde bones knocke they\n"
  "The marrow, for they caste naught away\n"
  "That may go through the gullet soft and swoot*                    *sweet\n"
  "Of spicery and leaves, of bark and root,\n"
  "Shall be his sauce y-maked by delight,\n"
  "To make him have a newer appetite.\n"
  "But, certes, he that haunteth such delices\n"
  "Is dead while that he liveth in those vices.\n"
  "\n"
  "A lecherous thing is wine, and drunkenness\n"
  "Is full of striving and of wretchedness.\n"
  "O drunken man! disfgur'd is thy face,<16>\n"
  "Sour is thy breath, foul art thou to embrace:\n"
  "And through thy drunken nose sowneth the soun',\n"
  "As though thous saidest aye, Samsoun! Samsoun!\n"
  "And yet, God wot, Samson drank never wine.\n"
  "Thou fallest as it were a sticked swine;\n"
  "Thy tongue is lost, and all thine honest cure;*                    *care\n"
  "For drunkenness is very sepulture*                                 *tomb\n"
  "Of manne's wit and his discretion.\n"
  "In whom that drink hath domination,\n"
  "He can no counsel keep, it is no dread.*                          *doubt\n"
  "Now keep you from the white and from the red,\n"
  "And namely* from the white wine of Lepe,<17>                 *especially\n"
  "That is to sell in Fish Street <18> and in Cheap.\n"
  "This wine of Spaine creepeth subtilly  --\n"
  "In other wines growing faste by,\n"
  "Of which there riseth such fumosity,\n"
  "That when a man hath drunken draughtes three,\n"
  "And weeneth that he be at home in Cheap,\n"
  "He is in Spain, right at the town of Lepe,\n"
  "Not at the Rochelle, nor at Bourdeaux town;\n"
  "And thenne will he say, Samsoun! Samsoun!\n"
  "But hearken, lordings, one word, I you pray,\n"
  "That all the sovreign actes, dare I say,\n"
  "Of victories in the Old Testament,\n"
  "Through very God that is omnipotent,\n"
  "Were done in abstinence and in prayere:\n"
  "Look in the Bible, and there ye may it lear.*                     *learn\n"
  "Look, Attila, the greate conqueror,\n"
  "Died in his sleep, <19> with shame and dishonour,\n"
  "Bleeding aye at his nose in drunkenness:\n"
  "A captain should aye live in soberness\n"
  "And o'er all this, advise* you right well             *consider, bethink\n"
  "What was commanded unto Lemuel; <20>\n"
  "Not Samuel, but Lemuel, say I.\n"
  "Reade the Bible, and find it expressly\n"
  "Of wine giving to them that have justice.\n"
  "No more of this, for it may well suffice.\n"
  "\n"
  "And, now that I have spoke of gluttony,\n"
  "Now will I you *defende hazardry.*                     *forbid gambling*\n"
  "Hazard is very mother of leasings,*                                *lies\n"
  "And of deceit, and cursed forswearings:\n"
  "Blasphem' of Christ, manslaughter, and waste also\n"
  "Of chattel* and of time; and furthermo'                        *property\n"
  "It is repreve,* and contrar' of honour,                        *reproach\n"
  "For to be held a common hazardour.\n"
  "And ever the higher he is of estate,\n"
  "The more he is holden desolate.*                      *undone, worthless\n"
  "If that a prince use hazardry,\n"
  "In alle governance and policy\n"
  "He is, as by common opinion,\n"
  "Y-hold the less in reputation.\n"
  "\n"
  "Chilon, that was a wise ambassador,\n"
  "Was sent to Corinth with full great honor\n"
  "From Lacedemon, <21> to make alliance;\n"
  "And when he came, it happen'd him, by chance,\n"
  "That all the greatest that were of that land,\n"
  "Y-playing atte hazard he them fand.*                              *found\n"
  "For which, as soon as that it mighte be,\n"
  "He stole him home again to his country\n"
  "And saide there, \"I will not lose my name,\n"
  "Nor will I take on me so great diffame,*                       *reproach\n"
  "You to ally unto no hazardors.*                                *gamblers\n"
  "Sende some other wise ambassadors,\n"
  "For, by my troth, me were lever* die,                            *rather\n"
  "Than I should you to hazardors ally.\n"
  "For ye, that be so glorious in honours,\n"
  "Shall not ally you to no hazardours,\n"
  "As by my will, nor as by my treaty.\"\n"
  "This wise philosopher thus said he.\n"
  "Look eke how to the King Demetrius\n"
  "The King of Parthes, as the book saith us,\n"
  "Sent him a pair of dice of gold in scorn,\n"
  "For he had used hazard therebeforn:\n"
  "For which he held his glory and renown\n"
  "At no value or reputatioun.\n"
  "Lordes may finden other manner play\n"
  "Honest enough to drive the day away.\n"
  "\n"
  "Now will I speak of oathes false and great\n"
  "A word or two, as olde bookes treat.\n"
  "Great swearing is a thing abominable,\n"
  "And false swearing is more reprovable.\n"
  "The highe God forbade swearing at all;\n"
  "Witness on Matthew: <22> but in special\n"
  "Of swearing saith the holy Jeremie, <23>\n"
  "Thou thalt swear sooth thine oathes, and not lie:\n"
  "And swear in doom* and eke in righteousness;                  *judgement\n"
  "But idle swearing is a cursedness.*                          *wickedness\n"
  "Behold and see, there in the firste table\n"
  "Of highe Godde's hestes* honourable,                       *commandments\n"
  "How that the second best of him is this,\n"
  "Take not my name in idle* or amiss.                             *in vain\n"
  "Lo, rather* he forbiddeth such swearing,                         *sooner\n"
  "Than homicide, or many a cursed thing;\n"
  "I say that as by order thus it standeth;\n"
  "This knoweth he that his hests* understandeth,             *commandments\n"
  "How that the second hest of God is that.\n"
  "And farthermore, I will thee tell all plat,*            *flatly, plainly\n"
  "That vengeance shall not parte from his house,\n"
  "That of his oathes is outrageous.\n"
  "\"By Godde's precious heart, and by his nails, <24>\n"
  "And by the blood of Christ, that is in Hailes, <25>\n"
  "Seven is my chance, and thine is cinque and trey:\n"
  "By Godde's armes, if thou falsely play,\n"
  "This dagger shall throughout thine hearte go.\"\n"
  "This fruit comes of the *bicched bones two,*   *two cursed bones (dice)*\n"
  "Forswearing, ire, falseness, and homicide.\n"
  "Now, for the love of Christ that for us died,\n"
  "Leave your oathes, bothe great and smale.\n"
  "But, Sirs, now will I ell you forth my tale.\n"
  "\n"
  "";
// }

const char pardonersTale1[] PGMSECTION = // { // 19690 bytes
  "These riotoures three, of which I tell,\n"
  "Long *erst than* prime rang of any bell,                         *before\n"
  "Were set them in a tavern for to drink;\n"
  "And as they sat, they heard a belle clink\n"
  "Before a corpse, was carried to the grave.\n"
  "That one of them gan calle to his knave,*                       *servant\n"
  "\"Go bet,\" <26> quoth he, \"and aske readily\n"
  "What corpse is this, that passeth here forth by;\n"
  "And look that thou report his name well.\"\n"
  "\"Sir,\" quoth the boy, \"it needeth never a deal;*                   *whit\n"
  "It was me told ere ye came here two hours;\n"
  "He was, pardie, an old fellow of yours,\n"
  "And suddenly he was y-slain to-night;\n"
  "Fordrunk* as he sat on his bench upright,              *completely drunk\n"
  "There came a privy thief, men clepe Death,\n"
  "That in this country all the people slay'th,\n"
  "And with his spear he smote his heart in two,\n"
  "And went his way withoute wordes mo'.\n"
  "He hath a thousand slain this pestilence;\n"
  "And, master, ere you come in his presence,\n"
  "Me thinketh that it were full necessary\n"
  "For to beware of such an adversary;\n"
  "Be ready for to meet him evermore.\n"
  "Thus taughte me my dame; I say no more.\"\n"
  "\"By Sainte Mary,\" said the tavernere,\n"
  "\"The child saith sooth, for he hath slain this year,\n"
  "Hence ov'r a mile, within a great village,\n"
  "Both man and woman, child, and hind, and page;\n"
  "I trow his habitation be there;\n"
  "To be advised* great wisdom it were,           *watchful, on one's guard\n"
  "Ere* that he did a man a dishonour.\"                               *lest\n"
  "\n"
  "\"Yea, Godde's armes,\" quoth this riotour,\n"
  "\"Is it such peril with him for to meet?\n"
  "I shall him seek, by stile and eke by street.\n"
  "I make a vow, by Godde's digne* bones.\"                          *worthy\n"
  "Hearken, fellows, we three be alle ones:*                        *at one\n"
  "Let each of us hold up his hand to other,\n"
  "And each of us become the other's brother,\n"
  "And we will slay this false traitor Death;\n"
  "He shall be slain, he that so many slay'th,\n"
  "By Godde's dignity, ere it be night.\"\n"
  "Together have these three their trothe plight\n"
  "To live and die each one of them for other\n"
  "As though he were his owen sworen brother.\n"
  "And up they start, all drunken, in this rage,\n"
  "And forth they go towardes that village\n"
  "Of which the taverner had spoke beforn,\n"
  "And many a grisly* oathe have they sworn,                      *dreadful\n"
  "And Christe's blessed body they to-rent;*            *tore to pieces <7>\n"
  "\"Death shall be dead, if that we may him hent.\"*                  *catch\n"
  "When they had gone not fully half a mile,\n"
  "Right as they would have trodden o'er a stile,\n"
  "An old man and a poore with them met.\n"
  "This olde man full meekely them gret,*                          *greeted\n"
  "And saide thus; \"Now, lordes, God you see!\"*         *look on graciously\n"
  "The proudest of these riotoures three\n"
  "Answer'd again; \"What? churl, with sorry grace,\n"
  "Why art thou all forwrapped* save thy face?            *closely wrapt up\n"
  "Why livest thou so long in so great age?\"\n"
  "This olde man gan look on his visage,\n"
  "And saide thus; \"For that I cannot find\n"
  "A man, though that I walked unto Ind,\n"
  "Neither in city, nor in no village go,\n"
  "That woulde change his youthe for mine age;\n"
  "And therefore must I have mine age still\n"
  "As longe time as it is Godde's will.\n"
  "And Death, alas! he will not have my life.\n"
  "Thus walk I like a resteless caitife,*                 *miserable wretch\n"
  "And on the ground, which is my mother's gate,\n"
  "I knocke with my staff, early and late,\n"
  "And say to her, 'Leve* mother, let me in.                          *dear\n"
  "Lo, how I wane, flesh, and blood, and skin;\n"
  "Alas! when shall my bones be at rest?\n"
  "Mother, with you I woulde change my chest,\n"
  "That in my chamber longe time hath be,\n"
  "Yea, for an hairy clout to *wrap in me.'*               *wrap myself in*\n"
  "But yet to me she will not do that grace,\n"
  "For which fall pale and welked* is my face.                    *withered\n"
  "But, Sirs, to you it is no courtesy\n"
  "To speak unto an old man villainy,\n"
  "But* he trespass in word or else in deed.                        *except\n"
  "In Holy Writ ye may yourselves read;\n"
  "'Against* an old man, hoar upon his head,                       *to meet\n"
  "Ye should arise:' therefore I you rede,*                         *advise\n"
  "Ne do unto an old man no harm now,\n"
  "No more than ye would a man did you\n"
  "In age, if that ye may so long abide.\n"
  "And God be with you, whether ye go or ride\n"
  "I must go thither as I have to go.\"\n"
  "\n"
  "\"Nay, olde churl, by God thou shalt not so,\"\n"
  "Saide this other hazardor anon;\n"
  "\"Thou partest not so lightly, by Saint John.\n"
  "Thou spakest right now of that traitor Death,\n"
  "That in this country all our friendes slay'th;\n"
  "Have here my troth, as thou art his espy;*                          *spy\n"
  "Tell where he is, or thou shalt it abie,*                    *suffer for\n"
  "By God and by the holy sacrament;\n"
  "For soothly thou art one of his assent\n"
  "To slay us younge folk, thou false thief.\"\n"
  "\"Now, Sirs,\" quoth he, \"if it be you so lief*                    *desire\n"
  "To finde Death, turn up this crooked way,\n"
  "For in that grove I left him, by my fay,\n"
  "Under a tree, and there he will abide;\n"
  "Nor for your boast he will him nothing hide.\n"
  "See ye that oak? right there ye shall him find.\n"
  "God save you, that bought again mankind,\n"
  "And you amend!\" Thus said this olde man;\n"
  "And evereach of these riotoures ran,\n"
  "Till they came to the tree, and there they found\n"
  "Of florins fine, of gold y-coined round,\n"
  "Well nigh a seven bushels, as them thought.\n"
  "No longer as then after Death they sought;\n"
  "But each of them so glad was of the sight,\n"
  "For that the florins were so fair and bright,\n"
  "That down they sat them by the precious hoard.\n"
  "The youngest of them spake the firste word:\n"
  "\"Brethren,\" quoth he, \"*take keep* what I shall say;              *heed*\n"
  "My wit is great, though that I bourde* and play            *joke, frolic\n"
  "This treasure hath Fortune unto us given\n"
  "In mirth and jollity our life to liven;\n"
  "And lightly as it comes, so will we spend.\n"
  "Hey! Godde's precious dignity! who wend*                *weened, thought\n"
  "Today that we should have so fair a grace?\n"
  "But might this gold he carried from this place\n"
  "Home to my house, or elles unto yours\n"
  "(For well I wot that all this gold is ours),\n"
  "Then were we in high felicity.\n"
  "But truely by day it may not be;\n"
  "Men woulde say that we were thieves strong,\n"
  "And for our owen treasure do us hong.*                   *have us hanged\n"
  "This treasure muste carried be by night,\n"
  "As wisely and as slily as it might.\n"
  "Wherefore I rede,* that cut** among us all                *advise **lots\n"
  "We draw, and let see where the cut will fall:\n"
  "And he that hath the cut, with hearte blithe\n"
  "Shall run unto the town, and that full swithe,*                 *quickly\n"
  "And bring us bread and wine full privily:\n"
  "And two of us shall keepe subtilly\n"
  "This treasure well: and if he will not tarry,\n"
  "When it is night, we will this treasure carry,\n"
  "By one assent, where as us thinketh best.\"\n"
  "Then one of them the cut brought in his fist,\n"
  "And bade them draw, and look where it would fall;\n"
  "And it fell on the youngest of them all;\n"
  "And forth toward the town he went anon.\n"
  "And all so soon as  that he was y-gone,\n"
  "The one of them spake thus unto the other;\n"
  "\"Thou knowest well that thou art my sworn brother,\n"
  "*Thy profit* will I tell thee right anon.             *what is for thine\n"
  "Thou knowest well that our fellow is gone,                    advantage*\n"
  "And here is gold, and that full great plenty,\n"
  "That shall departed* he among us three.                         *divided\n"
  "But natheless, if I could shape* it so                         *contrive\n"
  "That it departed were among us two,\n"
  "Had I not done a friende's turn to thee?\"\n"
  "Th' other answer'd, \"I n'ot* how that may be;                  *know not\n"
  "He knows well that the gold is with us tway.\n"
  "What shall we do? what shall we to him say?\"\n"
  "\"Shall it be counsel?\"* said the firste shrew;**        *secret **wretch\n"
  "\"And I shall tell to thee in wordes few\n"
  "What we shall do, and bring it well about.\"\n"
  "\"I grante,\" quoth the other, \"out of doubt,\n"
  "That by my truth I will thee not bewray.\"*                       *betray\n"
  "\"Now,\" quoth the first, \"thou know'st well we be tway,\n"
  "And two of us shall stronger be than one.\n"
  "Look; when that he is set,* thou right anon                    *sat down\n"
  "Arise, as though thou wouldest with him play;\n"
  "And I shall rive* him through the sides tway,                      *stab\n"
  "While that thou strugglest with him as in game;\n"
  "And with thy dagger look thou do the same.\n"
  "And then shall all this gold departed* be,                      *divided\n"
  "My deare friend, betwixte thee and me:\n"
  "Then may we both our lustes* all fulfil,                      *pleasures\n"
  "And play at dice right at our owen will.\"\n"
  "And thus accorded* be these shrewes** tway            *agreed **wretches\n"
  "To slay the third, as ye have heard me say.\n"
  "\n"
  "The youngest, which that wente to the town,\n"
  "Full oft in heart he rolled up and down\n"
  "The beauty of these florins new and bright.\n"
  "\"O Lord!\" quoth he, \"if so were that I might\n"
  "Have all this treasure to myself alone,\n"
  "There is no man that lives under the throne\n"
  "Of God, that shoulde have so merry as I.\"\n"
  "And at the last the fiend our enemy\n"
  "Put in his thought, that he should poison buy,\n"
  "With which he mighte slay his fellows twy.*                         *two\n"
  "For why, the fiend found him *in such living,*           *leading such a\n"
  "That he had leave to sorrow him to bring.                    (bad) life*\n"
  "For this was utterly his full intent\n"
  "To slay them both, and never to repent.\n"
  "And forth he went, no longer would he tarry,\n"
  "Into the town to an apothecary,\n"
  "And prayed him that he him woulde sell\n"
  "Some poison, that he might *his rattes quell,*           *kill his rats*\n"
  "And eke there was a polecat in his haw,*          *farm-yard, hedge <27>\n"
  "That, as he said, his eapons had y-slaw:*                         *slain\n"
  "And fain he would him wreak,* if that he might,                 *revenge\n"
  "Of vermin that destroyed him by night.\n"
  "Th'apothecary answer'd, \"Thou shalt have\n"
  "A thing, as wisly* God my soule save,                            *surely\n"
  "In all this world there is no creature\n"
  "That eat or drank hath of this confecture,\n"
  "Not but the mountance* of a corn of wheat,                       *amount\n"
  "That he shall not his life *anon forlete;*        *immediately lay down*\n"
  "Yea, sterve* he shall, and that in lesse while                      *die\n"
  "Than thou wilt go *apace* nought but a mile:                   *quickly*\n"
  "This poison is so strong and violent.\"\n"
  "This cursed man hath in his hand y-hent*                          *taken\n"
  "This poison in a box, and swift he ran\n"
  "Into the nexte street, unto a man,\n"
  "And borrow'd of him large bottles three;\n"
  "And in the two the poison poured he;\n"
  "The third he kepte clean for his own drink,\n"
  "For all the night he shope him* for to swink**        *purposed **labour\n"
  "In carrying off the gold out of that place.\n"
  "And when this riotour, with sorry grace,\n"
  "Had fill'd with wine his greate bottles three,\n"
  "\n"
  "To his fellows again repaired he.\n"
  "What needeth it thereof to sermon* more?                *talk, discourse\n"
  "For, right as they had cast* his death before,                  *plotted\n"
  "Right so they have him slain, and that anon.\n"
  "And when that this was done, thus spake the one;\n"
  "\"Now let us sit and drink, and make us merry,\n"
  "And afterward we will his body bury.\"\n"
  "And with that word it happen'd him *par cas*                  *by chance\n"
  "To take the bottle where the poison was,\n"
  "And drank, and gave his fellow drink also,\n"
  "For which anon they sterved* both the two.                         *died\n"
  "But certes I suppose that Avicen\n"
  "Wrote never in no canon, nor no fen, <28>\n"
  "More wondrous signes of empoisoning,\n"
  "Than had these wretches two ere their ending.\n"
  "Thus ended be these homicides two,\n"
  "And eke the false empoisoner also.\n"
  "\n"
  "O cursed sin, full of all cursedness!\n"
  "O trait'rous homicide! O wickedness!\n"
  "O glutt'ny, luxury, and hazardry!\n"
  "Thou blasphemer of Christ with villany,*               *outrage, impiety\n"
  "And oathes great, of usage and of pride!\n"
  "Alas! mankinde, how may it betide,\n"
  "That to thy Creator, which that thee wrought,\n"
  "And with his precious hearte-blood thee bought,\n"
  "Thou art so false and so unkind,* alas!                       *unnatural\n"
  "Now, good men, God forgive you your trespass,\n"
  "And ware* you from the sin of avarice.                             *keep\n"
  "Mine holy pardon may you all warice,*                              *heal\n"
  "So that ye offer *nobles or sterlings,*           *gold or silver coins*\n"
  "Or elles silver brooches, spoons, or rings.\n"
  "Bowe your head under this holy bull.\n"
  "Come up, ye wives, and offer of your will;\n"
  "Your names I enter in my roll anon;\n"
  "Into the bliss of heaven shall ye gon;\n"
  "I you assoil* by mine high powere,                         *absolve <29>\n"
  "You that will offer, as clean and eke as clear\n"
  "As ye were born. Lo, Sires, thus I preach;\n"
  "And Jesus Christ, that is our soules' leech,*                    *healer\n"
  "So grante you his pardon to receive;\n"
  "For that is best, I will not deceive.\n"
  "\n"
  "But, Sirs, one word forgot I in my tale;\n"
  "I have relics and pardon in my mail,\n"
  "As fair as any man in Engleland,\n"
  "Which were me given by the Pope's hand.\n"
  "If any of you will of devotion\n"
  "Offer, and have mine absolution,\n"
  "Come forth anon, and kneele here adown\n"
  "And meekely receive my pardoun.\n"
  "Or elles take pardon, as ye wend,*                                   *go\n"
  "All new and fresh at every towne's end,\n"
  "So that ye offer, always new and new,\n"
  "Nobles or pence which that be good and true.\n"
  "'Tis an honour to evereach* that is here,                      *each one\n"
  "That ye have a suffisant* pardonere                            *suitable\n"
  "T'assoile* you in country as ye ride,                           *absolve\n"
  "For aventures which that may betide.\n"
  "Paraventure there may fall one or two\n"
  "Down of his horse, and break his neck in two.\n"
  "Look, what a surety is it to you all,\n"
  "That I am in your fellowship y-fall,\n"
  "That may assoil* you bothe *more and lass,*                     *absolve\n"
  "When that the soul shall from the body pass.           *great and small*\n"
  "I rede* that our Hoste shall begin,                              *advise\n"
  "For he is most enveloped in sin.\n"
  "Come forth, Sir Host, and offer first anon,\n"
  "And thou shalt kiss; the relics every one,\n"
  "Yea, for a groat; unbuckle anon thy purse.\n"
  "\n"
  "\"Nay, nay,\" quoth he, \"then have I Christe's curse!\n"
  "Let be,\" quoth he, \"it shall not be, *so the'ch.*      *so may I thrive*\n"
  "Thou wouldest make me kiss thine olde breech,\n"
  "And swear it were a relic of a saint,\n"
  "Though it were with thy *fundament depaint'.*   *stained by your bottom*\n"
  "But, by the cross which that Saint Helen fand,*              *found <30>\n"
  "I would I had thy coilons* in mine hand,                      *testicles\n"
  "Instead of relics, or of sanctuary.\n"
  "Let cut them off, I will thee help them carry;\n"
  "They shall be shrined in a hogge's turd.\"\n"
  "The Pardoner answered not one word;\n"
  "So wroth he was, no worde would he say.\n"
  "\n"
  "\"Now,\" quoth our Host, \"I will no longer play\n"
  "With thee, nor with none other angry man.\"\n"
  "But right anon the worthy Knight began\n"
  "(When that he saw that all the people lough*),                  *laughed\n"
  "\"No more of this, for it is right enough.\n"
  "Sir Pardoner, be merry and glad of cheer;\n"
  "And ye, Sir Host, that be to me so dear,\n"
  "I pray you that ye kiss the Pardoner;\n"
  "And, Pardoner, I pray thee draw thee ner,*                       *nearer\n"
  "And as we didde, let us laugh and play.\"\n"
  "Anon they kiss'd, and rode forth their way.\n"
  "\n"
  "\n"
  "Notes to the Pardoner's Tale\n"
  "\n"
  "\n"
  "1. The outline of this Tale is to be found in the \"Cento Novelle\n"
  "Antiche,\" but the original is now lost. As in the case of the Wife\n"
  "of Bath's Tale, there is a long prologue, but in this case it has\n"
  "been treated as part of the Tale.\n"
  "\n"
  "2. Hautein: loud, lofty; from French, \"hautain.\"\n"
  "\n"
  "3. Radix malorum est cupiditas: \"the love of money is the root\n"
  "of all evil\" (1 Tim.vi. 10)\n"
  "\n"
  "4.All had she taken priestes two or three: even if she had\n"
  "committed adultery with two or three priests.\n"
  "\n"
  "5. Blackburied: The meaning of this is not very clear, but it is\n"
  "probably a periphrastic and picturesque way of indicating\n"
  "damnation.\n"
  "\n"
  "6. Grisly: dreadful; fitted to \"agrise\" or horrify the listener.\n"
  "\n"
  "7.  Mr Wright says: \"The common oaths in the Middle Ages\n"
  "were by the different parts of God's body; and the popular\n"
  "preachers represented that profane swearers tore Christ's body\n"
  "by their imprecations.\" The idea was doubtless borrowed from\n"
  "the passage in Hebrews (vi. 6), where apostates are said to\n"
  "\"crucify to themselves the Son of God afresh, and put Him to\n"
  "an open shame.\"\n"
  "\n"
  "8. Tombesteres: female dancers or tumblers; from Anglo-\n"
  "Saxon, \"tumban,\" to dance.\n"
  "\n"
  "9. \"Be not drunk with wine, wherein is excess.\" Eph. v.18.\n"
  "\n"
  "10. The reference is probably to the diligent inquiries Herod\n"
  "made at the time of Christ's birth. See Matt. ii. 4-8\n"
  "\n"
  "11. A drunkard. \"Perhaps,\" says Tyrwhitt, \"Chaucer refers to\n"
  "Epist. LXXXIII., 'Extende in plures dies illum ebrii habitum;\n"
  "nunquid de furore dubitabis? nunc quoque non est minor sed\n"
  "brevior.'\"  (\"Prolong the drunkard's condition to several days;\n"
  "will you doubt his madness? Even as it is, the madness is no\n"
  "less; merely shorter.\")\n"
  "\n"
  "12. Defended: forbidden; French, \"defendu.\"  St Jerome, in his\n"
  "book against Jovinian, says that so long as Adam fasted, he was\n"
  "in Paradise; he ate, and he was thrust out.\n"
  "\n"
  "13. \"Meats for the belly, and the belly for meats; but God shall\n"
  "destroy both it and them.\" 1 Cor. vi. 13.\n"
  "\n"
  "14. \"For many walk, of whom I have told you often, and now\n"
  "tell you even weeping, that they are the enemies of the cross of\n"
  "Christ:  Whose end is destruction, whose God is their belly, and\n"
  "whose glory is in their shame, who mind earthly things.\"  Phil.\n"
  "iii. 18, 19.\n"
  "\n"
  "15. Cod: bag; Anglo-Saxon, \"codde;\" hence peas-cod, pin-cod\n"
  "(pin-cushion), &c.\n"
  "\n"
  "16. Compare with the lines which follow, the picture of the\n"
  "drunken messenger in the Man of Law's Tale.\n"
  "\n"
  "17. Lepe:  A town near Cadiz, whence a stronger wine than the\n"
  "Gascon vintages afforded was imported to England. French\n"
  "wine was often adulterated with the cheaper and stronger\n"
  "Spanish.\n"
  "\n"
  "18. Another reading is \"Fleet Street.\"\n"
  "\n"
  "19. Attila was suffocated in the night by a haemorrhage,\n"
  "brought on by a debauch, when he was preparing a new\n"
  "invasion of Italy, in 453.\n"
  "\n"
  "20. \"It is not for kings, O Lemuel, it is not for kings to drink\n"
  "wine, nor for princes strong drink; lest they drink, and forget\n"
  "the law, and pervert the judgment of any of the afflicted.\" Prov.\n"
  "xxxi. 4, 5.\n"
  "\n"
  "21. Most manuscripts, evidently in error, have \"Stilbon\" and\n"
  "\"Calidone\" for Chilon and Lacedaemon. Chilon was one of the\n"
  "seven sages of Greece, and flourished about B.C. 590.\n"
  "According to Diogenes Laertius, he died, under the pressure of\n"
  "age and joy, in the arms of his son, who had just been crowned\n"
  "victor at the Olympic games.\n"
  "\n"
  "22. \"Swear not at all;\" Christ's words in Matt. v. 34.\n"
  "\n"
  "23. \"And thou shalt swear, the lord liveth in truth, in judgement,\n"
  "and in righteousness.\"  Jeremiah iv. 2\n"
  "\n"
  "24. The nails that fastened Christ on the cross, which were\n"
  "regarded with superstitious reverence.\n"
  "\n"
  "25. Hailes: An abbey in Gloucestershire, where, under the\n"
  "designation of \"the blood of Hailes,\" a portion of  Christ's blood\n"
  "was preserved.\n"
  "\n"
  "26. Go bet: a hunting phrase; apparently its force is, \"go beat up\n"
  "the game.\"\n"
  "\n"
  "27. Haw; farm-yard, hedge  Compare the French, \"haie.\"\n"
  "\n"
  "28. Avicen, or Avicenna, was among the distinguished\n"
  "physicians of the Arabian school in the eleventh century, and\n"
  "very popular in the Middle Ages.  His great work was called\n"
  "\"Canon Medicinae,\" and was divided into \"fens,\" \"fennes,\" or\n"
  "sections.\n"
  "\n"
  "29. Assoil:  absolve. compare the Scotch law-term \"assoilzie,\"\n"
  "to acquit.\n"
  "\n"
  "30. Saint Helen, according to Sir John Mandeville, found the\n"
  "cross of Christ deep below ground, under a rock, where the\n"
  "Jews had hidden it; and she tested the genuineness of the sacred\n"
  "tree, by raising to life a dead man laid upon it.\n"
  "\n"
  "\n"
  "\n"
  "\n"
  "\n"
  "";
// }

const char shipmansTale[] PGMSECTION = // { // 24604 bytes
  "THE SHIPMAN'S TALE.<1>\n"
  "\n"
  "\n"
  "THE PROLOGUE\n"
  "\n"
  "\n"
  "Our Host upon his stirrups stood anon,\n"
  "And saide; \"Good men, hearken every one,\n"
  "This was a thrifty* tale for the nones.            *discreet, profitable\n"
  "Sir Parish Priest,\" quoth he, \"for Godde's bones,\n"
  "Tell us a tale, as was thy *forword yore:*            *promise formerly*\n"
  "I see well that ye learned men in lore\n"
  "Can* muche good, by Godde's dignity.\"                              *know\n"
  "The Parson him answer'd, \"Ben'dicite!\n"
  "What ails the man, so sinfully to swear?\"\n"
  "Our Host answer'd, \"O Jankin, be ye there?\n"
  "Now, good men,\" quoth our Host, \"hearken to me.\n"
  "I smell a Lollard <2> in the wind,\" quoth he.\n"
  "\"Abide, for Godde's digne* passion,                              *worthy\n"
  "For we shall have a predication:\n"
  "This Lollard here will preachen us somewhat.\"\n"
  "\"Nay, by my father's soul, that shall he not,\n"
  "Saide the Shipman; \"Here shall he not preach,\n"
  "He shall no gospel glose* here nor teach.                  *comment upon\n"
  "We all believe in the great God,\" quoth he.\n"
  "\"He woulde sowe some difficulty,\n"
  "Or springe cockle <3> in our cleane corn.\n"
  "And therefore, Host, I warne thee beforn,\n"
  "My jolly body shall a tale tell,\n"
  "And I shall clinke you so merry a bell,\n"
  "That I shall waken all this company;\n"
  "But it shall not be of philosophy,\n"
  "Nor of physic, nor termes quaint of law;\n"
  "There is but little Latin in my maw.\"*                            *belly\n"
  "\n"
  "\n"
  "Notes to the Prologue to the Shipman's Tale\n"
  "\n"
  "\n"
  "1. The Prologue here given was transferred by Tyrwhitt from\n"
  "the place, preceding the Squire's Tale, which it had formerly\n"
  "occupied; the Shipman's Tale having no Prologue in the best\n"
  "manuscripts.\n"
  "\n"
  "2. Lollard: A contemptuous name for the followers of\n"
  "Wyckliffe; presumably derived from the Latin, \"lolium,\" tares,\n"
  "as if they were the tares among the Lord's wheat; so, a few lines\n"
  "below, the Shipman intimates his fear lest the Parson should\n"
  "\"spring cockle in our clean corn.\"\n"
  "\n"
  "3. Cockle: A weed, the \"Agrostemma githago\" of Linnaeus;\n"
  "perhaps named from the Anglo-Saxon, \"ceocan,\" because it\n"
  "chokes the corn.\n"
  "(Transcriber's note: It is also possible Chaucer had in mind\n"
  "Matthew 13:25, where in some translations, an enemy sowed\n"
  "\"cockle\" amongst the wheat. (Other translations have \"tares\"\n"
  "and \"darnel\".))\n"
  "\n"
  "\n"
  "THE TALE. <1>\n"
  "\n"
  "\n"
  "A Merchant whilom dwell'd at Saint Denise,\n"
  "That riche was, for which men held him wise.\n"
  "A wife he had of excellent beauty,\n"
  "And *companiable and revellous* was she,            *fond of society and\n"
  "Which is a thing that causeth more dispence                merry making*\n"
  "Than worth is all the cheer and reverence\n"
  "That men them do at feastes and at dances.\n"
  "Such salutations and countenances\n"
  "Passen, as doth the shadow on the wall;\n"
  "Put woe is him that paye must for all.\n"
  "The sely* husband algate** he must pay,               *innocent **always\n"
  "He must us <2> clothe and he must us array\n"
  "All for his owen worship richely:\n"
  "In which array we dance jollily.\n"
  "And if that he may not, paraventure,\n"
  "Or elles list not such dispence endure,\n"
  "But thinketh it is wasted and y-lost,\n"
  "Then must another paye for our cost,\n"
  "Or lend us gold, and that is perilous.\n"
  "\n"
  "This noble merchant held a noble house;\n"
  "For which he had all day so great repair,*           *resort of visitors\n"
  "For his largesse, and for his wife was fair,\n"
  "That wonder is; but hearken to my tale.\n"
  "Amonges all these guestes great and smale,\n"
  "There was a monk, a fair man and a bold,\n"
  "I trow a thirty winter he was old,\n"
  "That ever-in-one* was drawing to that place.                 *constantly\n"
  "This younge monk, that was so fair of face,\n"
  "Acquainted was so with this goode man,\n"
  "Since that their firste knowledge began,\n"
  "That in his house as familiar was he\n"
  "As it is possible any friend to be.\n"
  "And, for as muchel as this goode man,\n"
  "And eke this monk of which that I began,\n"
  "Were both the two y-born in one village,\n"
  "The monk *him claimed, as for cousinage,*               *claimed kindred\n"
  "And he again him said not once nay,                            with him*\n"
  "But was as glad thereof as fowl of day;\n"
  "\"For to his heart it was a great pleasance.\n"
  "Thus be they knit with etern' alliance,\n"
  "And each of them gan other to assure\n"
  "Of brotherhood while that their life may dure.\n"
  "Free was Dan <3> John, and namely* of dispence,** *especially **spending\n"
  "As in that house, and full of diligence\n"
  "To do pleasance, and also *great costage;*              *liberal outlay*\n"
  "He not forgot to give the leaste page\n"
  "In all that house; but, after their degree,\n"
  "He gave the lord, and sithen* his meinie,**       *afterwards **servants\n"
  "When that he came, some manner honest thing;\n"
  "For which they were as glad of his coming\n"
  "As fowl is fain when that the sun upriseth.\n"
  "No more of this as now, for it sufficeth.\n"
  "\n"
  "But so befell, this merchant on a day\n"
  "Shope* him to make ready his array                   *resolved, arranged\n"
  "Toward the town of Bruges <4> for to fare,\n"
  "To buye there a portion of ware;*                           *merchandise\n"
  "For which he hath to Paris sent anon\n"
  "A messenger, and prayed hath Dan John\n"
  "That he should come to Saint Denis, and play*             *enjoy himself\n"
  "With him, and with his wife, a day or tway,\n"
  "Ere he to Bruges went, in alle wise.\n"
  "This noble monk, of which I you devise,*                           *tell\n"
  "Had of his abbot, as him list, licence,\n"
  "(Because he was a man of high prudence,\n"
  "And eke an officer out for to ride,\n"
  "To see their granges and their barnes wide); <5>\n"
  "And unto Saint Denis he came anon.\n"
  "Who was so welcome as my lord Dan John,\n"
  "Our deare cousin, full of courtesy?\n"
  "With him he brought a jub* of malvesie,                             *jug\n"
  "And eke another full of fine vernage, <6>\n"
  "And volatile,* as aye was his usage:                          *wild-fowl\n"
  "And thus I let them eat, and drink, and play,\n"
  "This merchant and this monk, a day or tway.\n"
  "The thirde day the merchant up ariseth,\n"
  "And on his needeis sadly him adviseth;\n"
  "And up into his countour-house* went he,             *counting-house <7>\n"
  "To reckon with himself as well may be,\n"
  "Of thilke* year, how that it with him stood,                       *that\n"
  "And how that he dispended bad his good,\n"
  "And if that he increased were or non.\n"
  "His bookes and his bagges many a one\n"
  "He laid before him on his counting-board.\n"
  "Full riche was his treasure and his hoard;\n"
  "For which full fast his countour door he shet;\n"
  "And eke he would that no man should him let*                     *hinder\n"
  "Of his accountes, for the meane time:\n"
  "And thus he sat, till it was passed prime.\n"
  "\n"
  "Dan John was risen in the morn also,\n"
  "And in the garden walked to and fro,\n"
  "And had his thinges said full courteously.\n"
  "The good wife came walking full privily\n"
  "Into the garden, where he walked soft,\n"
  "And him saluted, as she had done oft;\n"
  "A maiden child came in her company,\n"
  "Which as her list she might govern and gie,*                      *guide\n"
  "For yet under the yarde* was the maid.                          *rod <8>\n"
  "\"O deare cousin mine, Dan John,\" she said,\n"
  "\"What aileth you so rath* for to arise?\"                          *early\n"
  "\"Niece,\" quoth he, \"it ought enough suffice\n"
  "Five houres for to sleep upon a night;'\n"
  "But* it were for an old appalled** wight,       *unless **pallid, wasted\n"
  "As be these wedded men, that lie and dare,*                       *stare\n"
  "As in a forme sits a weary hare,\n"
  "Alle forstraught* with houndes great and smale;  *distracted, confounded\n"
  "But, deare niece, why be ye so pale?\n"
  "I trowe certes that our goode man\n"
  "Hath you so laboured, since this night began,\n"
  "That you were need to reste hastily.\"\n"
  "And with that word he laugh'd full merrily,\n"
  "And of his owen thought he wax'd all red.\n"
  "This faire wife gan for to shake her head,\n"
  "And saide thus; \"Yea, God wot all\" quoth she.\n"
  "\"Nay, cousin mine, it stands not so with me;\n"
  "For by that God, that gave me soul and life,\n"
  "In all the realm of France is there no wife\n"
  "That lesse lust hath to that sorry play;\n"
  "For I may sing alas and well-away!\n"
  "That I was born; but to no wight,\" quoth she,\n"
  "\"Dare I not tell how that it stands with me.\n"
  "Wherefore I think out of this land to wend,\n"
  "Or elles of myself to make an end,\n"
  "So full am I of dread and eke of care.\"\n"
  "\n"
  "This monk began upon this wife to stare,\n"
  "And said, \"Alas! my niece, God forbid\n"
  "That ye for any sorrow, or any dread,\n"
  "Fordo* yourself: but telle me your grief,                       *destroy\n"
  "Paraventure I may, in your mischief,*                          *distress\n"
  "Counsel or help; and therefore telle me\n"
  "All your annoy, for it shall be secre.\n"
  "For on my portos* here I make an oath,                         *breviary\n"
  "That never in my life, *for lief nor loth,*       *willing or unwilling*\n"
  "Ne shall I of no counsel you bewray.\"\n"
  "\"The same again to you,\" quoth she, \"I say.\n"
  "By God and by this portos I you swear,\n"
  "Though men me woulden all in pieces tear,\n"
  "Ne shall I never, for* to go to hell,                   *though I should\n"
  "Bewray* one word of thing that ye me tell,                       *betray\n"
  "For no cousinage, nor alliance,\n"
  "But verily for love and affiance.\"*                 *confidence, promise\n"
  "Thus be they sworn, and thereupon they kiss'd,\n"
  "And each of them told other what them list.\n"
  "\"Cousin,\" quoth she, \"if that I hadde space,\n"
  "As I have none, and namely* in this place,                    *specially\n"
  "Then would I tell a legend of my life,\n"
  "What I have suffer'd since I was a wife\n"
  "With mine husband, all* be he your cousin.                     *although\n"
  "\"Nay,\" quoth this monk, \"by God and Saint Martin,\n"
  "He is no more cousin unto me,\n"
  "Than is the leaf that hangeth on the tree;\n"
  "I call him so, by Saint Denis of France,\n"
  "To have the more cause of acquaintance\n"
  "Of you, which I have loved specially\n"
  "Aboven alle women sickerly,*                                     *surely\n"
  "This swear I you *on my professioun;*            *by my vows of religion\n"
  "Tell me your grief, lest that he come adown,\n"
  "And hasten you, and go away anon.\"\n"
  "\n"
  "\"My deare love,\" quoth she, \"O my Dan John,\n"
  "Full lief* were me this counsel for to hide,                   *pleasant\n"
  "But out it must, I may no more abide.\n"
  "My husband is to me the worste man\n"
  "That ever was since that the world began;\n"
  "But since I am a wife, it sits* not me                          *becomes\n"
  "To telle no wight of our privity,\n"
  "Neither in bed, nor in none other place;\n"
  "God shield* I shoulde tell it for his grace;                     *forbid\n"
  "A wife shall not say of her husband\n"
  "But all honour, as I can understand;\n"
  "Save unto you thus much I telle shall;\n"
  "As help me God, he is nought worth at all\n"
  "In no degree, the value of a fly.\n"
  "But yet me grieveth most his niggardy.*                      *stinginess\n"
  "And well ye wot, that women naturally\n"
  "Desire thinges six, as well as I.\n"
  "They woulde that their husbands shoulde be\n"
  "Hardy,* and wise, and rich, and thereto free,                     *brave\n"
  "And buxom* to his wife, and fresh in bed.            *yielding, obedient\n"
  "But, by that ilke* Lord that for us bled,                          *same\n"
  "For his honour myself for to array,\n"
  "On Sunday next I muste needes pay\n"
  "A hundred francs, or elles am I lorn.*                   *ruined, undone\n"
  "Yet *were me lever* that I were unborn,                 *I would rather*\n"
  "Than me were done slander or villainy.\n"
  "And if mine husband eke might it espy,\n"
  "I were but lost; and therefore I you pray,\n"
  "Lend me this sum, or elles must I dey.*                             *die\n"
  "Dan John, I say, lend me these hundred francs;\n"
  "Pardie, I will not faile you, *my thanks,*            *if I can help it*\n"
  "If that you list to do that I you pray;\n"
  "For at a certain day I will you pay,\n"
  "And do to you what pleasance and service\n"
  "That I may do, right as you list devise.\n"
  "And but* I do, God take on me vengeance,                         *unless\n"
  "As foul as e'er had Ganilion <9> of France.\"\n"
  "\n"
  "This gentle monk answer'd in this mannere;\n"
  "\"Now truely, mine owen lady dear,\n"
  "I have,\" quoth he, \"on you so greate ruth,*                        *pity\n"
  "That I you swear, and plighte you my truth,\n"
  "That when your husband is to Flanders fare,*                       *gone\n"
  "I will deliver you out of this care,\n"
  "For I will bringe you a hundred francs.\"\n"
  "And with that word he caught her by the flanks,\n"
  "And her embraced hard, and kissed her oft.\n"
  "\"Go now your way,\" quoth he, \"all still and soft,\n"
  "And let us dine as soon as that ye may,\n"
  "For by my cylinder* 'tis prime of day;                 *portable sundial\n"
  "Go now, and be as true as I shall be .\"\n"
  "\"Now elles God forbidde, Sir,\" quoth she;\n"
  "And forth she went, as jolly as a pie,\n"
  "And bade the cookes that they should them hie,*              *make haste\n"
  "So that men mighte dine, and that anon.\n"
  "Up to her husband is this wife gone,\n"
  "And knocked at his contour boldely.\n"
  "*\"Qui est la?\"* quoth he. \"Peter! it am I,\"              *who is there?*\n"
  "Quoth she; \"What, Sir, how longe all will ye fast?\n"
  "How longe time will ye reckon and cast\n"
  "Your summes, and your bookes, and your things?\n"
  "The devil have part of all such reckonings!\n"
  "Ye have enough, pardie, of Godde's sond.*                *sending, gifts\n"
  "Come down to-day, and let your bagges stond.*                     *stand\n"
  "Ne be ye not ashamed, that Dan John\n"
  "Shall fasting all this day elenge* gon?                   *see note <10>\n"
  "What? let us hear a mass, and go we dine.\"\n"
  "\"Wife,\" quoth this man, \"little canst thou divine\n"
  "The curious businesse that we have;\n"
  "For of us chapmen,* all so God me save,                       *merchants\n"
  "And by that lord that cleped is Saint Ive,\n"
  "Scarcely amonges twenty, ten shall thrive\n"
  "Continually, lasting unto our age.\n"
  "We may well make cheer and good visage,\n"
  "And drive forth the world as it may be,\n"
  "And keepen our estate in privity,\n"
  "Till we be dead, or elles that we play\n"
  "A pilgrimage, or go out of the way.\n"
  "And therefore have I great necessity\n"
  "Upon this quaint* world to advise** me.              *strange **consider\n"
  "For evermore must we stand in dread\n"
  "Of hap and fortune in our chapmanhead.*                         *trading\n"
  "To Flanders will I go to-morrow at day,\n"
  "And come again as soon as e'er I may:\n"
  "For which, my deare wife, I thee beseek                         *beseech\n"
  "As be to every wight buxom* and meek,                  *civil, courteous\n"
  "And for to keep our good be curious,\n"
  "And honestly governe well our house.\n"
  "Thou hast enough, in every manner wise,\n"
  "That to a thrifty household may suffice.\n"
  "Thee lacketh none array, nor no vitail;\n"
  "Of silver in thy purse thou shalt not fail.\"\n"
  "\n"
  "And with that word his contour door he shet,*                      *shut\n"
  "And down he went; no longer would he let;*                *delay, hinder\n"
  "And hastily a mass was there said,\n"
  "And speedily the tables were laid,\n"
  "And to the dinner faste they them sped,\n"
  "And richely this monk the chapman fed.\n"
  "And after dinner Dan John soberly\n"
  "This chapman took apart, and privily\n"
  "He said him thus: \"Cousin, it standeth so,\n"
  "That, well I see, to Bruges ye will go;\n"
  "God and Saint Austin speede you and guide.\n"
  "I pray you, cousin, wisely that ye ride:\n"
  "Governe you also of your diet\n"
  "Attemperly,* and namely** in this heat.                      *moderately\n"
  "Betwixt us two needeth no *strange fare;*                *ado, ceremony*\n"
  "Farewell, cousin, God shielde you from care.\n"
  "If any thing there be, by day or night,\n"
  "If it lie in my power and my might,\n"
  "That ye me will command in any wise,\n"
  "It shall be done, right as ye will devise.\n"
  "But one thing ere ye go, if it may be;\n"
  "I woulde pray you for to lend to me\n"
  "A hundred frankes, for a week or twy,\n"
  "For certain beastes that I muste buy,\n"
  "To store with a place that is ours\n"
  "(God help me so, I would that it were yours);\n"
  "I shall not faile surely of my day,\n"
  "Not for a thousand francs, a mile way.\n"
  "But let this thing be secret, I you pray;\n"
  "For yet to-night these beastes must I buy.\n"
  "And fare now well, mine owen cousin dear;\n"
  "*Grand mercy* of your cost and of your cheer.\"            *great thanks*\n"
  "\n"
  "This noble merchant gentilly* anon                     *like a gentleman\n"
  "Answer'd and said, \"O cousin mine, Dan John,\n"
  "Now sickerly this is a small request:\n"
  "My gold is youres, when that it you lest,\n"
  "And not only my gold, but my chaffare;*                     *merchandise\n"
  "Take what you list, *God shielde that ye spare.*    *God forbid that you\n"
  "But one thing is, ye know it well enow           should take too little*\n"
  "Of chapmen, that their money is their plough.\n"
  "We may creance* while we have a name,                     *obtain credit\n"
  "But goldless for to be it is no game.\n"
  "Pay it again when it lies in your ease;\n"
  "After my might full fain would I you please.\"\n"
  "\n"
  "These hundred frankes set he forth anon,\n"
  "And privily he took them to Dan John;\n"
  "No wight in all this world wist of this loan,\n"
  "Saving the merchant and Dan John alone.\n"
  "They drink, and speak, and roam a while, and play,\n"
  "Till that Dan John rode unto his abbay.\n"
  "The morrow came, and forth this merchant rideth\n"
  "To Flanders-ward, his prentice well him guideth,\n"
  "Till he came unto Bruges merrily.\n"
  "Now went this merchant fast and busily\n"
  "About his need, and buyed and creanced;*                     *got credit\n"
  "He neither played at the dice, nor danced;\n"
  "But as a merchant, shortly for to tell,\n"
  "He led his life; and there I let him dwell.\n"
  "\n"
  "The Sunday next* the merchant was y-gone,                         *after\n"
  "To Saint Denis y-comen is Dan John,\n"
  "With crown and beard all fresh and newly shave,\n"
  "In all the house was not so little a knave,*                *servant-boy\n"
  "Nor no wight elles that was not full fain\n"
  "For that my lord Dan John was come again.\n"
  "And shortly to the point right for to gon,\n"
  "The faire wife accorded with Dan John,\n"
  "That for these hundred francs he should all night\n"
  "Have her in his armes bolt upright;\n"
  "And this accord performed was in deed.\n"
  "In mirth all night a busy life they lead,\n"
  "Till it was day, that Dan John went his way,\n"
  "And bade the meinie* \"Farewell; have good day.\"                *servants\n"
  "For none of them, nor no wight in the town,\n"
  "Had of Dan John right no suspicioun;\n"
  "And forth he rode home to his abbay,\n"
  "Or where him list; no more of him I say.\n"
  "\n"
  "The merchant, when that ended was the fair,\n"
  "To Saint Denis he gan for to repair,\n"
  "And with his wife he made feast and cheer,\n"
  "And tolde her that chaffare* was so dear,                   *merchandise\n"
  "That needes must he make a chevisance;*                       *loan <11>\n"
  "For he was bound in a recognisance\n"
  "To paye twenty thousand shields* anon.                     *crowns, ecus\n"
  "For which this merchant is to Paris gone,\n"
  "To borrow of certain friendes that he had\n"
  "A certain francs, and some with him he lad.*                       *took\n"
  "And when that he was come into the town,\n"
  "For great cherte* and great affectioun                             *love\n"
  "Unto Dan John he wente first to play;\n"
  "Not for to borrow of him no money,\n"
  "Bat for to weet* and see of his welfare,                           *know\n"
  "And for to telle him of his chaffare,\n"
  "As friendes do, when they be met in fere.*                      *company\n"
  "Dan John him made feast and merry cheer;\n"
  "And he him told again full specially,\n"
  "How he had well y-bought and graciously\n"
  "(Thanked be God) all whole his merchandise;\n"
  "Save that he must, in alle manner wise,\n"
  "Maken a chevisance, as for his best;\n"
  "And then he shoulde be in joy and rest.\n"
  "Dan John answered, \"Certes, I am fain*                             *glad\n"
  "That ye in health be come borne again:\n"
  "And if that I were rich, as have I bliss,\n"
  "Of twenty thousand shields should ye not miss,\n"
  "For ye so kindely the other day\n"
  "Lente me gold, and as I can and may\n"
  "I thanke you, by God and by Saint Jame.\n"
  "But natheless I took unto our Dame,\n"
  "Your wife at home, the same gold again,\n"
  "Upon your bench; she wot it well, certain,\n"
  "By certain tokens that I can her tell\n"
  "Now, by your leave, I may no longer dwell;\n"
  "Our abbot will out of this town anon,\n"
  "And in his company I muste gon.\n"
  "Greet well our Dame, mine owen niece sweet,\n"
  "And farewell, deare cousin, till we meet.\n"
  "\n"
  "This merchant, which that was full ware and wise,\n"
  "*Creanced hath,* and paid eke in Paris             *had obtained credit*\n"
  "To certain Lombards ready in their hond\n"
  "The sum of gold, and got of them his bond,\n"
  "And home he went, merry as a popinjay.*                          *parrot\n"
  "For well he knew he stood in such array\n"
  "That needes must he win in that voyage\n"
  "A thousand francs, above all his costage.*                     *expenses\n"
  "His wife full ready met him at the gate,\n"
  "As she was wont of old usage algate*                             *always\n"
  "And all that night in mirthe they beset;*                         *spent\n"
  "For he was rich, and clearly out of debt.\n"
  "When it was day, the merchant gan embrace\n"
  "His wife all new, and kiss'd her in her face,\n"
  "And up he went, and maked it full tough.\n"
  "\n"
  "\"No more,\" quoth she, \"by God ye have enough;\"\n"
  "And wantonly again with him she play'd,\n"
  "Till at the last this merchant to her said.\n"
  "\"By God,\" quoth he, \"I am a little wroth\n"
  "With you, my wife, although it be me loth;\n"
  "And wot ye why? by God, as that I guess,\n"
  "That ye have made a *manner strangeness*        *a kind of estrangement*\n"
  "Betwixte me and my cousin, Dan John.\n"
  "Ye should have warned me, ere I had gone,\n"
  "That he you had a hundred frankes paid\n"
  "By ready token; he *had him evil apaid*                 *was displeased*\n"
  "For that I to him spake of chevisance,*                       *borrowing\n"
  "(He seemed so as by his countenance);\n"
  "But natheless, by God of heaven king,\n"
  "I thoughte not to ask of him no thing.\n"
  "I pray thee, wife, do thou no more so.\n"
  "Tell me alway, ere that I from thee go,\n"
  "If any debtor hath in mine absence\n"
  "Y-payed thee, lest through thy negligence\n"
  "I might him ask a thing that he hath paid.\"\n"
  "\n"
  "This wife was not afeared nor afraid,\n"
  "But boldely she said, and that anon;\n"
  "\"Mary! I defy that false monk Dan John,\n"
  "I keep* not of his tokens never a deal:**                   *care **whit\n"
  "He took me certain gold, I wot it well. --\n"
  "What? evil thedom* on his monke's snout! --                    *thriving\n"
  "For, God it wot, I ween'd withoute doubt\n"
  "That he had given it me, because of you,\n"
  "To do therewith mine honour and my prow,*                        *profit\n"
  "For cousinage, and eke for belle cheer\n"
  "That he hath had full often here.\n"
  "But since I see I stand in such disjoint,*             *awkward position\n"
  "I will answer you shortly to the point.\n"
  "Ye have more slacke debtors than am I;\n"
  "For I will pay you well and readily,\n"
  "From day to day, and if so be I fail,\n"
  "I am your wife, score it upon my tail,\n"
  "And I shall pay as soon as ever I may.\n"
  "For, by my troth, I have on mine array,\n"
  "And not in waste, bestow'd it every deal.\n"
  "And, for I have bestowed it so well,\n"
  "For your honour, for Godde's sake I say,\n"
  "As be not wroth, but let us laugh and play.\n"
  "Ye shall my jolly body have *to wed;*                        *in pledge*\n"
  "By God, I will not pay you but in bed;\n"
  "Forgive it me, mine owen spouse dear;\n"
  "Turn hitherward, and make better cheer.\"\n"
  "\n"
  "The merchant saw none other remedy;\n"
  "And for to chide, it were but a folly,\n"
  "Since that the thing might not amended be.\n"
  "\"Now, wife,\" he said, \"and I forgive it thee;\n"
  "But by thy life be no more so large;*                   *liberal, lavish\n"
  "Keep better my good, this give I thee in charge.\"\n"
  "Thus endeth now my tale; and God us send\n"
  "Taling enough, until our lives' end!\n"
  "\n"
  "\n"
  "Notes to the Shipman's Tale\n"
  "\n"
  "\n"
  "1. In this Tale Chaucer seems to have followed an old French\n"
  "story, which also formed the groundwork of the first story in\n"
  "the eighth day of the \"Decameron.\"\n"
  "\n"
  "2. \"He must us clothe\": So in all the manuscripts and from this\n"
  "and the following lines, it must be inferred that Chaucer had\n"
  "intended to put the Tale in  the mouth of a female speaker.\n"
  "\n"
  "3. Dan: a title bestowed on priests and scholars; from\n"
  "\"Dominus,\" like the Spanish \"Don\".\n"
  "\n"
  "4. Bruges was in Chaucer's time the great emporium of\n"
  "European commerce.\n"
  "\n"
  "5. The monk had been appointed by his abbot to inspect and\n"
  "manage the rural property of the monastery.\n"
  "\n"
  "6. Malvesie or Malmesy wine derived its name from Malvasia, a\n"
  "region of the Morea near Cape Malea, where it was made, as it\n"
  "also was on Chios and some other Greek islands. Vernage was\n"
  "\"vernaccia\", a sweet Italian wine.\n"
  "\n"
  " 7. Contour-house: counting-house; French, \"comptoir.\"\n"
  "\n"
  "8. Under the yarde: under the rod; in pupillage; a phrase\n"
  "properly used of children, but employed by the Clerk in the\n"
  "prologue to his tale.  See note 1 to the Prologue to the Clerk's\n"
  "Tale.\n"
  "\n"
  "9. Genelon, Ganelon, or Ganilion; one of Charlemagne's\n"
  "officers, whose treachery was the cause of the disastrous defeat\n"
  "of the Christians by the Saracens at Roncevalles; he was torn to\n"
  "pieces by four horses.\n"
  "\n"
  "10. Elenge:  From French, \"eloigner,\" to remove; it may mean\n"
  "either the lonely, cheerless condition of the priest, or the strange\n"
  "behaviour of the merchant in leaving him to himself.\n"
  "\n"
  "11. Make a chevisance: raise money by means of a borrowing\n"
  "agreement; from French,  \"achever,\" to finish; the general\n"
  "meaning of the word is a bargain, an agreement.\n"
  "\n"
  "\n"
  "\n"
  "";
// }

const char prioresssTale[] PGMSECTION = // { // 14609 bytes
  "THE PRIORESS'S TALE.\n"
  "\n"
  "\n"
  "THE PROLOGUE.\n"
  "\n"
  "\n"
  "\"WELL said, by *corpus Domini,\"* quoth our Host;       *the Lord's body*\n"
  "\"Now longe may'st thou saile by the coast,\n"
  "Thou gentle Master, gentle Marinere.\n"
  "God give the monk *a thousand last quad year!*   *ever so much evil* <1>\n"
  "Aha! fellows, beware of such a jape.*                             *trick\n"
  "The monk *put in the manne's hood an ape,*                  *fooled him*\n"
  "And in his wife's eke, by Saint Austin.\n"
  "Drawe no monkes more into your inn.\n"
  "But now pass over, and let us seek about,\n"
  "Who shall now telle first of all this rout\n"
  "Another tale;\" and with that word he said,\n"
  "As courteously as it had been a maid;\n"
  "\"My Lady Prioresse, by your leave,\n"
  "So that I wist I shoulde you not grieve,*                        *offend\n"
  "I woulde deeme* that ye telle should                      *judge, decide\n"
  "A tale next, if so were that ye would.\n"
  "Now will ye vouchesafe, my lady dear?\"\n"
  "\"Gladly,\" quoth she; and said as ye shall hear.\n"
  "\n"
  "\n"
  "Notes to the Prologue to the Prioress's Tale.\n"
  "\n"
  "\n"
  "1. A thousand last quad year: ever so much evil.   \"Last\" means\n"
  "a load, \"quad,\" bad; and literally we may read \"a thousand\n"
  "weight of bad years.\" The Italians use \"mal anno\" in the same\n"
  "sense.\n"
  "\n"
  "\n"
  "THE TALE. <1>\n"
  "\n"
  "\n"
  "O Lord our Lord! thy name how marvellous\n"
  "Is in this large world y-spread! <2> (quoth she)\n"
  "For not only thy laude* precious                                 *praise\n"
  "Performed is by men of high degree,\n"
  "But by the mouth of children thy bounte*                       *goodness\n"
  "Performed is, for on the breast sucking\n"
  "Sometimes showe they thy herying.* <3>                            *glory\n"
  "\n"
  "Wherefore in laud, as I best can or may\n"
  "Of thee, and of the white lily flow'r\n"
  "Which that thee bare, and is a maid alway,\n"
  "To tell a story I will do my labour;\n"
  "Not that I may increase her honour,\n"
  "For she herselven is honour and root\n"
  "Of bounte, next her son, and soules' boot.*                        *help\n"
  "\n"
  "O mother maid, O maid and mother free!*                       *bounteous\n"
  "O bush unburnt, burning in Moses' sight,\n"
  "That ravished'st down from the deity,\n"
  "Through thy humbless, the ghost that in thee light; <4>\n"
  "Of whose virtue, when he thine hearte light,*      *lightened, gladdened\n"
  "Conceived was the Father's sapience;\n"
  "Help me to tell it to thy reverence.\n"
  "\n"
  "Lady! thy bounty, thy magnificence,\n"
  "Thy virtue, and thy great humility,\n"
  "There may no tongue express in no science:\n"
  "For sometimes, Lady! ere men pray to thee,\n"
  "Thou go'st before, of thy benignity,\n"
  "And gettest us the light, through thy prayere,\n"
  "To guiden us unto thy son so dear.\n"
  "\n"
  "My conning* is so weak, O blissful queen,                *skill, ability\n"
  "For to declare thy great worthiness,\n"
  "That I not may the weight of it sustene;\n"
  "But as a child of twelvemonth old, or less,\n"
  "That can unnethes* any word express,                           *scarcely\n"
  "Right so fare I; and therefore, I you pray,\n"
  "Guide my song that I shall of you say.\n"
  "\n"
  "There was in Asia, in a great city,\n"
  "Amonges Christian folk, a Jewery,<5>\n"
  "Sustained by a lord of that country,\n"
  "For foul usure, and lucre of villainy,\n"
  "Hateful to Christ, and to his company;\n"
  "And through the street men mighte ride and wend,*              *go, walk\n"
  "For it was free, and open at each end.\n"
  "\n"
  "A little school of Christian folk there stood\n"
  "Down at the farther end, in which there were\n"
  "Children an heap y-come of Christian blood,\n"
  "That learned in that schoole year by year\n"
  "Such manner doctrine as men used there;\n"
  "This is to say, to singen and to read,\n"
  "As smalle children do in their childhead.\n"
  "\n"
  "Among these children was a widow's son,\n"
  "A little clergion,* seven year of age,           *young clerk or scholar\n"
  "That day by day to scholay* was his won,**                 *study **wont\n"
  "And eke also, whereso he saw th' image\n"
  "Of Christe's mother, had he in usage,\n"
  "As him was taught, to kneel adown, and say\n"
  "Ave Maria as he went by the way.\n"
  "\n"
  "Thus had this widow her little son y-taught\n"
  "Our blissful Lady, Christe's mother dear,\n"
  "To worship aye, and he forgot it not;\n"
  "For sely* child will always soone lear.**              *innocent **learn\n"
  "But aye when I remember on this mattere,\n"
  "Saint Nicholas <6> stands ever in my presence;\n"
  "For he so young to Christ did reverence.\n"
  "\n"
  "This little child his little book learning,\n"
  "As he sat in the school at his primere,\n"
  "He Alma redemptoris <7> hearde sing,\n"
  "As children learned their antiphonere; <8>\n"
  "And as he durst, he drew him nere and nere,*                     *nearer\n"
  "And hearken'd aye the wordes and the note,\n"
  "Till he the firste verse knew all by rote.\n"
  "\n"
  "Nought wist he what this Latin was tosay,*                        *meant\n"
  "For he so young and tender was of age;\n"
  "But on a day his fellow gan he pray\n"
  "To expound him this song in his language,\n"
  "Or tell him why this song was in usage:\n"
  "This pray'd he him to construe and declare,\n"
  "Full oftentime upon his knees bare.\n"
  "\n"
  "His fellow, which that elder was than he,\n"
  "Answer'd him thus: \"This song, I have heard say,\n"
  "Was maked of our blissful Lady free,\n"
  "Her to salute, and eke her to pray\n"
  "To be our help and succour when we dey.*                            *die\n"
  "I can no more expound in this mattere:\n"
  "I learne song, I know but small grammere.\"\n"
  "\n"
  "\"And is this song y-made in reverence\n"
  "Of Christe's mother?\" said this innocent;\n"
  "Now certes I will do my diligence\n"
  "To conne* it all, ere Christemas be went;                    *learn; con\n"
  "Though that I for my primer shall be shent,*                  *disgraced\n"
  "And shall be beaten thries in an hour,\n"
  "I will it conne, our Lady to honour.\"\n"
  "\n"
  "His fellow taught him homeward* privily                 *on the way home\n"
  "From day to day, till he coud* it by rote,                         *knew\n"
  "And then he sang it well and boldely\n"
  "From word to word according with the note;\n"
  "Twice in a day it passed through his throat;\n"
  "To schoole-ward, and homeward when he went;\n"
  "On Christ's mother was set all his intent.\n"
  "\n"
  "As I have said, throughout the Jewery,\n"
  "This little child, as he came to and fro,\n"
  "Full merrily then would he sing and cry,\n"
  "O Alma redemptoris, evermo';\n"
  "The sweetness hath his hearte pierced so\n"
  "Of Christe's mother, that to her to pray\n"
  "He cannot stint* of singing by the way.                           *cease\n"
  "\n"
  "Our firste foe, the serpent Satanas,\n"
  "That hath in Jewes' heart his waspe's nest,\n"
  "Upswell'd and said, \"O Hebrew people, alas!\n"
  "Is this to you a thing that is honest,*            *creditable, becoming\n"
  "That such a boy shall walken as him lest\n"
  "In your despite, and sing of such sentence,\n"
  "Which is against your lawe's reverence?\"\n"
  "\n"
  "From thenceforth the Jewes have conspired\n"
  "This innocent out of the world to chase;\n"
  "A homicide thereto have they hired,\n"
  "That in an alley had a privy place,\n"
  "And, as the child gan forth by for to pace,\n"
  "This cursed Jew him hent,* and held him fast                     *seized\n"
  "And cut his throat, and in a pit him cast.\n"
  "\n"
  "I say that in a wardrobe* he him threw,                           *privy\n"
  "Where as the Jewes purged their entrail.\n"
  "O cursed folk! O Herodes all new!\n"
  "What may your evil intente you avail?\n"
  "Murder will out, certain it will not fail,\n"
  "And namely* where th' honour of God shall spread;            *especially\n"
  "The blood out crieth on your cursed deed.\n"
  "\n"
  "O martyr souded* to virginity,                            *confirmed <9>\n"
  "Now may'st thou sing, and follow ever-in-one*               *continually\n"
  "The white Lamb celestial (quoth she),\n"
  "Of which the great Evangelist Saint John\n"
  "In Patmos wrote, which saith that they that gon\n"
  "Before this Lamb, and sing a song all new,\n"
  "That never fleshly woman they ne knew.<10>\n"
  "\n"
  "This poore widow waited all that night\n"
  "After her little child, but he came not;\n"
  "For which, as soon as it was daye's light,\n"
  "With face pale, in dread and busy thought,\n"
  "She hath at school and elleswhere him sought,\n"
  "Till finally she gan so far espy,\n"
  "That he was last seen in the Jewery.\n"
  "\n"
  "With mother's pity in her breast enclosed,\n"
  "She went, as she were half out of her mind,\n"
  "To every place, where she hath supposed\n"
  "By likelihood her little child to find:\n"
  "And ever on Christ's mother meek and kind\n"
  "She cried, and at the laste thus she wrought,\n"
  "Among the cursed Jewes she him sought.\n"
  "\n"
  "She freined,* and she prayed piteously                      *asked* <11>\n"
  "To every Jew that dwelled in that place,\n"
  "To tell her, if her childe went thereby;\n"
  "They saide, \"Nay;\" but Jesus of his grace\n"
  "Gave in her thought, within a little space,\n"
  "That in that place after her son she cried,\n"
  "Where he was cast into a pit beside.\n"
  "\n"
  "O greate God, that preformest thy laud\n"
  "By mouth of innocents, lo here thy might!\n"
  "This gem of chastity, this emeraud,*                            *emerald\n"
  "And eke of martyrdom the ruby bright,\n"
  "Where he with throat y-carven* lay upright,                         *cut\n"
  "He Alma Redemptoris gan to sing\n"
  "So loud, that all the place began to ring.\n"
  "\n"
  "The Christian folk, that through the streete went,\n"
  "In came, for to wonder on this thing:\n"
  "And hastily they for the provost sent.\n"
  "He came anon withoute tarrying,\n"
  "And heried* Christ, that is of heaven king,                     *praised\n"
  "And eke his mother, honour of mankind;\n"
  "And after that the Jewes let* he bind.                           *caused\n"
  "\n"
  "With torment, and with shameful death each one\n"
  "The provost did* these Jewes for to sterve**               *caused **die\n"
  "That of this murder wist, and that anon;\n"
  "He woulde no such cursedness observe*                          *overlook\n"
  "Evil shall have that evil will deserve;\n"
  "Therefore with horses wild he did them draw,\n"
  "And after that he hung them by the law.\n"
  "\n"
  "The child, with piteous lamentation,\n"
  "Was taken up, singing his song alway:\n"
  "And with honour and great procession,\n"
  "They crry him unto the next abbay.\n"
  "His mother swooning by the biere lay;\n"
  "Unnethes* might the people that were there                     *scarcely\n"
  "This newe Rachel bringe from his bier.\n"
  "\n"
  "Upon his biere lay this innocent\n"
  "Before the altar while the masses last';*                        *lasted\n"
  "And, after that, th' abbot with his convent\n"
  "Have sped them for to bury him full fast;\n"
  "And when they holy water on him cast,\n"
  "Yet spake this child, when sprinkled was the water,\n"
  "And sang, O Alma redemptoris mater!\n"
  "\n"
  "This abbot, which that was a holy man,\n"
  "As monkes be, or elles ought to be,\n"
  "This younger child to conjure he began,\n"
  "And said; \"O deare child! I halse* thee,                   *implore <12>\n"
  "In virtue of the holy Trinity;\n"
  "Tell me what is thy cause for to sing,\n"
  "Since that thy throat is cut, to my seeming.\"\n"
  "\n"
  "\"My throat is cut unto my necke-bone,\"\n"
  "Saide this child, \"and, as *by way of kind,*       *in course of nature*\n"
  "I should have died, yea long time agone;\n"
  "But Jesus Christ, as ye in bookes find,\n"
  "Will that his glory last and be in mind;\n"
  "And, for the worship* of his mother dear,                         *glory\n"
  "Yet may I sing O Alma loud and clear.\n"
  "\n"
  "\"This well* of mercy, Christe's mother sweet,                  *fountain\n"
  "I loved alway, after my conning:*                             *knowledge\n"
  "And when that I my life should forlete,*                          *leave\n"
  "To me she came, and bade me for to sing\n"
  "This anthem verily in my dying,\n"
  "As ye have heard; and, when that I had sung,\n"
  "Me thought she laid a grain upon my tongue.\n"
  "\n"
  "\"Wherefore I sing, and sing I must certain,\n"
  "In honour of that blissful maiden free,\n"
  "Till from my tongue off taken is the grain.\n"
  "And after that thus saide she to me;\n"
  "'My little child, then will I fetche thee,\n"
  "When that the grain is from thy tongue take:\n"
  "Be not aghast,* I will thee not forsake.'\"                       *afraid\n"
  "\n"
  "This holy monk, this abbot him mean I,\n"
  "His tongue out caught, and took away the grain;\n"
  "And he gave up the ghost full softely.\n"
  "And when this abbot had this wonder seen,\n"
  "His salte teares trickled down as rain:\n"
  "And groff* he fell all flat upon the ground,      *prostrate, grovelling\n"
  "And still he lay, as he had been y-bound.\n"
  "\n"
  "The convent* lay eke on the pavement                      *all the monks\n"
  "Weeping, and herying* Christ's mother dear.                    *praising\n"
  "And after that they rose, and forth they went,\n"
  "And took away this martyr from his bier,\n"
  "And in a tomb of marble stones clear\n"
  "Enclosed they his little body sweet;\n"
  "Where he is now, God lene* us for to meet.                        *grant\n"
  "\n"
  "O younge Hugh of Lincoln!<13> slain also\n"
  "With cursed Jewes, -- as it is notable,\n"
  "For it is but a little while ago, --\n"
  "Pray eke for us, we sinful folk unstable,\n"
  "That, of his mercy, God so merciable*                          *merciful\n"
  "On us his greate mercy multiply,\n"
  "For reverence of his mother Mary.\n"
  "\n"
  "\n"
  "Notes to the Prioress's Tale\n"
  "\n"
  "\n"
  "1. Tales of the murder of children by Jews were frequent in the\n"
  "Middle Ages, being probably designed to keep up the bitter\n"
  "feeling of the Christians against the Jews. Not a few children\n"
  "were canonised on this account; and the scene of the misdeeds\n"
  "was laid anywhere and everywhere, so that Chaucer could be at\n"
  "no loss for material.\n"
  "\n"
  "2. This is from Psalm viii. 1, \"Domine, dominus noster,quam\n"
  "admirabile est nomen tuum in universa terra.\"\n"
  "\n"
  "3. \"Out of the mouths of babes and sucklings hast Thou\n"
  "ordained strength.\" -- Psalms viii. 2.\n"
  "\n"
  "4. The ghost that in thee light: the spirit that on thee alighted;\n"
  "the Holy Ghost through whose power Christ was conceived.\n"
  "\n"
  "5. Jewery: A quarter which the Jews were permitted to inhabit;\n"
  "the Old Jewry in London got its name in this way.\n"
  "\n"
  "6. St. Nicholas, even in his swaddling clothes -- so says the\n"
  "\"Breviarium Romanum\" --gave promise of extraordinary virtue\n"
  "and holiness; for, though he sucked freely on other days, on\n"
  "Wednesdays and Fridays he applied to the breast only once, and\n"
  "that not until the evening.\n"
  "\n"
  "7. \"O Alma Redemptoris Mater,\" (\"O soul mother of the\n"
  "Redeemer\") -- the beginning of a hymn to the Virgin.\n"
  "\n"
  "8. Antiphonere: A book of anthems, or psalms, chanted in the\n"
  "choir by alternate verses.\n"
  "\n"
  "9. Souded; confirmed; from French, \"soulde;\" Latin, \"solidatus.\"\n"
  "\n"
  "10. \"And they sung as it were a new song before the throne, and\n"
  "before the four beasts, and the elders: and no man could learn\n"
  "that song but the hundred and forty and four thousand, which\n"
  "were redeemed from the earth.\n"
  "These are they which were not defiled with women; for they are\n"
  "virgins. These are they which follow the Lamb whithersoever he\n"
  "goeth. These were redeemed from among men, being the\n"
  "firstfruits unto God and to the Lamb.\"\n"
  "-- Revelations xiv. 3, 4.\n"
  "\n"
  "11. Freined: asked, inquired; from Anglo-Saxon, \"frinan,\"\n"
  "\"fraegnian.\" Compare German, \"fragen.\"\n"
  "\n"
  "12. Halse:  embrace or salute; implore: from Anglo-Saxon\n"
  "\"hals,\" the neck.\n"
  "\n"
  "14 A boy said to have been slain by the Jews at Lincoln in 1255,\n"
  "according to Matthew Paris.  Many popular ballads were made\n"
  "about the event, which the diligence of the Church doubtless\n"
  "kept fresh in mind at Chaucer's day.\n"
  "\n"
  "\n"
  "\n"
  "";
// }

const char taleOfSirThopas[] PGMSECTION = // { // 14429 bytes
  "CHAUCER'S TALE OF SIR THOPAS.\n"
  "\n"
  "\n"
  "THE PROLOGUE.<1>\n"
  "\n"
  "\n"
  "WHEN said was this miracle, every man\n"
  "As sober* was, that wonder was to see,                          *serious\n"
  "Till that our Host to japen* he began,                     *talk lightly\n"
  "And then *at erst* he looked upon me,               *for the first time*\n"
  "And saide thus; \"What man art thou?\" quoth he;\n"
  "\"Thou lookest as thou wouldest find an hare,\n"
  "For ever on the ground I see thee stare.\n"
  "\n"
  "\"Approache near, and look up merrily.\n"
  "Now ware you, Sirs, and let this man have place.\n"
  "He in the waist is shapen as well as I; <2>\n"
  "This were a puppet in an arm t'embrace\n"
  "For any woman small and fair of face.\n"
  "He seemeth elvish* by his countenance,                    *surly, morose\n"
  "For unto no wight doth he dalliance.\n"
  "\n"
  "\"Say now somewhat, since other folk have said;\n"
  "Tell us a tale of mirth, and that anon.\"\n"
  "\"Hoste,\" quoth I, \"be not evil apaid,*                     *dissatisfied\n"
  "For other tale certes can* I none,                                 *know\n"
  "Eut of a rhyme I learned yore* agone.\"                             *long\n"
  "\"Yea, that is good,\" quoth he; \"now shall we hear\n"
  "Some dainty thing, me thinketh by thy cheer.\"*         *expression, mien\n"
  "\n"
  "\n"
  "Notes to the Prologue to Chaucer's Tale of Sir Thopas\n"
  "\n"
  "\n"
  "1. This prologue is interesting, for the picture which it gives of\n"
  "Chaucer himself; riding apart from and indifferent to the rest of\n"
  "the pilgrims, with eyes fixed on the ground, and an \"elvish\",\n"
  "morose, or rather self-absorbed air; portly, if not actually stout,\n"
  "in body; and evidently a man out of the common, as the closing\n"
  "words of the Host imply.\n"
  "\n"
  "2. Referring to the poet's corpulency.\n"
  "\n"
  "\n"
  "THE TALE <1>\n"
  "\n"
  "\n"
  "The First Fit*                                                     *part\n"
  "\n"
  "Listen, lordings, in good intent,\n"
  "And I will tell you verrament*                                    *truly\n"
  "Of mirth and of solas,*                                 *delight, solace\n"
  "All of a knight was fair and gent,*                              *gentle\n"
  "In battle and in tournament,\n"
  "His name was Sir Thopas.\n"
  "\n"
  "Y-born he was in far country,\n"
  "In Flanders, all beyond the sea,\n"
  "At Popering <2> in the place;\n"
  "His father was a man full free,\n"
  "And lord he was of that country,\n"
  "As it was Godde's grace. <3>\n"
  "\n"
  "Sir Thopas was a doughty swain,\n"
  "White was his face as paindemain, <4>\n"
  "His lippes red as rose.\n"
  "His rode* is like scarlet in grain,                          *complexion\n"
  "And I you tell in good certain\n"
  "He had a seemly nose.\n"
  "\n"
  "His hair, his beard, was like saffroun,\n"
  "That to his girdle reach'd adown,\n"
  "His shoes of cordewane:<5>\n"
  "Of Bruges were his hosen brown;\n"
  "His robe was of ciclatoun,<6>\n"
  "That coste many a jane.<7>\n"
  "\n"
  "He coulde hunt at the wild deer,\n"
  "And ride on hawking *for rivere*                          *by the river*\n"
  "With gray goshawk on hand: <8>\n"
  "Thereto he was a good archere,\n"
  "Of wrestling was there none his peer,\n"
  "Where any ram <9> should stand.\n"
  "\n"
  "Full many a maiden bright in bow'r\n"
  "They mourned for him par amour,\n"
  "When them were better sleep;\n"
  "But he was chaste, and no lechour,\n"
  "And sweet as is the bramble flow'r\n"
  "That beareth the red heep.*                                         *hip\n"
  "\n"
  "And so it fell upon a day,\n"
  "For sooth as I you telle may,\n"
  "Sir Thopas would out ride;\n"
  "He worth* upon his steede gray,                                 *mounted\n"
  "And in his hand a launcegay,*                                *spear <10>\n"
  "A long sword by his side.\n"
  "\n"
  "He pricked through a fair forest,\n"
  "Wherein is many a wilde beast,\n"
  "Yea, bothe buck and hare;\n"
  "And as he pricked north and east,\n"
  "I tell it you, him had almest                                    *almost\n"
  "Betid* a sorry care.                                           *befallen\n"
  "\n"
  "There sprange herbes great and small,\n"
  "The liquorice and the setewall,*                               *valerian\n"
  "And many a clove-gilofre, <12>\n"
  "And nutemeg to put in ale,\n"
  "Whether it be moist* or stale,                                      *new\n"
  "Or for to lay in coffer.\n"
  "\n"
  "The birdes sang, it is no nay,\n"
  "The sperhawk* and the popinjay,**             *sparrowhawk **parrot <13>\n"
  "That joy it was to hear;\n"
  "The throstle-cock made eke his lay,\n"
  "The woode-dove upon the spray\n"
  "She sang full loud and clear.\n"
  "\n"
  "Sir Thopas fell in love-longing\n"
  "All when he heard the throstle sing,\n"
  "And *prick'd as he were wood;*                            *rode as if he\n"
  "His faire steed in his pricking                                were mad*\n"
  "So sweated, that men might him wring,\n"
  "His sides were all blood.\n"
  "\n"
  "Sir Thopas eke so weary was\n"
  "For pricking on the softe grass,\n"
  "So fierce was his corage,*                          *inclination, spirit\n"
  "That down he laid him in that place,\n"
  "To make his steed some solace,\n"
  "And gave him good forage.\n"
  "\n"
  "\"Ah, Saint Mary, ben'dicite,\n"
  "What aileth thilke* love at me                                     *this\n"
  "To binde me so sore?\n"
  "Me dreamed all this night, pardie,\n"
  "An elf-queen shall my leman* be,                               *mistress\n"
  "And sleep under my gore.*                                         *shirt\n"
  "\n"
  "An elf-queen will I love, y-wis,*                             *assuredly\n"
  "For in this world no woman is\n"
  "Worthy to be my make*                                              *mate\n"
  "In town;\n"
  "All other women I forsake,\n"
  "And to an elf-queen I me take\n"
  "By dale and eke by down.\" <14>\n"
  "\n"
  "Into his saddle he clomb anon,\n"
  "And pricked over stile and stone\n"
  "An elf-queen for to spy,\n"
  "Till he so long had ridden and gone,\n"
  "That he found in a privy wonne*                                   *haunt\n"
  "The country of Faery,\n"
  "So wild;\n"
  "For in that country was there none\n"
  "That to him durste ride or gon,\n"
  "Neither wife nor child.\n"
  "\n"
  "Till that there came a great giaunt,\n"
  "His name was Sir Oliphaunt,<15>\n"
  "A perilous man of deed;\n"
  "He saide, \"Child,* by Termagaunt, <16>                        *young man\n"
  "*But if* thou prick out of mine haunt,                           *unless\n"
  "Anon I slay thy steed\n"
  "With mace.\n"
  "Here is the Queen of Faery,\n"
  "With harp, and pipe, and symphony,\n"
  "Dwelling in this place.\"\n"
  "\n"
  "The Child said, \"All so may I the,*                              *thrive\n"
  "To-morrow will I meete thee,\n"
  "When I have mine armor;\n"
  "And yet I hope, *par ma fay,*                              *by my faith*\n"
  "That thou shalt with this launcegay\n"
  "Abyen* it full sore;                                         *suffer for\n"
  "Thy maw*                                                          *belly\n"
  "Shall I pierce, if I may,\n"
  "Ere it be fully prime of day,\n"
  "For here thou shalt be slaw.\"*                                    *slain\n"
  "\n"
  "Sir Thopas drew aback full fast;\n"
  "This giant at him stones cast\n"
  "Out of a fell staff sling:\n"
  "But fair escaped Child Thopas,\n"
  "And all it was through Godde's grace,\n"
  "And through his fair bearing. <17>\n"
  "\n"
  "Yet listen, lordings, to my tale,\n"
  "Merrier than the nightingale,\n"
  "For now I will you rown,*                                       *whisper\n"
  "How Sir Thopas, with sides smale,*                           *small <18>\n"
  "Pricking over hill and dale,\n"
  "Is come again to town.\n"
  "\n"
  "His merry men commanded he\n"
  "To make him both game and glee;\n"
  "For needes must he fight\n"
  "With a giant with heades three,\n"
  "For paramour and jollity\n"
  "Of one that shone full bright.\n"
  "\n"
  "\"*Do come,*\" he saide, \"my minstrales                           *summon*\n"
  "And gestours* for to telle tales.                         *story-tellers\n"
  "Anon in mine arming,\n"
  "Of romances that be royales, <19>\n"
  "Of popes and of cardinales,\n"
  "And eke of love-longing.\"\n"
  "\n"
  "They fetch'd him first the sweete wine,\n"
  "And mead eke in a maseline,*                              *drinking-bowl\n"
  "And royal spicery;                                    of maple wood <20>\n"
  "Of ginger-bread that was full fine,\n"
  "And liquorice and eke cumin,\n"
  "With sugar that is trie.*                                       *refined\n"
  "\n"
  "He didde,* next his white lere,**                         *put on **skin\n"
  "Of cloth of lake* fine and clear,                            *fine linen\n"
  "A breech and eke a shirt;\n"
  "And next his shirt an haketon,*                                 *cassock\n"
  "And over that an habergeon,*                               *coat of mail\n"
  "For piercing of his heart;\n"
  "\n"
  "And over that a fine hauberk,*                             *plate-armour\n"
  "Was all y-wrought of Jewes'* werk,                           *magicians'\n"
  "Full strong it was of plate;\n"
  "And over that his coat-armour,*                        *knight's surcoat\n"
  "As white as is the lily flow'r, <21>\n"
  "In which he would debate.*                                        *fight\n"
  "\n"
  "His shield was all of gold so red\n"
  "And therein was a boare's head,\n"
  "A charboucle* beside;                                    *carbuncle <22>\n"
  "And there he swore on ale and bread,\n"
  "How that the giant should be dead,\n"
  "Betide whatso betide.\n"
  "\n"
  "His jambeaux* were of cuirbouly, <23>                             *boots\n"
  "His sworde's sheath of ivory,\n"
  "His helm of latoun* bright,                                       *brass\n"
  "His saddle was of rewel <24> bone,\n"
  "His bridle as the sunne shone,\n"
  "Or as the moonelight.\n"
  "\n"
  "His speare was of fine cypress,\n"
  "That bodeth war, and nothing peace;\n"
  "The head full sharp y-ground.\n"
  "His steede was all dapple gray,\n"
  "It went an amble in the way\n"
  "Full softely and round\n"
  "In land.\n"
  "\n"
  "Lo, Lordes mine, here is a fytt;\n"
  "If ye will any more of it,\n"
  "To tell it will I fand.*                                            *try\n"
  "\n"
  "\n"
  "The Second Fit\n"
  "\n"
  "\n"
  "Now hold your mouth for charity,\n"
  "Bothe knight and lady free,\n"
  "And hearken to my spell;*                                     *tale <25>\n"
  "Of battle and of chivalry,\n"
  "Of ladies' love and druerie,*                                 *gallantry\n"
  "Anon I will you tell.\n"
  "\n"
  "Men speak of romances of price*                          * worth, esteem\n"
  "Of Horn Child, and of Ipotis,\n"
  "Of Bevis, and Sir Guy, <26>\n"
  "Of Sir Libeux, <27> and Pleindamour,\n"
  "But Sir Thopas, he bears the flow'r\n"
  "Of royal chivalry.\n"
  "\n"
  "His goode steed he all bestrode,\n"
  "And forth upon his way he glode,*                                 *shone\n"
  "As sparkle out of brand;*                                         *torch\n"
  "Upon his crest he bare a tow'r,\n"
  "And therein stick'd a lily flow'r; <28>\n"
  "God shield his corse* from shand!**                         *body **harm\n"
  "\n"
  "And, for he was a knight auntrous,*                         *adventurous\n"
  "He woulde sleepen in none house,\n"
  "But liggen* in his hood,                                            *lie\n"
  "His brighte helm was his wanger,*                           *pillow <29>\n"
  "And by him baited* his destrer**                       *fed **horse <30>\n"
  "Of herbes fine and good.\n"
  "\n"
  "Himself drank water of the well,\n"
  "As did the knight Sir Percivel, <31>\n"
  "So worthy under weed;\n"
  "Till on a day -   .   .   .\n"
  "\n"
  "\n"
  "Notes to Chaucer's Tale of Sir Thopas\n"
  "\n"
  "\n"
  "1. \"The Rhyme of Sir Thopas,\" as it is generally called, is\n"
  "introduced by Chaucer as a satire on the dull, pompous, and\n"
  "prolix metrical romances then in vogue. It is full of phrases\n"
  "taken from the popular rhymesters in the vein which he holds up\n"
  "to ridicule; if, indeed -- though of that there is no evidence -- it\n"
  "be not actually part of an old romance which Chaucer selected\n"
  "and reproduced to point his assault on the prevailing taste in\n"
  "literature.\n"
  "Transcriber's note: The Tale is full of incongruities of every\n"
  "kind, which Purves does not refer to; I point some of them out\n"
  "in the notes which follow - marked TN.\n"
  "\n"
  "2. Poppering, or Poppeling, a parish in the marches of Calais of\n"
  "which the famous antiquary Leland was once Rector. TN: The\n"
  "inhabitants of Popering had a reputation for stupidity.\n"
  "\n"
  "3. TN: The lord of Popering was the abbot of the local\n"
  "monastery - who could, of course, have no legitimate children.\n"
  "\n"
  "4. Paindemain: Either \"pain de matin,\" morning bread, or \"pain\n"
  "de Maine,\" because it was made best in that province; a kind of\n"
  "fine white bread.\n"
  "\n"
  "5. Cordewane: Cordovan; fine Spanish leather, so called from\n"
  "the name of the city where it was prepared\n"
  "\n"
  "6. Ciclatoun: A rich Oriental stuff of silk and gold, of which was\n"
  "made the circular robe of state called a \"ciclaton,\" from the\n"
  "Latin, \"cyclas.\" The word is French.\n"
  "\n"
  "7. Jane: a Genoese coin, of small value; in our old statutes\n"
  "called \"gallihalpens,\" or galley half-pence.\n"
  "\n"
  "8. TN: In Mediaeval falconry the goshawk was not regarded as\n"
  "a fit bird for a knight.  It was the yeoman's bird.\n"
  "\n"
  "9. A ram was the usual prize of wrestling contests. TN:\n"
  "Wrestling and archery were sports of the common people, not\n"
  "knightly accomplishments.\n"
  "\n"
  "10. Launcegay: spear; \"azagay\" is the name of a Moorish\n"
  "weapon, and the identity of termination is singular.\n"
  "\n"
  "12. Clove-gilofre: clove-gilliflower; \"Caryophyllus hortensis.\"\n"
  "\n"
  "13. TN: The sparrowhawk and parrot can only squawk\n"
  "unpleasantly.\n"
  "\n"
  "14. TN: The sudden and pointless changes in the stanza form\n"
  "are of course part of Chaucer's parody.\n"
  "\n"
  "15. Sir Oliphaunt: literally, \"Sir Elephant;\" Sir John Mandeville\n"
  "calls those animals \"Olyfauntes.\"\n"
  "\n"
  "16. Termagaunt: A pagan or Saracen deity, otherwise named\n"
  "Tervagan, and often mentioned in Middle Age literature. His\n"
  "name has passed into our language, to denote a ranter or\n"
  "blusterer, as be was represented to be.\n"
  "\n"
  "17. TN: His \"fair bearing\" would not have been much defence\n"
  "against a sling-stone.\n"
  "\n"
  "18. TN: \"Sides small\": a conventional description for a woman,\n"
  "not a man.\n"
  "\n"
  "19. Romances that be royal:  so called because they related to\n"
  "Charlemagne and his family.\n"
  "\n"
  "20. TN: A knight would be expected to have a gold or silver\n"
  "drinking vessel.\n"
  "\n"
  "21. TN: The coat-armour or coat of arms should have had his\n"
  "heraldic emblems on it, not been pure white\n"
  "\n"
  "22. Charboucle:  Carbuncle; French, \"escarboucle;\" a heraldic\n"
  "device resembling a jewel.\n"
  "\n"
  "23. Cuirbouly:  \"Cuir boulli,\" French, boiled or prepared\n"
  "leather; also used to cover shields, &c.\n"
  "\n"
  "24. Rewel bone: No satisfactory explanation has been furnished\n"
  "of  this word, used to describe some material from which  rich\n"
  "saddles were made. TN: The OED defines it as narwhal ivory.\n"
  "\n"
  "25. Spell:  Tale, discourse, from Anglo-Saxon, \"spellian,\" to\n"
  "declare, tell a story.\n"
  "\n"
  "26. Sir Bevis of Hampton, and Sir Guy of Warwick, two\n"
  "knights of great renown.\n"
  "\n"
  "27. Libeux:  One of Arthur's knights, called \"Ly beau\n"
  "desconus,\" \"the fair unknown.\"\n"
  "\n"
  "28. TN: The crest was a small emblem worn on top of a knight's\n"
  "helmet. A tower with a lily stuck in it would have been\n"
  "unwieldy and absurd.\n"
  "\n"
  "29. Wanger:  pillow; from Anglo-Saxon, \"wangere,\" because\n"
  "the \"wanges;\" or cheeks, rested on it.\n"
  "\n"
  "30. Destrer:  \"destrier,\" French, a war-horse; in Latin,\n"
  "\"dextrarius,\" as if led by the right hand.\n"
  "\n"
  "31. Sir Percival de Galois, whose adventures were written in\n"
  "more than 60,000 verses by Chretien de Troyes, one of the\n"
  "oldest and best French romancers, in 1191.\n"
  "\n"
  "\n"
  "\n"
  "";
// }

const char taleOfMeliboeus0[] PGMSECTION = // { // 25797 bytes
  "CHAUCER'S TALE OF MELIBOEUS.\n"
  "\n"
  "\n"
  "THE PROLOGUE.\n"
  "\n"
  "\n"
  "\"No more of this, for Godde's dignity!\"\n"
  "Quoth oure Hoste; \"for thou makest me\n"
  "So weary of thy very lewedness,*               *stupidity, ignorance <1>\n"
  "That, all so wisly* God my soule bless,                          *surely\n"
  "Mine eares ache for thy drafty* speech.                   *worthless <2>\n"
  "Now such a rhyme the devil I beteche:*                       *commend to\n"
  "This may well be rhyme doggerel,\" quoth he.\n"
  "\"Why so?\" quoth I; \"why wilt thou lette* me                     *prevent\n"
  "More of my tale than any other man,\n"
  "Since that it is the best rhyme that I can?\"*                      *know\n"
  "\"By God!\" quoth he, \"for, plainly at one word,\n"
  "Thy drafty rhyming is not worth a tord:\n"
  "Thou dost naught elles but dispendest* time.                    *wastest\n"
  "Sir, at one word, thou shalt no longer rhyme.\n"
  "Let see whether thou canst tellen aught *in gest,*            *by way of\n"
  "Or tell in prose somewhat, at the least,                      narrative*\n"
  "In which there be some mirth or some doctrine.\"\n"
  "\"Gladly,\" quoth I, \"by Godde's sweete pine,*                  *suffering\n"
  "I will you tell a little thing in prose,\n"
  "That oughte like* you, as I suppose,                             *please\n"
  "Or else certes ye be too dangerous.*                         *fastidious\n"
  "It is a moral tale virtuous,\n"
  "*All be it* told sometimes in sundry wise               *although it be*\n"
  "By sundry folk, as I shall you devise.\n"
  "As thus, ye wot that ev'ry Evangelist,\n"
  "That telleth us the pain* of Jesus Christ,                      *passion\n"
  "He saith not all thing as his fellow doth;\n"
  "But natheless their sentence is all soth,*                         *true\n"
  "And all accorden as in their sentence,*                         *meaning\n"
  "All be there in their telling difference;\n"
  "For some of them say more, and some say less,\n"
  "When they his piteous passion express;\n"
  "I mean of Mark and Matthew, Luke and John;\n"
  "But doubteless their sentence is all one.\n"
  "Therefore, lordinges all, I you beseech,\n"
  "If that ye think I vary in my speech,\n"
  "As thus, though that I telle somedeal more\n"
  "Of proverbes, than ye have heard before\n"
  "Comprehended in this little treatise here,\n"
  "*T'enforce with* the effect of my mattere,                *with which to\n"
  "And though I not the same wordes say                            enforce*\n"
  "As ye have heard, yet to you all I pray\n"
  "Blame me not; for as in my sentence\n"
  "Shall ye nowhere finde no difference\n"
  "From the sentence of thilke* treatise lite,**             *this **little\n"
  "After the which this merry tale I write.\n"
  "And therefore hearken to what I shall say,\n"
  "And let me tellen all my tale, I pray.\"\n"
  "\n"
  "\n"
  "Notes to the Prologue to Chaucer's Tale of Meliboeus.\n"
  "\n"
  "\n"
  "1. Chaucer crowns the satire on the romanticists by making the\n"
  "very landlord of the Tabard cry out in indignant disgust against\n"
  "the stuff which he had heard recited -- the good Host ascribing\n"
  "to sheer ignorance the string of pompous platitudes and prosaic\n"
  "details which Chaucer had uttered.\n"
  "\n"
  "2. Drafty:  worthless, vile; no better than draff or dregs; from\n"
  "the Anglo-Saxon, \"drifan\" to drive away, expel.\n"
  "\n"
  "\n"
  "THE TALE.<1>\n"
  "\n"
  "\n"
  "A young man called Meliboeus, mighty and rich, begat upon his\n"
  "wife, that called was Prudence, a daughter which that called was\n"
  "Sophia. Upon a day befell, that he for his disport went into the\n"
  "fields him to play.  His wife and eke his daughter hath he left\n"
  "within his house, of which the doors were fast shut. Three of his\n"
  "old foes have it espied, and set ladders to the walls of his house,\n"
  "and by the windows be entered, and beaten his wife, and\n"
  "wounded his daughter with five mortal wounds, in five sundry\n"
  "places; that is to say, in her feet, in her hands, in her ears, in her\n"
  "nose, and in her mouth; and left her for dead, and went away.\n"
  "When Meliboeus returned was into his house, and saw all this\n"
  "mischief, he, like a man mad, rending his clothes, gan weep and\n"
  "cry. Prudence his wife, as farforth as she durst, besought him of\n"
  "his weeping for to stint: but not forthy [notwithstanding] he gan\n"
  "to weep and cry ever longer the more.\n"
  "\n"
  "This noble wife Prudence remembered her upon the sentence of\n"
  "Ovid, in his book that called is the \"Remedy of Love,\" <2>\n"
  "where he saith: He is a fool that disturbeth the mother to weep\n"
  "in the death of her child, till she have wept her fill, as for a\n"
  "certain time; and then shall a man do his diligence with amiable\n"
  "words her to recomfort and pray her of her weeping for to stint\n"
  "[cease]. For which reason this noble wife Prudence suffered her\n"
  "husband for to weep and cry, as for a certain space; and when\n"
  "she saw her time, she said to him in this wise: \"Alas! my lord,\"\n"
  "quoth she, \"why make ye yourself for to be like a fool? For\n"
  "sooth it appertaineth not to a wise man to make such a sorrow.\n"
  "Your daughter, with the grace of God, shall warish [be cured]\n"
  "and escape. And all [although] were it so that she right now\n"
  "were dead, ye ought not for her death yourself to destroy.\n"
  "Seneca saith, 'The wise man shall not take too great discomfort\n"
  "for the death of his children, but certes he should suffer it in\n"
  "patience, as well as he abideth the death of his own proper\n"
  "person.'\"\n"
  "\n"
  "Meliboeus answered anon and said: \"What man,\" quoth he,\n"
  "\"should of his weeping stint, that hath so great a cause to weep?\n"
  "Jesus Christ, our Lord, himself wept for the death of Lazarus\n"
  "his friend.\"  Prudence answered, \"Certes, well I wot,\n"
  "attempered [moderate] weeping is nothing defended [forbidden]\n"
  "to him that sorrowful is, among folk in sorrow but it is rather\n"
  "granted him to weep.  The Apostle Paul unto the Romans\n"
  "writeth, 'Man shall rejoice with them that make joy, and weep\n"
  "with such folk as weep.'  But though temperate weeping be\n"
  "granted, outrageous weeping certes is defended. Measure of\n"
  "weeping should be conserved,  after the lore [doctrine] that\n"
  "teacheth us Seneca.  'When that thy friend is dead,' quoth he, 'let\n"
  "not thine eyes too moist be of tears, nor too much dry: although\n"
  "the tears come to thine eyes, let them not fall.  And when thou\n"
  "hast forgone [lost] thy friend, do diligence to get again another\n"
  "friend: and this is more wisdom than to weep for thy friend\n"
  "which that thou hast lorn [lost] for therein is no boot\n"
  "[advantage].  And therefore if ye govern you by sapience, put\n"
  "away sorrow out of your heart. Remember you that Jesus\n"
  "Sirach saith, 'A man that is joyous and glad in heart, it him\n"
  "conserveth flourishing in his age: but soothly a sorrowful heart\n"
  "maketh his bones dry.'  He said eke thus, 'that sorrow in heart\n"
  "slayth full many a man.' Solomon  saith 'that right as moths in\n"
  "the sheep's fleece annoy [do injury] to the clothes, and the small\n"
  "worms to the tree, right so annoyeth sorrow to the heart of\n"
  "man.' Wherefore us ought as well in the death of our children,\n"
  "as in the loss of our goods temporal, have patience. Remember\n"
  "you upon the patient Job, when he had lost his children and his\n"
  "temporal substance, and in his body endured and received full\n"
  "many a grievous tribulation, yet said he thus: 'Our Lord hath\n"
  "given it to me, our Lord hath bereft it me; right as our Lord\n"
  "would, right so be it done; blessed be the name of our Lord.\"'\n"
  "\n"
  "To these foresaid things answered Meliboeus unto his wife\n"
  "Prudence: \"All thy words,\" quoth he, \"be true, and thereto\n"
  "[also] profitable, but truly mine heart is troubled with this\n"
  "sorrow so grievously, that I know not what to do.\"  \"Let call,\"\n"
  "quoth Prudence, \"thy true friends all, and thy lineage, which be\n"
  "wise, and tell to them your case, and hearken what they say in\n"
  "counselling, and govern you after their sentence [opinion].\n"
  "Solomon saith, 'Work all things by counsel, and thou shall never\n"
  "repent.'\" Then, by counsel of his wife Prudence, this Meliboeus\n"
  "let call [sent for] a great congregation of folk, as surgeons,\n"
  "physicians, old folk and young, and some of his old enemies\n"
  "reconciled (as by their semblance) to his love and to his grace;\n"
  "and therewithal there come some of his neighbours, that did him\n"
  "reverence more for dread than for love, as happeneth oft. There\n"
  "come also full many subtle flatterers, and wise advocates\n"
  "learned in the law. And when these folk together assembled\n"
  "were, this Meliboeus in sorrowful wise showed them his case,\n"
  "and by the manner of his speech it seemed that in heart he bare\n"
  "a cruel ire, ready to do vengeance upon his foes, and suddenly\n"
  "desired that the war should begin, but nevertheless yet asked he\n"
  "their counsel in this matter. A surgeon, by licence and assent of\n"
  "such as were wise, up rose, and to Meliboeus said as ye may\n"
  "hear.  \"Sir,\" quoth he, \"as to us surgeons appertaineth, that we\n"
  "do to every wight the best that we can, where as we be\n"
  "withholden, [employed] and to our patient that we do no\n"
  "damage; wherefore it happeneth many a time and oft, that when\n"
  "two men have wounded each other, one same surgeon healeth\n"
  "them both; wherefore unto our art it is not pertinent to nurse\n"
  "war, nor parties to support [take sides].  But certes, as to the\n"
  "warishing [healing] of your daughter, albeit so that perilously\n"
  "she be wounded, we shall do so attentive business from day to\n"
  "night, that, with the grace of God, she shall be whole and\n"
  "sound, as soon as is possible.\" Almost right in the same wise the\n"
  "physicians answered, save that they said a few words more: that\n"
  "right as maladies be cured by their contraries, right so shall man\n"
  "warish war (by peace). His neighbours full of envy, his feigned\n"
  "friends that seemed reconciled, and his flatterers, made\n"
  "semblance of weeping, and impaired and agregged [aggravated]\n"
  "much of this matter, in praising greatly Meliboeus of might, of\n"
  "power, of riches, and of friends, despising the power of his\n"
  "adversaries: and said utterly, that he anon should wreak him on\n"
  "his foes, and begin war.\n"
  "\n"
  "Up rose then an advocate that was wise, by leave and by\n"
  "counsel of other that were wise, and said, \"Lordings, the need\n"
  "[business] for which we be assembled in this place, is a full\n"
  "heavy thing, and an high matter, because of the wrong and of\n"
  "the wickedness that hath been done, and eke by reason of the\n"
  "great damages that in time coming be possible to fall for the\n"
  "same cause, and eke by reason of the great riches and power of\n"
  "the parties both; for which reasons, it were a full great peril to\n"
  "err in this matter. Wherefore, Meliboeus, this is our sentence\n"
  "[opinion]; we counsel you, above all things, that right anon thou\n"
  "do thy diligence in keeping of thy body, in such a wise that thou\n"
  "want no espy  nor watch thy body to save. And after that, we\n"
  "counsel that in thine house thou set sufficient garrison, so that\n"
  "they may as well thy body as thy house defend. But, certes, to\n"
  "move war or suddenly to do vengeance, we may not deem\n"
  "[judge] in so little time that it were profitable. Wherefore we\n"
  "ask leisure and space to have deliberation in this case to deem;\n"
  "for the common proverb saith thus; 'He that soon deemeth soon\n"
  "shall repent.' And eke men say, that that judge is wise, that soon\n"
  "understandeth a matter, and judgeth by leisure. For albeit so\n"
  "that all tarrying be annoying, algates [nevertheless] it is no\n"
  "reproof [subject for reproach] in giving of judgement, nor in\n"
  "vengeance taking, when it is sufficient and, reasonable.  And\n"
  "that shewed our Lord Jesus Christ by example; for when that\n"
  "the woman that was taken in adultery was brought in his\n"
  "presence to know what should be done with her person, albeit\n"
  "that he wist well himself what he would answer, yet would he\n"
  "not answer suddenly, but he would have deliberation, and in the\n"
  "ground he wrote twice. And by these causes we ask deliberation\n"
  "and we shall then by the grace of God counsel the thing that\n"
  "shall be profitable.\"\n"
  "\n"
  "Up started then the young folk anon at once, and the most part\n"
  "of that company have scorned these old wise men and begun to\n"
  "make noise and said, \"Right as while that iron is hot men should\n"
  "smite, right so men should wreak their wrongs while that they\n"
  "be fresh and new:\"  and with loud voice they cried. \"War! War!\"\n"
  "Up rose then one of these old wise, and with his hand made\n"
  "countenance [a sign, gesture] that men should hold them still,\n"
  "and give him audience. \"Lordings,\" quoth he, \"there is full many\n"
  "a man that crieth, 'War! war!' that wot full little what war\n"
  "amounteth.  War at his beginning hath so great an entering and\n"
  "so large, that every wight may enter when him liketh, and lightly\n"
  "[easily] find war: but certes what end shall fall thereof it is not\n"
  "light to know. For soothly when war is once begun, there is full\n"
  "many a child unborn of his mother, that shall sterve [die] young\n"
  "by cause of that war, or else live in sorrow and die in\n"
  "wretchedness; and therefore, ere that any war be begun, men\n"
  "must have great counsel and great deliberation.\"  And when this\n"
  "old man weened [thought, intended] to enforce his tale by\n"
  "reasons, well-nigh all at once began they to rise for to break his\n"
  "tale, and bid him full oft his words abridge. For soothly he that\n"
  "preacheth to them that list not hear his words, his sermon them\n"
  "annoyeth. For Jesus Sirach saith, that music in weeping is a\n"
  "noyous [troublesome] thing.  This is to say, as much availeth to\n"
  "speak before folk to whom his speech annoyeth, as to sing\n"
  "before him that weepeth.  And when this wise man saw that him\n"
  "wanted audience, all shamefast he sat him down again.  For\n"
  "Solomon saith, 'Where as thou mayest have no audience,\n"
  "enforce thee not to speak.'  \"I  see well,\" quoth this wise man,\n"
  "\"that the common proverb is sooth, that good counsel wanteth,\n"
  "when it is most need.\" Yet [besides, further] had this Meliboeus\n"
  "in his council many folk, that privily in his ear counselled him\n"
  "certain thing, and counselled him the contrary in general\n"
  "audience. When Meliboeus had heard that the greatest part of\n"
  "his council were accorded [in agreement] that he should make\n"
  "war, anon he consented to their counselling, and fully affirmed\n"
  "their sentence [opinion, judgement].\n"
  "\n"
  "(Dame Prudence, seeing her husband's resolution thus taken, in\n"
  "full humble wise, when she saw her time, begins to counsel him\n"
  "against war, by a warning against haste in requital of either\n"
  "good or evil.  Meliboeus tells her that he will not work by her\n"
  "counsel, because he should be held a fool if he rejected for her\n"
  "advice the opinion of so many wise men; because all women are\n"
  "bad; because it would seem that he had given her the mastery\n"
  "over him; and because she could not keep his secret, if he\n"
  "resolved to follow her advice. To these reasons Prudence\n"
  "answers that it is no folly to change counsel when things, or\n"
  "men's judgements of them, change -- especially to alter a\n"
  "resolution taken on the impulse of a great multitude of folk,\n"
  "where every man crieth and clattereth what him liketh; that if all\n"
  "women had been wicked, Jesus Christ would never have\n"
  "descended to be born of a woman, nor have showed himself\n"
  "first to a woman after his resurrection and that when Solomon\n"
  "said he had found no good woman, he meant that God alone\n"
  "was supremely good; <3> that her husband would not seem to\n"
  "give her the mastery by following her counsel, for he had his\n"
  "own free choice in following or rejecting it; and that he knew\n"
  "well and had often tested her great silence, patience, and\n"
  "secrecy. And whereas he had quoted a saying, that in wicked\n"
  "counsel women vanquish men, she reminds him that she would\n"
  "counsel him against doing a wickedness on which he had set his\n"
  "mind, and cites instances to show that many women have been\n"
  "and yet are full good, and their counsel wholesome and\n"
  "profitable. Lastly, she quotes the words of God himself, when\n"
  "he was about to make woman as an help meet for man; and\n"
  "promises that, if her husband will trust her counsel, she will\n"
  "restore to him his daughter whole and sound, and make him\n"
  "have honour in this case.  Meliboeus answers that because of his\n"
  "wife's sweet words, and also because he has proved and assayed\n"
  "her great wisdom and her great truth, he will govern him by her\n"
  "counsel in all things. Thus encouraged, Prudence enters on a\n"
  "long discourse, full of learned citations, regarding the manner in\n"
  "which counsellors should be chosen and consulted, and the\n"
  "times and reasons for changing a counsel. First, God must be\n"
  "besought for guidance. Then a man must well examine his own\n"
  "thoughts, of such things as he holds to be best for his own\n"
  "profit; driving out of his heart anger, covetousness, and\n"
  "hastiness, which perturb and pervert the judgement. Then he\n"
  "must keep his counsel secret, unless confiding it to another shall\n"
  "be more profitable; but, in so confiding it, he shall say nothing\n"
  "to bias the mind of the counsellor toward flattery or\n"
  "subserviency. After that he should consider his friends and his\n"
  "enemies, choosing of the former such as be most faithful and\n"
  "wise, and eldest and most approved in counselling; and even of\n"
  "these only a few. Then he must eschew the counselling of fools,\n"
  "of flatterers, of his old enemies that be reconciled, of servants\n"
  "who bear him great reverence and fear, of folk that be drunken\n"
  "and can hide no counsel, of such as counsel one thing privily\n"
  "and the contrary openly; and of young folk, for their counselling\n"
  "is not ripe. Then, in examining his counsel, he must truly tell his\n"
  "tale; he must consider whether the thing he proposes to do be\n"
  "reasonable, within his power, and acceptable to the more part\n"
  "and the better part of his counsellors; he must look at the things\n"
  "that may follow from that counselling, choosing the best and\n"
  "waiving all besides; he must consider the root whence the\n"
  "matter of his counsel is engendered, what  fruits it may bear,\n"
  "and from what causes they be sprung.  And having thus\n"
  "examined his counsel and approved it by many wise folk and\n"
  "old, he shall consider if he may perform it and make of it a good\n"
  "end; if he be in doubt, he shall choose rather to suffer than to\n"
  "begin; but otherwise he shall prosecute his resolution steadfastly\n"
  "till the enterprise be at an end. As to changing his counsel, a\n"
  "man may do so without reproach, if the cause cease, or when a\n"
  "new case betides, or if he find that by error or otherwise harm\n"
  "or damage may result, or if his counsel be dishonest or come of\n"
  "dishonest cause, or if it be impossible or may not properly be\n"
  "kept; and he must take it for a general rule, that every counsel\n"
  "which is affirmed so strongly, that it may not be changed for\n"
  "any condition that may betide, that counsel is wicked.\n"
  "Meliboeus, admitting that his wife had spoken well and suitably\n"
  "as to counsellors and counsel in general, prays her to tell him in\n"
  "especial what she thinks of the counsellors whom they have\n"
  "chosen in their present need. Prudence replies that his counsel in\n"
  "this case could not properly be called a counselling, but a\n"
  "movement of folly; and points out that he has erred in sundry\n"
  "wise against the rules which he had just laid down. Granting\n"
  "that he has erred, Meliboeus says that he is all ready to change\n"
  "his counsel right as she will devise; for, as the proverb runs, to\n"
  "do sin is human, but to persevere long in sin is work of the\n"
  "Devil. Prudence then minutely recites, analyses, and criticises\n"
  "the counsel given to her husband in the assembly of his friends.\n"
  "She commends the advice of the physicians and surgeons, and\n"
  "urges that they should be well rewarded for their noble speech\n"
  "and their services in healing Sophia; and she asks Meliboeus\n"
  "how he understands their proposition that one contrary must be\n"
  "cured by another contrary. Meliboeus answers, that he should\n"
  "do vengeance on his enemies, who had done him wrong.\n"
  "Prudence, however, insists that vengeance is not the contrary of\n"
  "vengeance, nor wrong of wrong, but the like; and that\n"
  "wickedness should be healed by goodness, discord by accord,\n"
  "war by peace.  She proceeds to deal with the counsel of the\n"
  "lawyers and wise folk that advised Meliboeus to take prudent\n"
  "measures for the security of his body and of his house. First, she\n"
  "would have her husband pray for the protection and aid of\n"
  "Christ; then commit the keeping of his person to his true\n"
  "friends; then suspect and avoid all strange folk, and liars, and\n"
  "such people as she had already warned him against; then beware\n"
  "of presuming on his strength, or the weakness of his adversary,\n"
  "and neglecting to guard his person -- for every wise man\n"
  "dreadeth his enemy; then he should evermore be on the watch\n"
  "against ambush and all espial, even in what seems a place of\n"
  "safety; though he should not be so cowardly, as to fear where is\n"
  "no cause for dread; yet he should dread to be poisoned, and\n"
  "therefore shun scorners, and fly their words as venom.  As to\n"
  "the fortification of his house, she points out that towers and\n"
  "great edifices are costly and laborious, yet useless unless\n"
  "defended by true friends that be old and wise; and the greatest\n"
  "and strongest garrison that a rich man may have, as well to keep\n"
  "his person as his goods, is, that he be beloved by his subjects\n"
  "and by his neighbours. Warmly approving the counsel that in all\n"
  "this business Meliboeus should proceed with great diligence and\n"
  "deliberation, Prudence goes on to examine the advice given by\n"
  "his neighbours that do him reverence without love, his old\n"
  "enemies reconciled, his flatterers that counselled him certain\n"
  "things privily and openly counselled him the contrary, and the\n"
  "young folk that counselled him to avenge himself and make war\n"
  "at once.  She reminds him that he stands alone against three\n"
  "powerful enemies, whose kindred are numerous and close,\n"
  "while his are fewer and remote in relationship; that only the\n"
  "judge who has jurisdiction in a case may take sudden vengeance\n"
  "on any man; that her husband's power does not accord with his\n"
  "desire; and that, if he did take vengeance, it would only breed\n"
  "fresh wrongs and contests. As to the causes of the wrong done\n"
  "to him, she holds that God, the causer of all things, has\n"
  "permitted him to suffer because he has drunk so much honey\n"
  "<4> of sweet temporal riches, and delights, and honours of this\n"
  "world, that he is drunken, and has forgotten Jesus Christ his\n"
  "Saviour; the three enemies of mankind, the flesh, the fiend, and\n"
  "the world, have entered his heart by the windows of his body,\n"
  "and wounded his soul in five places -- that is to say, the deadly\n"
  "sins that have entered into his heart by the five senses; and in\n"
  "the same manner Christ has suffered his three enemies to enter\n"
  "his house by the windows, and wound his daughter in the five\n"
  "places before specified. Meliboeus demurs, that if his wife's\n"
  "objections prevailed, vengeance would never be taken, and\n"
  "thence great mischiefs would arise; but Prudence replies that the\n"
  "taking of vengeance lies with the judges, to whom the private\n"
  "individual must have recourse.  Meliboeus declares that such\n"
  "vengeance does not please him, and that, as Fortune has\n"
  "nourished and helped him from his childhood, he will now assay\n"
  "her, trusting, with God's help, that she will aid him to avenge his\n"
  "shame. Prudence warns him against trusting to Fortune, all the\n"
  "less because she has hitherto favoured him, for just on that\n"
  "account she is the more likely to fail him; and she calls on him\n"
  "to leave his vengeance with the Sovereign Judge, that avengeth\n"
  "all villainies and wrongs. Meliboeus argues that if he refrains\n"
  "from taking vengeance he will invite his enemies to do him\n"
  "further wrong, and he will be put and held over low; but\n"
  "Prudence contends that such a result can be brought about only\n"
  "by the neglect of the judges, not by the patience of the\n"
  "individual.  Supposing that he had leave to avenge himself, she\n"
  "repeats that he is not strong enough, and quotes the common\n"
  "saw, that it is madness for a man to strive with a stronger than\n"
  "himself, peril to strive with one of equal strength, and folly to\n"
  "strive with a weaker. But, considering his own defaults and\n"
  "demerits, -- remembering the patience of Christ and the\n"
  "undeserved tribulations of the saints, the brevity of this life with\n"
  "all its trouble and sorrow, the discredit thrown on the wisdom\n"
  "and training of  a man who cannot bear wrong with patience --\n"
  "he should refrain wholly from taking vengeance. Meliboeus\n"
  "submits that he is not at all a perfect man, and his heart will\n"
  "never be at peace until he is avenged; and that as his enemies\n"
  "disregarded the peril when they attacked him, so he might,\n"
  "without reproach, incur some peril in attacking them in return,\n"
  "even though he did a great excess in avenging one wrong by\n"
  "another. Prudence strongly deprecates all outrage or excess; but\n"
  "Meliboeus insists that he cannot see that it might greatly harm\n"
  "him though he took a vengeance, for he is richer and mightier\n"
  "than his enemies, and all things obey money. Prudence\n"
  "thereupon launches into a long dissertation on the advantages of\n"
  "riches, the evils of poverty, the means by which wealth should\n"
  "be gathered, and the manner in which it should be used; and\n"
  "concludes by counselling her husband not to move war and\n"
  "battle through trust in his riches, for they suffice not to maintain\n"
  "war, the battle is not always to the strong or the numerous, and\n"
  "the perils of conflict are many. Meliboeus then curtly asks her\n"
  "for her counsel how he shall do in this need; and she answers\n"
  "that certainly she counsels him to agree with his adversaries and\n"
  "have peace with them. Meliboeus on this cries out that plainly\n"
  "she loves not his honour or his worship, in counselling him to\n"
  "go and humble himself before his enemies, crying mercy to them\n"
  "that, having done him so grievous wrong, ask him not to be\n"
  "reconciled. Then Prudence, making semblance of wrath, retorts\n"
  "that she loves his honour and profit as she loves her own, and\n"
  "ever has done; she cites the Scriptures in support of her counsel\n"
  "to seek peace; and says she will leave him to his own courses,\n"
  "for she knows well he is so stubborn, that he will do nothing for\n"
  "her. Meliboeus then relents; admits that he is angry and cannot\n"
  "judge aright; and puts himself wholly in her hands, promising to\n"
  "do just as she desires, and admitting that he is the more held to\n"
  "love and praise her, if she reproves him of his folly)\n"
  "\n"
  "";
// }

const char taleOfMeliboeus1[] PGMSECTION = // { // 16705 bytes
  "Then Dame Prudence discovered all her counsel and her will\n"
  "unto him, and said: \"I counsel you,\" quoth she, \"above all\n"
  "things, that ye make peace between God and you, and be\n"
  "reconciled unto Him and to his grace; for, as I have said to you\n"
  "herebefore, God hath suffered you to have this tribulation and\n"
  "disease [distress, trouble] for your sins; and if ye do as I say\n"
  "you, God will send your adversaries unto you, and make them\n"
  "fall at your feet, ready to do your will and your commandment.\n"
  "For Solomon saith, 'When the condition of man is pleasant and\n"
  "liking to God, he changeth the hearts of the man's adversaries,\n"
  "and constraineth them to beseech him of peace of grace.'  And I\n"
  "pray you let me speak with your adversaries in privy place, for\n"
  "they shall not know it is by your will or your assent; and then,\n"
  "when I know their will and their intent, I may counsel you the\n"
  "more surely.\" '\"Dame,\" quoth Meliboeus, '\"do your will and\n"
  "your liking, for I put me wholly in your disposition and\n"
  "ordinance.\"\n"
  "\n"
  "Then Dame Prudence, when she saw the goodwill of her\n"
  "husband, deliberated and took advice in herself, thinking how\n"
  "she might bring this need [affair, emergency] unto a good end.\n"
  "And when she saw her time, she sent for these adversaries to\n"
  "come into her into a privy place, and showed wisely into them\n"
  "the great goods that come of peace, and the great harms and\n"
  "perils that be in war; and said to them, in goodly manner, how\n"
  "that they ought have great repentance of the injuries and\n"
  "wrongs that they had done to Meliboeus her Lord, and unto her\n"
  "and her daughter.  And when they heard the goodly words of\n"
  "Dame Prudence, then they were surprised and ravished, and had\n"
  "so great joy of her, that wonder was to tell.  \"Ah lady!\" quoth\n"
  "they, \"ye have showed unto us the blessing of sweetness, after\n"
  "the saying of David the prophet; for the reconciling which we\n"
  "be not worthy to have in no manner, but we ought require it\n"
  "with great contrition and humility, ye of your great goodness\n"
  "have presented unto us. Now see we well, that the science and\n"
  "conning [knowledge] of Solomon is full true; for he saith, that\n"
  "sweet words multiply and increase friends, and make shrews\n"
  "[the ill-natured or angry] to be debonair [gentle, courteous] and\n"
  "meek.  Certes we put our deed, and all our matter and cause, all\n"
  "wholly in your goodwill, and be ready to obey unto the speech\n"
  "and commandment of my lord Meliboeus. And therefore, dear\n"
  "and benign lady, we pray you and beseech you as meekly as we\n"
  "can and may, that it like unto your great goodness to fulfil in\n"
  "deed your goodly words. For we consider and acknowledge\n"
  "that we have offended and grieved my lord Meliboeus out of\n"
  "measure, so far forth that we be not of power to make him\n"
  "amends; and therefore we oblige and bind us and our friends to\n"
  "do all his will and his commandment. But peradventure he hath\n"
  "such heaviness and such wrath to usward, [towards us] because\n"
  "of our offence, that he will enjoin us such a pain [penalty] as we\n"
  "may not bear nor sustain; and therefore, noble lady, we beseech\n"
  "to your womanly pity to take such advisement [consideration]\n"
  "in this need, that we, nor our friends, be not disinherited and\n"
  "destroyed through our folly.\"\n"
  "\n"
  "\"Certes,\" quoth Prudence, \"it is an hard thing, and right\n"
  "perilous, that a man put him all utterly in the arbitration and\n"
  "judgement and in the might and power of his enemy. For\n"
  "Solomon saith, 'Believe me, and give credence to that that I\n"
  "shall say: to thy son, to thy wife, to thy friend, nor to thy\n"
  "brother, give thou never might nor mastery over thy body, while\n"
  "thou livest.'  Now, since he defendeth [forbiddeth] that a man\n"
  "should not give to his brother, nor to his friend, the might of his\n"
  "body, by a stronger reason he defendeth and forbiddeth a man\n"
  "to give himself to his enemy. And nevertheless, I counsel you\n"
  "that ye mistrust not my lord: for I wot well and know verily,\n"
  "that he is debonair and meek, large, courteous and nothing\n"
  "desirous nor envious of good nor riches: for there is nothing in\n"
  "this world that he desireth save only worship and honour.\n"
  "Furthermore I know well, and am right sure, that he shall\n"
  "nothing do in this need without counsel of me; and I shall so\n"
  "work in this case, that by the grace of our Lord God ye shall be\n"
  "reconciled unto us.\"\n"
  "\n"
  "Then said they with one voice, \"\"Worshipful lady, we put us\n"
  "and our goods all fully in your will and disposition, and be ready\n"
  "to come, what day that it like unto your nobleness to limit us or\n"
  "assign us, for to make our obligation and bond, as strong as it\n"
  "liketh unto your goodness, that we may fulfil the will of you and\n"
  "of my lord Meliboeus.\"\n"
  "\n"
  "When Dame Prudence had heard the answer of these men, she\n"
  "bade them go again privily, and she returned to her lord\n"
  "Meliboeus, and told him how she found his adversaries full\n"
  "repentant, acknowledging full lowly their sins and trespasses,\n"
  "and how they were ready to suffer all pain, requiring and\n"
  "praying him of mercy and pity. Then said Meliboeus, \"He is well\n"
  "worthy to have pardon and forgiveness of his sin, that excuseth\n"
  "not his sin, but acknowledgeth, and repenteth him, asking\n"
  "indulgence.  For Seneca saith, 'There is the remission and\n"
  "forgiveness, where the confession is; for confession is neighbour\n"
  "to innocence.' And therefore I assent and confirm me to have\n"
  "peace, but it is good that we do naught without the assent and\n"
  "will of our friends.\" Then was Prudence right glad and joyful,\n"
  "and said, \"Certes, Sir, ye be well and goodly advised; for right\n"
  "as by the counsel, assent, and help of your friends ye have been\n"
  "stirred to avenge you and make war, right so without their\n"
  "counsel shall ye not accord you, nor have peace with your\n"
  "adversaries. For the law saith, 'There is nothing so good by way\n"
  "of kind, [nature] as a thing to be unbound by him that it was\n"
  "bound.'\"\n"
  "\n"
  "And then Dame Prudence, without delay or tarrying, sent anon\n"
  "her messengers for their kin and for their old friends, which\n"
  "were true and wise; and told them by order, in the presence of\n"
  "Meliboeus, all this matter, as it is above expressed and declared;\n"
  "and prayed them that they would give their advice and counsel\n"
  "what were best to do in this need. And when Meliboeus' friends\n"
  "had taken their advice and deliberation of the foresaid matter,\n"
  "and had examined it by great business and great diligence, they\n"
  "gave full counsel for to have peace and rest, and that Meliboeus\n"
  "should with good heart receive his adversaries to forgiveness\n"
  "and mercy. And when Dame Prudence had heard the assent of\n"
  "her lord Meliboeus, and the counsel of his friends, accord with\n"
  "her will and her intention, she was wondrous glad in her heart,\n"
  "and said: \"There is an old proverb that saith, 'The goodness that\n"
  "thou mayest do this day, do it, and abide not nor delay it not till\n"
  "to-morrow:' and therefore I counsel you that ye send your\n"
  "messengers, such as be discreet and wise, unto your adversaries,\n"
  "telling them on your behalf, that if they will treat of peace and\n"
  "of accord, that they shape [prepare] them, without delay or\n"
  "tarrying, to come unto us.\" Which thing performed was indeed.\n"
  "And when these trespassers and repenting folk of their follies,\n"
  "that is to say, the adversaries of Meliboeus, had heard what\n"
  "these messengers said unto them, they were right glad and\n"
  "joyful, and answered full meekly and benignly, yielding graces\n"
  "and thanks to their lord Meliboeus, and to all his company; and\n"
  "shaped them without delay to go with the messengers, and obey\n"
  "to the commandment of their lord Meliboeus.  And right anon\n"
  "they took their way to the court of Meliboeus, and took with\n"
  "them some of their true friends, to make faith for them, and for\n"
  "to be their borrows [sureties].\n"
  "\n"
  "And when they were come to the presence of Meliboeus, he\n"
  "said to them these words; \"It stands thus,\" quoth Meliboeus,\n"
  "\"and sooth it is, that ye causeless, and without skill and reason,\n"
  "have done great injuries and wrongs to me, and to my wife\n"
  "Prudence, and to my daughter also; for ye have entered into my\n"
  "house by violence, and have done such outrage, that all men\n"
  "know well that ye have deserved the death: and therefore will I\n"
  "know and weet of you, whether ye will put the punishing and\n"
  "chastising, and the vengeance of this outrage, in the will of me\n"
  "and of my wife, or ye will not?\" Then the wisest of them three\n"
  "answered for them all, and said; \"Sir,\" quoth he, \"we know well,\n"
  "that we be I unworthy to come to the court of so great a lord\n"
  "and so worthy as ye be, for we have so greatly mistaken us, and\n"
  "have offended and aguilt [incurred guilt] in such wise against\n"
  "your high lordship, that truly we have deserved the death. But\n"
  "yet for the great goodness and debonairte [courtesy, gentleness]\n"
  "that all the world witnesseth of your person, we submit us to\n"
  "the excellence and benignity of your gracious lordship, and be\n"
  "ready to obey to all your commandments, beseeching you, that\n"
  "of your  merciable [merciful] pity ye will consider our great\n"
  "repentance and low submission, and grant us forgiveness of our\n"
  "outrageous trespass and offence; for well we know, that your\n"
  "liberal grace and mercy stretch them farther into goodness, than\n"
  "do our outrageous guilt and trespass into wickedness; albeit that\n"
  "cursedly [wickedly] and damnably we have aguilt [incurred\n"
  "guilt] against your high lordship.\" Then Meliboeus took them\n"
  "up from the ground full benignly, and received their obligations\n"
  "and their bonds, by their oaths upon their pledges and borrows,\n"
  "[sureties] and assigned them a certain day to return unto his\n"
  "court for to receive and accept sentence and judgement, that\n"
  "Meliboeus would command to be done on them, by the causes\n"
  "aforesaid; which things ordained, every man returned home to\n"
  "his house.\n"
  "\n"
  "And when that Dame Prudence saw her time she freined\n"
  "[inquired] and asked her lord Meliboeus, what vengeance he\n"
  "thought to take of his adversaries. To which Meliboeus\n"
  "answered, and said; \"Certes,\" quoth he, \"I think and purpose me\n"
  "fully to disinherit them of all that ever they have, and for to put\n"
  "them in exile for evermore.\" \"Certes,\" quoth Dame Prudence,\n"
  "\"this were a cruel sentence, and much against reason. For ye be\n"
  "rich enough, and have no need of other men's goods; and ye\n"
  "might lightly [easily] in this wise get you a covetous name,\n"
  "which is a vicious thing, and ought to be eschewed of every\n"
  "good man: for, after the saying of the Apostle, covetousness is\n"
  "root of all harms. And therefore it were better for you to lose\n"
  "much good of your own, than for to take of their good in this\n"
  "manner. For better it is to lose good with worship [honour],\n"
  "than to win good with villainy and shame. And every man ought\n"
  "to do his diligence and his business to get him a good name.\n"
  "And yet [further] shall he not only busy him in keeping his good\n"
  "name, but he shall also enforce him alway to do some thing by\n"
  "which he may renew his good name; for it is written, that the\n"
  "old good los [reputation <5>] of a man is soon gone and\n"
  "passed, when it is not renewed.  And as touching that ye say,\n"
  "that ye will exile your adversaries, that thinketh ye much against\n"
  "reason, and out of measure, [moderation] considered the power\n"
  "that they have given you upon themselves. And it is written,\n"
  "that he is worthy to lose his privilege, that misuseth the might\n"
  "and the power that is given him.  And I set case [if I assume] ye\n"
  "might enjoin them that pain by right and by law (which I trow\n"
  "ye may not do), I say, ye might not put it to execution\n"
  "peradventure, and then it were like to return to the war, as it\n"
  "was before.  And therefore if ye will that men do you obeisance,\n"
  "ye must deem [decide] more courteously, that is to say, ye must\n"
  "give more easy sentences and judgements. For it is written, 'He\n"
  "that most courteously commandeth, to him men most obey.'\n"
  "And therefore I pray you, that in this necessity and in this need\n"
  "ye cast you [endeavour, devise a way] to overcome your heart.\n"
  "For Seneca saith, that he that overcometh his heart, overcometh\n"
  "twice. And Tullius saith, 'There is nothing so commendable in a\n"
  "great lord, as when he is debonair and meek, and appeaseth him\n"
  "lightly [easily].' And I pray you, that ye will now forbear to do\n"
  "vengeance, in such a manner, that your good name may be kept\n"
  "and conserved, and that men may have cause and matter to\n"
  "praise you of pity and of mercy; and that ye have no cause to\n"
  "repent you of thing that ye do. For Seneca saith, 'He\n"
  "overcometh in an evil manner, that repenteth him of his victory.'\n"
  "Wherefore I pray you let mercy be in your heart, to the effect\n"
  "and intent that God Almighty have mercy upon you in his last\n"
  "judgement; for Saint James saith in his Epistle, 'Judgement\n"
  "without mercy shall be done to him, that hath no mercy of\n"
  "another wight.'\"\n"
  "\n"
  "When Meliboeus had heard the great skills [arguments, reasons]\n"
  "and reasons of Dame Prudence, and her wise information and\n"
  "teaching, his heart gan incline to the will of his wife, considering\n"
  "her true intent, he conformed him anon and assented fully to\n"
  "work after her counsel, and thanked God, of whom proceedeth\n"
  "all goodness and all virtue, that him sent a wife of so great\n"
  "discretion. And when the day came that his adversaries should\n"
  "appear in his presence, he spake to them full goodly, and said in\n"
  "this wise; \"Albeit so, that of your pride and high presumption\n"
  "and folly, an of your negligence and unconning, [ignorance] ye\n"
  "have misborne [misbehaved] you, and trespassed [done injury]\n"
  "unto me, yet forasmuch as I see and behold your great humility,\n"
  "and that ye be sorry and repentant of your guilts, it constraineth\n"
  "me to do you grace and mercy. Wherefore I receive you into my\n"
  "grace, and forgive you utterly all the offences, injuries, and\n"
  "wrongs, that ye have done against me and mine, to this effect\n"
  "and to this end, that God of his endless mercy will at the time of\n"
  "our dying forgive us our guilts, that we have trespassed to him\n"
  "in this wretched world; for doubtless, if we be sorry and\n"
  "repentant of the sins and guilts which we have trespassed in the\n"
  "sight of our Lord God, he is so free and so merciable [merciful],\n"
  "that he will forgive us our guilts, and bring us to the bliss that\n"
  "never hath end.\" Amen.\n"
  "\n"
  "\n"
  "Notes to Chaucer's Tale of Meliboeus.\n"
  "\n"
  "\n"
  "1. The Tale of Meliboeus is literally translated from a French\n"
  "story, or rather \"treatise,\" in prose, entitled \"Le Livre de\n"
  "Melibee et de Dame Prudence,\" of which two manuscripts, both\n"
  "dating from the fifteenth century, are preserved in the British\n"
  "Museum. Tyrwhitt, justly enough, says of it that it is indeed, as\n"
  "Chaucer called it in the prologue, \"'a moral tale virtuous,' and\n"
  "was probably much esteemed in its time; but, in this age of\n"
  "levity, I doubt some readers will be apt to regret that he did not\n"
  "rather give us the remainder of Sir Thopas.\"  It has been\n"
  "remarked that in the earlier portion of the Tale, as it left the\n"
  "hand of the poet, a number of blank verses were intermixed;\n"
  "though this peculiarity of style, noticeable in any case only in\n"
  "the first 150 or 200 lines, has necessarily all but disappeared by\n"
  "the changes of spelling made in the modern editions. The\n"
  "Editor's purpose being to present to the public not \"The\n"
  "Canterbury Tales\" merely, but \"The Poems of Chaucer,\" so far\n"
  "as may be consistent with the limits of this volume, he has\n"
  "condensed the long reasonings and learned quotations of Dame\n"
  "Prudence into a mere outline, connecting those portions of the\n"
  "Tale wherein lies so much of story as it actually possesses, and\n"
  "the general reader will probably not regret the sacrifice, made in\n"
  "the view of retaining so far as possible the completeness of the\n"
  "Tales, while lessening the intrusion of prose into a volume or\n"
  "poems.  The good wife of Meliboeus literally overflows with\n"
  "quotations from David, Solomon, Jesus the Son of Sirach, the\n"
  "Apostles, Ovid, Cicero, Seneca, Cassiodorus, Cato, Petrus\n"
  "Alphonsus -- the converted Spanish Jew, of the twelfth century,\n"
  "who wrote the \"Disciplina Clericalis\"  -- and other authorities;\n"
  "and in some passages, especially where husband and wife debate\n"
  "the merits or demerits of women, and where Prudence dilates\n"
  "on the evils of poverty, Chaucer only reproduces much that had\n"
  "been said already in the Tales that preceded -- such as the\n"
  "Merchant's and the Man of Law's.\n"
  "\n"
  "2. The lines which follow are a close translation of the original\n"
  "Latin, which reads:\n"
  "     \"Quis matrem, nisi mentis inops, in funere nati\n"
  "      Flere vetet? non hoc illa monenda loco.\n"
  "      Cum dederit lacrymas, animumque expleverit aegrum,\n"
  "      Ille dolor verbis emoderandus erit.\"\n"
  "Ovid, \"Remedia Amoris,\" 127-131.\n"
  "\n"
  "3. See the conversation between Pluto and Proserpine, in the\n"
  "Merchant's Tale.\n"
  "\n"
  "4. \"Thy name,\" she says, \"is Meliboeus; that is to say, a man\n"
  "that drinketh honey.\"\n"
  "\n"
  "5. Los: reputation; from the past participle of the Anglo-Saxon,\n"
  "\"hlisan\" to celebrate. Compare Latin, \"laus.\"\n"
  "\n"
  "\n"
  "\n"
  "";
// }

const char monksTale0[] PGMSECTION = // { // 24315 bytes
  "THE MONK'S TALE.\n"
  "\n"
  "\n"
  "THE PROLOGUE\n"
  "\n"
  "\n"
  "WHEN ended was my tale of Melibee,\n"
  "And of Prudence and her benignity,\n"
  "Our Hoste said, \"As I am faithful man,\n"
  "And by the precious corpus Madrian,<1>\n"
  "I had lever* than a barrel of ale,                               *rather\n"
  "That goode lefe* my wife had heard this tale;                      *dear\n"
  "For she is no thing of such patience\n"
  "As was this Meliboeus' wife Prudence.\n"
  "By Godde's bones! when I beat my knaves\n"
  "She bringeth me the greate clubbed staves,\n"
  "And crieth, 'Slay the dogges every one,\n"
  "And break of them both back and ev'ry bone.'\n"
  "And if that any neighebour of mine\n"
  "Will not in church unto my wife incline,\n"
  "Or be so hardy to her to trespace,*                              *offend\n"
  "When she comes home she rampeth* in my face,                    *springs\n"
  "And crieth, 'False coward, wreak* thy wife                       *avenge\n"
  "By corpus Domini, I will have thy knife,\n"
  "And thou shalt have my distaff, and go spin.'\n"
  "From day till night right thus she will begin.\n"
  " 'Alas!' she saith, 'that ever I was shape*                    *destined\n"
  "To wed a milksop, or a coward ape,\n"
  "That will be overlad* with every wight!                      *imposed on\n"
  "Thou darest not stand by thy wife's right.'\n"
  "\n"
  "\"This is my life, *but if* that I will fight;                    *unless\n"
  "And out at door anon I must me dight,*                    *betake myself\n"
  "Or elles I am lost, but if that I\n"
  "Be, like a wilde lion, fool-hardy.\n"
  "I wot well she will do* me slay some day                           *make\n"
  "Some neighebour and thenne *go my way;*                 *take to flight*\n"
  "For I am perilous with knife in hand,\n"
  "Albeit that I dare not her withstand;\n"
  "For she is big in armes, by my faith!\n"
  "That shall he find, that her misdoth or saith. <2>\n"
  "But let us pass away from this mattere.\n"
  "My lord the Monk,\" quoth he, \"be merry of cheer,\n"
  "For ye shall tell a tale truely.\n"
  "Lo, Rochester stands here faste by.\n"
  "Ride forth, mine owen lord, break not our game.\n"
  "But by my troth I cannot tell your name;\n"
  "Whether shall I call you my lord Dan John,\n"
  "Or Dan Thomas, or elles Dan Albon?\n"
  "Of what house be ye, by your father's kin?\n"
  "I vow to God, thou hast a full fair skin;\n"
  "It is a gentle pasture where thou go'st;\n"
  "Thou art not like a penant* or a ghost.                        *penitent\n"
  "Upon my faith thou art some officer,\n"
  "Some worthy sexton, or some cellarer.\n"
  "For by my father's soul, *as to my dome,*              *in my judgement*\n"
  "Thou art a master when thou art at home;\n"
  "No poore cloisterer, nor no novice,\n"
  "But a governor, both wily and wise,\n"
  "And therewithal, of brawnes* and of bones,                       *sinews\n"
  "A right well-faring person for the nonce.\n"
  "I pray to God give him confusion\n"
  "That first thee brought into religion.\n"
  "Thou would'st have been a treade-fowl* aright;                     *cock\n"
  "Hadst thou as greate leave, as thou hast might,\n"
  "To perform all thy lust in engendrure,*          *generation, begettting\n"
  "Thou hadst begotten many a creature.\n"
  "Alas! why wearest thou so wide a cope? <3>\n"
  "God give me sorrow, but, an* I were pope,                            *if\n"
  "Not only thou, but every mighty man,\n"
  "Though he were shorn full high upon his pan,* <4>                 *crown\n"
  "Should have a wife; for all this world is lorn;*         *undone, ruined\n"
  "Religion hath ta'en up all the corn\n"
  "Of treading, and we borel* men be shrimps:                          *lay\n"
  "Of feeble trees there come wretched imps.*                   *shoots <5>\n"
  "This maketh that our heires be so slender\n"
  "And feeble, that they may not well engender.\n"
  "This maketh that our wives will assay\n"
  "Religious folk, for they may better pay\n"
  "Of Venus' payementes than may we:\n"
  "God wot, no lusheburghes <6> paye ye.\n"
  "But be not wroth, my lord, though that I play;\n"
  "Full oft in game a sooth have I heard say.\"\n"
  "\n"
  "This worthy Monk took all in patience,\n"
  "And said, \"I will do all my diligence,\n"
  "As far as *souneth unto honesty,*             *agrees with good manners*\n"
  "To telle you a tale, or two or three.\n"
  "And if you list to hearken hitherward,\n"
  "I will you say the life of Saint Edward;\n"
  "Or elles first tragedies I will tell,\n"
  "Of which I have an hundred in my cell.\n"
  "Tragedy *is to say* a certain story,                             *means*\n"
  "As olde bookes maken us memory,\n"
  "Of him that stood in great prosperity,\n"
  "And is y-fallen out of high degree\n"
  "In misery, and endeth wretchedly.\n"
  "And they be versified commonly\n"
  "Of six feet, which men call hexametron;\n"
  "In prose eke* be indited many a one,                               *also\n"
  "And eke in metre, in many a sundry wise.\n"
  "Lo, this declaring ought enough suffice.\n"
  "Now hearken, if ye like for to hear.\n"
  "But first I you beseech in this mattere,\n"
  "Though I by order telle not these things,\n"
  "Be it of popes, emperors, or kings,\n"
  "*After their ages,* as men written find,        *in chronological order*\n"
  "But tell them some before and some behind,\n"
  "As it now cometh to my remembrance,\n"
  "Have me excused of mine ignorance.\"\n"
  "\n"
  "\n"
  "Notes to the Prologue to The Monk's Tale\n"
  "\n"
  "\n"
  "1. The Corpus Madrian: the body of St. Maternus, of Treves.\n"
  "\n"
  "2. That her misdoth or saith: that does or says any thing to\n"
  "offend her.\n"
  "\n"
  "3. Cope:  An ecclesiastcal vestment covering all the body like a\n"
  "cloak.\n"
  "\n"
  "4. Though he were shorn full high upon his pan: though he were\n"
  "tonsured, as the clergy are.\n"
  "\n"
  "5. Imps: shoots, branches; from Anglo-Saxon, \"impian,\"\n"
  "German, \"impfen,\" to implant, ingraft. The word is now used in\n"
  "a very restricted sense, to signify the progeny, children, of the\n"
  "devil.\n"
  "\n"
  "6. Lusheburghes: base or counterfeit coins; so called because\n"
  "struck at Luxemburg.  A great importation of them took place\n"
  "during the reigns of the earlier Edwards, and they caused much\n"
  "annoyance and complaint, till in 1351 it was declared treason to\n"
  "bring them into the country.\n"
  "\n"
  "\n"
  "THE TALE. <1>\n"
  "\n"
  "\n"
  "I will bewail, in manner of tragedy,\n"
  "The harm of them that stood in high degree,\n"
  "And felle so, that there was no remedy\n"
  "To bring them out of their adversity.\n"
  "For, certain, when that Fortune list to flee,\n"
  "There may no man the course of her wheel hold:\n"
  "Let no man trust in blind prosperity;\n"
  "Beware by these examples true and old.\n"
  "\n"
  "\n"
  "At LUCIFER, though he an angel were,\n"
  "And not a man, at him I will begin.\n"
  "For though Fortune may no angel dere,*                             *hurt\n"
  "From high degree yet fell he for his sin\n"
  "Down into hell, where as he yet is in.\n"
  "O Lucifer! brightest of angels all,\n"
  "Now art thou Satanas, that may'st not twin*                      *depart\n"
  "Out of the misery in which thou art fall.\n"
  "\n"
  "\n"
  "Lo ADAM, in the field of Damascene <2>\n"
  "With Godde's owen finger wrought was he,\n"
  "And not begotten of man's sperm unclean;\n"
  "And welt* all Paradise saving one tree:                       *commanded\n"
  "Had never worldly man so high degree\n"
  "As Adam, till he for misgovernance*                        *misbehaviour\n"
  "Was driven out of his prosperity\n"
  "To labour, and to hell, and to mischance.\n"
  "\n"
  "\n"
  "Lo SAMPSON, which that was annunciate\n"
  "By the angel, long ere his nativity; <3>\n"
  "And was to God Almighty consecrate,\n"
  "And stood in nobless while that he might see;\n"
  "Was never such another as was he,\n"
  "To speak of strength, and thereto hardiness;*                   *courage\n"
  "But to his wives told he his secre,\n"
  "Through which he slew himself for wretchedness.\n"
  "\n"
  "Sampson, this noble and mighty champion,\n"
  "Withoute weapon, save his handes tway,\n"
  "He slew and all to-rente* the lion,                      *tore to pieces\n"
  "Toward his wedding walking by the way.\n"
  "His false wife could him so please, and pray,\n"
  "Till she his counsel knew; and she, untrue,\n"
  "Unto his foes his counsel gan bewray,\n"
  "And him forsook, and took another new.\n"
  "\n"
  "Three hundred foxes Sampson took for ire,\n"
  "And all their tailes he together band,\n"
  "And set the foxes' tailes all on fire,\n"
  "For he in every tail had knit a brand,\n"
  "And they burnt all the combs of that lend,\n"
  "And all their oliveres* and vines eke.                  *olive trees <4>\n"
  "A thousand men he slew eke with his hand,\n"
  "And had no weapon but an ass's cheek.\n"
  "\n"
  "When they were slain, so thirsted him, that he\n"
  "Was *well-nigh lorn,* for which he gan to pray       *near to perishing*\n"
  "That God would on his pain have some pity,\n"
  "And send him drink, or elles must he die;\n"
  "And of this ass's check, that was so dry,\n"
  "Out of a wang-tooth* sprang anon a well,                    *cheek-tooth\n"
  "Of which, he drank enough, shortly to say.\n"
  "Thus help'd him God, as Judicum <5>  can tell.\n"
  "\n"
  "By very force, at Gaza, on a night,\n"
  "Maugre* the Philistines of that city,                       *in spite of\n"
  "The gates of the town he hath up plight,*             *plucked, wrenched\n"
  "And on his back y-carried them hath he\n"
  "High on an hill, where as men might them see.\n"
  "O noble mighty Sampson, lefe* and dear,                           *loved\n"
  "Hadst thou not told to women thy secre,\n"
  "In all this world there had not been thy peer.\n"
  "\n"
  "This Sampson never cider drank nor wine,\n"
  "Nor on his head came razor none nor shear,\n"
  "By precept of the messenger divine;\n"
  "For all his strengthes in his haires were;\n"
  "And fully twenty winters, year by year,\n"
  "He had of Israel the governance;\n"
  "But soone shall he weepe many a tear,\n"
  "For women shall him bringe to mischance.\n"
  "\n"
  "Unto his leman* Dalila he told,                                *mistress\n"
  "That in his haires all his strengthe lay;\n"
  "And falsely to his foemen she him sold,\n"
  "And sleeping in her barme* upon a day                               *lap\n"
  "She made to clip or shear his hair away,\n"
  "And made his foemen all his craft espien.\n"
  "And when they founde him in this array,\n"
  "They bound him fast, and put out both his eyen.\n"
  "\n"
  "But, ere his hair was clipped or y-shave,\n"
  "There was no bond with which men might him bind;\n"
  "But now is he in prison in a cave,\n"
  "Where as they made him at the querne* grind.                   *mill <6>\n"
  "O noble Sampson, strongest of mankind!\n"
  "O whilom judge in glory and richess!\n"
  "Now may'st thou weepe with thine eyen blind,\n"
  "Since thou from weal art fall'n to wretchedness.\n"
  "\n"
  "Th'end of this caitiff* was as I shall say;                *wretched man\n"
  "His foemen made a feast upon a day,\n"
  "And made him as their fool before them play;\n"
  "And this was in a temple of great array.\n"
  "But at the last he made a foul affray,\n"
  "For he two pillars shook, and made them fall,\n"
  "And down fell temple and all, and there it lay,\n"
  "And slew himself and eke his foemen all;\n"
  "\n"
  "This is to say, the princes every one;\n"
  "And eke three thousand bodies were there slain\n"
  "With falling of the great temple of stone.\n"
  "Of Sampson now will I no more sayn;\n"
  "Beware by this example old and plain,\n"
  "That no man tell his counsel to his wife\n"
  "Of such thing as he would *have secret fain,*        *wish to be secret*\n"
  "If that it touch his limbes or his life.\n"
  "\n"
  "\n"
  "Of HERCULES the sov'reign conquerour\n"
  "Singe his workes' land and high renown;\n"
  "For in his time of strength he bare the flow'r.\n"
  "He slew and reft the skin of the lion\n"
  "He of the Centaurs laid the boast adown;\n"
  "He Harpies <7> slew, the cruel birdes fell;\n"
  "He golden apples reft from the dragon\n"
  "He drew out Cerberus the hound of hell.\n"
  "\n"
  "He slew the cruel tyrant Busirus. <8>\n"
  "And made his horse to fret* him flesh and bone;                  *devour\n"
  "He slew the fiery serpent venomous;\n"
  "Of Achelous' two hornes brake he one.\n"
  "And he slew Cacus in a cave of stone;\n"
  "He slew the giant Antaeus the strong;\n"
  "He slew the grisly boar, and that anon;\n"
  "And bare the heav'n upon his necke long. <9>\n"
  "\n"
  "Was never wight, since that the world began,\n"
  "That slew so many monsters as did he;\n"
  "Throughout the wide world his name ran,\n"
  "What for his strength, and for his high bounte;\n"
  "And every realme went he for to see;\n"
  "He was so strong that no man might him let;*                  *withstand\n"
  "At both the worlde's ends, as saith Trophee, <10>\n"
  "Instead of boundes he a pillar set.\n"
  "\n"
  "A leman had this noble champion,\n"
  "That highte Dejanira, fresh as May;\n"
  "And, as these clerkes make mention,\n"
  "She hath him sent a shirte fresh and gay;\n"
  "Alas! this shirt, alas and well-away!\n"
  "Envenomed was subtilly withal,\n"
  "That ere that he had worn it half a day,\n"
  "It made his flesh all from his bones fall.\n"
  "\n"
  "But natheless some clerkes her excuse\n"
  "By one, that highte Nessus, that it maked;\n"
  "Be as he may, I will not her accuse;\n"
  "But on his back this shirt he wore all naked,\n"
  "Till that his flesh was for the venom blaked.*                *blackened\n"
  "And when he saw none other remedy,\n"
  "In hote coals he hath himselfe raked,\n"
  "For with no venom deigned he to die.\n"
  "\n"
  "Thus sterf* this worthy mighty Hercules.                           *died\n"
  "Lo, who may trust on Fortune *any throw?*                 *for a moment*\n"
  "For him that followeth all this world of pres,*               *near <11>\n"
  "Ere he be ware, is often laid full low;\n"
  "Full wise is he that can himselfe know.\n"
  "Beware, for when that Fortune list to glose\n"
  "Then waiteth she her man to overthrow,\n"
  "By such a way as he would least suppose.\n"
  "\n"
  "\n"
  "The mighty throne, the precious treasor,\n"
  "The glorious sceptre, and royal majesty,\n"
  "That had the king NABUCHODONOSOR\n"
  "With tongue unnethes* may described be.                        *scarcely\n"
  "He twice won Jerusalem the city,\n"
  "The vessels of the temple he with him lad;*                   *took away\n"
  "At Babylone was his sov'reign see,*                                *seat\n"
  "In which his glory and delight he had.\n"
  "\n"
  "The fairest children of the blood royal\n"
  "Of Israel he *did do geld* anon,                *caused to be castrated*\n"
  "And maked each of them to be his thrall.*                         *slave\n"
  "Amonges others Daniel was one,\n"
  "That was the wisest child of every one;\n"
  "For he the dreames of the king expounded,\n"
  "Where in Chaldaea clerkes was there none\n"
  "That wiste to what fine* his dreames sounded.                       *end\n"
  "\n"
  "This proude king let make a statue of gold\n"
  "Sixty cubites long, and seven in bread',\n"
  "To which image hathe young and old\n"
  "Commanded he to lout,* and have in dread,                   *bow down to\n"
  "Or in a furnace, full of flames red,\n"
  "He should be burnt that woulde not obey:\n"
  "But never would assente to that deed\n"
  "Daniel, nor his younge fellows tway.\n"
  "\n"
  "This king of kinges proud was and elate;*                         *lofty\n"
  "He ween'd* that God, that sits in majesty,                      *thought\n"
  "Mighte him not bereave of his estate;\n"
  "But suddenly he lost his dignity,\n"
  "And like a beast he seemed for to be,\n"
  "And ate hay as an ox, and lay thereout\n"
  "In rain, with wilde beastes walked he,\n"
  "Till certain time was y-come about.\n"
  "\n"
  "And like an eagle's feathers wax'd his hairs,\n"
  "His nailes like a birde's clawes were,\n"
  "Till God released him at certain years,\n"
  "And gave him wit; and then with many a tear\n"
  "He thanked God, and ever his life in fear\n"
  "Was he to do amiss, or more trespace:\n"
  "And till that time he laid was on his bier,\n"
  "He knew that God was full of might and grace.\n"
  "\n"
  "\n"
  "His sone, which that highte BALTHASAR,\n"
  "That *held the regne* after his father's day,    *possessed the kingdom*\n"
  "He by his father coulde not beware,\n"
  "For proud he was of heart and of array;\n"
  "And eke an idolaster was he aye.\n"
  "His high estate assured* him in pride;                        *confirmed\n"
  "But Fortune cast him down, and there he lay,\n"
  "And suddenly his regne gan divide.\n"
  "\n"
  "A feast he made unto his lordes all\n"
  "Upon a time, and made them blithe be,\n"
  "And then his officeres gan he call;\n"
  "\"Go, bringe forth the vessels,\" saide he,\n"
  "\"Which that my father in his prosperity\n"
  "Out of the temple of Jerusalem reft,\n"
  "And to our highe goddes thanks we\n"
  "Of honour, that our elders* with us left.\"                  *forefathers\n"
  "\n"
  "His wife, his lordes, and his concubines\n"
  "Aye dranke, while their appetites did last,\n"
  "Out of these noble vessels sundry wines.\n"
  "And on a wall this king his eyen cast,\n"
  "And saw an hand, armless, that wrote full fast;\n"
  "For fear of which he quaked, and sighed sore.\n"
  "This hand, that Balthasar so sore aghast,*                     *dismayed\n"
  "Wrote Mane, tekel, phares, and no more.\n"
  "\n"
  "In all that land magician was there none\n"
  "That could expounde what this letter meant.\n"
  "But Daniel expounded it anon,\n"
  "And said, \"O King, God to thy father lent\n"
  "Glory and honour, regne, treasure, rent;*                       *revenue\n"
  "And he was proud, and nothing God he drad;*                     *dreaded\n"
  "And therefore God great wreche* upon him sent,                *vengeance\n"
  "And him bereft the regne that he had.\n"
  "\n"
  "\"He was cast out of manne's company;\n"
  "With asses was his habitation\n"
  "And ate hay, as a beast, in wet and dry,\n"
  "Till that he knew by grace and by reason\n"
  "That God of heaven hath domination\n"
  "O'er every regne, and every creature;\n"
  "And then had God of him compassion,\n"
  "And him restor'd his regne and his figure.\n"
  "\n"
  "\"Eke thou, that art his son, art proud also,\n"
  "And knowest all these thinges verily;\n"
  "And art rebel to God, and art his foe.\n"
  "Thou drankest of his vessels boldely;\n"
  "Thy wife eke, and thy wenches, sinfully\n"
  "Drank of the same vessels sundry wines,\n"
  "And heried* false goddes cursedly;                              *praised\n"
  "Therefore *to thee y-shapen full great pine is.*    *great punishment is\n"
  "                                                      prepared for thee*\n"
  "\"This hand was sent from God, that on the wall\n"
  "Wrote Mane, tekel, phares, truste me;\n"
  "Thy reign is done; thou weighest naught at all;\n"
  "Divided is thy regne, and it shall be\n"
  "To Medes and to Persians giv'n,\" quoth he.\n"
  "And thilke same night this king was slaw*                         *slain\n"
  "And Darius occupied his degree,\n"
  "Though he thereto had neither right nor law.\n"
  "\n"
  "Lordings, example hereby may ye take,\n"
  "How that in lordship is no sickerness;*                        *security\n"
  "For when that Fortune will a man forsake,\n"
  "She bears away his regne and his richess,\n"
  "And eke his friendes bothe more and less,\n"
  "For what man that hath friendes through fortune,\n"
  "Mishap will make them enemies, I guess;\n"
  "This proverb is full sooth, and full commune.\n"
  "\n"
  "\n"
  "ZENOBIA, of Palmyrie the queen, <12>\n"
  "As write Persians of her nobless,\n"
  "So worthy was in armes, and so keen,\n"
  "That no wight passed her in hardiness,\n"
  "Nor in lineage, nor other gentleness.*                  *noble qualities\n"
  "Of the king's blood of Perse* is she descended;                  *Persia\n"
  "I say not that she hadde most fairness,\n"
  "But of her shape she might not he amended.\n"
  "\n"
  "From her childhood I finde that she fled\n"
  "Office of woman, and to woods she went,\n"
  "And many a wilde harte's blood she shed\n"
  "With arrows broad that she against them sent;\n"
  "She was so swift, that she anon them hent.*                      *caught\n"
  "And when that she was older, she would kill\n"
  "Lions, leopards, and beares all to-rent,*                *torn to pieces\n"
  "And in her armes wield them at her will.\n"
  "\n"
  "She durst the wilde beastes' dennes seek,\n"
  "And runnen in the mountains all the night,\n"
  "And sleep under a bush; and she could eke\n"
  "Wrestle by very force and very might\n"
  "With any young man, were he ne'er so wight;*             *active, nimble\n"
  "There mighte nothing in her armes stond.\n"
  "She kept her maidenhood from every wight,\n"
  "To no man deigned she for to be bond.\n"
  "\n"
  "But at the last her friendes have her married\n"
  "To Odenate, <13> a prince of that country;\n"
  "All were it so, that she them longe tarried.\n"
  "And ye shall understande how that he\n"
  "Hadde such fantasies as hadde she;\n"
  "But natheless, when they were knit in fere,*                   *together\n"
  "They liv'd in joy, and in felicity,\n"
  "For each of them had other lefe* and dear.                        *loved\n"
  "\n"
  "Save one thing, that she never would assent,\n"
  "By no way, that he shoulde by her lie\n"
  "But ones, for it was her plain intent\n"
  "To have a child, the world to multiply;\n"
  "And all so soon as that she might espy\n"
  "That she was not with childe by that deed,\n"
  "Then would she suffer him do his fantasy\n"
  "Eftsoon,* and not but ones, *out of dread.*       *again *without doubt*\n"
  "\n"
  "And if she were with child at thilke* cast,                        *that\n"
  "No more should he playe thilke game\n"
  "Till fully forty dayes were past;\n"
  "Then would she once suffer him do the same.\n"
  "All* were this Odenatus wild or tame,                           *whether\n"
  "He got no more of her; for thus she said,\n"
  "It was to wives lechery and shame\n"
  "In other case* if that men with them play'd.              on other terms\n"
  "\n"
  "Two sones, by this Odenate had she,\n"
  "The which she kept in virtue and lettrure.*                    *learning\n"
  "But now unto our tale turne we;\n"
  "I say, so worshipful a creature,\n"
  "And wise therewith, and large* with measure,**   *bountiful **moderation\n"
  "So penible* in the war, and courteous eke,                    *laborious\n"
  "Nor more labour might in war endure,\n"
  "Was none, though all this worlde men should seek.\n"
  "\n"
  "Her rich array it mighte not be told,\n"
  "As well in vessel as in her clothing:\n"
  "She was all clad in pierrie* and in gold,                     *jewellery\n"
  "And eke she *lefte not,* for no hunting,               *did not neglect*\n"
  "To have of sundry tongues full knowing,\n"
  "When that she leisure had, and for t'intend*                      *apply\n"
  "To learne bookes was all her liking,\n"
  "How she in virtue might her life dispend.\n"
  "\n"
  "And, shortly of this story for to treat,\n"
  "So doughty was her husband and eke she,\n"
  "That they conquered many regnes great\n"
  "In th'Orient, with many a fair city\n"
  "Appertinent unto the majesty\n"
  "Of Rome, and with strong hande held them fast,\n"
  "Nor ever might their foemen do* them flee,                         *make\n"
  "Aye while that Odenatus' dayes last'.\n"
  "\n"
  "Her battles, whoso list them for to read,\n"
  "Against Sapor the king, <14> and other mo',\n"
  "And how that all this process fell in deed,\n"
  "Why she conquer'd, and what title thereto,\n"
  "And after of her mischief* and her woe,                      *misfortune\n"
  "How that she was besieged and y-take,\n"
  "Let him unto my master Petrarch go,\n"
  "That writes enough of this, I undertake.\n"
  "\n"
  "When Odenate was dead, she mightily\n"
  "The regne held, and with her proper hand\n"
  "Against her foes she fought so cruelly,\n"
  "That there n'as* king nor prince in all that land,              *was not\n"
  "That was not glad, if be that grace fand\n"
  "That she would not upon his land warray;*                      *make war\n"
  "With her they maden alliance by bond,\n"
  "To be in peace, and let her ride and play.\n"
  "\n"
  "The emperor of Rome, Claudius,\n"
  "Nor, him before, the Roman Gallien,\n"
  "Durste never be so courageous,\n"
  "Nor no Armenian, nor Egyptien,\n"
  "Nor Syrian, nor no Arabien,\n"
  "Within the fielde durste with her fight,\n"
  "Lest that she would them with her handes slen,*                    *slay\n"
  "Or with her meinie* putte them to flight.                        *troops\n"
  "\n"
  "In kinges' habit went her sones two,\n"
  "As heires of their father's regnes all;\n"
  "And Heremanno and Timolao\n"
  "Their names were, as Persians them call\n"
  "But aye Fortune hath in her honey gall;\n"
  "This mighty queene may no while endure;\n"
  "Fortune out of her regne made her fall\n"
  "To wretchedness and to misadventure.\n"
  "\n"
  "Aurelian, when that the governance\n"
  "Of Rome came into his handes tway, <15>\n"
  "He shope* upon this queen to do vengeance;                     *prepared\n"
  "And with his legions he took his way\n"
  "Toward Zenobie, and, shortly for to say,\n"
  "He made her flee, and at the last her hent,*                       *took\n"
  "And fetter'd her, and eke her children tway,\n"
  "And won the land, and home to Rome he went.\n"
  "\n"
  "Amonges other thinges that he wan,\n"
  "Her car, that was with gold wrought and pierrie,*                *jewels\n"
  "This greate Roman, this Aurelian\n"
  "Hath with him led, for that men should it see.\n"
  "Before in his triumphe walked she\n"
  "With gilte chains upon her neck hanging;\n"
  "Crowned she was, as after* her degree,                     *according to\n"
  "And full of pierrie her clothing.\n"
  "\n"
  "Alas, Fortune! she that whilom was\n"
  "Dreadful to kinges and to emperours,\n"
  "Now galeth* all the people on her, alas!                        *yelleth\n"
  "And she that *helmed was in starke stowres,*           *wore a helmet in\n"
  "And won by force townes strong and tow'rs,            obstinate battles*\n"
  "Shall on her head now wear a vitremite; <16>\n"
  "And she that bare the sceptre full of flow'rs\n"
  "Shall bear a distaff, *her cost for to quite.*     * to make her living*\n"
  "\n"
  "\n"
  "Although that NERO were so vicious\n"
  "As any fiend that lies full low adown,\n"
  "Yet he, as telleth us Suetonius,<17>\n"
  "This wide world had in subjectioun,\n"
  "Both East and West, South and Septentrioun.\n"
  "Of rubies, sapphires, and of pearles white\n"
  "Were all his clothes embroider'd up and down,\n"
  "For he in gemmes greatly gan delight.\n"
  "\n"
  "More delicate, more pompous of array,\n"
  "More proud, was never emperor than he;\n"
  "That *ilke cloth* that he had worn one day,                  *same robe*\n"
  "After that time he would it never see;\n"
  "Nettes of gold thread had he great plenty,\n"
  "To fish in Tiber, when him list to play;\n"
  "His lustes* were as law, in his degree,                       *pleasures\n"
  "For Fortune as his friend would him obey.\n"
  "\n"
  "";
// }

const char monksTale1[] PGMSECTION = // { // 24249 bytes
  "He Rome burnt for his delicacy;*                               *pleasure\n"
  "The senators he slew upon a day,\n"
  "To heare how that men would weep and cry;\n"
  "And slew his brother, and by his sister lay.\n"
  "His mother made he in piteous array;\n"
  "For he her wombe slitte, to behold\n"
  "Where he conceived was; so well-away!\n"
  "That he so little of his mother told.*                           *valued\n"
  "\n"
  "No tear out of his eyen for that sight\n"
  "Came; but he said, a fair woman was she.\n"
  "Great wonder is, how that he could or might\n"
  "Be doomesman* of her deade beauty:                                *judge\n"
  "The wine to bringe him commanded he,\n"
  "And drank anon; none other woe he made,\n"
  "When might is joined unto cruelty,\n"
  "Alas! too deepe will the venom wade.\n"
  "\n"
  "In youth a master had this emperour,\n"
  "To teache him lettrure* and courtesy;              *literature, learning\n"
  "For of morality he was the flow'r,\n"
  "As in his time, *but if* bookes lie.                             *unless\n"
  "And while this master had of him mast'ry,\n"
  "He made him so conning and so souple,*                           *subtle\n"
  "That longe time it was ere tyranny,\n"
  "Or any vice, durst in him uncouple.*                       *be let loose\n"
  "\n"
  "This Seneca, of which that I devise,*                              *tell\n"
  "Because Nero had of him suche dread,\n"
  "For he from vices would him aye chastise\n"
  "Discreetly, as by word, and not by deed;\n"
  "\"Sir,\" he would say, \"an emperor must need\n"
  "Be virtuous, and hate tyranny.\"\n"
  "For which he made him in a bath to bleed\n"
  "On both his armes, till he muste die.\n"
  "\n"
  "This Nero had eke of a custumance*                                *habit\n"
  "In youth against his master for to rise;*         *stand in his presence\n"
  "Which afterward he thought a great grievance;\n"
  "Therefore he made him dien in this wise.\n"
  "But natheless this Seneca the wise\n"
  "Chose in a bath to die in this mannere,\n"
  "Rather than have another tormentise;*                           *torture\n"
  "And thus hath Nero slain his master dear.\n"
  "\n"
  "Now fell it so, that Fortune list no longer\n"
  "The highe pride of Nero to cherice;*                            *cherish\n"
  "For though he were strong, yet was she stronger.\n"
  "She thoughte thus; \"By God, I am too nice*                      *foolish\n"
  "To set a man, that is full fill'd of vice,\n"
  "In high degree, and emperor him call!\n"
  "By God, out of his seat I will him trice!*                  *thrust <18>\n"
  "When he least weeneth,* soonest shall he fall.\"               *expecteth\n"
  "\n"
  "The people rose upon him on a night,\n"
  "For  his default; and when he it espied,\n"
  "Out of his doors anon he hath him dight*                *betaken himself\n"
  "Alone, and where he ween'd  t'have been allied,*          *regarded with\n"
  "He knocked fast, and aye the more he cried                    friendship\n"
  "The faster shutte they their doores all;\n"
  "Then wist he well he had himself misgied,*                       *misled\n"
  "And went his way, no longer durst he call.\n"
  "\n"
  "The people cried and rumbled up and down,\n"
  "That with his eares heard he how they said;\n"
  "\"Where is this false tyrant, this Neroun?\"\n"
  "For fear almost out of his wit he braid,*                          *went\n"
  "And to his goddes piteously he pray'd\n"
  "For succour, but it mighte not betide\n"
  "For dread of this he thoughte that died,\n"
  "And ran into a garden him to hide.\n"
  "\n"
  "And in this garden found he churles tway,\n"
  "That satte by a fire great and red;\n"
  "And to these churles two he gan to pray\n"
  "To slay him, and to girdon* off his head,                        *strike\n"
  "That to his body, when that he were dead,\n"
  "Were no despite done for his defame.*                            *infamy\n"
  "Himself he slew, *he coud no better rede;*            *he knew no better\n"
  "Of which Fortune laugh'd and hadde game.                        counsel*\n"
  "\n"
  "\n"
  "Was never capitain under a king,\n"
  "That regnes more put in subjectioun,\n"
  "Nor stronger was in field of alle thing\n"
  "As in his time, nor greater of renown,\n"
  "Nor more pompous in high presumptioun,\n"
  "Than HOLOFERNES, whom Fortune aye kiss'd\n"
  "So lik'rously, and led him up and down,\n"
  "Till that his head was off *ere that he wist.*       *before he knew it*\n"
  "\n"
  "Not only that this world had of him awe,\n"
  "For losing of richess and liberty;\n"
  "But he made every man *reny his law.*        *renounce his religion <19>\n"
  "Nabuchodonosor was God, said he;\n"
  "None other Godde should honoured be.\n"
  "Against his hest* there dare no wight trespace,                 *command\n"
  "Save in Bethulia, a strong city,\n"
  "Where Eliachim priest was of that place.\n"
  "\n"
  "But take keep* of the death of Holofern;                         *notice\n"
  "Amid his host he drunken lay at night\n"
  "Within his tente, large as is a bern;*                             *barn\n"
  "And yet, for all his pomp and all his might,\n"
  "Judith, a woman, as he lay upright\n"
  "Sleeping, his head off smote, and from his tent\n"
  "Full privily she stole from every wight,\n"
  "And with his head unto her town she went.\n"
  "\n"
  "\n"
  "What needeth it of king ANTIOCHUS <20>\n"
  "To tell his high and royal majesty,\n"
  "His great pride, and his workes venomous?\n"
  "For such another was there none as he;\n"
  "Reade what that he was in Maccabee.\n"
  "And read the proude wordes that he said,\n"
  "And why he fell from his prosperity,\n"
  "And in an hill how wretchedly he died.\n"
  "\n"
  "Fortune him had enhanced so in pride,\n"
  "That verily he ween'd he might attain\n"
  "Unto the starres upon every side,\n"
  "And in a balance weighen each mountain,\n"
  "And all the floodes of the sea restrain.\n"
  "And Godde's people had he most in hate\n"
  "Them would he slay in torment and in pain,\n"
  "Weening that God might not his pride abate.\n"
  "\n"
  "And for that Nicanor and Timothee\n"
  "With Jewes were vanquish'd mightily, <21>\n"
  "Unto the Jewes such an hate had he,\n"
  "That he bade *graith his car* full hastily,        *prepare his chariot*\n"
  "And swore and saide full dispiteously,\n"
  "Unto Jerusalem he would eftsoon,*                           *immediately\n"
  "To wreak his ire on it full cruelly\n"
  "But of his purpose was he let* full soon.                     *prevented\n"
  "\n"
  "God for his menace him so sore smote,\n"
  "With invisible wound incurable,\n"
  "That in his guttes carf* it so and bote,**                 *cut **gnawed\n"
  "Till that his paines were importable;*                      *unendurable\n"
  "And certainly the wreche* was reasonable,                     *vengeance\n"
  "For many a manne's guttes did he pain;\n"
  "But from his purpose, curs'd* and damnable,                     *impious\n"
  "For all his smart he would him not restrain;\n"
  "But bade anon apparaile* his host.                              *prepare\n"
  "\n"
  "And suddenly, ere he was of it ware,\n"
  "God daunted all his pride, and all his boast\n"
  "For he so sore fell out of his chare,*                          *chariot\n"
  "That it his limbes and his skin to-tare,\n"
  "So that he neither mighte go nor ride\n"
  "But in a chaire men about him bare,\n"
  "Alle forbruised bothe back and side.\n"
  "\n"
  "The wreche* of God him smote so cruelly,                      *vengeance\n"
  "That through his body wicked wormes crept,\n"
  "And therewithal he stank so horribly\n"
  "That none of all his meinie* that him kept,                    *servants\n"
  "Whether so that he woke or elles slept,\n"
  "Ne mighte not of him the stink endure.\n"
  "In this mischief he wailed and eke wept,\n"
  "And knew God Lord of every creature.\n"
  "\n"
  "To all his host, and to himself also,\n"
  "Full wlatsem* was the stink of his carrain;**          *loathsome **body\n"
  "No manne might him beare to and fro.\n"
  "And in this stink, and this horrible pain,\n"
  "He starf* full wretchedly in a mountain.                           *dies\n"
  "Thus hath this robber, and this homicide,\n"
  "That many a manne made to weep and plain,\n"
  "Such guerdon* as belongeth unto pride.                           *reward\n"
  "\n"
  "\n"
  "The story of ALEXANDER is so commune,\n"
  "That ev'ry wight that hath discretion\n"
  "Hath heard somewhat or all of his fortune.\n"
  "This wide world, as in conclusion,\n"
  "He won by strength; or, for his high renown,\n"
  "They were glad for peace to him to send.\n"
  "The pride and boast of man he laid adown,\n"
  "Whereso he came, unto the worlde's end.\n"
  "\n"
  "Comparison yet never might be maked\n"
  "Between him and another conqueror;\n"
  "For all this world for dread of him had quaked\n"
  "He was of knighthood and of freedom flow'r:\n"
  "Fortune him made the heir of her honour.\n"
  "Save wine and women, nothing might assuage\n"
  "His high intent in arms and labour,\n"
  "So was he full of leonine courage.\n"
  "\n"
  "What praise were it to him, though I you told\n"
  "Of Darius, and a hundred thousand mo',\n"
  "Of kinges, princes, dukes, and earles bold,\n"
  "Which he conquer'd, and brought them into woe?\n"
  "I say, as far as man may ride or go,\n"
  "The world was his, why should I more devise?*                      *tell\n"
  "For, though I wrote or told you evermo',\n"
  "Of his knighthood it mighte not suffice.\n"
  "\n"
  "Twelve years he reigned, as saith Maccabee\n"
  "Philippe's son of Macedon he was,\n"
  "That first was king in Greece the country.\n"
  "O worthy gentle* Alexander, alas                                  *noble\n"
  "That ever should thee falle such a case!\n"
  "Empoison'd of thine owen folk thou were;\n"
  "Thy six <22> fortune hath turn'd into an ace,\n"
  "And yet for thee she wepte never a tear.\n"
  "\n"
  "Who shall me give teares to complain\n"
  "The death of gentiless, and of franchise,*                   *generosity\n"
  "That all this worlde had in his demaine,*                      *dominion\n"
  "And yet he thought it mighte not suffice,\n"
  "So full was his corage* of high emprise?                         *spirit\n"
  "Alas! who shall me helpe to indite\n"
  "False Fortune, and poison to despise?\n"
  "The whiche two of all this woe I wite.*                           *blame\n"
  "\n"
  "\n"
  "By wisdom, manhood, and by great labour,\n"
  "From humbleness to royal majesty\n"
  "Up rose he, JULIUS the Conquerour,\n"
  "That won all th' Occident,* by land and sea,                       *West\n"
  "By strength of hand or elles by treaty,\n"
  "And unto Rome made them tributary;\n"
  "And since* of Rome the emperor was he,                       *afterwards\n"
  "Till that Fortune wax'd his adversary.\n"
  "\n"
  "O mighty Caesar, that in Thessaly\n"
  "Against POMPEIUS, father thine in law, <23>\n"
  "That of th' Orient had all the chivalry,\n"
  "As far as that the day begins to daw,\n"
  "That through thy knighthood hast them take and slaw,*             slain*\n"
  "Save fewe folk that with Pompeius fled;\n"
  "Through which thou put all th' Orient in awe; <24>\n"
  "Thanke Fortune that so well thee sped.\n"
  "\n"
  "But now a little while I will bewail\n"
  "This Pompeius, this noble governor\n"
  "Of Rome, which that fled at this battaile\n"
  "I say, one of his men, a false traitor,\n"
  "His head off smote, to winne him favor\n"
  "Of Julius, and him the head he brought;\n"
  "Alas! Pompey, of th' Orient conqueror,\n"
  "That Fortune unto such a fine* thee brought!                        *end\n"
  "\n"
  "To Rome again repaired Julius,\n"
  "With his triumphe laureate full high;\n"
  "But on a time Brutus and Cassius,\n"
  "That ever had of his estate envy,\n"
  "Full privily have made conspiracy\n"
  "Against this Julius in subtle wise\n"
  "And cast* the place in which he shoulde die,                   *arranged\n"
  "With bodekins,* as I shall you devise.**                 *daggers **tell\n"
  "\n"
  "This Julius to the Capitole went\n"
  "Upon a day, as he was wont to gon;\n"
  "And in the Capitol anon him hent*                                *seized\n"
  "This false Brutus, and his other fone,*                            *foes\n"
  "And sticked him with bodekins anon\n"
  "With many a wound, and thus they let him lie.\n"
  "But never groan'd he at no stroke but one,\n"
  "Or else at two, *but if* the story lie.                          *unless\n"
  "\n"
  "So manly was this Julius of heart,\n"
  "And so well loved *estately honesty                *dignified propriety*\n"
  "That, though his deadly woundes sore smart,*                 *pained him\n"
  "His mantle o'er his hippes caste he,\n"
  "That ne man shoulde see his privity\n"
  "And as he lay a-dying in a trance,\n"
  "And wiste verily that dead was he,\n"
  "Of honesty yet had he remembrance.\n"
  "\n"
  "Lucan, to thee this story I recommend,\n"
  "And to Sueton', and Valerie also,\n"
  "That of this story write *word and end*                 *the whole* <25>\n"
  "How that to these great conquerores two\n"
  "Fortune was first a friend, and since* a foe.                *afterwards\n"
  "No manne trust upon her favour long,\n"
  "But *have her in await for evermo';*      *ever be watchful against her*\n"
  "Witness on all these conquerores strong.\n"
  "\n"
  "\n"
  "The riche CROESUS, <26> whilom king of Lyde, --\n"
  "Of which Croesus Cyrus him sore drad,* --                       *dreaded\n"
  "Yet was he caught amiddes all his pride,\n"
  "And to be burnt men to the fire him lad;\n"
  "But such a rain down *from the welkin shad,*       *poured from the sky*\n"
  "That slew the fire, and made him to escape:\n"
  "But to beware no grace yet he had,\n"
  "Till fortune on the gallows made him gape.\n"
  "\n"
  "When he escaped was, he could not stint*                        *refrain\n"
  "For to begin a newe war again;\n"
  "He weened well, for that Fortune him sent\n"
  "Such hap, that he escaped through the rain,\n"
  "That of his foes he mighte not be slain.\n"
  "And eke a sweven* on a night he mette,**                *dream **dreamed\n"
  "Of which he was so proud, and eke so fain,*                        *glad\n"
  "That he in vengeance all his hearte set.\n"
  "\n"
  "Upon a tree he was set, as he thought,\n"
  "Where Jupiter him wash'd, both back and side,\n"
  "And Phoebus eke a fair towel him brought\n"
  "To dry him with; and therefore wax'd his pride.\n"
  "And to his daughter that stood him beside,\n"
  "Which he knew in high science to abound,\n"
  "He bade her tell him what it signified;\n"
  "And she his dream began right thus expound.\n"
  "\n"
  "\"The tree,\" quoth she, \"the gallows is to mean,\n"
  "And Jupiter betokens snow and rain,\n"
  "And Phoebus, with his towel clear and clean,\n"
  "These be the sunne's streames* sooth to sayn;                      *rays\n"
  "Thou shalt y-hangeth be, father, certain;\n"
  "Rain shall thee wash, and sunne shall thee dry.\"\n"
  "Thus warned him full plat and eke full plain\n"
  "His daughter, which that called was Phanie.\n"
  "\n"
  "And hanged was Croesus the proude king;\n"
  "His royal throne might him not avail.\n"
  "Tragedy is none other manner thing,\n"
  "Nor can in singing crien nor bewail,\n"
  "But for that Fortune all day will assail\n"
  "With unware stroke the regnes* that be proud:<27>              *kingdoms\n"
  "For when men truste her, then will she fail,\n"
  "And cover her bright face with a cloud.\n"
  "\n"
  "\n"
  "O noble, O worthy PEDRO, <28> glory OF SPAIN,\n"
  "Whem Fortune held so high in majesty,\n"
  "Well oughte men thy piteous death complain.\n"
  "Out of thy land thy brother made thee flee,\n"
  "And after, at a siege, by subtlety,\n"
  "Thou wert betray'd, and led unto his tent,\n"
  "Where as he with his owen hand slew thee,\n"
  "Succeeding in thy regne* and in thy rent.**           *kingdom *revenues\n"
  "\n"
  "The field of snow, with th' eagle of black therein,\n"
  "Caught with the lion, red-colour'd as the glede,*          *burning coal\n"
  "He brew'd this cursedness,* and all this sin;      *wickedness, villainy\n"
  "The wicked nest was worker of this deed;\n"
  "Not Charles' Oliver, <29> that took aye heed\n"
  "Of truth and honour, but of Armorike\n"
  "Ganilien Oliver, corrupt for meed,*                       *reward, bribe\n"
  "Broughte this worthy king in such a brike.*                *breach, ruin\n"
  "\n"
  "\n"
  "O worthy PETRO, King of CYPRE <30> also,\n"
  "That Alexandre won by high mast'ry,\n"
  "Full many a heathnen wroughtest thou full woe,\n"
  "Of which thine owen lieges had envy;\n"
  "And, for no thing but for thy chivalry,\n"
  "They in thy bed have slain thee by the morrow;\n"
  "Thus can Fortune her wheel govern and gie,*                       *guide\n"
  "And out of joy bringe men into sorrow.\n"
  "\n"
  "\n"
  "Of Milan greate BARNABO VISCOUNT,<30>\n"
  "God of delight, and scourge of Lombardy,\n"
  "Why should I not thine clomben*  wert so high?                  *climbed\n"
  "Thy brother's son, that was thy double ally,\n"
  "For he thy nephew was and son-in-law,\n"
  "Within his prison made thee to die,\n"
  "But why, nor how, *n'ot I* that thou were slaw.*    *I know not* *slain*\n"
  "\n"
  "\n"
  "Of th' Earl HUGOLIN OF PISE the languour*                         *agony\n"
  "There may no tongue telle for pity.\n"
  "But little out of Pisa stands a tow'r,\n"
  "In whiche tow'r in prison put was he,\n"
  "Aud with him be his little children three;\n"
  "The eldest scarcely five years was of age;\n"
  "Alas! Fortune, it was great cruelty\n"
  "Such birdes for to put in such a cage.\n"
  "\n"
  "Damned was he to die in that prison;\n"
  "For Roger, which that bishop was of Pise,\n"
  "Had on him made a false suggestion,\n"
  "Through which the people gan upon him rise,\n"
  "And put him in prison, in such a wise\n"
  "As ye have heard; and meat and drink he had\n"
  "So small, that well unneth* it might suffice,                  *scarcely\n"
  "And therewithal it was full poor and bad.\n"
  "\n"
  "And on a day befell, that in that hour\n"
  "When that his meate wont was to be brought,\n"
  "The jailor shut the doores of the tow'r;\n"
  "He heard it right well, but he spake nought.\n"
  "And in his heart anon there fell a thought,\n"
  "That they for hunger woulde *do him dien;*            *cause him to die*\n"
  "\"Alas!\" quoth he, \"alas that I was wrought!\"*                *made, born\n"
  "Therewith the teares fell from his eyen.\n"
  "\n"
  "His youngest son, that three years was of age,\n"
  "Unto him said, \"Father, why do ye weep?\n"
  "When will the jailor bringen our pottage?\n"
  "Is there no morsel bread that ye do keep?\n"
  "I am so hungry, that I may not sleep.\n"
  "Now woulde God that I might sleepen ever!\n"
  "Then should not hunger in my wombe* creep;                      *stomach\n"
  "There is no thing, save bread, that one were lever.\"*            *dearer\n"
  "\n"
  "Thus day by day this child begun to cry,\n"
  "Till in his father's barme* adown he lay,                           *lap\n"
  "And saide, \"Farewell, father, I must die;\"\n"
  "And kiss'd his father, and died the same day.\n"
  "And when the woeful father did it sey,*                             *see\n"
  "For woe his armes two he gan to bite,\n"
  "And said, \"Alas! Fortune, and well-away!\n"
  "To thy false wheel my woe all may I wite.\"*                       *blame\n"
  "\n"
  "His children ween'd that it for hunger was\n"
  "That he his armes gnaw'd, and not for woe,\n"
  "And saide, \"Father, do not so, alas!\n"
  "But rather eat the flesh upon us two.\n"
  "Our flesh thou gave us, our flesh take us fro',\n"
  "And eat enough;\" right thus they to him said.\n"
  "And after that, within a day or two,\n"
  "They laid them in his lap adown, and died.\n"
  "\n"
  "Himself, despaired, eke for hunger starf.*                         *died\n"
  "Thus ended is this Earl of Pise;\n"
  "From high estate Fortune away him carf.*                        *cut off\n"
  "Of this tragedy it ought enough suffice\n"
  "Whoso will hear it *in a longer wise,*               *at greater length*\n"
  "Reade the greate poet of ltale,\n"
  "That Dante hight, for he can it devise <32>\n"
  "From point to point, not one word will he fail.\n"
  "\n"
  "\n"
  "Notes to the Monk's Tale\n"
  "\n"
  "\n"
  "1. The Monk's Tale is founded in its main features on\n"
  "Bocccacio's work, \"De Casibus Virorum Illustrium;\" (\"Stories\n"
  "of Illustrious Men\") but Chaucer has taken the separate stories\n"
  "of which it is composed from different authors, and dealt with\n"
  "them after his own fashion.\n"
  "\n"
  " 2. Boccaccio opens his book with Adam, whose story is told at\n"
  "much greater length than here. Lydgate, in his translation from\n"
  "Boccaccio, speaks of Adam and Eve as made  \"of slime of the\n"
  "erth in Damascene the felde.\"\n"
  "\n"
  "3.  Judges xiii. 3. Boccaccio also tells the story of Samson; but\n"
  "Chaucer seems, by his quotation a few lines below, to have\n"
  "taken his version direct from the sacred book.\n"
  "\n"
  "4. Oliveres: olive trees; French, \"oliviers.\"\n"
  "\n"
  "5. \"Liber Judicum,\" the Book of Judges; chap. xv.\n"
  "\n"
  "6. Querne:  mill; from Anglo-Saxon, \"cyrran,\" to turn,\n"
  "\"cweorn,\" a mill,\n"
  "\n"
  "7.Harpies: the Stymphalian Birds, which fed on human flesh.\n"
  "\n"
  "8.  Busiris, king of Egypt, was wont to sacrifice all foreigners\n"
  "coming to his dominions. Hercules was seized, bound, and led\n"
  "to the altar by his orders, but the hero broke his bonds and slew\n"
  "the tyrant.\n"
  "\n"
  "9. The feats of Hercules here recorded are not all these known\n"
  "as the \"twelve labours;\" for instance, the cleansing of the\n"
  "Augean stables, and the capture of Hippolyte's girdle are not in\n"
  "this list -- other and less famous deeds of the hero taking their\n"
  "place. For this, however, we must accuse not Chaucer, but\n"
  "Boethius, whom he has almost literally translated, though with\n"
  "some change of order.\n"
  "\n"
  "10. Trophee:  One of the manuscripts has a marginal reference\n"
  "to \"Tropheus vates Chaldaeorum\" (\"Tropheus the prophet of\n"
  "the Chaldees\"); but it is not known what author Chaucer meant\n"
  "-- unless the reference is to a passage in the \"Filostrato\" of\n"
  "Boccaccio, on which Chaucer founded his \"Troilus and\n"
  "Cressida,\" and which Lydgate mentions, under the name of\n"
  "\"Trophe,\" as having been translated by Chaucer.\n"
  "\n"
  "11. Pres: near; French, \"pres;\" the meaning seems to be, this\n"
  "nearer, lower world.\n"
  "\n"
  "12 Chaucer has taken the story of Zenobia from Boccaccio's\n"
  "work \"De Claris Mulieribus.\" (\"Of Illustrious Women\")\n"
  "\n"
  "13.  Odenatus, who, for his services to the Romans, received\n"
  "from Gallienus the title of  \"Augustus;\" he was assassinated in\n"
  "A.D. 266 -- not, it was believed, without the connivance of\n"
  "Zenobia, who succeeded him on the throne.\n"
  "\n"
  "14. Sapor was king of Persia, who made the Emperor Valerian\n"
  "prisoner, conquered Syria, and was pressing triumphantly\n"
  "westward when he was met and defeated by Odenatus and\n"
  "Zenobia.\n"
  "\n"
  "15. Aurelain became Emperor in A.D. 270.\n"
  "\n"
  "16. Vitremite:  The signification of this word,  which is spelled\n"
  "in several ways, is not known. Skinner's explanation, \"another\n"
  "attire,\" founded on the spelling \"autremite,\" is obviously\n"
  "insufficient.\n"
  "\n"
  "17. Great part of this \"tragedy\" of Nero is really borrowed,\n"
  "however, from the \"Romance of the Rose.\"\n"
  "\n"
  "18. Trice:  thrust; from Anglo-Saxon, \"thriccan.\"\n"
  "\n"
  "19. So, in the Man of  Law's Tale, the Sultaness promises her\n"
  "son that she will \"reny her lay.\"\n"
  "\n"
  "20. As the \"tragedy\" of Holofernes is founded on the book of\n"
  "Judith, so is that of Antiochus on the Second Book of the\n"
  "Maccabees, chap. ix.\n"
  "\n"
  "21. By the insurgents under the leadership of Judas Maccabeus;\n"
  "2 Macc. chap. viii.\n"
  "\n"
  "22. Six:  the highest cast on a dicing-cube; here representing the\n"
  "highest favour of fortune.\n"
  "\n"
  "23. Pompey had married his daughter Julia to Caesar; but she\n"
  "died six years before Pompey's final overthrow.\n"
  "\n"
  "24. At the battle of Pharsalia, B.C. 48.\n"
  "\n"
  "25. Word and end: apparently a corruption of the Anglo-Saxon\n"
  "phrase, \"ord and end,\" meaning the whole, the beginning and\n"
  "the end.\n"
  "\n"
  "26. At the opening of the story of Croesus, Chaucer has copied\n"
  "from his own translation of Boethius; but the story is mainly\n"
  "taken from the \"Romance of the Rose\"\n"
  "\n"
  "27. \"This reflection,\" says Tyrwhttt, \"seems to have been\n"
  "suggested by one which follows soon after the mention of\n"
  "Croesus in the passage just cited from Boethius. 'What other\n"
  "thing bewail the cryings of tragedies but only the deeds of\n"
  "fortune, that with an awkward stroke, overturneth the realms of\n"
  "great nobley?'\" --  in some manuscripts the four \"tragedies\" that\n"
  "follow are placed between those of Zenobia and Nero; but\n"
  "although the general reflection with which the \"tragedy\" of\n"
  "Croesus closes might most appropriately wind up the whole\n"
  "series, the general chronological arrangement which is observed\n"
  "in the other cases recommends the order followed in the text.\n"
  "Besides, since, like several other Tales, the Monk's tragedies\n"
  "were cut short by the impatience of the auditors, it is more\n"
  "natural that the Tale should close abruptly, than by such a\n"
  "rhetorical finish as these lines afford.\n"
  "\n"
  "28. Pedro the Cruel, King of Aragon, against whom his brother\n"
  "Henry rebelled. He was by false pretences inveigled into his\n"
  "brother's tent, and treacherously slain. Mr Wright has remarked\n"
  "that \"the cause of Pedro, though he was no better than a cruel\n"
  "and reckless tyrant, was popular in England from the very\n"
  "circumstance that Prince Edward (the Black Prince) had\n"
  "embarked in it.\"\n"
  "\n"
  "29. Not the Oliver of Charlemagne -- but a traitorous Oliver of\n"
  "Armorica, corrupted by a bribe. Ganilion was the betrayer of\n"
  "the Christian army at Roncevalles (see note 9 to the Shipman's\n"
  "Tale); and his name appears to have been for a long time used in\n"
  "France to denote a traitor. Duguesclin, who betrayed Pedro into\n"
  "his brother's tent, seems to be intended by the term \"Ganilion\n"
  "Oliver,\" but if so, Chaucer has mistaken his name, which was\n"
  "Bertrand -- perhaps confounding him, as Tyrwhttt suggests,\n"
  "with Oliver du Clisson, another illustrious Breton of those\n"
  "times, who was also Constable of France, after Duguesclin. The\n"
  "arms of the latter are supposed to be described a little above\n"
  "\n"
  "30. Pierre de Lusignan, King of Cyprus, who captured\n"
  "Alexandria in 1363 (see note 6 to the Prologue to the Tales).\n"
  "He was assassinated in 1369.\n"
  "\n"
  "31. Bernabo Visconti, Duke of Milan, was deposed and\n"
  "imprisoned by his nephew, and died a captive in 1385. His death\n"
  "is the latest historical fact mentioned in the Tales; and thus it\n"
  "throws the date of their composition to about the sixtieth year\n"
  "of Chaucer's age.\n"
  "\n"
  "32. The story of Ugolino is told in the 33rd Canto of the\n"
  "\"Inferno.\"\n"
  "\n"
  "\n"
  "\n"
  "";
// }

const char nunsPriestsTale0[] PGMSECTION = // { // 22475 bytes
  "THE NUN'S PRIEST'S TALE.\n"
  "\n"
  "\n"
  "THE PROLOGUE.\n"
  "\n"
  "\n"
  "\"Ho!\" quoth the Knight, \"good sir, no more of this;\n"
  "That ye have said is right enough, y-wis,*                  *of a surety\n"
  "And muche more; for little heaviness\n"
  "Is right enough to muche folk, I guess.\n"
  "I say for me, it is a great disease,*     *source of distress, annoyance\n"
  "Where as men have been in great wealth and ease,\n"
  "To hearen of their sudden fall, alas!\n"
  "And the contrary is joy and great solas,*              *delight, comfort\n"
  "As when a man hath been in poor estate,\n"
  "And climbeth up, and waxeth fortunate,\n"
  "And there abideth in prosperity;\n"
  "Such thing is gladsome, as it thinketh me,\n"
  "And of such thing were goodly for to tell.\"\n"
  "\n"
  "\"Yea,\" quoth our Hoste, \"by Saint Paule's bell.\n"
  "Ye say right sooth; this monk hath clapped* loud;                *talked\n"
  "He spake how Fortune cover'd with a cloud\n"
  "I wot not what, and als' of a tragedy\n"
  "Right now ye heard: and pardie no remedy\n"
  "It is for to bewaile, nor complain\n"
  "That that is done, and also it is pain,\n"
  "As ye have said, to hear of heaviness.\n"
  "Sir Monk, no more of this, so God you bless;\n"
  "Your tale annoyeth all this company;\n"
  "Such talking is not worth a butterfly,\n"
  "For therein is there no sport nor game;\n"
  "Therefore, Sir Monke, Dan Piers by your name,\n"
  "I pray you heart'ly, tell us somewhat else,\n"
  "For sickerly, n'ere* clinking of your bells,        *were it not for the\n"
  "That on your bridle hang on every side,\n"
  "By heaven's king, that for us alle died,\n"
  "I should ere this have fallen down for sleep,\n"
  "Although the slough had been never so deep;\n"
  "Then had your tale been all told in vain.\n"
  "For certainly, as these clerkes sayn,\n"
  "Where as a man may have no audience,\n"
  "Nought helpeth it to telle his sentence.\n"
  "And well I wot the substance is in me,\n"
  "If anything shall well reported be.\n"
  "Sir, say somewhat of hunting, <1> I you pray.\"\n"
  "\n"
  "\"Nay,\" quoth the Monk, \"I have *no lust to play;*       *no fondness for\n"
  "Now let another tell, as I have told.\"                          jesting*\n"
  "Then spake our Host with rude speech and bold,\n"
  "And said unto the Nunne's Priest anon,\n"
  "\"Come near, thou Priest, come hither, thou Sir John, <2>\n"
  "Tell us such thing as may our heartes glade.*                   *gladden\n"
  "Be blithe, although thou ride upon a jade.\n"
  "What though thine horse be bothe foul and lean?\n"
  "If he will serve thee, reck thou not a bean;\n"
  "Look that thine heart be merry evermo'.\"\n"
  "\n"
  "\"Yes, Host,\" quoth he, \"so may I ride or go,\n"
  "But* I be merry, y-wis I will be blamed.\"                        *unless\n"
  "And right anon his tale he hath attamed*                  *commenced <3>\n"
  "And thus he said unto us every one,\n"
  "This sweete priest, this goodly man, Sir John.\n"
  "\n"
  "\n"
  "Notes to the Prologue to the Nun's Priest's Tale\n"
  "\n"
  "\n"
  "1. The request is justified by the description of Monk in the\n"
  "Prologue as \"an out-rider, that loved venery.\"\n"
  "\n"
  "2. On this Tyrwhitt remarks; \"I know not how it has happened,\n"
  "that in the principal modern languages, John, or its equivalent,\n"
  "is a name of contempt or at least of slight.  So the Italians use\n"
  "'Gianni,' from whence 'Zani;' the Spaniards 'Juan,' as 'Bobo\n"
  "Juan,' a foolish John; the French 'Jean,' with various additions;\n"
  "and in English, when we call a man 'a John,' we do not mean it\n"
  "as a title of honour.\"  The title of \"Sir\" was usually given by\n"
  "courtesy to priests.\n"
  "\n"
  "3. Attamed: commenced, broached. Compare French, \"entamer\",\n"
  "to cut the first piece off a joint; thence to begin.\n"
  "\n"
  "\n"
  "THE TALE. <1>\n"
  "\n"
  "\n"
  "A poor widow, *somedeal y-stept* in age,             *somewhat advanced*\n"
  "Was whilom dwelling in a poor cottage,\n"
  "Beside a grove, standing in a dale.\n"
  "This widow, of which I telle you my tale,\n"
  "Since thilke day that she was last a wife,\n"
  "In patience led a full simple life,\n"
  "For little was *her chattel and her rent.*    *her goods and her income*\n"
  "By husbandry* of such as God her sent,               *thrifty management\n"
  "She found* herself, and eke her daughters two.               *maintained\n"
  "Three large sowes had she, and no mo';\n"
  "Three kine, and eke a sheep that highte Mall.\n"
  "Full sooty was her bow'r,* and eke her hall,                    *chamber\n"
  "In which she ate full many a slender meal.\n"
  "Of poignant sauce knew she never a deal.*                          *whit\n"
  "No dainty morsel passed through her throat;\n"
  "Her diet was *accordant to her cote.*      *in keeping with her cottage*\n"
  "Repletion her made never sick;\n"
  "Attemper* diet was all her physic,                             *moderate\n"
  "And exercise, and *hearte's suffisance.*          *contentment of heart*\n"
  "The goute *let her nothing for to dance,*           *did not prevent her\n"
  "Nor apoplexy shente* not her head.                 from dancing*   *hurt\n"
  "No wine drank she, neither white nor red:\n"
  "Her board was served most with white and black,\n"
  "Milk and brown bread, in which she found no lack,\n"
  "Seind* bacon, and sometimes an egg or tway;                      *singed\n"
  "For she was as it were *a manner dey.*        *kind of day labourer* <2>\n"
  "A yard she had, enclosed all about\n"
  "With stickes, and a drye ditch without,\n"
  "In which she had a cock, hight Chanticleer;\n"
  "In all the land of crowing *n'as his peer.*          *was not his equal*\n"
  "His voice was merrier than the merry orgon,*                  *organ <3>\n"
  "On masse days that in the churches gon.\n"
  "Well sickerer* was his crowing in his lodge,             *more punctual*\n"
  "Than is a clock, or an abbay horloge.*                        *clock <4>\n"
  "By nature he knew each ascension\n"
  "Of th' equinoctial in thilke town;\n"
  "For when degrees fiftene were ascended,\n"
  "Then crew he, that it might not be amended.\n"
  "His comb was redder than the fine coral,\n"
  "Embattell'd <5> as it were a castle wall.\n"
  "His bill was black, and as the jet it shone;\n"
  "Like azure were his legges and his tone;*                          *toes\n"
  "His nailes whiter than the lily flow'r,\n"
  "And like the burnish'd gold was his colour,\n"
  "This gentle cock had in his governance\n"
  "Sev'n hennes, for to do all his pleasance,\n"
  "Which were his sisters and his paramours,\n"
  "And wondrous like to him as of colours.\n"
  "Of which the fairest-hued in the throat\n"
  "Was called Damoselle Partelote,\n"
  "Courteous she was, discreet, and debonair,\n"
  "And companiable,* and bare herself so fair,                    *sociable\n"
  "Since the day that she sev'n night was old,\n"
  "That truely she had the heart in hold\n"
  "Of Chanticleer, locked in every lith;*                             *limb\n"
  "He lov'd her so, that well was him therewith,\n"
  "But such a joy it was to hear them sing,\n"
  "When that the brighte sunne gan to spring,\n"
  "In sweet accord, *\"My lefe is fare in land.\"* <6>            *my love is\n"
  "For, at that time, as I have understand,                    gone abroad*\n"
  "Beastes and birdes coulde speak and sing.\n"
  "\n"
  "And so befell, that in a dawening,\n"
  "As Chanticleer among his wives all\n"
  "Sat on his perche, that was in the hall,\n"
  "And next him sat this faire Partelote,\n"
  "This Chanticleer gan groanen in his throat,\n"
  "As man that in his dream is dretched* sore,                   *oppressed\n"
  "And when that Partelote thus heard him roar,\n"
  "She was aghast,* and saide, \"Hearte dear,                        *afraid\n"
  "What aileth you to groan in this mannere?\n"
  "Ye be a very sleeper, fy for shame!\"\n"
  "And he answer'd and saide thus; \"Madame,\n"
  "I pray you that ye take it not agrief;*               *amiss, in umbrage\n"
  "By God, *me mette* I was in such mischief,**       *I dreamed* **trouble\n"
  "Right now, that yet mine heart is sore affright'.\n"
  "Now God,\" quoth he, \"my sweven* read aright              *dream, vision.\n"
  "And keep my body out of foul prisoun.\n"
  "*Me mette,* how that I roamed up and down                    *I dreamed*\n"
  "Within our yard, where as I saw a beast\n"
  "Was like an hound, and would have *made arrest*                 *siezed*\n"
  "Upon my body, and would have had me dead.\n"
  "His colour was betwixt yellow and red;\n"
  "And tipped was his tail, and both his ears,\n"
  "With black, unlike the remnant of his hairs.\n"
  "His snout was small, with glowing eyen tway;\n"
  "Yet of his look almost for fear I dey;*                            *died\n"
  "This caused me my groaning, doubteless.\"\n"
  "\n"
  "\"Away,\" <7> quoth she, \"fy on you, hearteless!*                  *coward\n"
  "Alas!\" quoth she, \"for, by that God above!\n"
  "Now have ye lost my heart and all my love;\n"
  "I cannot love a coward, by my faith.\n"
  "For certes, what so any woman saith,\n"
  "We all desiren, if it mighte be,\n"
  "To have husbandes hardy, wise, and free,\n"
  "And secret,* and no niggard nor no fool,                       *discreet\n"
  "Nor him that is aghast* of every tool,**           *afraid **rag, trifle\n"
  "Nor no avantour,* by that God above!                           *braggart\n"
  "How durste ye for shame say to your love\n"
  "That anything might make you afear'd?\n"
  "Have ye no manne's heart, and have a beard?\n"
  "Alas! and can ye be aghast of swevenes?*                         *dreams\n"
  "Nothing but vanity, God wot, in sweven is,\n"
  "Swevens *engender of repletions,*            *are caused by over-eating*\n"
  "And oft of fume,* and of complexions,                       *drunkenness\n"
  "When humours be too abundant in a wight.\n"
  "Certes this dream, which ye have mette tonight,\n"
  "Cometh of the great supefluity\n"
  "Of youre rede cholera,* pardie,                                    *bile\n"
  "Which causeth folk to dreaden in their dreams\n"
  "Of arrows, and of fire with redde beams,\n"
  "Of redde beastes, that they will them bite,\n"
  "Of conteke,* and of whelpes great and lite;**       *contention **little\n"
  "Right as the humour of melancholy\n"
  "Causeth full many a man in sleep to cry,\n"
  "For fear of bulles, or of beares blake,\n"
  "Or elles that black devils will them take,\n"
  "Of other humours could I tell also,\n"
  "That worke many a man in sleep much woe;\n"
  "That I will pass as lightly as I can.\n"
  "Lo, Cato, which that was so wise a man,\n"
  "Said he not thus, *'Ne do no force of* dreams,'<8>	*attach no weight to*\n"
  "Now, Sir,\" quoth she, \"when we fly from these beams,\n"
  "For Godde's love, as take some laxatife;\n"
  "On peril of my soul, and of my life,\n"
  "I counsel you the best, I will not lie,\n"
  "That both of choler, and melancholy,\n"
  "Ye purge you; and, for ye shall not tarry,\n"
  "Though in this town is no apothecary,\n"
  "I shall myself two herbes teache you,\n"
  "That shall be for your health, and for your prow;*               *profit\n"
  "And in our yard the herbes shall I find,\n"
  "The which have of their property by kind*                        *nature\n"
  "To purge you beneath, and eke above.\n"
  "Sire, forget not this for Godde's love;\n"
  "Ye be full choleric of complexion;\n"
  "Ware that the sun, in his ascension,\n"
  "You finde not replete of humours hot;\n"
  "And if it do, I dare well lay a groat,\n"
  "That ye shall have a fever tertiane,\n"
  "Or else an ague, that may be your bane,\n"
  "A day or two ye shall have digestives\n"
  "Of wormes, ere ye take your laxatives,\n"
  "Of laurel, centaury, <9> and fumeterere, <10>\n"
  "Or else of elder-berry, that groweth there,\n"
  "Of catapuce, <11> or of the gaitre-berries, <12>\n"
  "Or herb ivy growing in our yard, that merry is:\n"
  "Pick them right as they grow, and eat them in,\n"
  "Be merry, husband, for your father's kin;\n"
  "Dreade no dream; I can say you no more.\"\n"
  "\n"
  "\"Madame,\" quoth he, \"grand mercy of your lore,\n"
  "But natheless, as touching *Dan Catoun,*                           *Cato\n"
  "That hath of wisdom such a great renown,\n"
  "Though that he bade no dreames for to dread,\n"
  "By God, men may in olde bookes read\n"
  "Of many a man more of authority\n"
  "Than ever Cato was, so may I the,*                               *thrive\n"
  "That all the reverse say of his sentence,*                      *opinion\n"
  "And have well founden by experience\n"
  "That dreames be significations\n"
  "As well of joy, as tribulations\n"
  "That folk enduren in this life present.\n"
  "There needeth make of this no argument;\n"
  "The very preve* sheweth it indeed.                    *trial, experience\n"
  "One of the greatest authors that men read <13>\n"
  "Saith thus, that whilom two fellowes went\n"
  "On pilgrimage in a full good intent;\n"
  "And happen'd so, they came into a town\n"
  "Where there was such a congregatioun\n"
  "Of people, and eke so *strait of herbergage,*          *without lodging*\n"
  "That they found not as much as one cottage\n"
  "In which they bothe might y-lodged be:\n"
  "Wherefore they musten of necessity,\n"
  "As for that night, departe company;\n"
  "And each of them went to his hostelry,*                             *inn\n"
  "And took his lodging as it woulde fall.\n"
  "The one of them was lodged in a stall,\n"
  "Far in a yard, with oxen of the plough;\n"
  "That other man was lodged well enow,\n"
  "As was his aventure, or his fortune,\n"
  "That us governeth all, as in commune.\n"
  "And so befell, that, long ere it were day,\n"
  "This man mette* in his bed, there: as he lay,                   *dreamed\n"
  "How that his fellow gan upon him call,\n"
  "And said, 'Alas! for in an ox's stall\n"
  "This night shall I be murder'd, where I lie\n"
  "Now help me, deare brother, or I die;\n"
  "In alle haste come to me,' he said.\n"
  "This man out of his sleep for fear abraid;*                     *started\n"
  "But when that he was wak'd out of his sleep,\n"
  "He turned him, and *took of this no keep;*      *paid this no attention*\n"
  "He thought his dream was but a vanity.\n"
  "Thus twies* in his sleeping dreamed he,                           *twice\n"
  "And at the thirde time yet his fellaw again\n"
  "Came, as he thought, and said, 'I am now slaw;*                   *slain\n"
  "Behold my bloody woundes, deep and wide.\n"
  "Arise up early, in the morning, tide,\n"
  "And at the west gate of the town,' quoth he,\n"
  "'A carte full of dung there shalt: thou see,\n"
  "In which my body is hid privily.\n"
  "Do thilke cart arroste* boldely.                                   *stop\n"
  "My gold caused my murder, sooth to sayn.'\n"
  "And told him every point how he was slain,\n"
  "With a full piteous face, and pale of hue.\n"
  "\n"
  "\"And, truste well, his dream he found full true;\n"
  "For on the morrow, as soon as it was day,\n"
  "To his fellowes inn he took his way;\n"
  "And when that he came to this ox's stall,\n"
  "After his fellow he began to call.\n"
  "The hostelere answered him anon,\n"
  "And saide, 'Sir, your fellow is y-gone,\n"
  "As soon as day he went out of the town.'\n"
  "This man gan fallen in suspicioun,\n"
  "Rememb'ring on his dreames that he mette,*                      *dreamed\n"
  "And forth he went, no longer would he let,*                       *delay\n"
  "Unto the west gate of the town, and fand*                         *found\n"
  "A dung cart, as it went for to dung land,\n"
  "That was arrayed in the same wise\n"
  "As ye have heard the deade man devise;*                        *describe\n"
  "And with an hardy heart he gan to cry,\n"
  "'Vengeance and justice of this felony:\n"
  "My fellow murder'd in this same night\n"
  "And in this cart he lies, gaping upright.\n"
  "I cry out on the ministers,' quoth he.\n"
  "'That shoulde keep and rule this city;\n"
  "Harow! alas! here lies my fellow slain.'\n"
  "What should I more unto this tale sayn?\n"
  "The people out start, and cast the cart to ground\n"
  "And in the middle of the dung they found\n"
  "The deade man, that murder'd was all new.\n"
  "O blissful God! that art so good and true,\n"
  "Lo, how that thou bewray'st murder alway.\n"
  "Murder will out, that see we day by day.\n"
  "Murder is so wlatsom* and abominable                          *loathsome\n"
  "To God, that is so just and reasonable,\n"
  "That he will not suffer it heled* be;                    *concealed <14>\n"
  "Though it abide a year, or two, or three,\n"
  "Murder will out, this is my conclusioun,\n"
  "And right anon, the ministers of the town\n"
  "Have hent* the carter, and so sore him pined,**       *seized **tortured\n"
  "And eke the hostelere so sore engined,*                          *racked\n"
  "That they beknew* their wickedness anon,                      *confessed\n"
  "And were hanged by the necke bone.\n"
  "\n"
  "\"Here may ye see that dreames be to dread.\n"
  "And certes in the same book I read,\n"
  "Right in the nexte chapter after this\n"
  "(I gabbe* not, so have I joy and bliss),                      *talk idly\n"
  "Two men that would, have passed over sea,\n"
  "For certain cause, into a far country,\n"
  "If that the wind not hadde been contrary,\n"
  "That made them in a city for to tarry,\n"
  "That stood full merry upon an haven side;\n"
  "But on a day, against the even-tide,\n"
  "The wind gan change, and blew right *as them lest.*     *as they wished*\n"
  "Jolly and glad they wente to their rest,\n"
  "And caste* them full early for to sail.                        *resolved\n"
  "But to the one man fell a great marvail\n"
  "That one of them, in sleeping as he lay,\n"
  "He mette* a wondrous dream, against the day:                    *dreamed\n"
  "He thought a man stood by his bedde's side,\n"
  "And him commanded that he should abide;\n"
  "And said him thus; 'If thou to-morrow wend,\n"
  "Thou shalt be drown'd; my tale is at an end.'\n"
  "He woke, and told his follow what he mette,\n"
  "And prayed him his voyage for to let;*                            *delay\n"
  "As for that day, he pray'd him to abide.\n"
  "His fellow, that lay by his bedde's side,\n"
  "Gan for to laugh, and scorned him full fast.\n"
  "'No dream,' quoth he,'may so my heart aghast,*                 *frighten\n"
  "That I will lette* for to do my things.*                          *delay\n"
  "I sette not a straw by thy dreamings,\n"
  "For swevens* be but vanities and japes.**        *dreams **jokes,deceits\n"
  "Men dream all day of owles and of apes,\n"
  "And eke of many a maze* therewithal;                     *wild imagining\n"
  "Men dream of thing that never was, nor shall.\n"
  "But since I see, that thou wilt here abide,\n"
  "And thus forslothe* wilfully thy tide,**               *idle away **time\n"
  "God wot, *it rueth me;* and have good day.'          *I am sorry for it*\n"
  "And thus he took his leave, and went his way.\n"
  "But, ere that he had half his course sail'd,\n"
  "I know not why, nor what mischance it ail'd,\n"
  "But casually* the ship's bottom rent,                       *by accident\n"
  "And ship and man under the water went,\n"
  "In sight of other shippes there beside\n"
  "That with him sailed at the same tide.\n"
  "\n"
  "\"And therefore, faire Partelote so dear,\n"
  "By such examples olde may'st thou lear,*                          *learn\n"
  "That no man shoulde be too reckeless\n"
  "Of dreames, for I say thee doubteless,\n"
  "That many a dream full sore is for to dread.\n"
  "Lo, in the life of Saint Kenelm <15> I read,\n"
  "That was Kenulphus' son, the noble king\n"
  "Of Mercenrike, <16> how Kenelm mette a thing.\n"
  "A little ere he was murder'd on a day,\n"
  "His murder in his vision he say.*                                   *saw\n"
  "His norice* him expounded every deal**                     *nurse **part\n"
  "His sweven, and bade him to keep* him well                        *guard\n"
  "For treason; but he was but seven years old,\n"
  "And therefore *little tale hath he told*             *he attached little\n"
  "Of any dream, so holy was his heart.                    significance to*\n"
  "By God, I hadde lever than my shirt\n"
  "That ye had read his legend, as have I.\n"
  "Dame Partelote, I say you truely,\n"
  "Macrobius, that wrote the vision\n"
  "In Afric' of the worthy Scipion, <17>\n"
  "Affirmeth dreames, and saith that they be\n"
  "'Warnings of thinges that men after see.\n"
  "And furthermore, I pray you looke well\n"
  "In the Old Testament, of Daniel,\n"
  "If he held dreames any vanity.\n"
  "Read eke of Joseph, and there shall ye see\n"
  "Whether dreams be sometimes (I say not all)\n"
  "Warnings of thinges that shall after fall.\n"
  "Look of Egypt the king, Dan Pharaoh,\n"
  "His baker and his buteler also,\n"
  "Whether they felte none effect* in dreams.                 *significance\n"
  "Whoso will seek the acts of sundry remes*                        *realms\n"
  "May read of dreames many a wondrous thing.\n"
  "Lo Croesus, which that was of Lydia king,\n"
  "Mette he not that he sat upon a tree,\n"
  "Which signified he shoulde hanged be? <18>\n"
  "Lo here, Andromache, Hectore's wife, <19>\n"
  "That day that Hector shoulde lose his life,\n"
  "She dreamed on the same night beforn,\n"
  "How that the life of Hector should be lorn,*                       *lost\n"
  "If thilke day he went into battaile;\n"
  "She warned him, but it might not avail;\n"
  "He wente forth to fighte natheless,\n"
  "And was y-slain anon of Achilles.\n"
  "But thilke tale is all too long to tell;\n"
  "And eke it is nigh day, I may not dwell.\n"
  "Shortly I say, as for conclusion,\n"
  "That I shall have of this avision\n"
  "Adversity; and I say furthermore,\n"
  "That I ne *tell of laxatives no store,*                  *hold laxatives\n"
  "For they be venomous, I wot it well;                        of no value*\n"
  "I them defy,* I love them never a del.**                *distrust **whit\n"
  "\n"
  "\"But let us speak of mirth, and stint* all this;                  *cease\n"
  "Madame Partelote, so have I bliss,\n"
  "Of one thing God hath sent me large* grace;                      liberal\n"
  "For when I see the beauty of your face,\n"
  "Ye be so scarlet-hued about your eyen,\n"
  "I maketh all my dreade for to dien,\n"
  "For, all so sicker* as In principio,<20>                        *certain\n"
  "Mulier est hominis confusio.<21>\n"
  "Madam, the sentence* of of this Latin is,                       *meaning\n"
  "Woman is manne's joy and manne's bliss.\n"
  "For when I feel at night your softe side, --\n"
  "Albeit that I may not on you ride,\n"
  "For that our perch is made so narrow, Alas!\n"
  "I am so full of joy and of solas,*                              *delight\n"
  "That I defy both sweven and eke dream.\"\n"
  "And with that word he flew down from the beam,\n"
  "For it was day, and eke his hennes all;\n"
  "And with a chuck he gan them for to call,\n"
  "For he had found a corn, lay in the yard.\n"
  "Royal he was, he was no more afear'd;\n"
  "He feather'd Partelote twenty time,\n"
  "And as oft trode her, ere that it was prime.\n"
  "He looked as it were a grim lion,\n"
  "And on his toes he roamed up and down;\n"
  "He deigned not to set his feet to ground;\n"
  "He chucked, when he had a corn y-found,\n"
  "And to him ranne then his wives all.\n"
  "Thus royal, as a prince is in his hall,\n"
  "Leave I this Chanticleer in his pasture;\n"
  "And after will I tell his aventure.\n"
  "\n"
  "When that the month in which the world began,\n"
  "That highte March, when God first maked man,\n"
  "Was complete, and y-passed were also,\n"
  "Since March ended, thirty days and two,\n"
  "Befell that Chanticleer in all his pride,\n"
  "His seven wives walking him beside,\n"
  "Cast up his eyen to the brighte sun,\n"
  "That in the sign of Taurus had y-run\n"
  "Twenty degrees and one, and somewhat more;\n"
  "He knew by kind,* and by none other lore,**           *nature **learning\n"
  "That it was prime, and crew with blissful steven.*                *voice\n"
  "\"The sun,\" he said, \"is clomben up in heaven\n"
  "Twenty degrees and one, and more y-wis.*                      *assuredly\n"
  "Madame Partelote, my worlde's bliss,\n"
  "Hearken these blissful birdes how they sing,\n"
  "And see the freshe flowers how they spring;\n"
  "Full is mine heart of revel and solace.\"\n"
  "But suddenly him fell a sorrowful case;*                       *casualty\n"
  "For ever the latter end of joy is woe:\n"
  "God wot that worldly joy is soon y-go:\n"
  "And, if a rhetor* coulde fair indite,                            *orator\n"
  "He in a chronicle might it safely write,\n"
  "As for *a sov'reign notability*              *a thing supremely notable*\n"
  "Now every wise man, let him hearken me;\n"
  "This story is all as true, I undertake,\n"
  "As is the book of Launcelot du Lake,\n"
  "That women hold in full great reverence.\n"
  "Now will I turn again to my sentence.\n"
  "\n"
  "";
// }

const char nunsPriestsTale1[] PGMSECTION = // { // 21867 bytes
  "A col-fox, <22> full of sly iniquity,\n"
  "That in the grove had wonned* yeares three,                       *dwelt\n"
  "By high imagination forecast,\n"
  "The same night thorough the hedges brast*                         *burst\n"
  "Into the yard, where Chanticleer the fair\n"
  "Was wont, and eke his wives, to repair;\n"
  "And in a bed of wortes* still he lay,                          *cabbages\n"
  "Till it was passed undern <23> of the day,\n"
  "Waiting his time on Chanticleer to fall:\n"
  "As gladly do these homicides all,\n"
  "That in awaite lie to murder men.\n"
  "O false murd'rer! Rouking* in thy den!               *crouching, lurking\n"
  "O new Iscariot, new Ganilion! <24>\n"
  "O false dissimuler, O Greek Sinon,<25>\n"
  "That broughtest Troy all utterly to sorrow!\n"
  "O Chanticleer! accursed be the morrow\n"
  "That thou into thy yard flew from the beams;*                   *rafters\n"
  "Thou wert full well y-warned by thy dreams\n"
  "That thilke day was perilous to thee.\n"
  "But what that God forewot* must needes be,                    *foreknows\n"
  "After th' opinion of certain clerkes.\n"
  "Witness on him that any perfect clerk is,\n"
  "That in school is great altercation\n"
  "In this matter, and great disputation,\n"
  "And hath been of an hundred thousand men.\n"
  "But I ne cannot *boult it to the bren,*     *examine it thoroughly <26>*\n"
  "As can the holy doctor Augustine,\n"
  "Or Boece, or the bishop Bradwardine,<27>\n"
  "Whether that Godde's worthy foreweeting*                  *foreknowledge\n"
  "*Straineth me needly* for to do a thing                      *forces me*\n"
  "(Needly call I simple necessity),\n"
  "Or elles if free choice be granted me\n"
  "To do that same thing, or do it not,\n"
  "Though God forewot* it ere that it was wrought;         *knew in advance\n"
  "Or if *his weeting straineth never a deal,*      *his knowing constrains\n"
  "But by necessity conditionel.                                not at all*\n"
  "I will not have to do of such mattere;\n"
  "My tale is of a cock, as ye may hear,\n"
  "That took his counsel of his wife, with sorrow,\n"
  "To walken in the yard upon the morrow\n"
  "That he had mette the dream, as I you told.\n"
  "Womane's counsels be full often cold;*              *mischievous, unwise\n"
  "Womane's counsel brought us first to woe,\n"
  "And made Adam from Paradise to go,\n"
  "There as he was full merry and well at case.\n"
  "But, for I n'ot* to whom I might displease                     *know not\n"
  "If I counsel of women woulde blame,\n"
  "Pass over, for I said it in my game.*                              *jest\n"
  "Read authors, where they treat of such mattere\n"
  "And what they say of women ye may hear.\n"
  "These be the cocke's wordes, and not mine;\n"
  "I can no harm of no woman divine.*                  *conjecture, imagine\n"
  "Fair in the sand, to bathe* her merrily,                           *bask\n"
  "Lies Partelote, and all her sisters by,\n"
  "Against the sun, and Chanticleer so free\n"
  "Sang merrier than the mermaid in the sea;\n"
  "For Physiologus saith sickerly,*                              *certainly\n"
  "How that they singe well and merrily. <28>\n"
  "And so befell that, as he cast his eye\n"
  "Among the wortes,* on a butterfly,                             *cabbages\n"
  "He was ware of this fox that lay full low.\n"
  "Nothing *ne list him thenne* for to crow,        *he had no inclination*\n"
  "But cried anon \"Cock! cock!\" and up he start,\n"
  "As man that was affrayed in his heart.\n"
  "For naturally a beast desireth flee\n"
  "From his contrary,* if be may it see,                             *enemy\n"
  "Though he *ne'er erst* had soon it with his eye           *never before*\n"
  "This Chanticleer, when he gan him espy,\n"
  "He would have fled, but that the fox anon\n"
  "Said, \"Gentle Sir, alas! why will ye gon?\n"
  "Be ye afraid of me that am your friend?\n"
  "Now, certes, I were worse than any fiend,\n"
  "If I to you would harm or villainy.\n"
  "I am not come your counsel to espy.\n"
  "But truely the cause of my coming\n"
  "Was only for to hearken how ye sing;\n"
  "For truely ye have as merry a steven,*                            *voice\n"
  "As any angel hath that is in heaven;\n"
  "Therewith ye have of music more feeling,\n"
  "Than had Boece, or any that can sing.\n"
  "My lord your father (God his soule bless)\n"
  "And eke your mother of her gentleness,\n"
  "Have in mnine house been, to my great ease:*               *satisfaction\n"
  "And certes, Sir, full fain would I you please.\n"
  "But, for men speak of singing, I will say,\n"
  "So may I brooke* well mine eyen tway,            *enjoy, possess, or use\n"
  "Save you, I hearde never man so sing\n"
  "As did your father in the morrowning.\n"
  "Certes it was of heart all that he sung.\n"
  "And, for to make his voice the more strong,\n"
  "He would *so pain him,* that with both his eyen  *make such an exertion*\n"
  "He muste wink, so loud he woulde cryen,\n"
  "And standen on his tiptoes therewithal,\n"
  "And stretche forth his necke long and small.\n"
  "And eke he was of such discretion,\n"
  "That there was no man, in no region,\n"
  "That him in song or wisdom mighte pass.\n"
  "I have well read in Dan Burnel the Ass, <29>\n"
  "Among his verse, how that there was a cock\n"
  "That, for* a prieste's son gave him a knock                     *because\n"
  "Upon his leg, while he was young and nice,*                     *foolish\n"
  "He made him for to lose his benefice.\n"
  "But certain there is no comparison\n"
  "Betwixt the wisdom and discretion\n"
  "Of youre father, and his subtilty.\n"
  "Now singe, Sir, for sainte charity,\n"
  "Let see, can ye your father counterfeit?\"\n"
  "\n"
  "This Chanticleer his wings began to beat,\n"
  "As man that could not his treason espy,\n"
  "So was he ravish'd with his flattery.\n"
  "Alas! ye lordes, many a false flattour*                  *flatterer <30>\n"
  "Is in your court, and many a losengeour, *                *deceiver <31>\n"
  "That please you well more, by my faith,\n"
  "Than he that soothfastness* unto you saith.                       *truth\n"
  "Read in Ecclesiast' of flattery;\n"
  "Beware, ye lordes, of their treachery.\n"
  "This Chanticleer stood high upon his toes,\n"
  "Stretching his neck, and held his eyen close,\n"
  "And gan to crowe loude for the nonce\n"
  "And Dan Russel <32> the fox start up at once,\n"
  "And *by the gorge hente* Chanticleer,             *seized by the throat*\n"
  "And on his back toward the wood him bare.\n"
  "For yet was there no man that him pursu'd.\n"
  "O  destiny, that may'st not be eschew'd!*                       *escaped\n"
  "Alas, that Chanticleer flew from the beams!\n"
  "Alas, his wife raughte* nought of dreams!                      *regarded\n"
  "And on a Friday fell all this mischance.\n"
  "O Venus, that art goddess of pleasance,\n"
  "Since that thy servant was this Chanticleer\n"
  "And in thy service did all his powere,\n"
  "More for delight, than the world to multiply,\n"
  "Why wilt thou suffer him on thy day to die?\n"
  "O Gaufrid, deare master sovereign, <33>\n"
  "That, when thy worthy king Richard was slain\n"
  "With shot, complainedest his death so sore,\n"
  "Why n'had I now thy sentence and thy lore,\n"
  "The Friday for to chiden, as did ye?\n"
  "(For on a Friday, soothly, slain was he),\n"
  "Then would I shew you how that I could plain*                    *lament\n"
  "For Chanticleere's dread, and for his pain.\n"
  "\n"
  "Certes such cry nor lamentation\n"
  "Was ne'er of ladies made, when Ilion\n"
  "Was won, and Pyrrhus with his straighte sword,\n"
  "When he had hent* king Priam by the beard,                       *seized\n"
  "And slain him (as saith us Eneidos*),<34>                    *The Aeneid\n"
  "As maden all the hennes in the close,*                             *yard\n"
  "When they had seen of Chanticleer the sight.\n"
  "But sov'reignly* Dame Partelote shright,**             *above all others\n"
  "Full louder than did Hasdrubale's wife,                       **shrieked\n"
  "When that her husband hadde lost his life,\n"
  "And that the Romans had y-burnt Carthage;\n"
  "She was so full of torment and of rage,\n"
  "That wilfully into the fire she start,\n"
  "And burnt herselfe with a steadfast heart.\n"
  "O woeful hennes! right so cried ye,\n"
  "As, when that Nero burned the city\n"
  "Of Rome, cried the senatores' wives,\n"
  "For that their husbands losten all their lives;\n"
  "Withoute guilt this Nero hath them slain.\n"
  "Now will I turn unto my tale again;\n"
  "\n"
  "The sely* widow, and her daughters two,                  *simple, honest\n"
  "Hearde these hennes cry and make woe,\n"
  "And at the doors out started they anon,\n"
  "And saw the fox toward the wood is gone,\n"
  "And bare upon his back the cock away:\n"
  "They cried, \"Out! harow! and well-away!\n"
  "Aha! the fox!\" and after him they ran,\n"
  "And eke with staves many another man\n"
  "Ran Coll our dog, and Talbot, and Garland;\n"
  "And Malkin, with her distaff in her hand\n"
  "Ran cow and calf, and eke the very hogges\n"
  "So fear'd they were for barking of the dogges,\n"
  "And shouting of the men and women eke.\n"
  "They ranne so, them thought their hearts would break.\n"
  "They yelled as the fiendes do in hell;\n"
  "The duckes cried as men would them quell;*                *kill, destroy\n"
  "The geese for feare flewen o'er the trees,\n"
  "Out of the hive came the swarm of bees,\n"
  "So hideous was the noise, ben'dicite!\n"
  "Certes he, Jacke Straw,<35> and his meinie,*                  *followers\n"
  "Ne made never shoutes half so shrill\n"
  "When that they woulden any Fleming kill,\n"
  "As thilke day was made upon the fox.\n"
  "Of brass they broughte beames* and of box,                *trumpets <36>\n"
  "Of horn and bone, in which they blew and pooped,*               **tooted\n"
  "And therewithal they shrieked and they hooped;\n"
  "It seemed as the heaven shoulde fall\n"
  "\n"
  "Now, goode men, I pray you hearken all;\n"
  "Lo, how Fortune turneth suddenly\n"
  "The hope and pride eke of her enemy.\n"
  "This cock, that lay upon the fox's back,\n"
  "In all his dread unto the fox he spake,\n"
  "And saide, \"Sir, if that I were as ye,\n"
  "Yet would I say (as wisly* God help me),                         *surely\n"
  "'Turn ye again, ye proude churles all;\n"
  "A very pestilence upon you fall.\n"
  "Now am I come unto the woode's side,\n"
  "Maugre your head, the cock shall here abide;\n"
  "I will him eat, in faith, and that anon.'\"\n"
  "The fox answer'd, \"In faith it shall be done:\"\n"
  "And, as he spake the word, all suddenly\n"
  "The cock brake from his mouth deliverly,*                        *nimbly\n"
  "And high upon a tree he flew anon.\n"
  "And when the fox saw that the cock was gone,\n"
  "\"Alas!\" quoth he, \"O Chanticleer, alas!\n"
  "I have,\" quoth he, \"y-done to you trespass,*                    *offence\n"
  "Inasmuch as I maked you afear'd,\n"
  "When I you hent,* and brought out of your yard;                    *took\n"
  "But, Sir, I did it in no wick' intent;\n"
  "Come down, and I shall tell you what I meant.\n"
  "I shall say sooth to you, God help me so.\"\n"
  "\"Nay then,\" quoth he, \"I shrew* us both the two,                  *curse\n"
  "And first I shrew myself, both blood and bones,\n"
  "If thou beguile me oftener than once.\n"
  "Thou shalt no more through thy flattery\n"
  "Do* me to sing and winke with mine eye;                           *cause\n"
  "For he that winketh when he shoulde see,\n"
  "All wilfully, God let him never the.\"*                           *thrive\n"
  "\"Nay,\" quoth the fox; \"but God give him mischance\n"
  "That is so indiscreet of governance,\n"
  "That jangleth* when that he should hold his peace.\"            *chatters\n"
  "\n"
  "Lo, what it is for to be reckeless\n"
  "And negligent, and trust on flattery.\n"
  "But ye that holde this tale a folly,\n"
  "As of a fox, or of a cock or hen,\n"
  "Take the morality thereof, good men.\n"
  "For Saint Paul saith, That all that written is,\n"
  "*To our doctrine it written is y-wis.* <37>       *is surely written for\n"
  "Take the fruit, and let the chaff be still.             our instruction*\n"
  "\n"
  "Now goode God, if that it be thy will,\n"
  "As saith my Lord, <38> so make us all good men;\n"
  "And bring us all to thy high bliss. Amen.\n"
  "\n"
  "\n"
  "Notes to the Nun's Priest's Tale\n"
  "\n"
  "\n"
  "1.  The Tale of the Nun's Priest is founded on the fifth chapter\n"
  "of an old French metrical \"Romance of Renard;\" the same story\n"
  "forming one of the fables of Marie, the translator of the Breton\n"
  "Lays. (See note 2 to the Prologue to the Franklin's Tale.)\n"
  "Although Dryden was in error when he ascribed the Tale to\n"
  "Chaucer's own invention, still the materials on which he had to\n"
  "operate were out of cornparison more trivial than the result.\n"
  "\n"
  "2.  Tyrwhitt quotes two statutes of Edward III, in which \"deys\"\n"
  "are included among the servants employed in agricultural\n"
  "pursuits; the name seems to have originally meant a servant who\n"
  "gave his labour by the day, but afterwards to have been\n"
  "appropriated exclusively to one who superintended or worked\n"
  "in a dairy.\n"
  "\n"
  "3. Orgon: here licentiously used for the plural, \"organs\" or\n"
  "\"orgons,\" corresponding to the plural verb \"gon\" in the next\n"
  "line.\n"
  "\n"
  "4. Horloge: French, \"clock.\"\n"
  "\n"
  "5. Embattell'd: indented on the upper edge like the battlements\n"
  "of a castle.\n"
  "\n"
  "6. My lefe is fare in land: This seems to have been the refrain of\n"
  "some old song, and its precise meaning is uncertain. It\n"
  "corresponds in cadence with the morning salutation of the cock;\n"
  "and may be taken as a greeting to the sun, which is beloved of\n"
  "Chanticleer, and has just come upon the earth -- or in the sense\n"
  "of a more local boast, as vaunting the fairness of his favourite\n"
  "hen above all others in the country round.\n"
  "\n"
  "Transcriber's note: Later commentators explain \"fare in land\" as\n"
  "\"gone abroad\" and  have identified the song:\n"
  "\n"
  "My lefe is fare in lond\n"
  "Alas! Why is she so?\n"
  "And I am so sore bound\n"
  "I may not come her to.\n"
  "She hath my heart in hold\n"
  "Where ever she ride or go\n"
  "With true love a thousand-fold.\n"
  "\n"
  "(Printed in The Athenaeum, 1896, Vol II, p. 566).\n"
  "\n"
  "7. \"Avoi!\" is the word here rendered \"away!\" It was frequently\n"
  "used in the French fabliaux, and the Italians employ the word\n"
  "\"via!\" in the same sense.\n"
  "\n"
  "8. \"Ne do no force of dreams:\" \"Somnia ne cares;\" --  Cato\n"
  "\"De Moribus,\" 1 ii, dist. 32\n"
  "\n"
  "9. Centaury: the herb so called because by its virtue the centaur\n"
  "Chiron was healed when the poisoned arrow of Hercules had\n"
  "accidentally wounded his foot.\n"
  "\n"
  "10. Fumetere: the herb \"fumitory.\"\n"
  "\n"
  "11. Catapuce:  spurge; a plant of purgative qualities. To its\n"
  "name in the text correspond the Italian \"catapuzza,\" and French\n"
  "\"catapuce\" -- words the origin of which is connected with the\n"
  "effects of the plant.\n"
  "\n"
  "12. Gaitre-berries: dog-wood berries.\n"
  "\n"
  "13. One of the greatest authors that men read: Cicero, who in\n"
  "his book \"De Divinatione\" tells this and the following story,\n"
  "though in contrary order and with many differences.\n"
  "\n"
  "14. Haled or hylled; from Anglo-Saxon \"helan\" hid, concealed\n"
  "\n"
  "15.  Kenelm succeeded his father as king of the Saxon realm of\n"
  "Mercia in 811, at the age of seven years; but he was slain by his\n"
  "ambitious aunt Quendrada. The place of his burial was\n"
  "miraculously discovered, and he was subsequently elevated to\n"
  "the rank of a saint and martyr. His life is in the English \"Golden\n"
  "Legend.\"\n"
  "\n"
  "16. Mercenrike: the kingdom of Mercia; Anglo-Saxon,\n"
  "Myrcnarice. Compare the second member of the compound in\n"
  "the German, \"Frankreich,\" France; \"Oesterreich,\" Austria.\n"
  "\n"
  "17. Cicero (\"De Republica,\" lib. vi.) wrote the Dream of\n"
  "Scipio, in which the Younger relates the appearance of the\n"
  "Elder Africanus, and the counsels and exhortations which the\n"
  "shade addressed to the sleeper. Macrobius wrote an elaborate\n"
  "\"Commentary on the Dream of Scipio,\" -- a philosophical\n"
  "treatise much studied and relished during the Middle Ages.\n"
  "\n"
  "18. See the Monk's Tale for this story.\n"
  "\n"
  "19. Andromache's dream will not be found in Homer; It is\n"
  "related in the book of the fictitious Dares Phrygius, the most\n"
  "popular authority during the Middle Ages for the history of the\n"
  "Trojan War.\n"
  "\n"
  "20. In principio: In the beginning; the first words of Genesis and\n"
  "of the Gospel of John.\n"
  "\n"
  "21. Mulier est hominis confusio:  This line is taken from the\n"
  "same fabulous conference between the Emperor Adrian and the\n"
  "philosopher Secundus, whence Chaucer derived some of the\n"
  "arguments in praise of poverty employed in the Wife of Bath's\n"
  "Tale proper. See note 14 to the Wife of Bath's tale.  The\n"
  "passage transferred to the text is the commencement of a\n"
  "description of woman. \"Quid est mulier? hominis confusio,\" &c.\n"
  "(\"What is Woman? A union with man\", &c.)\n"
  "\n"
  "22. Col-fox: a blackish fox, so called because of its likeness to\n"
  "coal, according to Skinner; though more probably the prefix has\n"
  "a reproachful meaning, and is in some way connected with the\n"
  "word \"cold\" as, some forty lines below, it is applied to the\n"
  "prejudicial counsel of women, and as frequently it is used to\n"
  "describe \"sighs\" and other tokens of grief, and \"cares\" or\n"
  "\"anxieties.\"\n"
  "\n"
  "23. Undern:  In this case, the meaning of \"evening\" or\n"
  "\"afternoon\" can hardly be applied to the word, which must be\n"
  "taken to signify some early hour of the forenoon. See also note\n"
  "4 to the Wife of Bath's tale and note 5 to the Clerk's Tale.\n"
  "\n"
  "24. Ganilion: a traitor.  See note 9 to the Shipman's Tale and\n"
  "note 28 to the Monk's Tale.\n"
  "\n"
  "25. Greek Sinon: The inventor of the Trojan Horse. See note 14\n"
  "to the Squire's Tale\n"
  "\n"
  "26. Boult it from the bren: Examine the matter thoroughly; a\n"
  "metaphor taken from the sifting of meal, to divide the fine flour\n"
  "from the bran.\n"
  "\n"
  "27. Thomas Bradwardine, Archbishop of Canterbury in the\n"
  "thirteenth century, who wrote a book, \"De Causa Dei,\" in\n"
  "controversy with Pelagius; and also numerous other treatises,\n"
  "among them some  on predestination.\n"
  "\n"
  "28. In a popular mediaveal Latin treatise by one Theobaldus,\n"
  "entitled \"Physiologus de Naturis XII. Animalium\" (\"A\n"
  "description of the nature of twelve animals\"),  sirens or\n"
  "mermaids are described as skilled in song, and drawing unwary\n"
  "mariners to destruction by the sweetness of their voices.\n"
  "\n"
  "29. \"Nigellus Wireker,\" says Urry's Glossary, \"a monk and\n"
  "precentor of Canterbury, wrote a Latin poem intituled\n"
  "'Speculum Speculorum,' ('The mirror of mirrors') dedicated to\n"
  "William Longchamp, Bishop of Ely, and Lord Chancellor;\n"
  "wherein, under the fable of an Ass (which he calls 'Burnellus')\n"
  "that desired a longer tail, is represented the folly of such as are\n"
  "not content with their own condition. There is introduced a tale\n"
  "of a cock, who having his leg broke by a priest's son (called\n"
  "Gundulfus) watched an opportunity to be revenged; which at\n"
  "last presented itself on this occasion: A day was appointed for\n"
  "Gundulfus's being admitted into holy orders at a place remote\n"
  "from his father's habitation; he therefore orders the servants to\n"
  "call him at first cock-crowing, which the cock overhearing did\n"
  "not crow at all that morning. So Gundulfus overslept himself,\n"
  "and was thereby disappointed of his ordination, the office being\n"
  "quite finished before he came to the place.\" Wireker's satire was\n"
  "among the most celebrated and popular Latin poems of the\n"
  "Middle Ages. The Ass was probably as Tyrwhitt suggests,\n"
  "called \"Burnel\" or \"Brunel,\" from his brown colour; as, a little\n"
  "below, a reddish fox is called \"Russel.\"\n"
  "\n"
  "30. Flattour: flatterer; French, \"flatteur.\"\n"
  "\n"
  "31. Losengeour: deceiver, cozener; the word had analogues in\n"
  "the French \"losengier,\" and the Spanish \"lisongero.\" It is\n"
  "probably connected with \"leasing,\" falsehood; which has been\n"
  "derived from Anglo-Saxon \"hlisan,\" to celebrate -- as if it meant\n"
  "the spreading of a false renown\n"
  "\n"
  "32. Dan Russel: Master Russet; a name given to the fox, from\n"
  "his reddish colour.\n"
  "\n"
  "33. Geoffrey de Vinsauf was the author of a well-known\n"
  "mediaeval treatise on composition in various poetical styles of\n"
  "which he gave examples. Chaucer's irony is therefore directed\n"
  "against some grandiose and affected lines on the death of\n"
  "Richard I., intended to illustrate the pathetic style, in which\n"
  "Friday is addressed as \"O Veneris lachrymosa dies\" (\"O tearful\n"
  "day of Venus\").\n"
  "\n"
  "34. \"Priamum altaria ad ipsa trementem\n"
  "     Traxit, et in multo lapsantem sanguine nati\n"
  "     Implicuitque comam laeva, dextraque coruscum\n"
  "     Extulit, ac lateri capulo tenus abdidit ensem.\n"
  "     Haec finis Priami fatorum.\"\n"
  "(\"He dragged Priam trembling to his own altar, slipping on the\n"
  "blood of his child; He took his hair in his left hand, and with the\n"
  "right drew the flashing sword, and hid it to the hilt [in his body].\n"
  "Thus an end was made of Priam\")\n"
  "-- Virgil, Aeneid. ii. 550.\n"
  "\n"
  "35. Jack Straw: The leader of a Kentish rising, in the reign of\n"
  "Richard II, in 1381, by which the Flemish merchants in London\n"
  "were great sufferers.\n"
  "\n"
  "36. Beams: trumpets; Anglo-Saxon, \"bema.\"\n"
  "\n"
  "37. \"All scripture is given by inspiration of God, and is\n"
  "profitable for doctrine, for reproof, for correction, for\n"
  "instruction in righteousness: that the man of God may be\n"
  "perfect, throughly furnished unto all good works.\" -- 2 Tim. iii.\n"
  "16.\n"
  "\n"
  "\n"
  "THE EPILOGUE <1>\n"
  "\n"
  "\n"
  "\"Sir Nunne's Priest,\" our hoste said anon,\n"
  "\"Y-blessed be thy breech, and every stone;\n"
  "This was a merry tale of Chanticleer.\n"
  "But by my truth, if thou wert seculere,*                       *a layman\n"
  "Thou wouldest be a treadefowl* aright;                             *cock\n"
  "For if thou have courage as thou hast might,\n"
  "Thee were need of hennes, as I ween,\n"
  "Yea more than seven times seventeen.\n"
  "See, whate brawnes* hath this gentle priest,            *muscles, sinews\n"
  "So great a neck, and such a large breast\n"
  "He looketh as a sperhawk with his eyen\n"
  "Him needeth not his colour for to dyen\n"
  "With Brazil, nor with grain of Portugale.\n"
  "But, Sir, faire fall you for your tale'.\"\n"
  "And, after that, he with full merry cheer\n"
  "Said to another, as ye shall hear.\n"
  "\n"
  "\n"
  "Notes to the Epilogue to the Nun's Priest's Tale\n"
  "\n"
  "\n"
  "1.  The sixteen lines appended to the Tale of the Nun's Priest\n"
  "seem, as Tyrwhitt observes, to commence the prologue to the\n"
  "succeeding Tale -- but the difficulty is to determine which that\n"
  "Tale should be. In earlier editions, the lines formed the opening\n"
  "of the prologue to the Manciple's Tale; but most of the\n"
  "manuscripts acknowledge themselves defective in this part, and\n"
  "give the Nun's Tale after that of the Nun's Priest. In the Harleian\n"
  "manuscript, followed by Mr Wright, the second Nun's Tale, and\n"
  "the Canon's Yeoman's Tale, are placed after the Franklin's tale;\n"
  "and the sixteen lines above are not found -- the Manciple's\n"
  "prologue coming immediately after the \"Amen\" of the Nun's\n"
  "Priest. In two manuscripts, the last line of the sixteen runs thus:\n"
  "\"Said unto the Nun as ye shall hear;\" and six lines more\n"
  "evidently forged, are given to introduce the Nun's Tale.  All this\n"
  "confusion and doubt only strengthen the certainty, and deepen\n"
  "the regret, that \"The Canterbury Tales\" were left at Chaucer's,\n"
  "death not merely very imperfect as a whole, but destitute of\n"
  "many finishing touches that would have made them complete so\n"
  "far as the conception had actually been carried into\n"
  "performance.\n"
  "\n"
  "\n"
  "\n"
  "";
// }

const char secondNunsTale[] PGMSECTION = // { // 30028 bytes
  "THE SECOND NUN'S TALE <1>\n"
  "\n"
  "\n"
  "The minister and norice* unto vices,                              *nurse\n"
  "Which that men call in English idleness,\n"
  "The porter at the gate is of delices;*                         *delights\n"
  "T'eschew, and by her contrar' her oppress, --\n"
  "That is to say, by lawful business,* --            *occupation, activity\n"
  "Well oughte we to *do our all intent*                  *apply ourselves*\n"
  "Lest that the fiend through idleness us hent.*                    *seize\n"
  "\n"
  "For he, that with his thousand cordes sly\n"
  "Continually us waiteth to beclap,*                       *entangle, bind\n"
  "When he may man in idleness espy,\n"
  "He can so lightly catch him in his trap,\n"
  "Till that a man be hent* right by the lappe,**              *seize **hem\n"
  "He is not ware the fiend hath him in hand;\n"
  "Well ought we work, and idleness withstand.\n"
  "\n"
  "And though men dreaded never for to die,\n"
  "Yet see men well by reason, doubteless,\n"
  "That idleness is root of sluggardy,\n"
  "Of which there cometh never good increase;\n"
  "And see that sloth them holdeth in a leas,*                   *leash <2>\n"
  "Only to sleep, and for to eat and drink,\n"
  "And to devouren all that others swink.*                          *labour\n"
  "\n"
  "And, for to put us from such idleness,\n"
  "That cause is of so great confusion,\n"
  "I have here done my faithful business,\n"
  "After the Legend, in translation\n"
  "Right of thy glorious life and passion, --\n"
  "Thou with thy garland wrought of rose and lily,\n"
  "Thee mean I, maid and martyr, Saint Cecilie.\n"
  "\n"
  "And thou, thou art the flow'r of virgins all,\n"
  "Of whom that Bernard list so well to write, <3>\n"
  "To thee at my beginning first I call;\n"
  "Thou comfort of us wretches, do me indite\n"
  "Thy maiden's death, that won through her merite\n"
  "Th' eternal life, and o'er the fiend victory,\n"
  "As man may after readen in her story.\n"
  "\n"
  "Thou maid and mother, daughter of thy Son,\n"
  "Thou well of mercy, sinful soules' cure,\n"
  "In whom that God of bounte chose to won;*                         *dwell\n"
  "Thou humble and high o'er every creature,\n"
  "Thou nobilest, *so far forth our nature,*  *as far as our nature admits*\n"
  "That no disdain the Maker had of kind,*                          *nature\n"
  "His Son in blood and flesh to clothe and wind.*                    *wrap\n"
  "\n"
  "Within the cloister of thy blissful sides\n"
  "Took manne's shape th' eternal love and peace,\n"
  "That of *the trine compass* Lord and guide is              *the trinity*\n"
  "Whom earth, and sea, and heav'n, *out of release,*          *unceasingly\n"
  "*Aye hery;* and thou, Virgin wemmeless,*    *forever praise* *immaculate\n"
  "Bare of thy body, and dweltest maiden pure,\n"
  "The Creator of every creature.\n"
  "\n"
  "Assembled is in thee magnificence <4>\n"
  "With mercy, goodness, and with such pity,\n"
  "That thou, that art the sun of excellence,\n"
  "Not only helpest them that pray to thee,\n"
  "But oftentime, of thy benignity,\n"
  "Full freely, ere that men thine help beseech,\n"
  "Thou go'st before, and art their lives' leech.*        *healer, saviour.\n"
  "\n"
  "Now help, thou meek and blissful faire maid,\n"
  "Me, flemed* wretch, in this desert of gall;           *banished, outcast\n"
  "Think on the woman Cananee that said\n"
  "That whelpes eat some of the crumbes all\n"
  "That from their Lorde's table be y-fall;<5>\n"
  "And though that I, unworthy son of Eve,<6>\n"
  "Be sinful, yet accepte my believe.*                               *faith\n"
  "\n"
  "And, for that faith is dead withoute werkes,\n"
  "For to worke give me wit and space,\n"
  "That I be *quit from thennes that most derk is;*    *freed from the most\n"
  "O thou, that art so fair and full of grace,           dark place (Hell)*\n"
  "Be thou mine advocate in that high place,\n"
  "Where as withouten end is sung Osanne,\n"
  "Thou Christe's mother, daughter dear of Anne.\n"
  "\n"
  "And of thy light my soul in prison light,\n"
  "That troubled is by the contagion\n"
  "Of my body, and also by the weight\n"
  "Of earthly lust and false affection;\n"
  "O hav'n of refuge, O salvation\n"
  "Of them that be in sorrow and distress,\n"
  "Now help, for to my work I will me dress.\n"
  "\n"
  "Yet pray I you, that reade what I write, <6>\n"
  "Forgive me that I do no diligence\n"
  "This ilke* story subtilly t' indite.                               *same\n"
  "For both have I the wordes and sentence\n"
  "Of him that at the sainte's reverence\n"
  "The story wrote, and follow her legend;\n"
  "And pray you that you will my work amend.\n"
  "\n"
  "First will I you the name of Saint Cecilie\n"
  "Expound, as men may in her story see.\n"
  "It is to say in English, Heaven's lily,<7>\n"
  "For pure chasteness of virginity;\n"
  "Or, for she whiteness had of honesty,*                           *purity\n"
  "And green of conscience, and of good fame\n"
  "The sweete savour, Lilie was her name.\n"
  "\n"
  "Or Cecilie is to say, the way of blind;<7>\n"
  "For she example was by good teaching;\n"
  "Or else Cecilie, as I written find,\n"
  "Is joined by a manner conjoining\n"
  "Of heaven and Lia, <7> and herein figuring\n"
  "The heaven is set for thought of holiness,\n"
  "And Lia for her lasting business.\n"
  "\n"
  "Cecilie may eke be said in this mannere,\n"
  "Wanting of blindness, for her greate light\n"
  "Of sapience, and for her thewes* clear.                       *qualities\n"
  "Or elles, lo, this maiden's name bright\n"
  "Of heaven and Leos <7> comes, for which by right\n"
  "Men might her well the heaven of people call,\n"
  "Example of good and wise workes all;\n"
  "\n"
  "For Leos people in English is to say;\n"
  "And right as men may in the heaven see\n"
  "The sun and moon, and starres every way,\n"
  "Right so men ghostly,* in this maiden free,                 *spiritually\n"
  "Sawen of faith the magnanimity,\n"
  "And eke the clearness whole of sapience,\n"
  "And sundry workes bright of excellence.\n"
  "\n"
  "And right so as these philosophers write,\n"
  "That heav'n is swift and round, and eke burning,\n"
  "Right so was faire Cecilie the white\n"
  "Full swift and busy in every good working,\n"
  "And round and whole in good persevering, <8>\n"
  "And burning ever in charity full bright;\n"
  "Now have I you declared *what she hight.*         *why she had her name*\n"
  "\n"
  "This maiden bright Cecile, as her life saith,\n"
  "Was come of Romans, and of noble kind,\n"
  "And from her cradle foster'd in the faith\n"
  "Of Christ, and bare his Gospel in her mind:\n"
  "She never ceased, as I written find,\n"
  "Of her prayere, and God to love and dread,\n"
  "Beseeching him to keep her maidenhead.\n"
  "\n"
  "And when this maiden should unto a man\n"
  "Y-wedded be, that was full young of age,\n"
  "Which that y-called was Valerian,\n"
  "And come was the day of marriage,\n"
  "She, full devout and humble in her corage,*                       *heart\n"
  "Under her robe of gold, that sat full fair,\n"
  "Had next her flesh y-clad her in an hair.*        *garment of hair-cloth\n"
  "\n"
  "And while the organs made melody,\n"
  "To God alone thus in her heart sang she;\n"
  "\"O Lord, my soul and eke my body gie*                             *guide\n"
  "Unwemmed,* lest that I confounded be.\"                      *unblemished\n"
  "And, for his love that died upon the tree,\n"
  "Every second or third day she fast',\n"
  "Aye bidding* in her orisons full fast.                          *praying\n"
  "\n"
  "The night came, and to bedde must she gon\n"
  "With her husband, as it is the mannere;\n"
  "And privily she said to him anon;\n"
  "\"O sweet and well-beloved spouse dear,\n"
  "There is a counsel,* an'** ye will it hear,                 *secret **if\n"
  "Which that right fain I would unto you say,\n"
  "So that ye swear ye will it not bewray.\"*                        *betray\n"
  "\n"
  "Valerian gan fast unto her swear\n"
  "That for no case nor thing that mighte be,\n"
  "He never should to none bewrayen her;\n"
  "And then at erst* thus to him saide she;             *for the first time\n"
  "\"I have an angel which that loveth me,\n"
  "That with great love, whether I wake or sleep,\n"
  "Is ready aye my body for to keep;\n"
  "\n"
  "\"And if that he may feelen, *out of dread,*              *without doubt*\n"
  "That ye me touch or love in villainy,\n"
  "He right anon will slay you with the deed,\n"
  "And in your youthe thus ye shoulde die.\n"
  "And if that ye in cleane love me gie,\"*                           *guide\n"
  "He will you love as me, for your cleanness,\n"
  "And shew to you his joy and his brightness.\"\n"
  "\n"
  "Valerian, corrected as God wo'ld,\n"
  "Answer'd again, \"If I shall truste thee,\n"
  "Let me that angel see, and him behold;\n"
  "And if that it a very angel be,\n"
  "Then will I do as thou hast prayed me;\n"
  "And if thou love another man, forsooth\n"
  "Right with this sword then will I slay you both.\"\n"
  "\n"
  "Cecile answer'd anon right in this wise;\n"
  "\"If that you list, the angel shall ye see,\n"
  "So that ye trow* Of Christ, and you baptise;                       *know\n"
  "Go forth to Via Appia,\" quoth she,\n"
  "That from this towne stands but miles three,\n"
  "And to the poore folkes that there dwell\n"
  "Say them right thus, as that I shall you tell,\n"
  "\n"
  "\"Tell them, that I, Cecile, you to them sent\n"
  "To shewe you the good Urban the old,\n"
  "For secret needes,* and for good intent;                       *business\n"
  "And when that ye Saint Urban have behold,\n"
  "Tell him the wordes which I to you told\n"
  "And when that he hath purged you from sin,\n"
  "Then shall ye see that angel ere ye twin*                        *depart\n"
  "\n"
  "Valerian is to the place gone;\n"
  "And, right as he was taught by her learning\n"
  "He found this holy old Urban anon\n"
  "Among the saintes' burials louting;*                *lying concealed <9>\n"
  "And he anon, withoute tarrying,\n"
  "Did his message, and when that he it told,\n"
  "Urban for joy his handes gan uphold.\n"
  "\n"
  "The teares from his eyen let he fall;\n"
  "\"Almighty Lord, O Jesus Christ,\"\n"
  "Quoth he, \"Sower of chaste counsel, herd* of us all;           *shepherd\n"
  "The fruit of thilke* seed of chastity                              *that\n"
  "That thou hast sown in Cecile, take to thee\n"
  "Lo, like a busy bee, withoute guile,\n"
  "Thee serveth aye thine owen thrall* Cicile,                     *servant\n"
  "\n"
  "\"For thilke spouse, that she took *but now,*                    *lately*\n"
  "Full like a fierce lion, she sendeth here,\n"
  "As meek as e'er was any lamb to owe.\"\n"
  "And with that word anon there gan appear\n"
  "An old man, clad in white clothes clear,\n"
  "That had a book with letters of gold in hand,\n"
  "And gan before Valerian to stand.\n"
  "\n"
  "Valerian, as dead, fell down for dread,\n"
  "When he him saw; and he up hent* him tho,**                *took **there\n"
  "And on his book right thus he gan to read;\n"
  "\"One Lord, one faith, one God withoute mo',\n"
  "One Christendom, one Father of all also,\n"
  "Aboven all, and over all everywhere.\"\n"
  "These wordes all with gold y-written were.\n"
  "\n"
  "When this was read, then said this olde man,\n"
  "\"Believ'st thou this or no? say yea or nay.\"\n"
  "\"I believe all this,\" quoth Valerian,\n"
  "\"For soother* thing than this, I dare well say,                   *truer\n"
  "Under the Heaven no wight thinke may.\"\n"
  "Then vanish'd the old man, he wist not where\n"
  "And Pope Urban him christened right there.\n"
  "\n"
  "Valerian went home, and found Cecilie\n"
  "Within his chamber with an angel stand;\n"
  "This angel had of roses and of lily\n"
  "Corones* two, the which he bare in hand,                         *crowns\n"
  "And first to Cecile, as I understand,\n"
  "He gave the one, and after gan he take\n"
  "The other to Valerian her make.*                          *mate, husband\n"
  "\n"
  "\"With body clean, and with unwemmed* thought,      *unspotted, blameless\n"
  "Keep aye well these corones two,\" quoth he;\n"
  "\"From Paradise to you I have them brought,\n"
  "Nor ever more shall they rotten be,\n"
  "Nor lose their sweet savour, truste me,\n"
  "Nor ever wight shall see them with his eye,\n"
  "But he be chaste, and hate villainy.\n"
  "\n"
  "\"And thou, Valerian, for thou so soon\n"
  "Assented hast to good counsel, also\n"
  "Say what thee list,* and thou shalt have thy boon.\"**     *wish **desire\n"
  "\"I have a brother,\" quoth Valerian tho,*                           *then\n"
  "\"That in this world I love no man so;\n"
  "I pray you that my brother may have grace\n"
  "To know the truth, as I do in this place.\"\n"
  "\n"
  "The angel said, \"God liketh thy request,\n"
  "And bothe, with the palm of martyrdom,\n"
  "Ye shalle come unto this blissful rest.\"\n"
  "And, with that word, Tiburce his brother came.\n"
  "And when that he the savour undernome*                        *perceived\n"
  "Which that the roses and the lilies cast,\n"
  "Within his heart he gan to wonder fast;\n"
  "\n"
  "And said; \"I wonder, this time of the year,\n"
  "Whence that sweete savour cometh so\n"
  "Of rose and lilies, that I smelle here;\n"
  "For though I had them in mine handes two,\n"
  "The savour might in me no deeper go;\n"
  "The sweete smell, that in my heart I find,\n"
  "Hath changed me all in another kind.\"\n"
  "\n"
  "Valerian said, \"Two crownes here have we,\n"
  "Snow-white and rose-red, that shine clear,\n"
  "Which that thine eyen have no might to see;\n"
  "And, as thou smellest them through my prayere,\n"
  "So shalt thou see them, leve* brother dear,                     *beloved\n"
  "If it so be thou wilt withoute sloth\n"
  "Believe aright, and know the very troth. \"\n"
  "\n"
  "Tiburce answered, \"Say'st thou this to me\n"
  "In soothness, or in dreame hear I this?\"\n"
  "\"In dreames,\" quoth Valorian, \"have we be\n"
  "Unto this time, brother mine, y-wis\n"
  "But now *at erst* in truth our dwelling is.\"        *for the first time*\n"
  "How know'st thou this,\" quoth Tiburce; \"in what wise?\"\n"
  "Quoth Valerian, \"That shall I thee devise*                     *describe\n"
  "\n"
  "\"The angel of God hath me the truth y-taught,\n"
  "Which thou shalt see, if that thou wilt reny*                  *renounce\n"
  "The idols, and be clean, and elles nought.\"\n"
  "[And of the miracle of these crownes tway\n"
  "Saint Ambrose in his preface list to say;\n"
  "Solemnely this noble doctor dear\n"
  "Commendeth it, and saith in this mannere\n"
  "\n"
  "\"The palm of martyrdom for to receive,\n"
  "Saint Cecilie, full filled of God's gift,\n"
  "The world and eke her chamber gan to weive;*                    *forsake\n"
  "Witness Tiburce's and Cecilie's shrift,*                     *confession\n"
  "To which God of his bounty woulde shift\n"
  "Corones two, of flowers well smelling,\n"
  "And made his angel them the crownes bring.\n"
  "\n"
  "\"The maid hath brought these men to bliss above;\n"
  "The world hath wist what it is worth, certain,\n"
  "Devotion of chastity to love.\"] <10>\n"
  "Then showed him Cecilie all open and plain,\n"
  "That idols all are but a thing in vain,\n"
  "For they be dumb, and thereto* they be deave;**        *therefore **deaf\n"
  "And charged him his idols for to leave.\n"
  "\n"
  "\"Whoso that troweth* not this, a beast he is,\"                *believeth\n"
  "Quoth this Tiburce, \"if that I shall not lie.\"\n"
  "And she gan kiss his breast when she heard this,\n"
  "And was full glad he could the truth espy:\n"
  "\"This day I take thee for mine ally.\"*                    *chosen friend\n"
  "Saide this blissful faire maiden dear;\n"
  "And after that she said as ye may hear.\n"
  "\n"
  "\"Lo, right so as the love of Christ,\" quoth she,\n"
  "\"Made me thy brother's wife, right in that wise\n"
  "Anon for mine ally here take I thee,\n"
  "Since that thou wilt thine idoles despise.\n"
  "Go with thy brother now and thee baptise,\n"
  "And make thee clean, so that thou may'st behold\n"
  "The angel's face, of which thy brother told.\"\n"
  "\n"
  "Tiburce answer'd, and saide, \"Brother dear,\n"
  "First tell me whither I shall, and to what man?\"\n"
  "\"To whom?\" quoth he, \"come forth with goode cheer,\n"
  "I will thee lead unto the Pope Urban.\"\n"
  "\"To Urban? brother mine Valerian,\"\n"
  "Quoth then Tiburce; \"wilt thou me thither lead?\n"
  "Me thinketh that it were a wondrous deed.\n"
  "\n"
  "\"Meanest thou not that Urban,\" quoth he tho,*                      *then\n"
  "\"That is so often damned to be dead,\n"
  "And wons* in halkes** always to and fro,               *dwells **corners\n"
  "And dare not ones putte forth his head?\n"
  "Men should him brennen* in a fire so red,                          *burn\n"
  "If he were found, or if men might him spy:\n"
  "And us also, to bear him company.\n"
  "\n"
  "\"And while we seeke that Divinity\n"
  "That is y-hid in heaven privily,\n"
  "Algate* burnt in this world should we be.\"                 *nevertheless\n"
  "To whom Cecilie answer'd boldely;\n"
  "\"Men mighte dreade well and skilfully*                       *reasonably\n"
  "This life to lose, mine owen deare brother,\n"
  "If this were living only, and none other.\n"
  "\n"
  "\"But there is better life in other place,\n"
  "That never shall be loste, dread thee nought;\n"
  "Which Godde's Son us tolde through his grace\n"
  "That Father's Son which alle thinges wrought;\n"
  "And all that wrought is with a skilful* thought,             *reasonable\n"
  "The Ghost,* that from the Father gan proceed,               *Holy Spirit\n"
  "Hath souled* them, withouten any drede.**      *endowed them with a soul\n"
  "                                                                 **doubt\n"
  "By word and by miracle, high God's Son,\n"
  "When he was in this world, declared here.\n"
  "That there is other life where men may won.\"*                     *dwell\n"
  "To whom answer'd Tiburce, \"O sister dear,\n"
  "Saidest thou not right now in this mannere,\n"
  "There was but one God, Lord in soothfastness,*                    *truth\n"
  "And now of three how may'st thou bear witness?\"\n"
  "\n"
  "\"That shall I tell,\" quoth she, \"ere that I go.\n"
  "Right as a man hath sapiences* three,                  *mental faculties\n"
  "Memory, engine,* and intellect also,                           *wit <11>\n"
  "So in one being of divinity\n"
  "Three persones there maye right well be.\"\n"
  "Then gan she him full busily to preach\n"
  "Of Christe's coming, and his paines teach,\n"
  "\n"
  "And many pointes of his passion;\n"
  "How Godde's Son in this world was withhold*                    *employed\n"
  "To do mankinde plein* remission,                                   *full\n"
  "That was y-bound in sin and cares cold.*                  *wretched <12>\n"
  "All this thing she unto Tiburce told,\n"
  "And after that Tiburce, in good intent,\n"
  "With Valerian to Pope Urban he went.\n"
  "\n"
  "That thanked God, and with glad heart and light\n"
  "He christen'd him, and made him in that place\n"
  "Perfect in his learning, and Godde's knight.\n"
  "And after this Tiburce got such grace,\n"
  "That every day he saw in time and space\n"
  "Th' angel of God, and every manner boon*                *request, favour\n"
  "That be God asked, it was sped* full anon.          *granted, successful\n"
  "\n"
  "It were full hard by order for to sayn\n"
  "How many wonders Jesus for them wrought,\n"
  "But at the last, to telle short and plain,\n"
  "The sergeants of the town of Rome them sought,\n"
  "And them before Almach the Prefect brought,\n"
  "Which them apposed,* and knew all their intent,              *questioned\n"
  "And to th'image of Jupiter them sent.\n"
  "\n"
  "And said, \"Whoso will not do sacrifice,\n"
  "Swap* off his head, this is my sentence here.\"                   *strike\n"
  "Anon these martyrs, *that I you devise,*            *of whom I tell you*\n"
  "One Maximus, that was an officere\n"
  "Of the prefect's, and his corniculere <13>\n"
  "Them hent,* and when he forth the saintes lad,**           *seized **led\n"
  "Himself he wept for pity that he had.\n"
  "\n"
  "When Maximus had heard the saintes lore,*            *doctrine, teaching\n"
  "He got him of the tormentores* leave,                         *torturers\n"
  "And led them to his house withoute more;\n"
  "And with their preaching, ere that it were eve,\n"
  "They gonnen* from the tormentors to reave,**    *began **wrest, root out\n"
  "And from Maxim', and from his folk each one,\n"
  "The false faith, to trow* in God alone.                         *believe\n"
  "\n"
  "Cecilia came, when it was waxen night,\n"
  "With priestes, that them christen'd *all in fere;*        *in a company*\n"
  "And afterward, when day was waxen light,\n"
  "Cecile them said with a full steadfast cheer,*                     *mien\n"
  "\"Now, Christe's owen knightes lefe* and dear,                   *beloved\n"
  "Cast all away the workes of darkness,\n"
  "And arme you in armour of brightness.\n"
  "\n"
  "Ye have forsooth y-done a great battaile,\n"
  "Your course is done, your faith have ye conserved; <14>\n"
  "O to the crown of life that may not fail;\n"
  "The rightful Judge, which that ye have served\n"
  "Shall give it you, as ye have it deserved.\"\n"
  "And when this thing was said, as I devise,*                       relate\n"
  "Men led them forth to do the sacrifice.\n"
  "\n"
  "But when they were unto the place brought\n"
  "To telle shortly the conclusion,\n"
  "They would incense nor sacrifice right nought\n"
  "But on their knees they sette them adown,\n"
  "With humble heart and sad* devotion,                          *steadfast\n"
  "And loste both their heades in the place;\n"
  "Their soules wente to the King of grace.\n"
  "\n"
  "This Maximus, that saw this thing betide,\n"
  "With piteous teares told it anon right,\n"
  "That he their soules saw to heaven glide\n"
  "With angels, full of clearness and of light\n"
  "Andt with his word converted many a wight.\n"
  "For which Almachius *did him to-beat*                    *see note <15>*\n"
  "With whip of lead, till he his life gan lete.*                     *quit\n"
  "\n"
  "Cecile him took, and buried him anon\n"
  "By Tiburce and Valerian softely,\n"
  "Within their burying-place, under the stone.\n"
  "And after this Almachius hastily\n"
  "Bade his ministers fetchen openly\n"
  "Cecile, so that she might in his presence\n"
  "Do sacrifice, and Jupiter incense.*                     *burn incense to\n"
  "\n"
  "But they, converted at her wise lore,*                         *teaching\n"
  "Wepte full sore, and gave full credence\n"
  "Unto her word, and cried more and more;\n"
  "\"Christ, Godde's Son, withoute difference,\n"
  "Is very God, this is all our sentence,*                         *opinion\n"
  "That hath so good a servant him to serve\n"
  "Thus with one voice we trowe,* though we sterve.**        *believe **die\n"
  "\n"
  "Almachius, that heard of this doing,\n"
  "Bade fetch Cecilie, that he might her see;\n"
  "And alderfirst,* lo, this was his asking;                  *first of all\n"
  "\"What manner woman arte thou?\" quoth he,\n"
  "\"I am a gentle woman born,\" quoth she.\n"
  "\"I aske thee,\" quoth he,\"though it thee grieve,\n"
  "Of thy religion and of thy believe.\"\n"
  "\n"
  "\"Ye have begun your question foolishly,\"\n"
  "Quoth she, \"that wouldest two answers conclude\n"
  "In one demand? ye aske lewedly.\"*                            *ignorantly\n"
  "Almach answer'd to that similitude,\n"
  "\"Of whence comes thine answering so rude?\"\n"
  "\"Of whence?\" quoth she, when that she was freined,*               *asked\n"
  "\"Of conscience, and of good faith unfeigned.\"\n"
  "\n"
  "Almachius saide; \"Takest thou no heed\n"
  "Of my power?\" and she him answer'd this;\n"
  "\"Your might,\" quoth she, \"full little is to dread;\n"
  "For every mortal manne's power is\n"
  "But like a bladder full of wind, y-wis;*                      *certainly\n"
  "For with a needle's point, when it is blow',\n"
  "May all the boast of it be laid full low.\"\n"
  "\n"
  "\"Full wrongfully begunnest thou,\" quoth he,\n"
  "\"And yet in wrong is thy perseverance.\n"
  "Know'st thou not how our mighty princes free\n"
  "Have thus commanded and made ordinance,\n"
  "That every Christian wight shall have penance,*              *punishment\n"
  "But if that he his Christendom withsay,*                           *deny\n"
  "And go all quit, if he will it renay?\"*                        *renounce\n"
  "\n"
  "\"Your princes erren, as your nobley* doth,\"                    *nobility\n"
  "Quoth then Cecile, \"and with a *wood sentence*            *mad judgment*\n"
  "Ye make us guilty, and it is not sooth:*                           *true\n"
  "For ye that knowe well our innocence,\n"
  "Forasmuch as we do aye reverence\n"
  "To Christ, and for we bear a Christian name,\n"
  "Ye put on us a crime and eke a blame.\n"
  "\n"
  "\"But we that knowe thilke name so\n"
  "For virtuous, we may it not withsay.\"\n"
  "Almach answered, \"Choose one of these two,\n"
  "Do sacrifice, or Christendom renay,\n"
  "That thou may'st now escape by that way.\"\n"
  "At which the holy blissful faire maid\n"
  "Gan for to laugh, and to the judge said;\n"
  "\n"
  "\"O judge, *confused in thy nicety,*            *confounded in thy folly*\n"
  "Wouldest thou that I reny innocence?\n"
  "To make me a wicked wight,\" quoth she,\n"
  "\"Lo, he dissimuleth* here in audience;                       *dissembles\n"
  "He stareth and woodeth* in his advertence.\"**   *grows furious **thought\n"
  "To whom Almachius said, \"Unsely* wretch,                        *unhappy\n"
  "Knowest thou not how far my might may stretch?\n"
  "\n"
  "\"Have not our mighty princes to me given\n"
  "Yea bothe power and eke authority\n"
  "To make folk to dien or to liven?\n"
  "Why speakest thou so proudly then to me?\"\n"
  "\"I speake not but steadfastly,\" quoth she,\n"
  "Not proudly, for I say, as for my side,\n"
  "We hate deadly* thilke vice of pride.                          *mortally\n"
  "\n"
  "\"And, if thou dreade not a sooth* to hear,                        *truth\n"
  "Then will I shew all openly by right,\n"
  "That thou hast made a full great leasing* here.               *falsehood\n"
  "Thou say'st thy princes have thee given might\n"
  "Both for to slay and for to quick* a wight, --             *give life to\n"
  "Thou that may'st not but only life bereave;\n"
  "Thou hast none other power nor no leave.\n"
  "\n"
  "\"But thou may'st say, thy princes have thee maked\n"
  "Minister of death; for if thou speak of mo',\n"
  "Thou liest; for thy power is full naked.\"\n"
  "\"Do away thy boldness,\" said Almachius tho,*                       *then\n"
  "\"And sacrifice to our gods, ere thou go.\n"
  "I recke not what wrong that thou me proffer,\n"
  "For I can suffer it as a philosopher.\n"
  "\n"
  "\"But those wronges may I not endure,\n"
  "That thou speak'st of our goddes here,\" quoth he.\n"
  "Cecile answer'd, \"O nice* creature,                             *foolish\n"
  "Thou saidest no word, since thou spake to me,\n"
  "That I knew not therewith thy nicety,*                            *folly\n"
  "And that thou wert in *every manner wise*            *every sort of way*\n"
  "A lewed* officer, a vain justice.                              *ignorant\n"
  "\n"
  "\"There lacketh nothing to thine outward eyen\n"
  "That thou art blind; for thing that we see all\n"
  "That it is stone, that men may well espyen,\n"
  "That ilke* stone a god thou wilt it call.                *very, selfsame\n"
  "I rede* thee let thine hand upon it fall,                        *advise\n"
  "And taste* it well, and stone thou shalt it find;         *examine, test\n"
  "Since that thou see'st not with thine eyen blind.\n"
  "\n"
  "\"It is a shame that the people shall\n"
  "So scorne thee, and laugh at thy folly;\n"
  "For commonly men *wot it well over all,*            *know it everywhere*\n"
  "That mighty God is in his heaven high;\n"
  "And these images, well may'st thou espy,\n"
  "To thee nor to themselves may not profite,\n"
  "For in effect they be not worth a mite.\"\n"
  "\n"
  "These wordes and such others saide she,\n"
  "And he wax'd wroth, and bade men should her lead\n"
  "Home to her house; \"And in her house,\" quoth he,\n"
  "\"Burn her right in a bath, with flames red.\"\n"
  "And as he bade, right so was done the deed;\n"
  "For in a bath they gan her faste shetten,*                *shut, confine\n"
  "And night and day great fire they under betten.*       *kindled, applied\n"
  "\n"
  "The longe night, and eke a day also,\n"
  "For all the fire, and eke the bathe's heat,\n"
  "She sat all cold, and felt of it no woe,\n"
  "It made her not one droppe for to sweat;\n"
  "But in that bath her life she must lete.*                         *leave\n"
  "For he, Almachius, with full wick' intent,\n"
  "To slay her in the bath his sonde* sent.                 *message, order\n"
  "\n"
  "Three strokes in the neck he smote her tho,*                      *there\n"
  "The tormentor,* but for no manner chance                    *executioner\n"
  "He might not smite her faire neck in two:\n"
  "And, for there was that time an ordinance\n"
  "That no man should do man such penance,*              *severity, torture\n"
  "The fourthe stroke to smite, soft or sore,\n"
  "This tormentor he durste do no more;\n"
  "\n"
  "But half dead, with her necke carven* there                      *gashed\n"
  "He let her lie, and on his way is went.\n"
  "The Christian folk, which that about her were,\n"
  "With sheetes have the blood full fair y-hent;                  *taken up\n"
  "Three dayes lived she in this torment,\n"
  "And never ceased them the faith to teach,\n"
  "That she had foster'd them, she gan to preach.\n"
  "\n"
  "And them she gave her mebles* and her thing,                      *goods\n"
  "And to the Pope Urban betook* them tho;**              *commended **then\n"
  "And said, \"I aske this of heaven's king,\n"
  "To have respite three dayes and no mo',\n"
  "To recommend to you, ere that I go,\n"
  "These soules, lo; and that *I might do wirch*         *cause to be made*\n"
  "Here of mine house perpetually a church.\"\n"
  "\n"
  "Saint Urban, with his deacons, privily\n"
  "The body fetch'd, and buried it by night\n"
  "Among his other saintes honestly;\n"
  "Her house the church of Saint Cecilie hight;*                 *is called\n"
  "Saint Urban hallow'd it, as he well might;\n"
  "In which unto this day, in noble wise,\n"
  "Men do to Christ and to his saint service.\n"
  "\n"
  "\n"
  "Notes to the Nun's Priest's Tale\n"
  "\n"
  "\n"
  "1.  This Tale was originally composed by Chaucer as a separate\n"
  "work, and as such it is mentioned in the \"Legend of Good\n"
  "Women\" under the title of \"The Life of Saint Cecile\".  Tyrwhitt\n"
  "quotes the line in which the author calls himself an \"unworthy\n"
  "son of Eve,\" and that in which he says, \"Yet pray I you, that\n"
  "reade what I write\", as internal evidence that the insertion of the\n"
  "poem in the Canterbury Tales was the result of an afterthought;\n"
  "while the whole tenor of the introduction confirms the belief\n"
  "that Chaucer composed it as a writer or translator -- not,\n"
  "dramatically, as a speaker. The story is almost literally\n"
  "translated from the Life of St Cecilia in the \"Legenda Aurea.\"\n"
  "\n"
  "2. Leas: leash, snare; the same as \"las,\" oftener used by\n"
  "Chaucer.\n"
  "\n"
  "3. The nativity and assumption of the Virgin Mary formed the\n"
  "themes of some of St Bernard's most eloquent sermons.\n"
  "\n"
  "4. Compare with this stanza the fourth stanza of the Prioress's\n"
  "Tale, the substance of which is the same.\n"
  "\n"
  "5. \"But he answered and said, it is not meet to take the\n"
  "children's bread, and cast it to dogs.  And she said, Truth, Lord:\n"
  "yet the dogs eat of the crumbs which fall from their master's\n"
  "table.\" --  Matthew xv. 26, 27.\n"
  "\n"
  "6.  See note 1.\n"
  "\n"
  "7. These are Latin puns: Heaven's lily - \"Coeli lilium\"; The way\n"
  "of blind - \"Caeci via\";  Heaven and Lia - from \"Coeli\", heaven,\n"
  "and \"Ligo,\" to bind; Heaven and Leos - from Coeli and \"Laos,\"\n"
  "(Ionian Greek) or \"Leos\" (Attic Greek), the people. Such\n"
  "punning derivations of proper names were very much in favour\n"
  "in the Middle Ages. The explanations of St Cecilia's name are\n"
  "literally taken from the prologue to the Latin legend.\n"
  "\n"
  "8. This passage suggests Horace's description of the wise man,\n"
  "who, among other things, is \"in se ipse totus, teres, atque\n"
  "rotundus.\" (\"complete in himself, polished and rounded\") --\n"
  "Satires, 2, vii. 80.\n"
  "\n"
  "9. Louting: lingering, or lying concealed; the Latin original has\n"
  "\"Inter sepulchra martyrum latiantem\" (\"hiding among the tombs\n"
  "of martyrs\")\n"
  "\n"
  "10.  The fourteen lines within brackets are supposed to have\n"
  "been originally an interpolation in the Latin legend, from which\n"
  "they are literally translated. They awkwardly interrupt the flow\n"
  "of the narration.\n"
  "\n"
  "11. Engine: wit; the devising or constructive faculty; Latin,\n"
  "\"ingenium.\"\n"
  "\n"
  "12. Cold: wretched, distressful; see note 22 to the Nun's Priest's\n"
  "Tale.\n"
  "\n"
  "13. Corniculere:  The secretary or registrar who was charged\n"
  "with publishing the acts, decrees and orders of the prefect.\n"
  "\n"
  "14. \"I have fought a good fight, I have finished my course, I\n"
  "have kept the faith: Henceforth there is laid up for me a crown\n"
  "of righteousness\" -- 2 Tim. iv. 7, 8.\n"
  "\n"
  "15. Did him to-beat:  Caused him to be cruelly or fatally beaten;\n"
  "the force of the \"to\" is intensive.\n"
  "\n"
  "\n"
  "\n"
  "";
// }

const char canonsYeomansTale0[] PGMSECTION = // { // 26767 bytes
  "THE CANON'S YEOMAN'S TALE. <1>\n"
  "\n"
  "\n"
  "THE PROLOGUE.\n"
  "\n"
  "\n"
  "WHEN ended was the life of Saint Cecile,\n"
  "Ere we had ridden fully five mile, <2>\n"
  "At Boughton-under-Blee us gan o'ertake\n"
  "A man, that clothed was in clothes black,\n"
  "And underneath he wore a white surplice.\n"
  "His hackenay,* which was all pomely-gris,**           *nag **dapple-gray\n"
  "So sweated, that it wonder was to see;\n"
  "It seem'd as he had pricked* miles three.                       *spurred\n"
  "The horse eke that his yeoman rode upon\n"
  "So sweated, that unnethes* might he gon.**                  *hardly **go\n"
  "About the peytrel <3> stood the foam full high;\n"
  "He was of foam, as *flecked as a pie.*           *spotted like a magpie*\n"
  "A maile twyfold <4> on his crupper lay;\n"
  "It seemed that he carried little array;\n"
  "All light for summer rode this worthy man.\n"
  "And in my heart to wonder I began\n"
  "What that he was, till that I understood\n"
  "How that his cloak was sewed to his hood;\n"
  "For which, when I had long advised* me,                      *considered\n"
  "I deemed him some Canon for to be.\n"
  "His hat hung at his back down by a lace,*                          *cord\n"
  "For he had ridden more than trot or pace;\n"
  "He hadde pricked like as he were wood.*                             *mad\n"
  "A clote-leaf* he had laid  under his hood,                * burdock-leaf\n"
  "For sweat, and for to keep his head from heat.\n"
  "But it was joye for to see him sweat;\n"
  "His forehead dropped as a stillatory*                             *still\n"
  "Were full of plantain or of paritory.*                       *wallflower\n"
  "And when that he was come, he gan to cry,\n"
  "\"God save,\" quoth he, \"this jolly company.\n"
  "Fast have I pricked,\" quoth he, \"for your sake,\n"
  "Because that I would you overtake,\n"
  "To riden in this merry company.\"\n"
  "His Yeoman was eke full of courtesy,\n"
  "And saide, \"Sirs, now in the morning tide\n"
  "Out of your hostelry I saw you ride,\n"
  "And warned here my lord and sovereign,\n"
  "Which that to ride with you is full fain,\n"
  "For his disport; he loveth dalliance.\"\n"
  "\"Friend, for thy warning God give thee good chance,\"*           *fortune\n"
  "Said oure Host; \"certain it woulde seem\n"
  "Thy lord were wise, and so I may well deem;\n"
  "He is full jocund also, dare I lay;\n"
  "Can he aught tell a merry tale or tway,\n"
  "With which he gladden may this company?\"\n"
  "\"Who, Sir? my lord? Yea, Sir, withoute lie,\n"
  "He can* of mirth and eke of jollity                               *knows\n"
  "*Not but* enough; also, Sir, truste me,                  *not less than*\n"
  "An* ye him knew all so well as do I,                                 *if\n"
  "Ye would wonder how well and craftily\n"
  "He coulde work, and that in sundry wise.\n"
  "He hath take on him many a great emprise,*            *task, undertaking\n"
  "Which were full hard for any that is here\n"
  "To bring about, but* they of him it lear.**              *unless **learn\n"
  "As homely as he rides amonges you,\n"
  "If ye him knew, it would be for your prow:*                   *advantage\n"
  "Ye woulde not forego his acquaintance\n"
  "For muche good, I dare lay in balance\n"
  "All that I have in my possession.\n"
  "He is a man of high discretion.\n"
  "I warn you well, he is a passing* man.\"       *surpassing, extraordinary\n"
  "Well,\" quoth our Host, \"I pray thee tell me than,\n"
  "Is he a clerk,* or no? Tell what he is.\"                *scholar, priest\n"
  "\"Nay, he is greater than a clerk, y-wis,\"*                    *certainly\n"
  "Saide this Yeoman; \"and, in wordes few,\n"
  "Host, of his craft somewhat I will you shew,\n"
  "I say, my lord can* such a subtlety                               *knows\n"
  "(But all his craft ye may not weet* of me,                        *learn\n"
  "And somewhat help I yet to his working),\n"
  "That all the ground on which we be riding\n"
  "Till that we come to Canterbury town,\n"
  "He could all cleane turnen up so down,\n"
  "And pave it all of silver and of gold.\"\n"
  "And when this Yeoman had this tale told\n"
  "Unto our Host, he said; \"Ben'dicite!\n"
  "This thing is wonder marvellous to me,\n"
  "Since that thy lord is of so high prudence,\n"
  "Because of which men should him reverence,\n"
  "That of his worship* recketh he so lite;**              *honour **little\n"
  "His *overest slop* it is not worth a mite                *upper garment*\n"
  "As in effect to him, so may I go;\n"
  "It is all baudy* and to-tore also.                             *slovenly\n"
  "Why is thy lord so sluttish, I thee pray,\n"
  "And is of power better clothes to bey,*                             *buy\n"
  "If that his deed accordeth with thy speech?\n"
  "Telle me that, and that I thee beseech.\"\n"
  "\n"
  "\"Why?\" quoth this Yeoman, \"whereto ask ye me?\n"
  "God help me so, for he shall never the*                          *thrive\n"
  "(But I will not avowe* that I say,                                *admit\n"
  "And therefore keep it secret, I you pray);\n"
  "He is too wise, in faith, as I believe.\n"
  "Thing that is overdone, it will not preve*               *stand the test\n"
  "Aright, as clerkes say; it is a vice;\n"
  "Wherefore in that I hold him *lewd and nice.\"*    *ignorant and foolish*\n"
  "For when a man hath over great a wit,\n"
  "Full oft him happens to misusen it;\n"
  "So doth my lord, and that me grieveth sore.\n"
  "God it amend; I can say now no more.\"\n"
  "\n"
  "\"Thereof *no force,* good Yeoman, \"quoth our Host;           *no matter*\n"
  "\"Since of the conning* of thy lord, thou know'st,             *knowledge\n"
  "Tell how he doth, I pray thee heartily,\n"
  "Since that be is so crafty and so sly.*                            *wise\n"
  "Where dwelle ye, if it to telle be?\"\n"
  "\"In the suburbes of a town,\" quoth he,\n"
  "\"Lurking in hernes* and in lanes blind,                         *corners\n"
  "Where as these robbers and these thieves by kind*                *nature\n"
  "Holde their privy fearful residence,\n"
  "As they that dare not show their presence,\n"
  "So fare we, if I shall say the soothe.\"*                          *truth\n"
  "\"Yet,\" quoth our Hoste, \"let me talke to thee;\n"
  "Why art thou so discolour'd of thy face?\"\n"
  "\"Peter!\" quoth he, \"God give it harde grace,\n"
  "I am so us'd the hote fire to blow,\n"
  "That it hath changed my colour, I trow;\n"
  "I am not wont in no mirror to pry,\n"
  "But swinke* sore, and learn to multiply. <5>                     *labour\n"
  "We blunder* ever, and poren** in the fire,                  *toil **peer\n"
  "And, for all that, we fail of our desire\n"
  "For ever we lack our conclusion\n"
  "To muche folk we do illusion,\n"
  "And borrow gold, be it a pound or two,\n"
  "Or ten or twelve, or many summes mo',\n"
  "And make them weenen,* at the leaste way,                         *fancy\n"
  "That of a pounde we can make tway.\n"
  "Yet is it false; and aye we have good hope\n"
  "It for to do, and after it we grope:*                    *search, strive\n"
  "But that science is so far us beforn,\n"
  "That we may not, although we had it sworn,\n"
  "It overtake, it slides away so fast;\n"
  "It will us make beggars at the last.\"\n"
  "While this Yeoman was thus in his talking,\n"
  "This Canon drew him near, and heard all thing\n"
  "Which this Yeoman spake, for suspicion\n"
  "Of menne's speech ever had this Canon:\n"
  "For Cato saith, that he that guilty is, <6>\n"
  "Deemeth all things be spoken of him y-wis;*                      *surely\n"
  "Because of that he gan so nigh to draw\n"
  "To his Yeoman, that he heard all his saw;\n"
  "And thus he said unto his Yeoman tho*                              *then\n"
  "\"Hold thou thy peace,and speak no wordes mo':\n"
  "For if thou do, thou shalt *it dear abie.*           *pay dearly for it*\n"
  "Thou slanderest me here in this company\n"
  "And eke discoverest that thou shouldest hide.\"\n"
  "\"Yea,\" quoth our Host, \"tell on, whatso betide;\n"
  "Of all his threatening reck not a mite.\"\n"
  "\"In faith,\" quoth he, \"no more do I but lite.\"*                  *little\n"
  "And when this Canon saw it would not be\n"
  "But his Yeoman would tell his privity,*                         *secrets\n"
  "He fled away for very sorrow and shame.\n"
  "\n"
  "\"Ah!\" quoth the Yeoman, \"here shall rise a game;*        *some diversion\n"
  "All that I can anon I will you tell,\n"
  "Since he is gone; the foule fiend him quell!*                   *destroy\n"
  "For ne'er hereafter will I with him meet,\n"
  "For penny nor for pound, I you behete.*                         *promise\n"
  "He that me broughte first unto that game,\n"
  "Ere that he die, sorrow have he and shame.\n"
  "For it is earnest* to me, by my faith;                 *a serious matter\n"
  "That feel I well, what so any man saith;\n"
  "And yet for all my smart, and all my grief,\n"
  "For all my sorrow, labour, and mischief,*                       *trouble\n"
  "I coulde never leave it in no wise.\n"
  "Now would to God my witte might suffice\n"
  "To tellen all that longeth to that art!\n"
  "But natheless yet will I telle part;\n"
  "Since that my lord is gone, I will not spare;\n"
  "Such thing as that I know, I will declare.\"\n"
  "\n"
  "\n"
  "Notes to the Prologue to the Canon's Yeoman's Tale\n"
  "\n"
  "\n"
  "1. \"The introduction,\" says Tyrwhitt, \"of the Canon's\n"
  "Yeoman to tell a Tale at a time when so many of the original\n"
  "characters remain to be called upon, appears a little\n"
  "extraordinary. It should seem that some sudden resentment\n"
  "had determined Chaucer to interrupt the regular course of his\n"
  "work, in order to insert a satire against the alchemists. That\n"
  "their pretended science was much cultivated about this time,\n"
  "and produced its usual evils, may fairly be inferred from the\n"
  "Act, which was passed soon after, 5 H. IV. c. iv., to make it\n"
  "felony 'to multiply gold or silver, or to use the art of\n"
  "multiplication.'\" Tyrwhitt finds in the prologue some colour\n"
  "for the hypothesis that this Tale was intended by Chaucer to\n"
  "begin the return journey from Canterbury; but against this\n"
  "must be set the fact that the Yeoman himself expressly speaks\n"
  "of the distance to Canterbury yet to be ridden.\n"
  "\n"
  "2. Fully five mile:  From some place which the loss of the\n"
  "Second Nun's Prologue does not enable us to identify.\n"
  "\n"
  "3. Peytrel: the breast-plate of a horse's harness; French,\n"
  "\"poitrail.\"\n"
  "\n"
  "4. A maile twyfold:  a double valise; a wallet hanging across\n"
  "the crupper on either side of the horse.\n"
  "\n"
  "5. Multiply:  transmute metals, in the attempt to multiply gold\n"
  "and silver by alchemy.\n"
  "\n"
  "6. \"Conscius ipse sibi de se putat omnia dici\" (\"The\n"
  "conspirator believes that everything spoken refers to himself\")\n"
  "-- \"De Moribus,\" I. i. dist. 17.\n"
  "\n"
  "\n"
  "THE TALE. <1>\n"
  "\n"
  "\n"
  "With this Canon I dwelt have seven year,\n"
  "And of his science am I ne'er the near*                          *nearer\n"
  "All that I had I have lost thereby,\n"
  "And, God wot, so have many more than I.\n"
  "Where I was wont to be right fresh and gay\n"
  "Of clothing, and of other good array\n"
  "Now may I wear an hose upon mine head;\n"
  "And where my colour was both fresh and red,\n"
  "Now is it wan, and of a leaden hue\n"
  "(Whoso it useth, sore shall he it rue);\n"
  "And of my swink* yet bleared is mine eye;                        *labour\n"
  "Lo what advantage is to multiply!\n"
  "That sliding* science hath me made so bare,         *slippery, deceptive\n"
  "That I have no good,* where that ever I fare;                  *property\n"
  "And yet I am indebted so thereby\n"
  "Of gold, that I have borrow'd truely,\n"
  "That, while I live, I shall it quite* never;                      *repay\n"
  "Let every man beware by me for ever.\n"
  "What manner man that casteth* him thereto,                     *betaketh\n"
  "If he continue, I hold *his thrift y-do;*         *prosperity at an end*\n"
  "So help me God, thereby shall he not win,\n"
  "But empty his purse, and make his wittes thin.\n"
  "And when he, through his madness and folly,\n"
  "Hath lost his owen good through jupartie,*                   *hazard <2>\n"
  "Then he exciteth other men thereto,\n"
  "To lose their good as he himself hath do'.\n"
  "For unto shrewes* joy it is and ease                        *wicked folk\n"
  "To have their fellows in pain and disease.*                     *trouble\n"
  "Thus was I ones learned of a clerk;\n"
  "Of that no charge;* I will speak of our work.                    *matter\n"
  "\n"
  "When we be there as we shall exercise\n"
  "Our elvish* craft, we seeme wonder wise,              *fantastic, wicked\n"
  "Our termes be so *clergial and quaint.*             *learned and strange\n"
  "I blow the fire till that mine hearte faint.\n"
  "Why should I tellen each proportion\n"
  "Of thinges, whiche that we work upon,\n"
  "As on five or six ounces, may well be,\n"
  "Of silver, or some other quantity?\n"
  "And busy me to telle you the names,\n"
  "As orpiment, burnt bones, iron squames,*                     *scales <3>\n"
  "That into powder grounden be full small?\n"
  "And in an earthen pot how put is all,\n"
  "And, salt y-put in, and also peppere,\n"
  "Before these powders that I speak of here,\n"
  "And well y-cover'd with a lamp of glass?\n"
  "And of much other thing which that there was?\n"
  "And of the pots and glasses engluting,*                      *sealing up\n"
  "That of the air might passen out no thing?\n"
  "And of the easy* fire, and smart** also,                   *slow **quick\n"
  "Which that was made? and of the care and woe\n"
  "That we had in our matters subliming,\n"
  "And in amalgaming, and calcining\n"
  "Of quicksilver, called mercury crude?\n"
  "For all our sleightes we can not conclude.\n"
  "Our orpiment, and sublim'd mercury,\n"
  "Our ground litharge* eke on the porphyry,                    *white lead\n"
  "Of each of these of ounces a certain,*               *certain proportion\n"
  "Not helpeth us, our labour is in vain.\n"
  "Nor neither our spirits' ascensioun,\n"
  "Nor our matters that lie all fix'd adown,\n"
  "May in our working nothing us avail;\n"
  "For lost is all our labour and travail,\n"
  "And all the cost, a twenty devil way,\n"
  "Is lost also, which we upon it lay.\n"
  "\n"
  "There is also full many another thing\n"
  "That is unto our craft appertaining,\n"
  "Though I by order them not rehearse can,\n"
  "Because that I am a lewed* man;                               *unlearned\n"
  "Yet will I tell them as they come to mind,\n"
  "Although I cannot set them in their kind,\n"
  "As sal-armoniac, verdigris, borace;\n"
  "And sundry vessels made of earth and glass; <4>\n"
  "Our urinales, and our descensories,\n"
  "Phials, and croslets, and sublimatories,\n"
  "Cucurbites, and alembikes eke,\n"
  "And other suche, *dear enough a leek,*          *worth less than a leek*\n"
  "It needeth not for to rehearse them all.\n"
  "Waters rubifying, and bulles' gall,\n"
  "Arsenic, sal-armoniac, and brimstone,\n"
  "And herbes could I tell eke many a one,\n"
  "As egremoine,* valerian, and lunary,**             *agrimony **moon-wort\n"
  "And other such, if that me list to tarry;\n"
  "Our lampes burning bothe night and day,\n"
  "To bring about our craft if that we may;\n"
  "Our furnace eke of calcination,\n"
  "And of waters albification,\n"
  "Unslaked lime, chalk, and *glair of an ey,*                   *egg-white\n"
  "Powders diverse, ashes, dung, piss, and clay,\n"
  "Seared pokettes,<5> saltpetre, and vitriol;\n"
  "And divers fires made of wood and coal;\n"
  "Sal-tartar, alkali, salt preparate,\n"
  "And combust matters, and coagulate;\n"
  "Clay made with horse and manne's hair, and oil\n"
  "Of tartar, alum, glass, barm, wort, argoil,*           *potter's clay<6>\n"
  "Rosalgar,* and other matters imbibing;              *flowers of antimony\n"
  "And eke of our matters encorporing,*                      *incorporating\n"
  "And of our silver citrination, <7>\n"
  "Our cementing, and fermentation,\n"
  "Our ingots,* tests, and many thinges mo'.                    *moulds <8>\n"
  "I will you tell, as was me taught also,\n"
  "The foure spirits, and the bodies seven,\n"
  "By order, as oft I heard my lord them neven.*                      *name\n"
  "The first spirit Quicksilver called is;\n"
  "The second Orpiment; the third, y-wis,\n"
  "Sal-Armoniac, and the fourth Brimstone.\n"
  "The bodies sev'n eke, lo them here anon.\n"
  "Sol gold is, and Luna silver we threpe*                        *name <9>\n"
  "Mars iron, Mercury quicksilver we clepe;*                          *call\n"
  "Saturnus lead, and Jupiter is tin,\n"
  "And Venus copper, by my father's kin.\n"
  "\n"
  "This cursed craft whoso will exercise,\n"
  "He shall no good have that him may suffice;\n"
  "For all the good he spendeth thereabout,\n"
  "He lose shall, thereof have I no doubt.\n"
  "Whoso that list to utter* his folly,                            *display\n"
  "Let him come forth and learn to multiply:\n"
  "And every man that hath aught in his coffer,\n"
  "Let him appear, and wax a philosopher;\n"
  "Ascaunce* that craft is so light to lear.**               *as if **learn\n"
  "Nay, nay, God wot, all be he monk or frere,\n"
  "Priest or canon, or any other wight;\n"
  "Though he sit at his book both day and night;\n"
  "In learning of this *elvish nice* lore,             * fantastic, foolish\n"
  "All is in vain; and pardie muche more,\n"
  "Is to learn a lew'd* man this subtlety;                        *ignorant\n"
  "Fie! speak not thereof, for it will not be.\n"
  "And *conne he letterure,* or conne he none,       *if he knows learning*\n"
  "As in effect, he shall it find all one;\n"
  "For bothe two, by my salvation,\n"
  "Concluden in multiplication*                   *transmutation by alchemy\n"
  "Alike well, when they have all y-do;\n"
  "This is to say, they faile bothe two.\n"
  "Yet forgot I to make rehearsale\n"
  "Of waters corrosive, and of limaile,*                     *metal filings\n"
  "And of bodies' mollification,\n"
  "And also of their induration,\n"
  "Oiles, ablutions, metal fusible,\n"
  "To tellen all, would passen any Bible\n"
  "That owhere* is; wherefore, as for the best,                   *anywhere\n"
  "Of all these names now will I me rest;\n"
  "For, as I trow, I have you told enough\n"
  "To raise a fiend, all look he ne'er so rough.\n"
  "\n"
  "Ah! nay, let be; the philosopher's stone,\n"
  "Elixir call'd, we seeke fast each one;\n"
  "For had we him, then were we sicker* enow;                       *secure\n"
  "But unto God of heaven I make avow,*                         *confession\n"
  "For all our craft, when we have all y-do,\n"
  "And all our sleight, he will not come us to.\n"
  "He hath y-made us spende muche good,\n"
  "For sorrow of which almost we waxed wood,*                          *mad\n"
  "But that good hope creeped in our heart,\n"
  "Supposing ever, though we sore smart,\n"
  "To be relieved by him afterward.\n"
  "Such supposing and hope is sharp and hard.\n"
  "I warn you well it is to seeken ever.\n"
  "That future temps* hath made men dissever,**          *time  **part from\n"
  "In trust thereof, from all that ever they had,\n"
  "Yet of that art they cannot waxe sad,*                        *repentant\n"
  "For unto them it is a bitter sweet;\n"
  "So seemeth it; for had they but a sheet\n"
  "Which that they mighte wrap them in at night,\n"
  "And a bratt* to walk in by dayelight,                         *cloak<10>\n"
  "They would them sell, and spend it on this craft;\n"
  "They cannot stint,* until no thing be laft.                       *cease\n"
  "And evermore, wherever that they gon,\n"
  "Men may them knowe by smell of brimstone;\n"
  "For all the world they stinken as a goat;\n"
  "Their savour is so rammish and so hot,\n"
  "That though a man a mile from them be,\n"
  "The savour will infect him, truste me.\n"
  "Lo, thus by smelling and threadbare array,\n"
  "If that men list, this folk they knowe may.\n"
  "And if a man will ask them privily,\n"
  "Why they be clothed so unthriftily,*                           *shabbily\n"
  "They right anon will rownen* in his ear,                        *whisper\n"
  "And sayen, if that they espied were,\n"
  "Men would them slay, because of their science:\n"
  "Lo, thus these folk betrayen innocence!\n"
  "\n"
  "Pass over this; I go my tale unto.\n"
  "Ere that the pot be on the fire y-do*                            *placed\n"
  "Of metals, with a certain quantity\n"
  "My lord them tempers,* and no man but he        *adjusts the proportions\n"
  "(Now he is gone, I dare say boldely);\n"
  "For as men say, he can do craftily,\n"
  "Algate* I wot well he hath such a name,                        *although\n"
  "And yet full oft he runneth into blame;\n"
  "And know ye how? full oft it happ'neth so,\n"
  "The pot to-breaks, and farewell! all is go'.*                      *gone\n"
  "These metals be of so great violence,\n"
  "Our walles may not make them resistence,\n"
  "*But if* they were wrought of lime and stone;                   *unless*\n"
  "They pierce so, that through the wall they gon;\n"
  "And some of them sink down into the ground\n"
  "(Thus have we lost by times many a pound),\n"
  "And some are scatter'd all the floor about;\n"
  "Some leap into the roof withoute doubt.\n"
  "Though that the fiend not in our sight him show,\n"
  "I trowe that he be with us, that shrew;*                 *impious wretch\n"
  "In helle, where that he is lord and sire,\n"
  "Is there no more woe, rancour, nor ire.\n"
  "When that our pot is broke, as I have said,\n"
  "Every man chides, and holds him *evil apaid.*             *dissatisfied*\n"
  "Some said it was *long on* the fire-making;            *because of <11>*\n"
  "Some saide nay, it was on the blowing\n"
  "(Then was I fear'd, for that was mine office);\n"
  "\"Straw!\" quoth the third, \"ye be *lewed and **nice,  *ignorant **foolish\n"
  "It was not temper'd* as it ought to be.\"       *mixed in due proportions\n"
  "\"Nay,\" quoth the fourthe, \"stint* and hearken me;                  *stop\n"
  "Because our fire was not y-made of beech,\n"
  "That is the cause, and other none, *so the'ch.*        *so may I thrive*\n"
  "I cannot tell whereon it was along,\n"
  "But well I wot great strife is us among.\"\n"
  "\"What?\" quoth my lord, \"there is no more to do'n,\n"
  "Of these perils I will beware eftsoon.*                    *another time\n"
  "I am right sicker* that the pot was crazed.**            *sure **cracked\n"
  "Be as be may, be ye no thing amazed.*                        *confounded\n"
  "As usage is, let sweep the floor as swithe;*                    *quickly\n"
  "Pluck up your heartes and be glad and blithe.\"\n"
  "\n"
  "The mullok* on a heap y-sweeped was,                            *rubbish\n"
  "And on the floor y-cast a canevas,\n"
  "And all this mullok in a sieve y-throw,\n"
  "And sifted, and y-picked many a throw.*                            *time\n"
  "\"Pardie,\" quoth one, \"somewhat of our metal\n"
  "Yet is there here, though that we have not all.\n"
  "And though this thing *mishapped hath as now,*           *has gone amiss\n"
  "Another time it may be well enow.                            at present*\n"
  "We muste *put our good in adventure; *               *risk our property*\n"
  "A merchant, pardie, may not aye endure,\n"
  "Truste me well, in his prosperity:\n"
  "Sometimes his good is drenched* in the sea,               *drowned, sunk\n"
  "And sometimes comes it safe unto the land.\"\n"
  "\"Peace,\" quoth my lord; \"the next time I will fand*           *endeavour\n"
  "To bring our craft *all in another plight,*  *to a different conclusion*\n"
  "And but I do, Sirs, let me have the wite;*                        *blame\n"
  "There was default in somewhat, well I wot.\"\n"
  "Another said, the fire was over hot.\n"
  "But be it hot or cold, I dare say this,\n"
  "That we concluden evermore amiss;\n"
  "We fail alway of that which we would have;\n"
  "And in our madness evermore we rave.\n"
  "And when we be together every one,\n"
  "Every man seemeth a Solomon.\n"
  "But all thing, which that shineth as the gold,\n"
  "It is not gold, as I have heard it told;\n"
  "Nor every apple that is fair at eye,\n"
  "It is not good, what so men clap* or cry.                        *assert\n"
  "Right so, lo, fareth it amonges us.\n"
  "He that the wisest seemeth, by Jesus,\n"
  "Is most fool, when it cometh to the prefe;*                 *proof, test\n"
  "And he that seemeth truest, is a thief.\n"
  "That shall ye know, ere that I from you wend;\n"
  "By that I of my tale have made an end.\n"
  "\n"
  "There was a canon of religioun\n"
  "Amonges us, would infect* all a town,                           *deceive\n"
  "Though it as great were as was Nineveh,\n"
  "Rome, Alisandre,* Troy, or other three.                      *Alexandria\n"
  "His sleightes* and his infinite falseness                *cunning tricks\n"
  "There coulde no man writen, as I guess,\n"
  "Though that he mighte live a thousand year;\n"
  "In all this world of falseness n'is* his peer.             *there is not\n"
  "For in his termes he will him so wind,\n"
  "And speak his wordes in so sly a kind,\n"
  "When he commune shall with any wight,\n"
  "That he will make him doat* anon aright,               *become foolishly\n"
  "But it a fiende be, as himself is.                          fond of him*\n"
  "Full many a man hath he beguil'd ere this,\n"
  "And will, if that he may live any while;\n"
  "And yet men go and ride many a mile\n"
  "Him for to seek, and have his acquaintance,\n"
  "Not knowing of his false governance.*                 *deceitful conduct\n"
  "And if you list to give me audience,\n"
  "I will it telle here in your presence.\n"
  "But, worshipful canons religious,\n"
  "Ne deeme not that I slander your house,\n"
  "Although that my tale of a canon be.\n"
  "Of every order some shrew is, pardie;\n"
  "And God forbid that all a company\n"
  "Should rue a singular* manne's folly.                        *individual\n"
  "To slander you is no thing mine intent;\n"
  "But to correct that is amiss I meant.\n"
  "This tale was not only told for you,\n"
  "But eke for other more; ye wot well how\n"
  "That amonges Christe's apostles twelve\n"
  "There was no traitor but Judas himselve;\n"
  "Then why should all the remenant have blame,\n"
  "That guiltless were? By you I say the same.\n"
  "Save only this, if ye will hearken me,\n"
  "If any Judas in your convent be,\n"
  "Remove him betimes, I you rede,*                                *counsel\n"
  "If shame or loss may causen any dread.\n"
  "And be no thing displeased, I you pray;\n"
  "But in this case hearken what I say.\n"
  "\n"
  "In London was a priest, an annualere, <12>\n"
  "That therein dwelled hadde many a year,\n"
  "Which was so pleasant and so serviceable\n"
  "Unto the wife, where as he was at table,\n"
  "That she would suffer him no thing to pay\n"
  "For board nor clothing, went he ne'er so gay;\n"
  "And spending silver had he right enow;\n"
  "Thereof no force;* will proceed as now,                       *no matter\n"
  "And telle forth my tale of the canon,\n"
  "That brought this prieste to confusion.\n"
  "This false canon came upon a day\n"
  "Unto the prieste's chamber, where he lay,\n"
  "Beseeching him to lend him a certain\n"
  "Of gold, and he would quit it him again.\n"
  "\"Lend me a mark,\" quoth he, \"but dayes three,\n"
  "And at my day I will it quite thee.\n"
  "And if it so be that thou find me false,\n"
  "Another day hang me up by the halse.\"*                             *neck\n"
  "This priest him took a mark, and that as swithe,*               *quickly\n"
  "And this canon him thanked often sithe,*                          *times\n"
  "And took his leave, and wente forth his way;\n"
  "And at the thirde day brought his money;\n"
  "And to the priest he took his gold again,\n"
  "Whereof this priest was wondrous glad and fain.*                *pleased\n"
  "\"Certes,\" quoth he, *\"nothing annoyeth me*           *I am not unwiling*\n"
  "To lend a man a noble, or two, or three,\n"
  "Or what thing were in my possession,\n"
  "When he so true is of condition,\n"
  "That in no wise he breake will his day;\n"
  "To such a man I never can say nay.\"\n"
  "\"What,\" quoth this canon, \"should I be untrue?\n"
  "Nay, that were *thing y-fallen all of new!*      *a new thing to happen*\n"
  "Truth is a thing that I will ever keep,\n"
  "Unto the day in which that I shall creep\n"
  "Into my grave; and elles God forbid;\n"
  "Believe this as sicker* as your creed.                             *sure\n"
  "God thank I, and in good time be it said,\n"
  "That there was never man yet *evil apaid*     *displeased, dissatisfied*\n"
  "For gold nor silver that he to me lent,\n"
  "Nor ever falsehood in mine heart I meant.\n"
  "And Sir,\" quoth he, \"now of my privity,\n"
  "Since ye so goodly have been unto me,\n"
  "And kithed* to me so great gentleness,                            *shown\n"
  "Somewhat, to quite with your kindeness,\n"
  "I will you shew, and if you list to lear,*                        *learn\n"
  "I will you teache plainly the mannere\n"
  "How I can worken in philosophy.\n"
  "Take good heed, ye shall well see *at eye*           *with your own eye*\n"
  "That I will do a mas'try ere I go.\"\n"
  "\"Yea,\" quoth the priest; \"yea, Sir, and will ye so?\n"
  "Mary! thereof I pray you heartily.\"\n"
  "\"At your commandement, Sir, truely,\"\n"
  "Quoth the canon, \"and elles God forbid.\"\n"
  "Lo, how this thiefe could his service bede!*                      *offer\n"
  "\n"
  "";
// }

const char canonsYeomansTale1[] PGMSECTION = // { // 25078 bytes
  "Full sooth it is that such proffer'd service\n"
  "Stinketh, as witnesse *these olde wise;*        *those wise folk of old*\n"
  "And that full soon I will it verify\n"
  "In this canon, root of all treachery,\n"
  "That evermore delight had and gladness\n"
  "(Such fiendly thoughtes *in his heart impress*)   *press into his heart*\n"
  "How Christe's people he may to mischief bring.\n"
  "God keep us from his false dissimuling!\n"
  "What wiste this priest with whom that he dealt?\n"
  "Nor of his harm coming he nothing felt.\n"
  "O sely* priest, O sely innocent!                                 *simple\n"
  "With covetise anon thou shalt be blent;*              *blinded; beguiled\n"
  "O graceless, full blind is thy conceit!\n"
  "For nothing art thou ware of the deceit\n"
  "Which that this fox y-shapen* hath to thee;                   *contrived\n"
  "His wily wrenches* thou not mayest flee.                         *snares\n"
  "Wherefore, to go to the conclusioun\n"
  "That referreth to thy confusion,\n"
  "Unhappy man, anon I will me hie*                                 *hasten\n"
  "To telle thine unwit* and thy folly,                          *stupidity\n"
  "And eke the falseness of that other wretch,\n"
  "As farforth as that my conning* will stretch.                 *knowledge\n"
  "This canon was my lord, ye woulde ween;*                        *imagine\n"
  "Sir Host, in faith, and by the heaven's queen,\n"
  "It was another canon, and not he,\n"
  "That can* an hundred fold more subtlety.                          *knows\n"
  "He hath betrayed folkes many a time;\n"
  "Of his falseness it doleth* me to rhyme.                        *paineth\n"
  "And ever, when I speak of his falsehead,\n"
  "For shame of him my cheekes waxe red;\n"
  "Algates* they beginne for to glow,                             *at least\n"
  "For redness have I none, right well I know,\n"
  "In my visage; for fumes diverse\n"
  "Of metals, which ye have me heard rehearse,\n"
  "Consumed have and wasted my redness.\n"
  "Now take heed of this canon's cursedness.*                     *villainy\n"
  "\n"
  "\"Sir,\" quoth he to the priest, \"let your man gon\n"
  "For quicksilver, that we it had anon;\n"
  "And let him bringen ounces two or three;\n"
  "And when he comes, as faste shall ye see\n"
  "A wondrous thing, which ye saw ne'er ere this.\"\n"
  "\"Sir,\" quoth the priest, \"it shall be done, y-wis.\"*          *certainly\n"
  "He bade his servant fetche him this thing,\n"
  "And he all ready was at his bidding,\n"
  "And went him forth, and came anon again\n"
  "With this quicksilver, shortly for to sayn;\n"
  "And took these ounces three to the canoun;\n"
  "And he them laide well and fair adown,\n"
  "And bade the servant coales for to bring,\n"
  "That he anon might go to his working.\n"
  "The coales right anon weren y-fet,*                             *fetched\n"
  "And this canon y-took a crosselet*                             *crucible\n"
  "Out of his bosom, and shew'd to the priest.\n"
  "\"This instrument,\" quoth he, \"which that thou seest,\n"
  "Take in thine hand, and put thyself therein\n"
  "Of this quicksilver an ounce, and here begin,\n"
  "In the name of Christ, to wax a philosopher.\n"
  "There be full few, which that I woulde proffer\n"
  "To shewe them thus much of my science;\n"
  "For here shall ye see by experience\n"
  "That this quicksilver I will mortify,<13>\n"
  "Right in your sight anon withoute lie,\n"
  "And make it as good silver, and as fine,\n"
  "As there is any in your purse, or mine,\n"
  "Or elleswhere; and make it malleable,\n"
  "And elles holde me false and unable\n"
  "Amonge folk for ever to appear.\n"
  "I have a powder here that cost me dear,\n"
  "Shall make all good, for it is cause of all\n"
  "My conning,* which that I you shewe shall.                    *knowledge\n"
  "Voide* your man, and let him be thereout;                     *send away\n"
  "And shut the doore, while we be about\n"
  "Our privity, that no man us espy,\n"
  "While that we work in this phiosophy.\"\n"
  "All, as he bade, fulfilled was in deed.\n"
  "This ilke servant right anon out yede,*                            *went\n"
  "And his master y-shut the door anon,\n"
  "And to their labour speedily they gon.\n"
  "\n"
  "This priest, at this cursed canon's biddIng,\n"
  "Upon the fire anon he set this thing,\n"
  "And blew the fire, and busied him full fast.\n"
  "And this canon into the croslet cast\n"
  "A powder, I know not whereof it was\n"
  "Y-made, either of chalk, either of glass,\n"
  "Or somewhat elles, was not worth a fly,\n"
  "To blinden* with this priest; and bade him hie**   *deceive **make haste\n"
  "The coales for to couchen* all above                        lay in order\n"
  "The croslet; \"for, in token I thee love,\"\n"
  "Quoth this canon, \"thine owen handes two\n"
  "Shall work all thing that here shall be do'.\"\n"
  "*\"Grand mercy,\"* quoth the priest, and was full glad,     *great thanks*\n"
  "And couch'd the coales as the canon bade.\n"
  "And while he busy was, this fiendly wretch,\n"
  "This false canon (the foule fiend him fetch),\n"
  "Out of his bosom took a beechen coal,\n"
  "In which full subtifly was made a hole,\n"
  "And therein put was of silver limaile*                          *filings\n"
  "An ounce, and stopped was withoute fail\n"
  "The hole with wax, to keep the limaile in.\n"
  "And understande, that this false gin*                       *contrivance\n"
  "Was not made there, but it was made before;\n"
  "And other thinges I shall tell you more,\n"
  "Hereafterward, which that he with him brought;\n"
  "Ere he came there, him to beguile he thought,\n"
  "And so he did, ere that they *went atwin;*                   *separated*\n"
  "Till he had turned him, could he not blin.*                  *cease <14>\n"
  "It doleth* me, when that I of him speak;                        *paineth\n"
  "On his falsehood fain would I me awreak,*                *revenge myself\n"
  "If I wist how, but he is here and there;\n"
  "He is so variant,* he abides nowhere.                        *changeable\n"
  "\n"
  "But take heed, Sirs, now for Godde's love.\n"
  "He took his coal, of which I spake above,\n"
  "And in his hand he bare it privily,\n"
  "And while the prieste couched busily\n"
  "The coales, as I tolde you ere this,\n"
  "This canon saide, \"Friend, ye do amiss;\n"
  "This is not couched as it ought to be,\n"
  "But soon I shall amenden it,\" quoth he.\n"
  "\"Now let me meddle therewith but a while,\n"
  "For of you have I pity, by Saint Gile.\n"
  "Ye be right hot, I see well how ye sweat;\n"
  "Have here a cloth, and wipe away the wet.\"\n"
  "And while that the prieste wip'd his face,\n"
  "This canon took his coal, -- *with sorry grace,* --        *evil fortune\n"
  "And layed it above on the midward                           attend him!*\n"
  "Of the croslet, and blew well afterward,\n"
  "Till that the coals beganne fast to brenn.*                        *burn\n"
  "\"Now give us drinke,\" quoth this canon then,\n"
  "\"And swithe* all shall be well, I undertake.                    *quickly\n"
  "Sitte we down, and let us merry make.\"\n"
  "And whenne that this canon's beechen coal\n"
  "Was burnt, all the limaile out of the hole\n"
  "Into the crosselet anon fell down;\n"
  "And so it muste needes, by reasoun,\n"
  "Since it above so *even couched* was;                     *exactly laid*\n"
  "But thereof wist the priest no thing, alas!\n"
  "He deemed all the coals alike good,\n"
  "For of the sleight he nothing understood.\n"
  "\n"
  "And when this alchemister saw his time,\n"
  "\"Rise up, Sir Priest,\" quoth he, \"and stand by me;\n"
  "And, for I wot well ingot* have ye none;                          *mould\n"
  "Go, walke forth, and bring me a chalk stone;\n"
  "For I will make it of the same shape\n"
  "That is an ingot, if I may have hap.\n"
  "Bring eke with you a bowl, or else a pan,\n"
  "Full of water, and ye shall well see than*                         *then\n"
  "How that our business shall *hap and preve*                    *succeed*\n"
  "And yet, for ye shall have no misbelieve*                      *mistrust\n"
  "Nor wrong conceit of me, in your absence,\n"
  "I wille not be out of your presence,\n"
  "But go with you, and come with you again.\"\n"
  "The chamber-doore, shortly for to sayn,\n"
  "They opened and shut, and went their way,\n"
  "And forth with them they carried the key;\n"
  "And came again without any delay.\n"
  "Why should I tarry all the longe day?\n"
  "He took the chalk, and shap'd it in the wise\n"
  "Of an ingot, as I shall you devise;*                           *describe\n"
  "I say, he took out of his owen sleeve\n"
  "A teine* of silver (evil may he cheve!**)        *little piece **prosper\n"
  "Which that ne was but a just ounce of weight.\n"
  "And take heed now of his cursed sleight;\n"
  "He shap'd his ingot, in length and in brede*                    *breadth\n"
  "Of this teine, withouten any drede,*                              *doubt\n"
  "So slily, that the priest it not espied;\n"
  "And in his sleeve again he gan it hide;\n"
  "And from the fire he took up his mattere,\n"
  "And in th' ingot put it with merry cheer;\n"
  "And in the water-vessel he it cast,\n"
  "When that him list, and bade the priest as fast\n"
  "Look what there is; \"Put in thine hand and grope;\n"
  "There shalt thou finde silver, as I hope.\"\n"
  "What, devil of helle! should it elles be?\n"
  "Shaving of silver, silver is, pardie.\n"
  "He put his hand in, and took up a teine\n"
  "Of silver fine; and glad in every vein\n"
  "Was this priest, when he saw that it was so.\n"
  "\"Godde's blessing, and his mother's also,\n"
  "And alle hallows,* have ye, Sir Canon!\"                          *saints\n"
  "Saide this priest, \"and I their malison*                          *curse\n"
  "But, an'* ye vouchesafe to teache me                                 *if\n"
  "This noble craft and this subtility,\n"
  "I will be yours in all that ever I may.\"\n"
  "Quoth the canon, \"Yet will I make assay\n"
  "The second time, that ye may take heed,\n"
  "And be expert of this, and, in your need,\n"
  "Another day assay in mine absence\n"
  "This discipline, and this crafty science.\n"
  "Let take another ounce,\" quoth he tho,*                            *then\n"
  "\"Of quicksilver, withoute wordes mo',\n"
  "And do therewith as ye have done ere this\n"
  "With that other, which that now silver is. \"\n"
  "\n"
  "The priest him busied, all that e'er he can,\n"
  "To do as this canon, this cursed man,\n"
  "Commanded him, and fast he blew the fire\n"
  "For to come to th' effect of his desire.\n"
  "And this canon right in the meanewhile\n"
  "All ready was this priest eft* to beguile,                        *again\n"
  "and, for a countenance,* in his hande bare                    *stratagem\n"
  "An hollow sticke (take keep* and beware);                          *heed\n"
  "Of silver limaile put was, as before\n"
  "Was in his coal, and stopped with wax well\n"
  "For to keep in his limaile every deal.*                        *particle\n"
  "And while this priest was in his business,\n"
  "This canon with his sticke gan him dress*                         *apply\n"
  "To him anon, and his powder cast in,\n"
  "As he did erst (the devil out of his skin\n"
  "Him turn, I pray to God, for his falsehead,\n"
  "For he was ever false in thought and deed),\n"
  "And with his stick, above the crosselet,\n"
  "That was ordained* with that false get,**        *provided **contrivance\n"
  "He stirr'd the coales, till relente gan\n"
  "The wax against the fire, as every man,\n"
  "But he a fool be, knows well it must need.\n"
  "And all that in the sticke was out yede,*                          *went\n"
  "And in the croslet hastily* it fell.                            *quickly\n"
  "Now, goode Sirs, what will ye bet* than well?                    *better\n"
  "When that this priest was thus beguil'd again,\n"
  "Supposing naught but truthe, sooth to sayn,\n"
  "He was so glad, that I can not express\n"
  "In no mannere his mirth and his gladness;\n"
  "And to the canon he proffer'd eftsoon*                 *forthwith; again\n"
  "Body and good. \"Yea,\" quoth the canon soon,\n"
  "\"Though poor I be, crafty* thou shalt me find;                  *skilful\n"
  "I warn thee well, yet is there more behind.\n"
  "Is any copper here within?\" said he.\n"
  "\"Yea, Sir,\" the prieste said, \"I trow there be.\"\n"
  "\"Elles go buy us some, and that as swithe.*                     *swiftly\n"
  "Now, goode Sir, go forth thy way and hie* thee.\"                 *hasten\n"
  "He went his way, and with the copper came,\n"
  "And this canon it in his handes name,*                        *took <15>\n"
  "And of that copper weighed out an ounce.\n"
  "Too simple is my tongue to pronounce,\n"
  "As minister of my wit, the doubleness\n"
  "Of this canon, root of all cursedness.\n"
  "He friendly seem'd to them that knew him not;\n"
  "But he was fiendly, both in work and thought.\n"
  "It wearieth me to tell of his falseness;\n"
  "And natheless yet will I it express,\n"
  "To that intent men may beware thereby,\n"
  "And for none other cause truely.\n"
  "He put this copper in the crosselet,\n"
  "And on the fire as swithe* he hath it set,                      *swiftly\n"
  "And cast in powder, and made the priest to blow,\n"
  "And in his working for to stoope low,\n"
  "As he did erst,* and all was but a jape;**               *before **trick\n"
  "Right as him list the priest *he made his ape.*           *befooled him*\n"
  "And afterward in the ingot he it cast,\n"
  "And in the pan he put it at the last\n"
  "Of water, and in he put his own hand;\n"
  "And in his sleeve, as ye beforehand\n"
  "Hearde me tell, he had a silver teine;*                     *small piece\n"
  "He silly took it out, this cursed heine*                         *wretch\n"
  "(Unweeting* this priest of his false craft),               *unsuspecting\n"
  "And in the panne's bottom he it laft*                              *left\n"
  "And in the water rumbleth to and fro,\n"
  "And wondrous privily took up also\n"
  "The copper teine (not knowing thilke priest),\n"
  "And hid it, and him hente* by the breast,                          *took\n"
  "And to him spake, and thus said in his game;\n"
  "\"Stoop now adown; by God, ye be to blame;\n"
  "Helpe me now, as I did you whilere;*                             *before\n"
  "Put in your hand, and looke what is there.\"\n"
  "\n"
  "This priest took up this silver teine anon;\n"
  "And thenne said the canon, \"Let us gon,\n"
  "With these three teines which that we have wrought,\n"
  "To some goldsmith, and *weet if they be aught:*    *find out if they are\n"
  "For, by my faith, I would not for my hood                worth anything*\n"
  "*But if* they were silver fine and good,                         *unless\n"
  "And that as swithe* well proved shall it be.\"                   *quickly\n"
  "Unto the goldsmith with these teines three\n"
  "They went anon, and put them in assay*                            *proof\n"
  "To fire and hammer; might no man say nay,\n"
  "But that they weren as they ought to be.\n"
  "This sotted* priest, who gladder was than he?          *stupid, besotted\n"
  "Was never bird gladder against the day;\n"
  "Nor nightingale in the season of May\n"
  "Was never none, that better list to sing;\n"
  "Nor lady lustier in carolling,\n"
  "Or for to speak of love and womanhead;\n"
  "Nor knight in arms to do a hardy deed,\n"
  "To standen in grace of his lady dear,\n"
  "Than had this priest this crafte for to lear;\n"
  "And to the canon thus he spake and said;\n"
  "\"For love of God, that for us alle died,\n"
  "And as I may deserve it unto you,\n"
  "What shall this receipt coste? tell me now.\"\n"
  "\"By our Lady,\" quoth this canon, \"it is dear.\n"
  "I warn you well, that, save I and a frere,\n"
  "In Engleland there can no man it make.\"\n"
  "*\"No force,\"* quoth he; \"now, Sir, for Godde's sake,          *no matter\n"
  "What shall I pay? telle me, I you pray.\"\n"
  "\"Y-wis,\"* quoth he, \"it is full dear, I say.                  *certainly\n"
  "Sir, at one word, if that you list it have,\n"
  "Ye shall pay forty pound, so God me save;\n"
  "And n'ere* the friendship that ye did ere this          *were it not for\n"
  "To me, ye shoulde paye more, y-wis.\"\n"
  "This priest the sum of forty pound anon\n"
  "Of nobles fet,* and took them every one                         *fetched\n"
  "To this canon, for this ilke receipt.\n"
  "All his working was but fraud and deceit.\n"
  "\"Sir Priest,\" he said, \"I keep* to have no los**     *care **praise <16>\n"
  "Of my craft, for I would it were kept close;\n"
  "And as ye love me, keep it secre:\n"
  "For if men knewen all my subtlety,\n"
  "By God, they woulde have so great envy\n"
  "To me, because of my philosophy,\n"
  "I should be dead, there were no other way.\"\n"
  "\"God it forbid,\" quoth the priest, \"what ye say.\n"
  "Yet had I lever* spenden all the good                            *rather\n"
  "Which that I have (and elles were I wood*),                         *mad\n"
  "Than that ye shoulde fall in such mischief.\"\n"
  "\"For your good will, Sir, have ye right good prefe,\"*   *results of your\n"
  "Quoth the canon; \"and farewell, grand mercy.\"              *experiments*\n"
  "He went his way, and never the priest him sey *                     *saw\n"
  "After that day; and when that this priest should\n"
  "Maken assay, at such time as he would,\n"
  "Of this receipt, farewell! it would not be.\n"
  "Lo, thus bejaped* and beguil'd was he;                          *tricked\n"
  "Thus made he his introduction\n"
  "To bringe folk to their destruction.\n"
  "\n"
  "Consider, Sirs, how that in each estate\n"
  "Betwixte men and gold there is debate,\n"
  "So farforth that *unnethes is there none.*       *scarcely is there any*\n"
  "This multiplying blint* so many a one,                  *blinds, deceive\n"
  "That in good faith I trowe that it be\n"
  "The cause greatest of such scarcity.\n"
  "These philosophers speak so mistily\n"
  "In this craft, that men cannot come thereby,\n"
  "For any wit that men have how-a-days.\n"
  "They may well chatter, as do these jays,\n"
  "And in their termes set their *lust and pain,*   *pleasure and exertion*\n"
  "But to their purpose shall they ne'er attain.\n"
  "A man may lightly* learn, if he have aught,                      *easily\n"
  "To multiply, and bring his good to naught.\n"
  "Lo, such a lucre* is in this lusty** game;            *profit **pleasant\n"
  "A manne's mirth it will turn all to grame,*                 *sorrow <17>\n"
  "And empty also great and heavy purses,\n"
  "And make folke for to purchase curses\n"
  "Of them that have thereto their good y-lent.\n"
  "Oh, fy for shame! they that have been brent,*                     *burnt\n"
  "Alas! can they not flee the fire's heat?\n"
  "Ye that it use, I rede* that ye it lete,**               *advise **leave\n"
  "Lest ye lose all; for better than never is late;\n"
  "Never to thrive, were too long a date.\n"
  "Though ye prowl aye, ye shall it never find;\n"
  "Ye be as bold as is Bayard the blind,\n"
  "That blunders forth, and *peril casteth none;*     *perceives no danger*\n"
  "He is as bold to run against a stone,\n"
  "As for to go beside it in the way:\n"
  "So fare ye that multiply, I say.\n"
  "If that your eyen cannot see aright,\n"
  "Look that your minde lacke not his sight.\n"
  "For though you look never so broad, and stare,\n"
  "Ye shall not win a mite on that chaffare,*            *traffic, commerce\n"
  "But wasten all that ye may *rape and renn.*       *get by hook or crook*\n"
  "Withdraw the fire, lest it too faste brenn;*                       *burn\n"
  "Meddle no more with that art, I mean;\n"
  "For if ye do, your thrift* is gone full clean.               *prosperity\n"
  "And right as swithe* I will you telle here                      *quickly\n"
  "What philosophers say in this mattere.\n"
  "\n"
  "Lo, thus saith Arnold of the newe town, <18>\n"
  "As his Rosary maketh mentioun,\n"
  "He saith right thus, withouten any lie;\n"
  "\"There may no man mercury mortify,<13>\n"
  "But* it be with his brother's knowledging.\"                      *except\n"
  "Lo, how that he, which firste said this thing,\n"
  "Of philosophers father was, Hermes;<19>\n"
  "He saith, how that the dragon doubteless\n"
  "He dieth not, but if that he be slain\n"
  "With his brother. And this is for to sayn,\n"
  "By the dragon, Mercury, and none other,\n"
  "He understood, and Brimstone by his brother,\n"
  "That out of Sol and Luna were y-draw.*                   *drawn, derived\n"
  "\"And therefore,\" said he, \"take heed to my saw.                  *saying\n"
  "Let no man busy him this art to seech,*                  *study, explore\n"
  "*But if* that he th'intention and speech                         *unless\n"
  "Of philosophers understande can;\n"
  "And if he do, he is a lewed* man.                     *ignorant, foolish\n"
  "For this science and this conning,\"* quoth he,                *knowledge\n"
  "\"Is of the secret of secrets <20> pardie.\"\n"
  "Also there was a disciple of Plato,\n"
  "That on a time said his master to,\n"
  "As his book, Senior, <21> will bear witness,\n"
  "And this was his demand in soothfastness:\n"
  "\"Tell me the name of thilke* privy** stone.\"              *that **secret\n"
  "And Plato answer'd unto him anon;\n"
  "\"Take the stone that Titanos men name.\"\n"
  "\"Which is that?\" quoth he. \"Magnesia is the same,\"\n"
  "Saide Plato. \"Yea, Sir, and is it thus?\n"
  "This is ignotum per ignotius. <22>\n"
  "What is Magnesia, good Sir, I pray?\"\n"
  "\"It is a water that is made, I say,\n"
  "Of th' elementes foure,\" quoth Plato.\n"
  "\"Tell me the roote, good Sir,\" quoth he tho,*                      *then\n"
  "\"Of that water, if that it be your will.\"\n"
  "\"Nay, nay,\" quoth Plato, \"certain that I n'ill.*               *will not\n"
  "The philosophers sworn were every one,\n"
  "That they should not discover it to none,\n"
  "Nor in no book it write in no mannere;\n"
  "For unto God it is so lefe* and dear,                          *precious\n"
  "That he will not that it discover'd be,\n"
  "But where it liketh to his deity\n"
  "Man for to inspire, and eke for to defend'*                     *protect\n"
  "Whom that he liketh; lo, this is the end.\"\n"
  "\n"
  "Then thus conclude I, since that God of heaven\n"
  "Will not that these philosophers neven*                            *name\n"
  "How that a man shall come unto this stone,\n"
  "I rede* as for the best to let it gon.                          *counsel\n"
  "For whoso maketh God his adversary,\n"
  "As for to work any thing in contrary\n"
  "Of his will, certes never shall he thrive,\n"
  "Though that he multiply term of his live. <23>\n"
  "And there a point;* for ended is my tale.                           *end\n"
  "God send ev'ry good man *boot of his bale.*      *remedy for his sorrow*\n"
  "\n"
  "\n"
  "Note to the Canon's Yeoman's Tale\n"
  "\n"
  "\n"
  "1.  The Tale of the Canon's Yeoman, like those of the Wife of\n"
  "Bath and the Pardoner, is made up of two parts; a long\n"
  "general introduction, and the story proper. In the case of the\n"
  "Wife of Bath, the interruptions of other pilgrims, and the\n"
  "autobiographical nature of the discourse, recommend the\n"
  "separation of the prologue from the Tale proper; but in the\n"
  "other cases the introductory or merely connecting matter\n"
  "ceases wholly where the opening of \"The Tale\" has been\n"
  "marked in the text.\n"
  "\n"
  "2. Jupartie: Jeopardy, hazard.  In Froissart's French, \"a jeu\n"
  "partie\" is used to signify a game or contest in which the\n"
  "chances were exactly equal for both sides.\n"
  "\n"
  "3. Squames: Scales; Latin, \"squamae.\"\n"
  "\n"
  "4. Descensories: vessels for distillation \"per descensum;\" they\n"
  "were placed under the fire, and the spirit to be extracted was\n"
  "thrown downwards.\n"
  "Croslets: crucibles; French, \"creuset.\".\n"
  "Cucurbites: retorts; distilling-vessels; so called from their\n"
  "likeness in shape to a gourd -- Latin, \"cucurbita.\"\n"
  "Alembikes:stills, limbecs.\n"
  "\n"
  "5. Seared pokettes: the meaning of this phrase is obscure; but\n"
  "if we take the reading \"cered poketts,\" from the Harleian\n"
  "manuscript, we are led to the supposition that it signifies\n"
  "receptacles -- bags or pokes -- prepared with wax for some\n"
  "process. Latin, \"cera,\" wax.\n"
  "\n"
  "6. Argoil: potter's clay, used for luting or closing vessels in\n"
  "the laboratories of the alchemists; Latin, \"argilla;\" French,\n"
  "\"argile.\"\n"
  "\n"
  "7. Citrination: turning to a citrine colour, or yellow, by\n"
  "chemical action; that was the colour which proved the\n"
  "philosopher's stone.\n"
  "\n"
  "8. Ingots: not, as in its modern meaning, the masses of metal\n"
  "shaped by pouring into moulds; but the moulds themslves into\n"
  "which the fused metal was poured. Compare Dutch,\n"
  "\"ingieten,\" part. \"inghehoten,\" to infuse; German,\n"
  "\"eingiessen,\" part. \"eingegossen,\" to pour in.\n"
  "\n"
  "9. Threpe: name; from Anglo-Saxon, \"threapian.\"\n"
  "\n"
  "10. Bratt:  coarse cloak; Anglo-Saxon, \"bratt.\" The word is\n"
  "still used in Lincolnshire, and some parts of the north, to\n"
  "signify a coarse kind of apron.\n"
  "\n"
  "11. Long on: in consequence of; the modern vulgar phrase \"all\n"
  "along of,\" or \"all along on,\" best conveys the force of the\n"
  "words in the text.\n"
  "\n"
  "12. Annualere: a priest employed in singing \"annuals\" or\n"
  "anniversary masses for the dead, without any cure of souls;\n"
  "the office was such as, in the Prologue to the Tales, Chaucer\n"
  "praises the Parson for not seeking: Nor \"ran unto London,\n"
  "unto Saint Poul's, to seeke him a chantery for souls.\"\n"
  "\n"
  "13. Mortify:  a chemical phrase, signifying the dissolution of\n"
  "quicksilver in acid.\n"
  "\n"
  "14. Blin: cease; from Anglo-Saxon, \"blinnan,\" to desist.\n"
  "\n"
  "15. Name: took; from Anglo-Saxon, \"niman,\" to take.\n"
  "Compare German, \"nehmen,\" \"nahm.\"\n"
  "\n"
  "16. Los: praise, reputataion. See note 5 to Chaucer's tale of\n"
  "Meliboeus.\n"
  "\n"
  "17. Grame: sorrow; Anglo-Saxon, \"gram;\" German, \"Gram.\"\n"
  "\n"
  "18. Arnaldus Villanovanus, or Arnold de Villeneuve, was a\n"
  "distinguished French chemist and physician of the fourteenth\n"
  "century; his \"Rosarium Philosophorum\" was a favourite text-book\n"
  "with the alchemists of the generations that succeeded.\n"
  "\n"
  "19. Hermes Trismegistus, counsellor of Osiris, King of\n"
  "Egypt, was credited with the invention of writing and\n"
  "hieroglyphics, the drawing up of the laws of the Egyptians,\n"
  "and the origination of many sciences and arts. The\n"
  "Alexandrian school ascribed to him the mystic learning which\n"
  "it amplified; and the scholars of the Middle Ages regarded\n"
  "with enthusiasm and reverence the works attributed to him --\n"
  "notably a treatise on the philosopher's stone.\n"
  "\n"
  "20. Secret of secrets: \"Secreta Secretorum;\" a treatise, very\n"
  "popular in the Middle Ages, supposed to contain the sum of\n"
  "Aristotle's instructions to Alexander. Lydgate translated about\n"
  "half of the work, when his labour was interrupted by his death\n"
  "about 1460; and from the same treatise had been taken most\n"
  "of the seventh book of Gower's \"Confessio Amantis.\"\n"
  "\n"
  "21. Tyrwhitt says that this book was printed in the \"Theatrum\n"
  "Chemicum,\" under the title, \"Senioris Zadith fi. Hamuelis\n"
  "tabula chymica\" (\"The chemical tables of Senior Zadith, son\n"
  "of Hamuel\"); and the story here told of Plato and his disciple\n"
  "was there related of Solomon, but with some variations.\n"
  "\n"
  "22. Ignotum per ignotius: To explain the unknown by the\n"
  "more unknown.\n"
  "\n"
  "23. Though he multiply term of his live: Though he pursue the\n"
  "alchemist's art all his days.\n"
  "\n"
  "\n"
  "\n"
  "";
// }

const char manciplesTale[] PGMSECTION = // { // 20690 bytes
  "THE MANCIPLE'S TALE.\n"
  "\n"
  "\n"
  "THE PROLOGUE.\n"
  "\n"
  "\n"
  "WEET* ye not where there stands a little town,                     *know\n"
  "Which that y-called is Bob-up-and-down, <1>\n"
  "Under the Blee, in Canterbury way?\n"
  "There gan our Hoste for to jape and play,\n"
  "And saide, \"Sirs, what? Dun is in the mire.<2>\n"
  "Is there no man, for prayer nor for hire,\n"
  "That will awaken our fellow behind?\n"
  "A thief him might full* rob and bind                             *easily\n"
  "See how he nappeth, see, for cocke's bones,\n"
  "As he would falle from his horse at ones.\n"
  "Is that a Cook of London, with mischance? <3>\n"
  "Do* him come forth, he knoweth his penance;                        *make\n"
  "For he shall tell a tale, by my fay,*                             *faith\n"
  "Although it be not worth a bottle hay.\n"
  "\n"
  "Awake, thou Cook,\" quoth he; \"God give thee sorrow\n"
  "What aileth thee to sleepe *by the morrow?*            *in the day time*\n"
  "Hast thou had fleas all night, or art drunk?\n"
  "Or had thou with some quean* all night y-swunk,**      *whore **laboured\n"
  "So that thou mayest not hold up thine head?\"\n"
  "The Cook, that was full pale and nothing red,\n"
  "Said to Host, \"So God my soule bless,\n"
  "As there is fall'n on me such heaviness,\n"
  "I know not why, that me were lever* sleep,                       *rather\n"
  "Than the best gallon wine that is in Cheap.\"\n"
  "\"Well,\" quoth the Manciple, \"if it may do ease\n"
  "To thee, Sir Cook, and to no wight displease\n"
  "Which that here rideth in this company,\n"
  "And that our Host will of his courtesy,\n"
  "I will as now excuse thee of thy tale;\n"
  "For in good faith thy visage is full pale:\n"
  "Thine eyen daze,* soothly as me thinketh,                       *are dim\n"
  "And well I wot, thy breath full soure stinketh,\n"
  "That sheweth well thou art not well disposed;\n"
  "Of me certain thou shalt not be y-glosed.*                    *flattered\n"
  "See how he yawneth, lo, this drunken wight,\n"
  "As though he would us swallow anon right.\n"
  "Hold close thy mouth, man, by thy father's kin;\n"
  "The devil of helle set his foot therein!\n"
  "Thy cursed breath infecte will us all:\n"
  "Fy! stinking swine, fy! foul may thee befall.\n"
  "Ah! take heed, Sirs, of this lusty man.\n"
  "Now, sweete Sir, will ye joust at the fan?<4>\n"
  "Thereto, me thinketh, ye be well y-shape.\n"
  "I trow that ye have drunken wine of ape,<5>\n"
  "And that is when men playe with a straw.\"\n"
  "\n"
  "And with this speech the Cook waxed all wraw,*                 *wrathful\n"
  "And on the Manciple he gan nod fast\n"
  "For lack of speech; and down his horse him cast,\n"
  "Where as he lay, till that men him up took.\n"
  "This was a fair chevachie* of a cook:                *cavalry expedition\n"
  "Alas! that he had held him by his ladle!\n"
  "And ere that he again were in the saddle\n"
  "There was great shoving bothe to and fro\n"
  "To lift him up, and muche care and woe,\n"
  "So unwieldy was this silly paled ghost.\n"
  "And to the Manciple then spake our Host:\n"
  "\"Because that drink hath domination\n"
  "Upon this man, by my salvation\n"
  "I trow he lewedly* will tell his tale.                         *stupidly\n"
  "For were it wine, or old or moisty* ale,                            *new\n"
  "That he hath drunk, he speaketh in his nose,\n"
  "And sneezeth fast, and eke he hath the pose <6>\n"
  "He also hath to do more than enough\n"
  "To keep him on his capel* out of the slough;                      *horse\n"
  "And if he fall from off his capel eftsoon,*                       *again\n"
  "Then shall we alle have enough to do'n\n"
  "In lifting up his heavy drunken corse.\n"
  "Tell on thy tale, of him *make I no force.*          *I take no account*\n"
  "But yet, Manciple, in faith thou art too nice*                  *foolish\n"
  "Thus openly to reprove him of his vice;\n"
  "Another day he will paraventure\n"
  "Reclaime thee, and bring thee to the lure; <7>\n"
  "I mean, he speake will of smalle things,\n"
  "As for to *pinchen at* thy reckonings,                   *pick flaws in*\n"
  "That were not honest, if it came to prefe.\"*                *test, proof\n"
  "Quoth the Manciple, \"That were a great mischief;\n"
  "So might he lightly bring me in the snare.\n"
  "Yet had I lever* paye for the mare                               *rather\n"
  "Which he rides on, than he should with me strive.\n"
  "I will not wrathe him, so may I thrive)\n"
  "That that I spake, I said it in my bourde.*                        *jest\n"
  "And weet ye what? I have here in my gourd\n"
  "A draught of wine, yea, of a ripe grape,\n"
  "And right anon ye shall see a good jape.*                         *trick\n"
  "This Cook shall drink thereof, if that I may;\n"
  "On pain of my life he will not say nay.\"\n"
  "And certainly, to tellen as it was,\n"
  "Of this vessel the cook drank fast (alas!\n"
  "What needed it? he drank enough beforn),\n"
  "And when he hadde *pouped in his horn,*                        *belched*\n"
  "To the Manciple he took the gourd again.\n"
  "And of that drink the Cook was wondrous fain,\n"
  "And thanked him in such wise as he could.\n"
  "\n"
  "Then gan our Host to laughe wondrous loud,\n"
  "And said, \"I see well it is necessary\n"
  "Where that we go good drink with us to carry;\n"
  "For that will turne rancour and disease*             *trouble, annoyance\n"
  "T'accord and love, and many a wrong appease.\n"
  "O Bacchus, Bacchus, blessed be thy name,\n"
  "That so canst turnen earnest into game!\n"
  "Worship and thank be to thy deity.\n"
  "Of that mattere ye get no more of me.\n"
  "Tell on thy tale, Manciple, I thee pray.\"\n"
  "\"Well, Sir,\" quoth he, \"now hearken what I say.\"\n"
  "\n"
  "\n"
  "Notes to the Prologue to the Manciple's Tale\n"
  "\n"
  "\n"
  "1. Bob-up-and-down: Mr Wright supposes this to be the village of\n"
  "Harbledown, near Canterbury, which  is situated on a hill, and near\n"
  "which there are many ups and downs in the road. Like Boughton,\n"
  "where the Canon and his Yeoman overtook the pilgrims, it stood on\n"
  "the skirts of the Kentish forest of Blean or Blee.\n"
  "\n"
  "2. Dun is in the mire: a proverbial saying. \"Dun\" is a name for an\n"
  "ass, derived from his colour.\n"
  "\n"
  "3. The mention of the Cook here, with no hint that he had already\n"
  "told a story, confirms the indication given by the imperfect\n"
  "condition of his Tale, that Chaucer intended to suppress the Tale\n"
  "altogether, and make him tell a story in some other place.\n"
  "\n"
  "4. The quintain; called \"fan\" or \"vane,\" because it turned round like\n"
  "a weather-cock.\n"
  "\n"
  "5. Referring to the classification of wine, according to its effects on\n"
  "a man, given in the old \"Calendrier des Bergiers,\" The man of\n"
  "choleric temperament has \"wine of lion;\" the sanguine, \"wine of\n"
  "ape;\" the phlegmatic, \"wine of sheep;\" the melancholic, \"wine of\n"
  "sow.\" There is a Rabbinical tradition that, when Noah was planting\n"
  "vines, Satan slaughtered beside them the four animals named; hence\n"
  "the effect of wine in making those who drink it display in turn the\n"
  "characteristics of all the four.\n"
  "\n"
  "6. The pose:  a defluxion or rheum which stops the nose and\n"
  "obstructs the voice.\n"
  "\n"
  "7. Bring thee to his lure: A phrase in hawking -- to recall a hawk to\n"
  "the fist; the meaning here is, that the Cook may one day bring the\n"
  "Manciple to account, or pay him off, for the rebuke of his\n"
  "drunkenness.\n"
  "\n"
  "\n"
  "THE TALE. <1>\n"
  "\n"
  "\n"
  "When Phoebus dwelled here in earth adown,\n"
  "As olde bookes make mentioun,\n"
  "He was the moste lusty* bacheler                               *pleasant\n"
  "Of all this world, and eke* the best archer.                       *also\n"
  "He slew Python the serpent, as he lay\n"
  "Sleeping against the sun upon a day;\n"
  "And many another noble worthy deed\n"
  "He with his bow wrought, as men maye read.\n"
  "Playen he could on every minstrelsy,\n"
  "And singe, that it was a melody\n"
  "To hearen of his cleare voice the soun'.\n"
  "Certes the king of Thebes, Amphioun,\n"
  "That with his singing walled the city,\n"
  "Could never singe half so well as he.\n"
  "Thereto he was the seemlieste man\n"
  "That is, or was since that the world began;\n"
  "What needeth it his features to descrive?\n"
  "For in this world is none so fair alive.\n"
  "He was therewith full fill'd of gentleness,\n"
  "Of honour, and of perfect worthiness.\n"
  "\n"
  "This Phoebus, that was flower of bach'lery,\n"
  "As well in freedom* as in chivalry,                          *generosity\n"
  "For his disport, in sign eke of victory\n"
  "Of Python, so as telleth us the story,\n"
  "Was wont to bearen in his hand a bow.\n"
  "Now had this Phoebus in his house a crow,\n"
  "Which in a cage he foster'd many a day,\n"
  "And taught it speaken, as men teach a jay.\n"
  "White was this crow, as is a snow-white swan,\n"
  "And counterfeit the speech of every man\n"
  "He coulde, when he shoulde tell a tale.\n"
  "Therewith in all this world no nightingale\n"
  "Ne coulde by an hundred thousand deal*                             *part\n"
  "Singe so wondrous merrily and well.\n"
  "Now had this Phoebus in his house a wife;\n"
  "Which that he loved more than his life.\n"
  "And night and day did ever his diligence\n"
  "Her for to please, and do her reverence:\n"
  "Save only, if that I the sooth shall sayn,\n"
  "Jealous he was, and would have kept her fain.\n"
  "For him were loth y-japed* for to be;                 *tricked, deceived\n"
  "And so is every wight in such degree;\n"
  "But all for nought, for it availeth nought.\n"
  "A good wife, that is clean of work and thought,\n"
  "Should not be kept in none await* certain:                  *observation\n"
  "And truely the labour is in vain\n"
  "To keep a shrewe,* for it will not be.               *ill-disposed woman\n"
  "This hold I for a very nicety,*                             *sheer folly\n"
  "To spille* labour for to keepe wives;                              *lose\n"
  "\n"
  "Thus writen olde clerkes in their lives.\n"
  "But now to purpose, as I first began.\n"
  "This worthy Phoebus did all that he can\n"
  "To please her, weening, through such pleasance,\n"
  "And for his manhood and his governance,\n"
  "That no man should have put him from her grace;\n"
  "But, God it wot, there may no man embrace\n"
  "As to distrain* a thing, which that nature      *succeed in constraining\n"
  "Hath naturally set in a creature.\n"
  "Take any bird, and put it in a cage,\n"
  "And do all thine intent, and thy corage,*        *what thy heart prompts\n"
  "To foster it tenderly with meat and drink\n"
  "Of alle dainties that thou canst bethink,\n"
  "And keep it all so cleanly as thou may;\n"
  "Although the cage of gold be never so gay,\n"
  "Yet had this bird, by twenty thousand fold,\n"
  "Lever* in a forest, both wild and cold,                          *rather\n"
  "Go eate wormes, and such wretchedness.\n"
  "For ever this bird will do his business\n"
  "T'escape out of his cage when that he may:\n"
  "His liberty the bird desireth aye. <2>\n"
  "Let take a cat, and foster her with milk\n"
  "And tender flesh, and make her couch of silk,\n"
  "And let her see a mouse go by the wall,\n"
  "Anon she weiveth* milk, and flesh, and all,                   *forsaketh\n"
  "And every dainty that is in that house,\n"
  "Such appetite hath she to eat the mouse.\n"
  "Lo, here hath kind* her domination,                              *nature\n"
  "And appetite flemeth* discretion.                            *drives out\n"
  "A she-wolf hath also a villain's kind\n"
  "The lewedeste wolf that she may find,\n"
  "Or least of reputation, will she take\n"
  "In time when *her lust* to have a make.*              *she desires *mate\n"
  "All these examples speak I by* these men              *with reference to\n"
  "That be untrue, and nothing by women.\n"
  "For men have ever a lik'rous appetite\n"
  "On lower things to perform their delight\n"
  "Than on their wives, be they never so fair,\n"
  "Never so true, nor so debonair.*                           *gentle, mild\n"
  "Flesh is so newefangled, *with mischance,*              *ill luck to it*\n"
  "That we can in no thinge have pleasance\n"
  "That *souneth unto* virtue any while.                      *accords with\n"
  "\n"
  "This Phoebus, which that thought upon no guile,\n"
  "Deceived was for all his jollity;\n"
  "For under him another hadde she,\n"
  "A man of little reputation,\n"
  "Nought worth to Phoebus in comparison.\n"
  "The more harm is; it happens often so,\n"
  "Of which there cometh muche harm and woe.\n"
  "And so befell, when Phoebus was absent,\n"
  "His wife anon hath for her leman* sent.                  *unlawful lover\n"
  "Her leman! certes that is a knavish speech.\n"
  "Forgive it me, and that I you beseech.\n"
  "The wise Plato saith, as ye may read,\n"
  "The word must needs accorde with the deed;\n"
  "If men shall telle properly a thing,\n"
  "The word must cousin be to the working.\n"
  "I am a boistous* man, right thus I say.         *rough-spoken, downright\n"
  "There is no difference truely\n"
  "Betwixt a wife that is of high degree\n"
  "(If of her body dishonest she be),\n"
  "And any poore wench, other than this\n"
  "(If it so be they worke both amiss),\n"
  "But, for* the gentle is in estate above,                        *because\n"
  "She shall be call'd his lady and his love;\n"
  "And, for that other is a poor woman,\n"
  "She shall be call'd his wench and his leman:\n"
  "And God it wot, mine owen deare brother,\n"
  "Men lay the one as low as lies the other.\n"
  "Right so betwixt a *titleless tyrant*                          *usurper*\n"
  "And an outlaw, or else a thief errant,                        *wandering\n"
  "The same I say, there is no difference\n"
  "(To Alexander told was this sentence),\n"
  "But, for the tyrant is of greater might\n"
  "By force of meinie* for to slay downright,                    *followers\n"
  "And burn both house and home, and make all plain,*                *level\n"
  "Lo, therefore is he call'd a capitain;\n"
  "And, for the outlaw hath but small meinie,\n"
  "And may not do so great an harm as he,\n"
  "Nor bring a country to so great mischief,\n"
  "Men calle him an outlaw or a thief.\n"
  "But, for I am a man not textuel,                       *learned in texts\n"
  "I will not tell of texts never a deal;*                            *whit\n"
  "I will go to my tale, as I began.\n"
  "\n"
  "When Phoebus' wife had sent for her leman,\n"
  "Anon they wroughten all their *lust volage.*    *light or rash pleasure*\n"
  "This white crow, that hung aye in the cage,\n"
  "Beheld their work, and said never a word;\n"
  "And when that home was come Phoebus the lord,\n"
  "This crowe sung, \"Cuckoo, cuckoo, cuckoo!\"\n"
  "\"What? bird,\" quoth Phoebus, \"what song sing'st thou now?\n"
  "Wert thou not wont so merrily to sing,\n"
  "That to my heart it was a rejoicing\n"
  "To hear thy voice? alas! what song is this?\"\n"
  "\"By God,\" quoth he, \"I singe not amiss.\n"
  "Phoebus,\" quoth he, \"for all thy worthiness,\n"
  "For all thy beauty, and all thy gentleness,\n"
  "For all thy song, and all thy minstrelsy,\n"
  "*For all thy waiting, bleared is thine eye*   *despite all thy watching,\n"
  "With one of little reputation,                        thou art befooled*\n"
  "Not worth to thee, as in comparison,\n"
  "The mountance* of a gnat, so may I thrive;                        *value\n"
  "For on thy bed thy wife I saw him swive.\"\n"
  "What will ye more? the crow anon him told,\n"
  "By sade* tokens, and by wordes bold,                 *grave, trustworthy\n"
  "How that his wife had done her lechery,\n"
  "To his great shame and his great villainy;\n"
  "And told him oft, he saw it with his eyen.\n"
  "This Phoebus gan awayward for to wrien;*                     *turn aside\n"
  "Him thought his woeful hearte burst in two.\n"
  "His bow he bent, and set therein a flo,*                          *arrow\n"
  "And in his ire he hath his wife slain;\n"
  "This is th' effect, there is no more to sayn.\n"
  "For sorrow of which he brake his minstrelsy,\n"
  "Both harp and lute, gitern* and psaltery;                        *guitar\n"
  "And eke he brake his arrows and his bow;\n"
  "And after that thus spake he to the crow.\n"
  "\n"
  "\"Traitor,\" quoth he, \"with tongue of scorpion,\n"
  "Thou hast me brought to my confusion;\n"
  "Alas that I was wrought!* why n'ere** I dead?            *made **was not\n"
  "O deare wife, O gem of lustihead,*                         *pleasantness\n"
  "That wert to me so sad,* and eke so true,                     *steadfast\n"
  "Now liest thou dead, with face pale of hue,\n"
  "Full guilteless, that durst I swear y-wis!*                   *certainly\n"
  "O rakel* hand, to do so foul amiss                          *rash, hasty\n"
  "O troubled wit, O ire reckeless,\n"
  "That unadvised smit'st the guilteless!\n"
  "O wantrust,* full of false suspicion!                      *distrust <3>\n"
  "Where was thy wit and thy discretion?\n"
  "O! every man beware of rakelness,*                             *rashness\n"
  "Nor trow* no thing withoute strong witness.                     *believe\n"
  "Smite not too soon, ere that ye weete* why,                        *know\n"
  "And *be advised* well and sickerly**                  *consider* *surely\n"
  "Ere ye *do any execution                                *take any action\n"
  "Upon your ire* for suspicion.                           upon your anger*\n"
  "Alas! a thousand folk hath rakel ire\n"
  "Foully fordone, and brought them in the mire.\n"
  "Alas! for sorrow I will myself slee*                               *slay\n"
  "And to the crow, \"O false thief,\" said he,\n"
  "\"I will thee quite anon thy false tale.\n"
  "Thou sung whilom* like any nightingale,                  *once on a time\n"
  "Now shalt thou, false thief, thy song foregon,*                    *lose\n"
  "And eke thy white feathers every one,\n"
  "Nor ever in all thy life shalt thou speak;\n"
  "Thus shall men on a traitor be awreak.                         *revenged\n"
  "Thou and thine offspring ever shall be blake,*                    *black\n"
  "Nor ever sweete noise shall ye make,\n"
  "But ever cry against* tempest and rain,           *before, in warning of\n"
  "In token that through thee my wife is slain.\"\n"
  "And to the crow he start,* and that anon,                        *sprang\n"
  "And pull'd his white feathers every one,\n"
  "And made him black, and reft him all his song,\n"
  "And eke his speech, and out at door him flung\n"
  "Unto the devil, *which I him betake;*            *to whom I commend him*\n"
  "And for this cause be all crowes blake.\n"
  "Lordings, by this ensample, I you pray,\n"
  "Beware, and take keep* what that ye say;                           *heed\n"
  "Nor telle never man in all your life\n"
  "How that another man hath dight his wife;\n"
  "He will you hate mortally certain.\n"
  "Dan Solomon, as wise clerkes sayn,\n"
  "Teacheth a man to keep his tongue well;\n"
  "But, as I said, I am not textuel.\n"
  "But natheless thus taughte me my dame;\n"
  "\"My son, think on the crow, in Godde's name.\n"
  "My son, keep well thy tongue, and keep thy friend;\n"
  "A wicked tongue is worse than is a fiend:\n"
  "My sone, from a fiend men may them bless.*           *defend by crossing\n"
  "My son, God of his endeless goodness                          themselves\n"
  "Walled a tongue with teeth, and lippes eke,\n"
  "For* man should him advise,** what he speak.         *because **consider\n"
  "My son, full often for too muche speech\n"
  "Hath many a man been spilt,* as clerkes teach;                *destroyed\n"
  "But for a little speech advisedly\n"
  "Is no man shent,* to speak generally.                            *ruined\n"
  "My son, thy tongue shouldest thou restrain\n"
  "At alle time, *but when thou dost thy pain*          *except when you do\n"
  "To speak of God in honour and prayere.                 your best effort*\n"
  "The firste virtue, son, if thou wilt lear,*                       *learn\n"
  "Is to restrain and keepe well thy tongue;<4>\n"
  "Thus learne children, when that they be young.\n"
  "My son, of muche speaking evil advis'd,\n"
  "Where lesse speaking had enough suffic'd,\n"
  "Cometh much harm; thus was me told and taught;\n"
  "In muche speeche sinne wanteth not.\n"
  "Wost* thou whereof a rakel** tongue serveth?            *knowest **hasty\n"
  "Right as a sword forcutteth and forcarveth\n"
  "An arm in two, my deare son, right so\n"
  "A tongue cutteth friendship all in two.\n"
  "A jangler* is  to God abominable.                           *prating man\n"
  "Read Solomon, so wise and honourable;\n"
  "Read David in his Psalms, and read Senec'.\n"
  "My son, speak not, but with thine head thou beck,*          *beckon, nod\n"
  "Dissimule as thou wert deaf, if that thou hear\n"
  "A jangler speak of perilous mattere.\n"
  "The Fleming saith, and learn *if that thee lest,*   **if it please thee*\n"
  "That little jangling causeth muche rest.\n"
  "My son, if thou no wicked word hast said,\n"
  "*Thee thar not dreade for to be bewray'd;*         *thou hast no need to\n"
  "But he that hath missaid, I dare well sayn,         fear to be betrayed*\n"
  "He may by no way call his word again.\n"
  "Thing that is said is said, and forth it go'th, <5>\n"
  "Though him repent, or be he ne'er so loth;\n"
  "He is his thrall,* to whom that he hath said                      *slave\n"
  "A tale, *of which he is now evil apaid.*          *which he now regrets*\n"
  "My son, beware, and be no author new\n"
  "Of tidings, whether they be false or true; <6>\n"
  "Whereso thou come, amonges high or low,\n"
  "Keep well thy tongue, and think upon the crow.\"\n"
  "\n"
  "\n"
  "Notes to the Manciple's Tale\n"
  "\n"
  "\n"
  "1. \"The fable of 'The Crow,' says Tyrwhitt, \"which is the\n"
  "subject of the Manciple's Tale, has been related by so many\n"
  "authors, from Ovid down to Gower, that it is impossible to\n"
  "say whom Chaucer principally followed. His skill in new\n"
  "dressing an old story was never, perhaps, more successfully\n"
  "exerted.\"\n"
  "\n"
  "2. See the parallel to this passage in the Squire's Tale, and\n"
  "note 34 to that tale.\n"
  "\n"
  "3. Wantrust: distrust -- want of trust; so \"wanhope,\" despair -\n"
  "- want of hope.\n"
  "\n"
  "4. This is quoted in the French \"Romance of the Rose,\" from\n"
  "Cato \"De Moribus,\" 1. i., dist. 3: \"Virtutem primam esse puta\n"
  "compescere linguam.\" (\"The first virtue is to be able to\n"
  "control the tongue\")\n"
  "\n"
  "5. \"Semel emissum volat irrevocabile verbum.\" (\"A word once\n"
  "uttered flies away and cannot be called back\")   -- Horace,\n"
  "Epist. 1., 18, 71.\n"
  "\n"
  "6. This caution is also from Cato \"De Moribus,\" 1. i., dist.\n"
  "12: \"Rumoris fuge ne incipias novus auctor haberi.\" (\"Do not\n"
  "pass on rumours or be the author of new ones\")\n"
  "\n"
  "\n"
  "\n"
  "";
// }

const char parsonsTale0[] PGMSECTION = // { // 31555 bytes
  "THE PARSON'S TALE.\n"
  "\n"
  "\n"
  "THE PROLOGUE.\n"
  "\n"
  "\n"
  "By that the Manciple his tale had ended,\n"
  "The sunne from the south line was descended\n"
  "So lowe, that it was not to my sight\n"
  "Degrees nine-and-twenty as in height.\n"
  "Four of the clock it was then, as I guess,\n"
  "For eleven foot, a little more or less,\n"
  "My shadow was at thilke time, as there,\n"
  "Of such feet as my lengthe parted were\n"
  "In six feet equal of proportion.\n"
  "Therewith the moone's exaltation,*                               *rising\n"
  "*In meane* Libra, gan alway ascend,                   *in the middle of*\n"
  "As we were ent'ring at a thorpe's* end.                       *village's\n"
  "For which our Host, as he was wont to gie,*                      *govern\n"
  "As in this case, our jolly company,\n"
  "Said in this wise; \"Lordings every one,\n"
  "Now lacketh us no more tales than one.\n"
  "Fulfill'd is my sentence and my decree;\n"
  "I trow that we have heard of each degree.*       from each class or rank\n"
  "Almost fulfilled is mine ordinance;                       in the company\n"
  "I pray to God so give him right good chance\n"
  "That telleth us this tale lustily.\n"
  "Sir Priest,\" quoth he, \"art thou a vicary?*                       *vicar\n"
  "Or art thou a Parson? say sooth by thy fay.*                      *faith\n"
  "Be what thou be, breake thou not our play;\n"
  "For every man, save thou, hath told his tale.\n"
  "Unbuckle, and shew us what is in thy mail.*                      *wallet\n"
  "For truely me thinketh by thy cheer\n"
  "Thou shouldest knit up well a great mattere.\n"
  "Tell us a fable anon, for cocke's bones.\"\n"
  "\n"
  "This Parson him answered all at ones;\n"
  "\"Thou gettest fable none y-told for me,\n"
  "For Paul, that writeth unto Timothy,\n"
  "Reproveth them that *weive soothfastness,*               *forsake truth*\n"
  "And telle fables, and such wretchedness.\n"
  "Why should I sowe draff* out of my fist,                  *chaff, refuse\n"
  "When I may sowe wheat, if that me list?\n"
  "For which I say, if that you list to hear\n"
  "Morality and virtuous mattere,\n"
  "And then that ye will give me audience,\n"
  "I would full fain at Christe's reverence\n"
  "Do you pleasance lawful, as I can.\n"
  "But, truste well, I am a southern man,\n"
  "I cannot gest,* rom, ram, ruf, <1> by my letter;         *relate stories\n"
  "And, God wot, rhyme hold I but little better.\n"
  "And therefore if you list, I will not glose,*             *mince matters\n"
  "I will you tell a little tale in prose,\n"
  "To knit up all this feast, and make an end.\n"
  "And Jesus for his grace wit me send\n"
  "To shewe you the way, in this voyage,\n"
  "Of thilke perfect glorious pilgrimage, <2>\n"
  "That hight Jerusalem celestial.\n"
  "And if ye vouchesafe, anon I shall\n"
  "Begin upon my tale, for which I pray\n"
  "Tell your advice,* I can no better say.                         *opinion\n"
  "But natheless this meditation\n"
  "I put it aye under correction\n"
  "Of clerkes,* for I am not textuel;                             *scholars\n"
  "I take but the sentence,* trust me well.                 *meaning, sense\n"
  "Therefore I make a protestation,\n"
  "That I will stande to correction.\"\n"
  "Upon this word we have assented soon;\n"
  "For, as us seemed, it was *for to do'n,*           *a thing worth doing*\n"
  "To enden in some virtuous sentence,*                          *discourse\n"
  "And for to give him space and audience;\n"
  "And bade our Host he shoulde to him say\n"
  "That alle we to tell his tale him pray.\n"
  "Our Hoste had. the wordes for us all:\n"
  "\"Sir Priest,\" quoth he, \"now faire you befall;\n"
  "Say what you list, and we shall gladly hear.\"\n"
  "And with that word he said in this mannere;\n"
  "\"Telle,\" quoth he, \"your meditatioun,\n"
  "But hasten you, the sunne will adown.\n"
  "Be fructuous,* and that in little space;           *fruitful; profitable\n"
  "And to do well God sende you his grace.\"\n"
  "\n"
  "\n"
  "Notes to the Prologue to the Parson's Tale\n"
  "\n"
  "\n"
  "1. Rom, ram, ruf: a contemptuous reference to the alliterative\n"
  "poetry which was at that time very popular, in preference even,\n"
  "it would seem, to rhyme, in the northern parts of the country,\n"
  "where the language was much more barbarous and unpolished\n"
  "than in the south.\n"
  "\n"
  "2. Perfect glorious pilgrimage:  the word is used here to signify\n"
  "the shrine, or destination, to which pilgrimage is made.\n"
  "\n"
  "\n"
  "THE TALE. <1>\n"
  "\n"
  "\n"
  "[The Parson begins his \"little treatise\" -(which, if given at\n"
  "length, would extend to about thirty of these pages, and which\n"
  "cannot by any stretch of courtesy or fancy be said to merit the\n"
  "title of a \"Tale\") in these words: --]\n"
  "\n"
  "Our sweet Lord God of Heaven, that no man will perish, but\n"
  "will that we come all to the knowledge of him, and to the\n"
  "blissful life that is perdurable [everlasting], admonishes us by\n"
  "the prophet Jeremiah, that saith in this wise: \"Stand upon the\n"
  "ways, and see and ask of old paths, that is to say, of old\n"
  "sentences, which is the good way, and walk in that way, and ye\n"
  "shall find refreshing for your souls,\" <2> &c.  Many be the\n"
  "spiritual ways that lead folk to our Lord Jesus Christ, and to the\n"
  "reign of glory; of which ways there is a full noble way, and full\n"
  "convenable, which may not fail to man nor to woman, that\n"
  "through sin hath misgone from the right way of Jerusalem\n"
  "celestial; and this way is called penitence. Of which men should\n"
  "gladly hearken and inquire with all their hearts, to wit what is\n"
  "penitence, and whence it is called penitence, and in what\n"
  "manner, and in how many manners, be the actions or workings\n"
  "of penitence, and how many species there be of penitences, and\n"
  "what things appertain and behove to penitence, and what things\n"
  "disturb penitence.\n"
  "\n"
  "[Penitence is described, on the authority of Saints Ambrose,\n"
  "Isidore, and Gregory, as the bewailing of sin that has been\n"
  "wrought, with the purpose never again to do that thing, or any\n"
  "other thing which a man should bewail; for weeping and not\n"
  "ceasing to do the sin will not avail -- though it is to be hoped\n"
  "that after every time that a man falls, be it ever so often, he may\n"
  "find grace to arise through penitence. And repentant folk that\n"
  "leave their sin ere sin leave them, are accounted by Holy Church\n"
  "sure of their salvation, even though the repentance be at the last\n"
  "hour. There are three actions of penitence; that a man be\n"
  "baptized after he has sinned; that he do no deadly sin after\n"
  "receiving baptism; and that he fall into no venial sins from day\n"
  "to day. \"Thereof saith St Augustine, that penitence of good and\n"
  "humble folk is the penitence of every day.\" The species of\n"
  "penitence are three: solemn, when a man is openly expelled\n"
  "from Holy Church in Lent, or is compelled by Holy Church to\n"
  "do open penance for an open sin openly talked of in the\n"
  "country; common penance, enjoined by priests in certain cases,\n"
  "as to go on pilgrimage naked or barefoot; and privy penance,\n"
  "which men do daily for private sins, of which they confess\n"
  "privately and receive private penance. To very perfect penitence\n"
  "are behoveful and necessary three things: contrition of heart,\n"
  "confession of mouth, and satisfaction; which are fruitful\n"
  "penitence against delight in thinking, reckless speech, and\n"
  "wicked sinful works.\n"
  "\n"
  "Penitence may be likened to a tree, having its root in contrition,\n"
  "biding itself in the heart as a tree-root does in the earth; out of\n"
  "this root springs a stalk, that bears branches and leaves of\n"
  "confession, and fruit of satisfaction. Of this root also springs a\n"
  "seed of grace, which is mother of all security, and this seed is\n"
  "eager and hot; and the grace of this seed springs of God,\n"
  "through remembrance on the day of judgment and on the pains\n"
  "of hell. The heat of this seed is the love of God, and the desire\n"
  "of everlasting joy; and this heat draws the heart of man to God,\n"
  "and makes him hate his sin. Penance is the tree of life to them\n"
  "that receive it. In penance or contrition man shall understand\n"
  "four things: what is contrition; what are the causes that move a\n"
  "man to contrition; how he should be contrite; and what\n"
  "contrition availeth to the soul. Contrition is the heavy and\n"
  "grievous sorrow that a man receiveth in his heart for his sins,\n"
  "with earnest purpose to confess and do penance, and never\n"
  "more to sin. Six causes ought to move a man to contrition: 1.\n"
  "He should remember him of his sins; 2. He should reflect that\n"
  "sin putteth a man in great thraldom, and all the greater the\n"
  "higher is the estate from which he falls; 3. He should dread the\n"
  "day of doom and the horrible pains of hell; 4. The sorrowful\n"
  "remembrance of the good deeds that  man hath omitted to do\n"
  "here on earth, and also the good that he hath lost, ought to\n"
  "make him have contrition; 5. So also ought the remembrance of\n"
  "the passion that our Lord Jesus Christ suffered for our sins; 6.\n"
  "And so ought the hope of three things, that is to say,\n"
  "forgiveness of sin, the gift of grace to do well, and the glory of\n"
  "heaven with which God shall reward man for his good deeds. --\n"
  "All these points the Parson illustrates and enforces at length;\n"
  "waxing especially eloquent under the third head, and plainly\n"
  "setting forth the sternly realistic notions regarding future\n"
  "punishments that were entertained in the time of Chaucer:-] <3>\n"
  "\n"
  "Certes, all the sorrow that a man might make from the\n"
  "beginning of the world, is but a little thing, at retard of [in\n"
  "comparison with] the sorrow of hell. The cause why that Job\n"
  "calleth hell the land of darkness; <4> understand, that he calleth\n"
  "it land or earth, for it is stable and never shall fail, and dark, for\n"
  "he that is in hell hath default [is devoid] of light natural; for\n"
  "certes the dark light, that shall come out of the fire that ever\n"
  "shall burn, shall turn them all to pain that be in hell, for it\n"
  "sheweth them the horrible devils that them torment. Covered\n"
  "with the darkness of death; that is to say, that he that is in hell\n"
  "shall have default of the sight of God; for certes the sight of\n"
  "God is the life perdurable [everlasting]. The darkness of death,\n"
  "be the sins that the wretched man hath done, which that disturb\n"
  "[prevent] him to see the face of God, right as a dark cloud doth\n"
  "between us and the sun. Land of misease, because there be three\n"
  "manner of defaults against three things that folk of this world\n"
  "have in this present life; that is to say, honours, delights, and\n"
  "riches. Against honour have they in hell shame and confusion:\n"
  "for well ye wot, that men call honour the reverence that man\n"
  "doth to man; but in hell is no honour nor reverence; for certes\n"
  "no more reverence shall be done there to a king than to a knave\n"
  "[servant]. For which God saith by the prophet Jeremiah; \"The\n"
  "folk that me despise shall be in despite.\" Honour is also called\n"
  "great lordship. There shall no wight serve other, but of harm\n"
  "and torment. Honour is also called great dignity and highness;\n"
  "but in hell shall they be all fortrodden [trampled under foot] of\n"
  "devils. As God saith, \"The horrible devils shall go and come\n"
  "upon the heads of damned folk;\" and this is, forasmuch as the\n"
  "higher that they were in this present life, the more shall they be\n"
  "abated [abased] and defouled in hell. Against the riches of this\n"
  "world shall they have misease [trouble, torment] of poverty, and\n"
  "this poverty shall be in four things: in default [want] of treasure;\n"
  "of which David saith, \"The rich folk that embraced and oned\n"
  "[united] all their heart to treasure of this world, shall sleep in the\n"
  "sleeping of death, and nothing shall they find in their hands of\n"
  "all their treasure.\" And moreover, the misease of hell shall be in\n"
  "default of meat and drink. For God saith thus by Moses, \"They\n"
  "shall be wasted with hunger, and the birds of hell shall devour\n"
  "them with bitter death, and the gall of the dragon shall be their\n"
  "drink, and the venom of the dragon their morsels.\" And\n"
  "furthermore, their misease shall be in default of clothing, for\n"
  "they shall be naked in body, as of clothing, save the fire in\n"
  "which they burn, and other filths; and naked shall they be in\n"
  "soul, of all manner virtues, which that is the clothing of the soul.\n"
  "Where be then the gay robes, and the soft sheets, and the fine\n"
  "shirts? Lo, what saith of them the prophet Isaiah, that under\n"
  "them shall be strewed moths, and their covertures shall be of\n"
  "worms of hell. And furthermore, their misease shall be in default\n"
  "of friends, for he is not poor that hath good friends: but there is\n"
  "no friend; for neither God nor any good creature shall be friend\n"
  "to them, and evereach of them shall hate other with deadly hate.\n"
  "The Sons and the daughters shall rebel against father and\n"
  "mother, and kindred against kindred, and chide and despise each\n"
  "other, both day and night, as God saith by the prophet Micah.\n"
  "And the loving children, that whom loved so fleshly each other,\n"
  "would each of them eat the other if they might. For how should\n"
  "they love together in the pains of hell, when they hated each\n"
  "other in the prosperity of this life? For trust well, their fleshly\n"
  "love was deadly hate; as saith the prophet David; \"Whoso\n"
  "loveth wickedness, he hateth his own soul:\" and whoso hateth\n"
  "his own soul, certes he may love none other wight in no\n"
  "manner: and therefore in hell is no solace nor no friendship, but\n"
  "ever the more kindreds that be in hell, the more cursing, the\n"
  "more chiding, and the more deadly hate there is among them.\n"
  "And furtherover, they shall have default of all manner delights;\n"
  "for certes delights be after the appetites of the five wits\n"
  "[senses]; as sight, hearing, smelling, savouring [tasting], and\n"
  "touching. But in hell their sight shall be full of darkness and of\n"
  "smoke, and their eyes full of tears; and their hearing full of\n"
  "waimenting [lamenting] and grinting [gnashing] of teeth, as\n"
  "saith Jesus Christ; their nostrils shall be full of stinking; and, as\n"
  "saith Isaiah the prophet, their savouring  [tasting] shall be full of\n"
  "bitter gall; and touching of all their body shall be covered with\n"
  "fire that never shall quench, and with worms that never shall\n"
  "die, as God saith by the mouth of Isaiah. And forasmuch as they\n"
  "shall not ween that they may die for pain, and by death flee from\n"
  "pain, that may they understand in the word of Job, that saith,\n"
  "\"There is the shadow of death.\" Certes a shadow hath the\n"
  "likeness of the thing of which it is shadowed, but the shadow is\n"
  "not the same thing of which it is shadowed: right so fareth the\n"
  "pain of hell; it is like death, for the horrible anguish; and why?\n"
  "for it paineth them ever as though they should die anon; but\n"
  "certes they shall not die. For, as saith Saint Gregory, \"To\n"
  "wretched caitiffs shall be given death without death, and end\n"
  "without end, and default without failing; for their death shall\n"
  "always live, and their end shall evermore begin, and their default\n"
  "shall never fail.\" And therefore saith Saint John the Evangelist,\n"
  "\"They shall follow death, and they shall not find him, and they\n"
  "shall desire to die, and death shall flee from them.\" And eke Job\n"
  "saith, that in hell is no order of rule. And albeit that God hath\n"
  "created all things in right order, and nothing without order, but\n"
  "all things be ordered and numbered, yet nevertheless they that\n"
  "be damned be not in order, nor hold no order. For the earth\n"
  "shall bear them no fruit (for, as the prophet David saith, \"God\n"
  "shall destroy the fruit of the earth, as for them\"); nor water shall\n"
  "give them no moisture, nor the air no refreshing, nor the fire no\n"
  "light. For as saith Saint Basil, \"The burning of  the fire of this\n"
  "world shall God give in hell to them that be damned, but the\n"
  "light and the clearness shall be given in heaven to his children;\n"
  "right as the good man giveth flesh to his children, and bones to\n"
  "his hounds.\" And for they shall have no hope to escape, saith\n"
  "Job at last, that there shall horror and grisly dread dwell without\n"
  "end. Horror is always dread of harm that is to come, and this\n"
  "dread shall ever dwell in the hearts of them that be damned.\n"
  "And therefore have they lost all their hope for seven causes.\n"
  "First, for God that is their judge shall be without mercy to them;\n"
  "nor they may not please him; nor none of his hallows [saints];\n"
  "nor they may give nothing for their ransom; nor they have no\n"
  "voice to speak to him; nor they may not flee from pain; nor they\n"
  "have no goodness in them that they may shew to deliver them\n"
  "from pain.\n"
  "\n"
  "[Under the fourth head, of good works, the Parson says: --]\n"
  "\n"
  "The courteous Lord Jesus Christ will that no good work be lost,\n"
  "for in somewhat it shall avail. But forasmuch as the good works\n"
  "that men do while they be in good life be all amortised [killed,\n"
  "deadened] by sin following, and also since all the good works\n"
  "that men do while they be in deadly sin be utterly dead, as for to\n"
  "have the life perdurable [everlasting], well may that man that no\n"
  "good works doth, sing that new French song, J'ai tout perdu --\n"
  "mon temps et mon labour <5>. For certes, sin bereaveth a man\n"
  "both the goodness of nature, and eke the goodness of grace.\n"
  "For soothly the grace of the Holy Ghost fareth like fire, that\n"
  "may not be idle; for fire faileth anon as it forleteth [leaveth] its\n"
  "working, and right so grace faileth anon as it forleteth its\n"
  "working. Then loseth the sinful man the goodness of glory, that\n"
  "only is to good men that labour and work. Well may he be sorry\n"
  "then, that oweth all his life to God, as long as he hath lived, and\n"
  "also as long as he shall live, that no goodness hath to pay with\n"
  "his debt to God, to whom he oweth all his life: for trust well he\n"
  "shall give account, as saith Saint Bernard, of all the goods that\n"
  "have been given him in his present life, and how he hath them\n"
  "dispended, insomuch that there shall not perish an hair of his\n"
  "head, nor a moment of an hour shall not perish of his time, that\n"
  "he shall not give thereof a reckoning.\n"
  "\n"
  "[Having treated of the causes, the Parson comes to the manner,\n"
  "of contrition -- which should be universal and total, not merely\n"
  "of outward deeds of sin, but also of wicked delights and\n"
  "thoughts and words; \"for certes Almighty God is all good, and\n"
  "therefore either he forgiveth all, or else right naught.\" Further,\n"
  "contrition should be \"wonder sorrowful and anguishous,\" and\n"
  "also continual, with steadfast purpose of confession and\n"
  "amendment. Lastly, of what contrition availeth, the Parson says,\n"
  "that sometimes it delivereth man from sin; that without it neither\n"
  "confession nor satisfaction is of any worth; that it \"destroyeth\n"
  "the prison of hell, and maketh weak and feeble all the strengths\n"
  "of the devils, and restoreth the gifts of the Holy Ghost and of all\n"
  "good virtues, and cleanseth the soul of sin, and delivereth it\n"
  "from the pain of hell, and from the company of the devil, and\n"
  "from the servage [slavery] of sin, and restoreth it to all goods\n"
  "spiritual, and to the company and communion of Holy Church.\"\n"
  "He who should set his intent to these things, would no longer be\n"
  "inclined to sin, but would give his heart and body to the service\n"
  "of Jesus Christ, and thereof do him homage. \"For, certes, our\n"
  "Lord Jesus Christ hath spared us so benignly in our follies, that\n"
  "if he had not pity on man's soul, a sorry song might we all sing.\"\n"
  "\n"
  "The Second Part of the Parson's Tale or Treatise opens with an\n"
  "explanation of what is confession -- which is termed \"the\n"
  "second part of penitence, that is, sign of contrition;\" whether it\n"
  "ought needs be done or not; and what things be convenable to\n"
  "true confession. Confession is true shewing of sins to the priest,\n"
  "without excusing, hiding, or forwrapping [disguising] of\n"
  "anything, and without vaunting of good works. \"Also, it is\n"
  "necessary to understand whence that sins spring, and how they\n"
  "increase, and which they be.\" From Adam we took original sin;\n"
  "\"from him fleshly descended be we all, and engendered of vile\n"
  "and corrupt matter;\" and the penalty of Adam's transgression\n"
  "dwelleth with us as to temptation, which penalty is called\n"
  "concupiscence. \"This concupiscence, when it is wrongfully\n"
  "disposed or ordained in a man, it maketh him covet, by covetise\n"
  "of flesh, fleshly sin by sight of his eyes, as to earthly things, and\n"
  "also covetise of highness by pride of heart.\" The Parson\n"
  "proceeds to shew how man is tempted in his flesh to sin; how,\n"
  "after his natural concupiscence, comes suggestion of the devil,\n"
  "that is to say the devil's bellows, with which he bloweth in man\n"
  "the fire of con cupiscence; and how man then bethinketh him\n"
  "whether he will do or no the thing to which he is tempted. If he\n"
  "flame up into pleasure at the thought, and give way, then is he\n"
  "all dead in soul; \"and thus is sin accomplished, by temptation, by\n"
  "delight, and by consenting; and then is the sin actual.\" Sin is\n"
  "either venial, or deadly; deadly, when a man loves any creature\n"
  "more than Jesus Christ our Creator, venial, if he love Jesus\n"
  "Christ less than he ought. Venial sins diminish man's love to\n"
  "God more and more, and may in this wise skip into deadly sin;\n"
  "for many small make a great. \"And hearken this example: A\n"
  "great wave of the sea cometh sometimes with so great a\n"
  "violence, that it drencheth [causes to sink] the ship: and the\n"
  "same harm do sometimes the small drops, of water that enter\n"
  "through a little crevice in the thurrok [hold, bilge], and in the\n"
  "bottom of the ship, if men be so negligent that they discharge\n"
  "them not betimes. And therefore, although there be difference\n"
  "betwixt these two causes of drenching, algates [in any case] the\n"
  "ship is dreint [sunk]. Right so fareth it sometimes of deadly sin,\"\n"
  "and of venial sins when they multiply in a man so greatly as to\n"
  "make him love worldly things more than God. The Parson then\n"
  "enumerates specially a number of sins which many a man\n"
  "peradventure deems no sins, and confesses them not, and yet\n"
  "nevertheless they are truly sins: -- ]\n"
  "\n"
  "This is to say, at every time that a man eateth and drinketh more\n"
  "than sufficeth to the sustenance of his body, in certain he doth\n"
  "sin; eke when he speaketh more than it needeth, he doth sin; eke\n"
  "when he heareth not benignly the complaint of the poor; eke\n"
  "when he is in health of body, and will not fast when other folk\n"
  "fast, without cause reasonable; eke when he sleepeth more than\n"
  "needeth, or when he cometh by that occasion too late to church,\n"
  "or to other works of charity; eke when he useth his wife without\n"
  "sovereign desire of engendrure, to the honour of God, or for the\n"
  "intent to yield his wife his debt of his body; eke when he will not\n"
  "visit the sick, or the prisoner, if he may; eke if he love wife, or\n"
  "child, or other worldly thing, more than reason requireth; eke if\n"
  "he flatter or blandish more than he ought for any necessity; eke\n"
  "if he minish or withdraw the alms of the poor; eke if he apparail\n"
  "[prepare] his meat more deliciously than need is, or eat it too\n"
  "hastily by likerousness [gluttony];  eke if he talk vanities in the\n"
  "church, or at God's service, or that he be a talker of idle words\n"
  "of folly or villainy, for he shall yield account of them at the day\n"
  "of doom; eke when he behighteth [promiseth] or assureth to do\n"
  "things that he may not perform; eke when that by lightness of\n"
  "folly he missayeth or scorneth his neighbour; eke when he hath\n"
  "any wicked suspicion of thing, that he wot of it no\n"
  "soothfastness: these things, and more without number, be sins,\n"
  "as saith Saint Augustine.\n"
  "\n"
  "[No earthly man may eschew all venial sins; yet may he refrain\n"
  "him, by the burning love that he hath to our Lord Jesus Christ,\n"
  "and by prayer and confession, and other good works, so that it\n"
  "shall but little grieve. \"Furthermore, men may also refrain and\n"
  "put away venial sin, by receiving worthily the precious body of\n"
  "Jesus Christ; by receiving eke of holy water; by alms-deed; by\n"
  "general confession of Confiteor at mass, and at prime, and at\n"
  "compline [evening service]; and by blessing of bishops and\n"
  "priests, and by other good works.\" The Parson then proceeds to\n"
  "weightier matters:-- ]\n"
  "\n"
  "Now it is behovely [profitable, necessary] to tell which be\n"
  "deadly sins, that is to say, chieftains of sins; forasmuch as all\n"
  "they run in one leash, but in diverse manners. Now be they\n"
  "called chieftains, forasmuch as they be chief, and of them spring\n"
  "all other sins. The root of these sins, then, is pride, the general\n"
  "root of all harms. For of this root spring certain branches: as ire,\n"
  "envy, accidie <6> or sloth, avarice or covetousness (to common\n"
  "understanding), gluttony, and lechery: and each of these sins\n"
  "hath his branches and his twigs, as shall be declared in their\n"
  "chapters following. And though so be, that no man can tell\n"
  "utterly the number of the twigs, and of the harms that come of\n"
  "pride, yet will I shew a part of them, as ye shall understand.\n"
  "There is inobedience, vaunting, hypocrisy, despite, arrogance,\n"
  "impudence, swelling of hearte, insolence, elation, impatience,\n"
  "strife, contumacy, presumption, irreverence, pertinacity, vain-\n"
  "glory and many another twig that I cannot tell nor declare. . . .]\n"
  "\n"
  "And yet [moreover] there is a privy species of pride that waiteth\n"
  "first to be saluted ere he will salute, all [although] be he less\n"
  "worthy than that other is; and eke he waiteth [expecteth] or\n"
  "desireth to sit or to go above him in the way, or kiss the pax,\n"
  "<7> or be incensed, or go to offering before his neighbour, and\n"
  "such semblable [like] things, against his duty peradventure, but\n"
  "that he hath his heart and his intent in such a proud desire to be\n"
  "magnified and honoured before the people. Now be there two\n"
  "manner of prides; the one of them is within the heart of a man,\n"
  "and the other is without. Of which soothly these foresaid things,\n"
  "and more than I have said, appertain to pride that is within the\n"
  "heart of a man and there be other species of pride that be\n"
  "without: but nevertheless, the one of these species of pride is\n"
  "sign of the other, right as the gay levesell [bush] at the tavern is\n"
  "sign of the wine that is in the cellar. And this is in many things:\n"
  "as in speech and countenance, and outrageous array of clothing;\n"
  "for certes, if there had been no sin in clothing, Christ would not\n"
  "so soon have noted and spoken of the clothing of that rich man\n"
  "in the gospel. And Saint Gregory saith, that precious clothing is\n"
  "culpable for the dearth [dearness] of it, and for its softness, and\n"
  "for its strangeness and disguising, and for the superfluity or for\n"
  "the inordinate scantness of it; alas! may not a man see in our\n"
  "days the sinful costly array of clothing, and namely [specially] in\n"
  "too much superfluity, or else in too disordinate scantness? As to\n"
  "the first sin, in superfluity of clothing, which that maketh it so\n"
  "dear, to the harm of the people, not only the cost of the\n"
  "embroidering, the disguising, indenting or barring, ounding,\n"
  "paling, <8> winding, or banding, and semblable [similar] waste\n"
  "of cloth in vanity; but there is also the costly furring [lining or\n"
  "edging with fur] in their gowns, so much punching of chisels to\n"
  "make holes, so much dagging [cutting] of shears, with the\n"
  "superfluity in length of the foresaid gowns, trailing in the dung\n"
  "and in the mire, on horse and eke on foot, as well of man as of\n"
  "woman, that all that trailing is verily (as in effect) wasted,\n"
  "consumed, threadbare, and rotten with dung, rather than it is\n"
  "given to the poor, to great damage of the foresaid poor folk,\n"
  "and that in sundry wise: this is to say, the more that cloth is\n"
  "wasted, the more must it cost to the poor people for the\n"
  "scarceness; and furthermore, if so be that they would give such\n"
  "punched and dagged clothing to the poor people, it is not\n"
  "convenient to wear for their estate, nor sufficient to boot [help,\n"
  "remedy] their necessity, to keep them from the distemperance\n"
  "[inclemency] of the firmament. Upon the other side, to speak of\n"
  "the horrible disordinate scantness of clothing, as be these cutted\n"
  "slops or hanselines [breeches] , that through their shortness\n"
  "cover not the shameful member of man, to wicked intent alas!\n"
  "some of them shew the boss and the shape of the horrible\n"
  "swollen members, that seem like to the malady of hernia, in the\n"
  "wrapping of their hosen, and eke the buttocks of them, that fare\n"
  "as it were the hinder part of a she-ape in the full of the moon.\n"
  "And more over the wretched swollen members that they shew\n"
  "through disguising, in departing [dividing] of their hosen in\n"
  "white and red, seemeth that half their shameful privy members\n"
  "were flain [flayed]. And if so be that they depart their hosen in\n"
  "other colours, as is white and blue, or white and black, or black\n"
  "and red, and so forth; then seemeth it, by variance of colour,\n"
  "that the half part of their privy members be corrupt by the fire\n"
  "of Saint Anthony, or by canker, or other such mischance. And\n"
  "of the hinder part of their buttocks it is full horrible to see, for\n"
  "certes, in that part of their body where they purge their stinking\n"
  "ordure, that foul part shew they to the people proudly in despite\n"
  "of honesty [decency], which honesty Jesus Christ and his friends\n"
  "observed to shew in his life. Now as of the outrageous array of\n"
  "women, God wot, that though the visages of some of them\n"
  "seem full chaste and debonair [gentle], yet notify they, in their\n"
  "array of attire, likerousness and pride. I say not that honesty\n"
  "[reasonable and appropriate style] in clothing of man or woman\n"
  "unconvenable but, certes, the superfluity or disordinate scarcity\n"
  "of clothing is reprovable. Also the sin of their ornament, or of\n"
  "apparel, as in things that appertain to riding, as in too many\n"
  "delicate horses, that be holden for delight, that be so fair, fat,\n"
  "and costly; and also in many a vicious knave, [servant] that is\n"
  "sustained because of them; in curious harness, as in saddles,\n"
  "cruppers, peytrels, [breast-plates] and bridles, covered with\n"
  "precious cloth and rich bars and plates of gold and silver. For\n"
  "which God saith by Zechariah the prophet, \"I will confound the\n"
  "riders of such horses.\" These folk take little regard of the riding\n"
  "of God's Son of heaven, and of his harness, when he rode upon\n"
  "an ass, and had no other harness but the poor clothes of his\n"
  "disciples; nor we read not that ever he rode on any other beast.\n"
  "I speak this for the sin of superfluity, and not for reasonable\n"
  "honesty [seemliness], when reason it requireth. And moreover,\n"
  "certes, pride is greatly notified in holding of great meinie\n"
  "[retinue of servants], when they be of little profit or of right no\n"
  "profit, and namely [especially] when that meinie is felonous\n"
  "[violent ] and damageous [harmful] to the people by hardiness\n"
  "[arrogance] of high lordship, or by way of office; for certes,\n"
  "such lords sell then their lordship to the devil of hell, when they\n"
  "sustain the wickedness of their meinie. Or else, when these folk\n"
  "of low degree, as they that hold hostelries, sustain theft of their\n"
  "hostellers, and that is in many manner of deceits: that manner of\n"
  "folk be the flies that follow the honey, or else the hounds that\n"
  "follow the carrion. Such foresaid folk strangle spiritually their\n"
  "lordships; for which thus saith David the prophet, \"Wicked\n"
  "death may come unto these lordships, and God give that they\n"
  "may descend into hell adown; for in their houses is iniquity and\n"
  "shrewedness, [impiety] and not God of heaven.\" And certes, but\n"
  "if [unless] they do amendment, right as God gave his benison\n"
  "[blessing] to Laban by the service of Jacob, and to Pharaoh by\n"
  "the service of Joseph; right so God will give his malison\n"
  "[condemnation] to such lordships as sustain the wickedness of\n"
  "their servants, but [unless] they come to amendment. Pride of\n"
  "the table apaireth [worketh harm] eke full oft; for, certes, rich\n"
  "men be called to feasts, and poor folk be put away and rebuked;\n"
  "also in excess of divers meats and drinks, and namely [specially]\n"
  "such manner bake-meats and dish-meats burning of wild fire,\n"
  "and painted and castled with paper, and semblable [similar]\n"
  "waste, so that it is abuse to think. And eke in too great\n"
  "preciousness of vessel, [plate] and curiosity of minstrelsy, by\n"
  "which a man is stirred more to the delights of luxury, if so be\n"
  "that he set his heart the less upon our Lord Jesus Christ, certain\n"
  "it is a sin; and certainly the delights might be so great in this\n"
  "case, that a man might lightly [easily] fall by them into deadly\n"
  "sin.\n"
  "\n"
  "";
// }

const char parsonsTale1[] PGMSECTION = // { // 25737 bytes
  "[The sins that arise of pride advisedly and habitually are deadly;\n"
  "those that arise by frailty unadvised suddenly, and suddenly\n"
  "withdraw again, though grievous, are not deadly. Pride itself\n"
  "springs sometimes of the goods of nature, sometimes of the\n"
  "goods of fortune, sometimes of the goods of grace; but the\n"
  "Parson, enumerating and examining all these in turn, points out\n"
  "how little security they possess and how little ground for pride\n"
  "they furnish, and goes on to enforce the remedy against pride --\n"
  "which is humility or meekness, a virtue through which a man\n"
  "hath true knowledge of himself, and holdeth no high esteem of\n"
  "himself in regard of his deserts, considering ever his frailty.]\n"
  "\n"
  "Now be there three manners [kinds] of humility; as humility in\n"
  "heart, and another in the mouth, and the third in works. The\n"
  "humility in the heart is in four manners: the one is, when a man\n"
  "holdeth himself as nought worth before God of heaven; the\n"
  "second is, when he despiseth no other man; the third is, when he\n"
  "recketh not though men hold him nought worth; the fourth is,\n"
  "when he is not sorry of his humiliation. Also the humility of\n"
  "mouth is in four things: in temperate speech; in humility of\n"
  "speech; and when he confesseth with his own mouth that he is\n"
  "such as he thinketh that he is in his heart; another is, when he\n"
  "praiseth the bounte [goodness] of another man and nothing\n"
  "thereof diminisheth. Humility eke in works is in four manners:\n"
  "the first is, when he putteth other men before him; the second is,\n"
  "to choose the lowest place of all; the third is, gladly to assent to\n"
  "good counsel; the fourth is, to stand gladly by the award\n"
  "[judgment] of his sovereign, or of him that is higher in degree:\n"
  "certain this is a great work of humility.\n"
  "\n"
  "[The Parson proceeds to treat of the other cardinal sins, and\n"
  "their remedies: (2.) Envy, with its remedy, the love of God\n"
  "principally and of our neighbours as ourselves: (3.) Anger, with\n"
  "all its fruits in revenge, rancour, hate, discord, manslaughter,\n"
  "blasphemy, swearing, falsehood, flattery, chiding and reproving,\n"
  "scorning, treachery, sowing of strife, doubleness of tongue,\n"
  "betraying of counsel to a man's disgrace, menacing, idle words,\n"
  "jangling, japery or buffoonery, &c. -- and its remedy in the\n"
  "virtues called mansuetude, debonairte, or gentleness, and\n"
  "patience or sufferance: (4.) Sloth, or \"Accidie,\" which comes\n"
  "after the sin of Anger, because Envy blinds the eyes of a man,\n"
  "and Anger troubleth a man, and Sloth maketh him heavy,\n"
  "thoughtful, and peevish. It is opposed to every estate of man --\n"
  "as unfallen, and held to work in praising and adoring God; as\n"
  "sinful, and held to labour in praying for deliverance from sin;\n"
  "and as in the state of grace, and held to works of penitence. It\n"
  "resembles the heavy and sluggish condition of those in hell; it\n"
  "will suffer no hardness and no penance; it prevents any\n"
  "beginning of good works; it causes despair of God's mercy,\n"
  "which is the sin against the Holy Ghost; it induces somnolency\n"
  "and neglect of communion in prayer with God; and it breeds\n"
  "negligence or recklessness, that cares for nothing, and is the\n"
  "nurse of all mischiefs, if ignorance is their mother. Against\n"
  "Sloth, and these and other branches and fruits of it, the remedy\n"
  "lies in the virtue of fortitude or strength, in its various species of\n"
  "magnanimity or great courage; faith and hope in God and his\n"
  "saints; surety or sickerness, when a man fears nothing that can\n"
  "oppose the good works he has under taken; magnificence, when\n"
  "he carries out great works of goodness begun; constancy or\n"
  "stableness of heart; and other incentives to energy and laborious\n"
  "service: (5.) Avarice, or Covetousness, which is the root of all\n"
  "harms, since its votaries are idolaters, oppressors and enslavers\n"
  "of men, deceivers of their equals in business, simoniacs,\n"
  "gamblers, liars, thieves, false swearers, blasphemers, murderers,\n"
  "and sacrilegious. Its remedy lies in compassion and pity largely\n"
  "exercised, and in reasonable liberality -- for those who spend on\n"
  "\"fool-largesse,\" or ostentation of worldly estate and luxury,\n"
  "shall receive the malison [condemnation] that Christ shall give\n"
  "at the day of doom to them that shall be damned: (6.) Gluttony;\n"
  "-- of which the Parson treats so briefly that the chapter may be\n"
  "given in full: -- ]\n"
  "\n"
  "After Avarice cometh Gluttony, which is express against the\n"
  "commandment of God. Gluttony is unmeasurable appetite to eat\n"
  "or to drink; or else to do in aught to the unmeasurable appetite\n"
  "and disordered covetousness [craving] to eat or drink. This sin\n"
  "corrupted all this world, as is well shewed in the sin of Adam\n"
  "and of Eve. Look also what saith Saint Paul of gluttony:\n"
  "\"Many,\" saith he, \"go, of which I have oft said to you, and now\n"
  "I say it weeping, that they be enemies of the cross of Christ, of\n"
  "which the end is death, and of which their womb [stomach] is\n"
  "their God and their glory;\" in confusion of them that so savour\n"
  "[take delight in] earthly things. He that is usant [accustomed,\n"
  "addicted] to this sin of gluttony, he may no sin withstand, he\n"
  "must be in servage [bondage] of all vices,  for it is the devil's\n"
  "hoard, [lair, lurking-place] where he hideth him in and resteth.\n"
  "This sin hath many species. The first is drunkenness, that is the\n"
  "horrible sepulture of man's reason: and therefore when a man is\n"
  "drunken, he hath lost his reason; and this is deadly sin. But\n"
  "soothly, when that a man is not wont to strong drink, and\n"
  "peradventure knoweth not the strength of the drink, or hath\n"
  "feebleness in his head, or hath travailed [laboured], through\n"
  "which he drinketh the more, all [although] be he suddenly\n"
  "caught with drink, it is no deadly sin, but venial. The second\n"
  "species of gluttony is, that the spirit of a man waxeth all\n"
  "troubled for drunkenness, and bereaveth a man the discretion of\n"
  "his wit. The third species of gluttony is, when a man devoureth\n"
  "his meat, and hath no rightful manner of eating. The fourth is,\n"
  "when, through the great abundance of his meat, the humours of\n"
  "his body be distempered. The fifth is, forgetfulness by too much\n"
  "drinking, for which a man sometimes forgetteth by the morrow\n"
  "what be did at eve. In other manner be distinct the species of\n"
  "gluttony, after Saint Gregory. The first is, for to eat or drink\n"
  "before time. The second is, when a man getteth him too delicate\n"
  "meat or drink. The third is, when men take too much over\n"
  "measure [immoderately]. The fourth is curiosity [nicety] with\n"
  "great intent [application, pains] to make and apparel [prepare]\n"
  "his meat. The fifth is, for to eat too greedily. These be the five\n"
  "fingers of the devil's hand, by which he draweth folk to the sin.\n"
  "\n"
  "Against gluttony the remedy is abstinence, as saith Galen; but\n"
  "that I hold not meritorious, if he do it only for the health of his\n"
  "body. Saint Augustine will that abstinence be done for virtue,\n"
  "and with patience. Abstinence, saith he, is little worth, but  if\n"
  "[unless] a man have good will thereto, and but it be enforced by\n"
  "patience and by charity, and that men do it for God's sake, and\n"
  "in hope to have the bliss in heaven. The fellows of abstinence be\n"
  "temperance, that holdeth the mean in all things; also shame, that\n"
  "escheweth all dishonesty [indecency, impropriety], sufficiency,\n"
  "that seeketh no rich meats nor drinks, nor doth no force of [sets\n"
  "no value on] no outrageous apparelling of meat; measure\n"
  "[moderation] also, that restraineth by reason the unmeasurable\n"
  "appetite of eating; soberness also, that restraineth the outrage of\n"
  "drink; sparing also, that restraineth the delicate ease to sit long\n"
  "at meat, wherefore some folk stand of their own will to eat,\n"
  "because they will eat at less leisure.\n"
  "\n"
  "[At great length the Parson then points out the many varieties of\n"
  "the sin of (7.) Lechery, and its remedy in chastity and\n"
  "continence, alike in marriage and in widowhood; also in the\n"
  "abstaining from all such indulgences of eating, drinking, and\n"
  "sleeping as inflame the passions, and from the company of all\n"
  "who may tempt to the sin. Minute guidance is given as to the\n"
  "duty of confessing fully and faithfully the circumstances that\n"
  "attend and may aggravate this sin; and the Treatise then passes\n"
  "to the consideration of the conditions that are essential to a true\n"
  "and profitable confession of sin in general. First, it must be in\n"
  "sorrowful bitterness of spirit; a condition that has five signs --\n"
  "shamefastness, humility in heart and outward sign, weeping with\n"
  "the bodily eyes or in the heart, disregard of the shame that\n"
  "might curtail or garble confession, and obedience to the penance\n"
  "enjoined. Secondly, true confession must be promptly made, for\n"
  "dread of death, of increase of sinfulness, of forgetfulness of\n"
  "what should be confessed, of Christ's refusal to hear if it be put\n"
  "off to the last day of life; and this condition has four terms; that\n"
  "confession be well pondered beforehand, that the man\n"
  "confessing have comprehended in his mind the number and\n"
  "greatness of his sins and how long he has lain in sin, that he be\n"
  "contrite for and eschew his sins, and that he fear and flee the\n"
  "occasions for that sin to which he is inclined. -- What follows\n"
  "under this head is of some interest for the light which it throws\n"
  "on the rigorous government wielded by the Romish Church in\n"
  "those days --]\n"
  "\n"
  "Also thou shalt shrive thee of all thy sins to one man, and not a\n"
  "parcel [portion] to one man, and a parcel to another; that is to\n"
  "understand, in intent to depart [divide] thy confession for shame\n"
  "or dread; for it is but strangling of thy soul. For certes Jesus\n"
  "Christ is entirely all good, in him is none imperfection, and\n"
  "therefore either he forgiveth all perfectly, or else never a deal\n"
  "[not at all]. I say not that if thou be assigned to thy penitencer\n"
  "<9> for a certain sin, that thou art bound to shew him all the\n"
  "remnant of thy sins, of which thou hast been shriven of thy\n"
  "curate, but if it like thee [unless thou be pleased] of thy\n"
  "humility; this is no departing [division] of shrift. And I say not,\n"
  "where I speak of division of confession, that if thou have license\n"
  "to shrive thee to a discreet and an honest priest, and where thee\n"
  "liketh, and by the license of thy curate, that thou mayest not\n"
  "well shrive thee to him of all thy sins: but let no blot be behind,\n"
  "let no sin be untold as far as thou hast remembrance. And when\n"
  "thou shalt be shriven of thy curate, tell him eke all the sins that\n"
  "thou hast done since thou wert last shriven. This is no wicked\n"
  "intent of division of shrift. Also, very shrift [true confession]\n"
  "asketh certain  conditions. First, that thou shrive thee by thy\n"
  "free will, not constrained, nor for shame of folk, nor for malady\n"
  "[sickness],  or such things: for it is reason, that he that\n"
  "trespasseth by his free will, that by his free will he confess his\n"
  "trespass; and that no other man tell his sin but himself; nor he\n"
  "shall not nay nor deny his sin, nor wrath him against the priest\n"
  "for admonishing him to leave his sin. The second condition is,\n"
  "that thy shrift be lawful, that is to say, that thou that shrivest\n"
  "thee, and eke the priest that heareth thy confession, be verily in\n"
  "the faith of Holy Church, and that a man be not despaired of the\n"
  "mercy of Jesus Christ, as Cain and Judas were. And eke a man\n"
  "must accuse himself of his own trespass, and not another: but he\n"
  "shall blame and wite [accuse] himself of his own malice and of\n"
  "his sin, and none other: but nevertheless, if that another man be\n"
  "occasion or else enticer of his sin, or the estate of the person be\n"
  "such by which his sin is aggravated, or else that be may not\n"
  "plainly shrive him but [unless] he tell the person with which he\n"
  "hath sinned, then may he tell, so that his intent be not to\n"
  "backbite the person, but only to declare his confession. Thou\n"
  "shalt not eke make no leasings [falsehoods] in thy confession\n"
  "for humility, peradventure, to say that thou hast committed and\n"
  "done such sins of which that thou wert never guilty. For Saint\n"
  "Augustine saith, \"If that thou, because of humility, makest a\n"
  "leasing on thyself, though thou were not in sin before, yet art\n"
  "thou then in sin through thy leasing.\" Thou must also shew thy\n"
  "sin by thine own proper mouth, but [unless] thou be dumb, and\n"
  "not by letter; for thou that hast done the sin, thou shalt have the\n"
  "shame of the confession. Thou shalt not paint thy confession\n"
  "with fair and subtle words, to cover the more thy sin; for then\n"
  "beguilest thou thyself, and not the priest; thou must tell it\n"
  "plainly, be it never so foul nor so horrible. Thou shalt eke shrive\n"
  "thee to a priest that is discreet to counsel thee; and eke thou\n"
  "shalt not shrive thee for vain-glory, nor for hypocrisy, nor for\n"
  "no cause but only for the doubt [fear] of Jesus' Christ and the\n"
  "health of thy soul. Thou shalt not run to the priest all suddenly,\n"
  "to tell him lightly thy sin, as who telleth a jape [jest] or a tale,\n"
  "but advisedly and with good devotion; and generally shrive thee\n"
  "oft; if thou oft fall, oft arise by confession. And though thou\n"
  "shrive thee oftener than once of sin of which thou hast been\n"
  "shriven, it is more merit; and, as saith Saint Augustine, thou\n"
  "shalt have the more lightly [easily] release and grace of God,\n"
  "both of sin and of pain. And certes, once a year at the least way,\n"
  "it is lawful to be houseled, <10> for soothly once a year all\n"
  "things in the earth renovelen [renew themselves].\n"
  "\n"
  "[Here ends the Second Part of the Treatise; the Third Part,\n"
  "which contains the practical application of the whole, follows\n"
  "entire, along with the remarkable \"Prayer of Chaucer,\" as it\n"
  "stands in the Harleian Manuscript:--]\n"
  "\n"
  "De Tertia Parte Poenitentiae. [Of the third part of penitence]\n"
  "\n"
  "Now have I told you of very [true] confession, that is the\n"
  "second part of penitence: The third part of penitence is\n"
  "satisfaction, and that standeth generally in almsdeed and bodily\n"
  "pain. Now be there three manner of almsdeed: contrition of\n"
  "heart, where a man offereth himself to God; the second is, to\n"
  "have pity of the default of his neighbour; the third is, in giving\n"
  "of good counsel and comfort, ghostly and bodily, where men\n"
  "have need, and namely [specially] sustenance of man's food.\n"
  "And take keep [heed] that a man hath need of these things\n"
  "generally; he hath need of food, of clothing, and of herberow\n"
  "[lodging], he hath need of charitable counsel and visiting in\n"
  "prison and malady, and sepulture of his dead body. And if thou\n"
  "mayest not visit the needful with thy person, visit them by thy\n"
  "message and by thy gifts. These be generally alms or works of\n"
  "charity of them that have temporal riches or discretion in\n"
  "counselling. Of these works shalt thou hear at the day of doom.\n"
  "This alms shouldest thou do of thine own proper things, and\n"
  "hastily [promptly], and privily [secretly] if thou mayest; but\n"
  "nevertheless, if thou mayest not do it privily, thou shalt not\n"
  "forbear to do alms, though men see it, so that it be not done for\n"
  "thank of the world, but only for thank of Jesus Christ. For, as\n"
  "witnesseth Saint Matthew, chap. v., \"A city may not be hid that\n"
  "is set on a mountain, nor men light not a lantern and put it\n"
  "under a bushel, but men set it on a candlestick, to light the men\n"
  "in the house; right so shall your light lighten before men, that\n"
  "they may see your good works, and glorify your Father that is\n"
  "in heaven.\"\n"
  "\n"
  "Now as to speak of bodily pain, it is in prayer, in wakings,\n"
  "[watchings] in fastings, and in virtuous teachings. Of orisons ye\n"
  "shall understand, that orisons or prayers is to say a piteous will\n"
  "of heart, that redresseth it in God, and expresseth it by word\n"
  "outward, to remove harms, and to have things spiritual and\n"
  "durable, and sometimes temporal things. Of which orisons,\n"
  "certes in the orison of the Pater noster hath our Lord Jesus\n"
  "Christ enclosed most things. Certes, it is privileged of three\n"
  "things in its dignity, for which it is more digne [worthy] than\n"
  "any other prayer: for Jesus Christ himself made it: and it is\n"
  "short, for [in order] it should be coude the more lightly, [be\n"
  "more easily conned or learned] and to withhold [retain] it the\n"
  "more easy in heart, and help himself the oftener with this orison;\n"
  "and for a man should be the less weary to say it; and for a man\n"
  "may not excuse him to learn it, it is so short and so easy: and\n"
  "for it comprehendeth in itself all good prayers. The exposition\n"
  "of this holy prayer, that is so excellent and so digne, I betake\n"
  "[commit] to these masters of theology; save thus much will I\n"
  "say, when thou prayest that God should forgive thee thy guilts,\n"
  "as thou forgivest them that they guilt to thee, be full well ware\n"
  "that thou be not out of charity. This holy orison aminisheth\n"
  "[lesseneth] eke venial sin, and therefore it appertaineth specially\n"
  "to penitence. This prayer must be truly said, and in very faith,\n"
  "and that men pray to God ordinately, discreetly, and devoutly;\n"
  "and always a man shall put his will to be subject to the will of\n"
  "God. This orison must eke be said with great humbleness and\n"
  "full pure, and honestly, and not to the annoyance of any man or\n"
  "woman. It must eke be continued with the works of charity. It\n"
  "availeth against the vices of the soul; for, assaith Saint Jerome,\n"
  "by fasting be saved the vices of the flesh, and by prayer the\n"
  "vices of the soul\n"
  "\n"
  "After this thou shalt understand, that bodily pain stands in\n"
  "waking [watching].  For Jesus Christ saith \"Wake and pray, that\n"
  "ye enter not into temptation.\" Ye shall understand also, that\n"
  "fasting stands in three things: in forbearing of bodily meat and\n"
  "drink, and in forbearing of worldly jollity, and in forbearing of\n"
  "deadly sin; this is to say, that a man shall keep him from deadly\n"
  "sin in all that he may. And thou shalt understand eke, that God\n"
  "ordained fasting; and to fasting appertain four things: largeness\n"
  "[generosity] to poor folk; gladness of heart spiritual; not to be\n"
  "angry nor annoyed nor grudge [murmur] for he fasteth; and also\n"
  "reasonable hour for to eat by measure; that is to say, a man\n"
  "should not eat in untime [out of time],  nor sit the longer at his\n"
  "meal for [because] he fasteth. Then shalt thou understand, that\n"
  "bodily pain standeth in discipline, or teaching, by word, or by\n"
  "writing, or by ensample. Also in wearing of hairs [haircloth] or\n"
  "of stamin [coarse hempen cloth], or of habergeons [mail-shirts]\n"
  "<11> on their naked flesh for Christ's sake; but ware thee well\n"
  "that such manner penance of thy flesh make not thine heart\n"
  "bitter or angry, nor annoyed of thyself; for better is to cast away\n"
  "thine hair than to cast away the sweetness of our Lord Jesus\n"
  "Christ. And therefore saith Saint Paul, \"Clothe you, as they that\n"
  "be chosen of God in heart, of misericorde [with compassion],\n"
  "debonairte [gentleness], sufferance [patience], and such manner\n"
  "of clothing,\" of which Jesus Christ is more apaid [better\n"
  "pleased] than of hairs or of hauberks. Then is discipline eke in\n"
  "knocking of thy breast, in scourging with yards [rods], in\n"
  "kneelings, in tribulations, in suffering patiently wrongs that be\n"
  "done to him, and eke in patient sufferance of maladies, or losing\n"
  "of worldly catel [chattels], or of wife, or of child, or of other\n"
  "friends.\n"
  "\n"
  "Then shalt thou understand which things disturb penance, and\n"
  "this is in four things; that is dread, shame, hope, and wanhope,\n"
  "that is, desperation. And for to speak first of dread, for which\n"
  "he weeneth that he may suffer no penance, thereagainst is\n"
  "remedy for to think that bodily penance is but short and little at\n"
  "the regard of [in comparison with] the pain of hell, that is so\n"
  "cruel and so long, that it lasteth without end. Now against the\n"
  "shame that a man hath to shrive him, and namely [specially]\n"
  "these hypocrites, that would be holden so perfect, that they\n"
  "have no need to shrive them; against that shame should a man\n"
  "think, that by way of reason he that hath not been ashamed to\n"
  "do foul things, certes he ought not to be ashamed to do fair\n"
  "things, and that is confession. A man should eke think, that God\n"
  "seeth and knoweth all thy thoughts, and all thy works; to him\n"
  "may nothing be hid nor covered. Men should eke remember\n"
  "them of the shame that is to come at the day of doom, to them\n"
  "that be not penitent and shriven in this present life; for all the\n"
  "creatures in heaven, and in earth, and in hell, shall see apertly\n"
  "[openly] all that he hideth in this world.\n"
  "\n"
  "Now for to speak of them that be so negligent and slow to\n"
  "shrive them; that stands in two manners. The one is, that he\n"
  "hopeth to live long, and to purchase [acquire] much riches for\n"
  "his delight, and then he will shrive him: and, as he sayeth, he\n"
  "may, as him seemeth, timely enough come to shrift: another is,\n"
  "the surquedrie [presumption <12>] that he hath in Christ's\n"
  "mercy. Against the first vice, he shall think that our life is in no\n"
  "sickerness, [security] and eke that all the riches in this world be\n"
  "in adventure, and pass as a shadow on the wall; and, as saith St\n"
  "Gregory, that it appertaineth to the great righteousness of God,\n"
  "that never shall the pain stint [cease] of them, that never would\n"
  "withdraw them from sin, their thanks [with their goodwill], but\n"
  "aye continue in sin; for that perpetual will to do sin shall they\n"
  "have perpetual pain. Wanhope [despair] is in two manners [of\n"
  "two kinds]. The first wanhope is, in the mercy of God: the other\n"
  "is, that they think they might not long persevere in goodness.\n"
  "The first wanhope cometh of that he deemeth that he sinned so\n"
  "highly and so oft, and so long hath lain in sin, that he shall not\n"
  "be saved. Certes against that cursed wanhope should he think,\n"
  "that the passion of Jesus Christ is more strong for to unbind,\n"
  "than sin is strong for to bind. Against the second wanhope he\n"
  "shall think, that as oft as he falleth, he may arise again by\n"
  "penitence; and though he never so long hath lain in sin, the\n"
  "mercy of Christ is always ready to receive him to mercy.\n"
  "Against the wanhope that he thinketh he should not long\n"
  "persevere in goodness, he shall think that the feebleness of the\n"
  "devil may nothing do, but [unless] men will suffer him; and eke\n"
  "he shall have strength of the help of God, and of all Holy\n"
  "Church, and of the protection of angels, if him list.\n"
  "\n"
  "Then shall men understand, what is the fruit of penance; and\n"
  "after the word of Jesus Christ, it is the endless bliss of heaven,\n"
  "where joy hath no contrariety of woe nor of penance nor\n"
  "grievance; there all harms be passed of this present life; there as\n"
  "is the sickerness [security] from the pain of hell; there as is the\n"
  "blissful company, that rejoice them evermore each of the other's\n"
  "joy; there as the body of man, that whilom was foul and dark, is\n"
  "more clear than the sun; there as the body of man that whilom\n"
  "was sick and frail, feeble and mortal, is immortal, and so strong\n"
  "and so whole, that there may nothing apair [impair, injure] it;\n"
  "there is neither hunger, nor thirst, nor cold, but every soul\n"
  "replenished with the sight of the perfect knowing of God. This\n"
  "blissful regne [kingdom] may men purchase by poverty spiritual,\n"
  "and the glory by lowliness, the plenty of joy by hunger and\n"
  "thirst, the rest by travail, and the life by death and mortification\n"
  "of sin; to which life He us bring, that bought us with his\n"
  "precious blood! Amen.\n"
  "\n"
  "\n"
  "Notes to the Parson's Tale\n"
  "\n"
  "\n"
  "1. The Parson's Tale is believed to be a translation, more or less\n"
  "free, from some treatise on penitence that was in favour about\n"
  "Chaucer's time. Tyrwhitt says: \"I cannot recommend it as a very\n"
  "entertaining or edifying performance at this day; but the reader\n"
  "will please to remember, in excuse both of Chaucer and of his\n"
  "editor, that, considering The Canterbury Tales as a great picture\n"
  "of life and manners, the piece would not have been complete if\n"
  "it had not included the religion of the time.\" The Editor of the\n"
  "present volume has followed the same plan adopted with regard\n"
  "to Chaucer's Tale of Meliboeus, and mainly for the same\n"
  "reasons. (See note 1 to that Tale). An outline of the Parson's\n"
  "ponderous sermon -- for such it is -- has been drawn; while\n"
  "those passages have been given in full which more directly\n"
  "illustrate the social and the religious life of the time -- such as\n"
  "the picture of hell, the vehement and rather coarse, but, in an\n"
  "antiquarian sense, most curious and valuable attack on the\n"
  "fashionable garb of the day, the catalogue of venial sins, the\n"
  "description of gluttony and its remedy, &c. The brief third or\n"
  "concluding part, which contains the application of the whole,\n"
  "and the \"Retractation\" or \"Prayer\" that closes the Tale and the\n"
  "entire \"magnum opus\" of Chaucer, have been given in full.\n"
  "\n"
  "2. Jeremiah vi. 16.\n"
  "\n"
  "3. See Note 3 to the Sompnour's Tale.\n"
  "\n"
  "4. Just before, the Parson had cited the words of Job to God\n"
  "(Job x. 20-22), \"Suffer, Lord, that I may a while bewail and\n"
  "weep, ere I go without returning to the dark land, covered with\n"
  "the darkness of death; to the land of misease and of darkness,\n"
  "where as is the shadow of death; where as is no order nor\n"
  "ordinance, but grisly dread that ever shall last.\"\n"
  "\n"
  "5. \"I have lost everything - my time and my work.\"\n"
  "\n"
  "6. Accidie: neglectfulness or indifference; from the Greek,\n"
  "akedeia.\n"
  "\n"
  "7. The pax: an image which was presented to the people to be\n"
  "kissed, at that part of the mass where the priest said, \"Pax\n"
  "Domini sit semper vobiscum.\" (\"May the peace of the Lord be\n"
  "always with you\") The ceremony took the place, for greater\n"
  "convenience, of the \"kiss of peace,\" which clergy and people, at\n"
  "this passage, used to bestow upon each other.\n"
  "\n"
  "8. Three ways of ornamenting clothes with lace, &c.; in barring\n"
  "it was laid on crossways, in ounding it was waved, in paling it\n"
  "was laid on lengthways.\n"
  "\n"
  "9. Penitencer: a priest who enjoined penance in extraordinary\n"
  "cases.\n"
  "\n"
  "10. To be houseled: to receive the holy sacrament; from Anglo-\n"
  "Saxon, \"husel;\" Latin, \"hostia,\" or \"hostiola,\" the host.\n"
  "\n"
  "11. It was a frequent penance among the chivalric orders to\n"
  "wear mail shirts next the skin.\n"
  "\n"
  "12. Surquedrie: presumption; from old French, \"surcuider,\" to\n"
  "think arrogantly, be full of conceit.\n"
  "\n"
  "\n"
  "\n"
  "";
// }

const char precesDeChauceres[] PGMSECTION = // { // 3622 bytes
  "*PRECES DE CHAUCERES* <1>                            *Prayer of Chaucer*\n"
  "\n"
  "\n"
  "Now pray I to you all that hear this little treatise or read it, that\n"
  "if there be anything in it that likes them, that thereof they thank\n"
  "our Lord Jesus Christ, of whom proceedeth all wit and all\n"
  "goodness; and if there be anything that displeaseth them, I pray\n"
  "them also that they arette [impute] it to the default of mine\n"
  "unconning [unskilfulness], and not to my will, that would fain\n"
  "have said better if I had had conning; for the book saith, all that\n"
  "is written for our doctrine is written. Wherefore I beseech you\n"
  "meekly for the mercy of God that ye pray for me, that God have\n"
  "mercy on me and forgive me my guilts, and namely [specially]\n"
  "my translations and of inditing in worldly vanities, which I\n"
  "revoke in my Retractions, as is the Book of Troilus, the Book\n"
  "also of Fame, the Book of Twenty-five Ladies, the Book of the\n"
  "Duchess, the Book of Saint Valentine's Day and of the\n"
  "Parliament of Birds, the Tales of Canter bury, all those that\n"
  "sounen unto sin, [are sinful, tend towards sin] the Book of the\n"
  "Lion, and many other books, if they were in my mind or\n"
  "remembrance, and many a song and many a lecherous lay, of the\n"
  "which Christ for his great mercy forgive me the sins. But of the\n"
  "translation of Boece de Consolatione, and other books of\n"
  "consolation and of legend of lives of saints, and homilies, and\n"
  "moralities, and devotion, that thank I our Lord Jesus Christ, and\n"
  "his mother, and all the saints in heaven, beseeching them that\n"
  "they from henceforth unto my life's end send me grace to bewail\n"
  "my guilts, and to study to the salvation of my soul, and grant\n"
  "me grace and space of very repentance, penitence, confession,\n"
  "and satisfaction, to do in this present life, through the benign\n"
  "grace of Him that is King of kings and Priest of all priests, that\n"
  "bought us with his precious blood of his heart, so that I may be\n"
  "one of them at the day of doom that shall be saved: Qui cum\n"
  "Patre et Spiritu Sancto vivis et regnas Deus per omnia secula.\n"
  "Amen. <2>\n"
  "\n"
  "\n"
  "Notes to the Prayer of Chaucer\n"
  "\n"
  "\n"
  "1. The genuineness and real significance of this \"Prayer of\n"
  "Chaucer,\" usually called his \"Retractation,\" have been warmly\n"
  "disputed. On the one hand, it has been declared that the monks\n"
  "forged the retractation. and procured its insertion among the\n"
  "works of the man who had done so much to expose their abuses\n"
  "and ignorance, and to weaken their hold on popular credulity:\n"
  "on the other hand, Chaucer himself at the close of his life, is\n"
  "said to have greatly lamented the ribaldry and the attacks on the\n"
  "clergy which marked especially \"The Canterbury Tales,\" and to\n"
  "have drawn up a formal retractation of which the \"Prayer\" is\n"
  "either a copy or an abridgment. The beginning and end of the\n"
  "\"Prayer,\" as Tyrwhitt points out, are in tone and terms quite\n"
  "appropriate in the mouth of the Parson, while they carry on the\n"
  "subject of which he has been treating; and, despite the fact that\n"
  "Mr Wright holds the contrary opinion, Tyrwhitt seems to be\n"
  "justified in setting down the \"Retractation\" as interpolated into\n"
  "the close of the Parson's Tale. Of the circumstances under\n"
  "which the interpolation was made, or the causes by which it was\n"
  "dictated, little or nothing can now be confidently affirmed; but\n"
  "the agreement of the manuscripts and the early editions in\n"
  "giving it, render it impossible to discard it peremptorily as a\n"
  "declaration of prudish or of interested regret, with which\n"
  "Chaucer himself had nothing whatever to do.\n"
  "\n"
  "2. \"[You] Who with the Father and the Holy Spirit livest and\n"
  "reignest God for ever and ever. Amen.\"\n"
  "\n"
  "\n"
  "THE END OF THE CANTERBURY TALES\n"
  "\n"
  "\n"
  "\n"
  "";
// }

const char poemTheCourtOfLove0[] PGMSECTION = // { // 32650 bytes
  "                       THE COURT OF LOVE.\n"
  "\n"
  "\n"
  "\"The Court Of Love\" was probably Chaucer's first poem of any\n"
  "consequence. It is believed to have been written at the age, and\n"
  "under the circumstances, of which it contains express mention;\n"
  "that is, when the poet was eighteen years old, and resided as a\n"
  "student at Cambridge, -- about the year 1346. The composition\n"
  "is marked by an elegance, care, and finish very different from\n"
  "the bold freedom which in so great measure distinguishes the\n"
  "Canterbury Tales; and the fact is easily explained when we\n"
  "remember that, in the earlier poem, Chaucer followed a beaten\n"
  "path, in which he had many predecessors and competitors, all\n"
  "seeking to sound the praises of love with the grace, the\n"
  "ingenuity, and studious devotion, appropriate to the theme. The\n"
  "story of the poem is exceedingly simple. Under the name of\n"
  "Philogenet, a clerk or scholar of Cambridge, the poet relates\n"
  "that, summoned by Mercury to the Court of Love, he journeys\n"
  "to the splendid castle where the King and Queen of Love,\n"
  "Admetus and Alcestis, keep their state. Discovering among the\n"
  "courtiers a friend named Philobone, a chamberwoman to the\n"
  "Queen, Philogenet is led by her into a circular temple, where, in\n"
  "a tabernacle, sits Venus, with Cupid by her side. While he is\n"
  "surveying the motley crowd of suitors to the goddess,\n"
  "Philogenet is summoned back into the King's presence, chidden\n"
  "for his tardiness in coming to Court, and commanded to swear\n"
  "observance to the twenty Statutes of Love -- which are recited\n"
  "at length. Philogenet then makes his prayers and vows to\n"
  "Venus, desiring that he may have for his love a lady whom he\n"
  "has seen in a dream; and Philobone introduces him to the lady\n"
  "herself, named Rosial, to whom he does suit and service of love.\n"
  "At first the lady is obdurate to his entreaties; but, Philogenet\n"
  "having proved the sincerity of his passion by a fainting fit,\n"
  "Rosial relents, promises her favour, and orders Philobone to\n"
  "conduct him round the Court. The courtiers are then minutely\n"
  "described; but the description is broken off abruptly, and we are\n"
  "introduced to Rosial in the midst of a confession of her love.\n"
  "Finally she commands Philogenet to abide with her until the\n"
  "First of May, when the King of Love will hold high festival; he\n"
  "obeys; and the poem closes with the May Day festival service,\n"
  "celebrated by a choir of birds, who sing an ingenious, but what\n"
  "must have seemed in those days a more than slightly profane,\n"
  "paraphrase or parody of the matins for Trinity Sunday, to the\n"
  "praise of Cupid. From this outline, it will be seen at once that\n"
  "Chaucer's \"Court of Love\" is in important particulars different\n"
  "from the institutions which, in the two centuries preceding his\n"
  "own, had so much occupied the attention of poets and gallants,\n"
  "and so powerfully controlled the social life of the noble and\n"
  "refined classes. It is a regal, not a legal, Court which the poet\n"
  "pictures to us; we are not introduced to a regularly constituted\n"
  "and authoritative tribunal in which nice questions of conduct in\n"
  "the relations of lovers are discussed and decided -- but to the\n"
  "central and sovereign seat of Love's authority, where the\n"
  "statutes are moulded, and the decrees are issued, upon which\n"
  "the inferior and special tribunals we have mentioned frame their\n"
  "proceedings. The \"Courts of Love,\" in Chaucer's time, had lost\n"
  "none of the prestige and influence which had been conferred\n"
  "upon them by the patronage and participation of Kings, Queens,\n"
  "Emperors, and Popes. But the institution, in its legal or judicial\n"
  "character, was peculiar to France; and although the whole spirit\n"
  "of Chaucer's poem, especially as regards the esteem and\n"
  "reverence in which women were held, is that which animated\n"
  "the French Courts, his treatment of the subject is broader and\n"
  "more general, consequently more fitted to enlist the interest of\n"
  "English readers.\n"
  "(Transcriber's note: Modern scholars believe that Chaucer was\n"
  "not the author of this poem)\n"
  "\n"
  "The poem consists of 206 stanzas of seven lines each; of which,\n"
  "in this edition, eighty-three are represented by a prose\n"
  "abridgement.\n"
  "\n"
  "With timorous heart, and trembling hand of dread,\n"
  "Of cunning* naked, bare of eloquence,                             *skill\n"
  "Unto the *flow'r of port in womanhead*        *one who is the perfection\n"
  "I write, as he that none intelligence              of womanly behaviour*\n"
  "Of metres hath, <1> nor flowers of sentence,\n"
  "Save that me list my writing to convey,\n"
  "In that I can, to please her high nobley.*                    *nobleness\n"
  "\n"
  "The blossoms fresh of Tullius'* garden swoot**           *Cicero **sweet\n"
  "Present they not, my matter for to born:* <2>           *burnish, polish\n"
  "Poems of Virgil take here no root,\n"
  "Nor craft of Galfrid <3> may not here sojourn;\n"
  "Why *n'am I* cunning? O well may I mourn,                     *am I not*\n"
  "For lack of science, that I cannot write\n"
  "Unto the princess of my life aright!\n"
  "\n"
  "No terms are dign* unto her excellence,                          *worthy\n"
  "So is she sprung of noble stirp* and high;                    *stock <4>\n"
  "A world of honour and of reverence\n"
  "There is in her, this will I testify.\n"
  "Calliope, <5> thou sister wise and sly,*                        *skilful\n"
  "And thou, Minerva, guide me with thy grace,\n"
  "That language rude my matter not deface!\n"
  "\n"
  "Thy sugar droppes sweet of Helicon\n"
  "Distil in me, thou gentle Muse, I pray;\n"
  "And thee, Melpomene, <6> I call anon\n"
  "Of ignorance the mist to chase away;\n"
  "And give me grace so for to write and say,\n"
  "That she, my lady, of her worthiness,\n"
  "Accept *in gree* this little short treatess,*    *with favour* *treatise\n"
  "\n"
  "That is entitled thus, The Court of Love.\n"
  "And ye that be metricians,* me excuse,               *skilled versifiers\n"
  "I you beseech, for Venus' sake above;\n"
  "For what I mean in this ye need not muse:\n"
  "And if so be my lady it refuse\n"
  "For lack of ornate speech, I would be woe\n"
  "That I presume to her to write so.\n"
  "\n"
  "But my intent, and all my busy cure,*                              *care\n"
  "Is for to write this treatise, as I can,\n"
  "Unto my lady, stable, true, and sure,\n"
  "Faithful and kind, since first that she began\n"
  "Me to accept in service as her man;\n"
  "To her be all the pleasure of this book,\n"
  "That, when *her like,* she may it read and look.        *it pleases her*\n"
  "\n"
  "When [he] was young, at eighteen year of age,\n"
  "Lusty and light, desirous of pleasance,\n"
  "Approaching* full sad and ripe corage,<7>           *gradually attaining\n"
  "\n"
  "Then -- says the poet -- did Love urge him to do\n"
  "him obeisance, and to go \"the Court of Love to\n"
  "see, a lite [little] beside the Mount of Citharee.\"\n"
  "<8> Mercury bade him, on pain of death, to\n"
  "appear; and he went by strange and far countries\n"
  "in search of the Court. Seeing at last a crowd of\n"
  "people, \"as bees,\" making their way thither, the\n"
  "poet asked whither they went; and \"one that\n"
  "answer'd like a maid\" said that they were bound to\n"
  "the Court of Love, at Citheron,  where \"the King\n"
  "of Love, and all his noble rout [company],\n"
  "\n"
  "\"Dwelleth within a castle royally.\"\n"
  "So them apace I journey'd forth among,\n"
  "And as he said, so found I there truly;\n"
  "For I beheld the town -- so high and strong,\n"
  "And high pinnacles, large of height and long,\n"
  "With plate of gold bespread on ev'ry side,\n"
  "And precious stones, the stone work for to hide.\n"
  "\n"
  "No sapphire of Ind, no ruby rich of price,\n"
  "There lacked then, nor emerald so green,\n"
  "Balais, Turkeis, <9> nor thing, *to my devise,*        *in my judgement*\n"
  "That may the castle make for to sheen;*                    *be beautiful\n"
  "All was as bright as stars in winter be'n;\n"
  "And Phoebus shone, to make his peace again,\n"
  "For trespass* done to high estates twain,  --                   *offence\n"
  "\n"
  "When he had found Venus in the arms of Mars, and hastened to\n"
  "tell Vulcan of his wife's infidelity <10>. Now he was shining\n"
  "brightly on the castle, \"in sign he looked after Love's grace;\" for\n"
  "there is no god in Heaven or in Hell \"but he hath been right\n"
  "subject unto Love.\" Continuing his description of the castle,\n"
  "Philogenet says that he saw never any so large and high; within\n"
  "and without, it was painted \"with many a thousand daisies, red\n"
  "as rose,\" and white also, in signification of whom, he knew not;\n"
  "unless it was the flower of Alcestis <11>, who, under Venus,\n"
  "was queen of the place, as Admetus was king;\n"
  "\n"
  "To whom obey'd the ladies good nineteen <12>,\n"
  "With many a thousand other, bright of face.\n"
  "And young men fele* came forth with lusty pace,               *many <13>\n"
  "And aged eke, their homage to dispose;\n"
  "But what they were, I could not well disclose.\n"
  "\n"
  "Yet nere* and nere* forth in I gan me dress,                     *nearer\n"
  "Into a hall of noble apparail,*                             *furnishings\n"
  "With arras <14> spread, and cloth of gold, I guess,\n"
  "And other silk *of easier avail;*    *less difficult, costly, to attain*\n"
  "Under the *cloth of their estate,* sans fail,             *state canopy*\n"
  "The King and Queen there sat, as I beheld;\n"
  "It passed joy of *Elysee the feld.*                 *The Elysian Fields*\n"
  "\n"
  "There saintes* have their coming and resort,           *martyrs for love\n"
  "To see the King so royally beseen,*                             *adorned\n"
  "In purple clad, and eke the Queen *in sort;*                  *suitably*\n"
  "And on their heades saw I crownes twain,\n"
  "With stones frett,* so that it was no pain,                     *adorned\n"
  "Withoute meat or drink, to stand and see\n"
  "The Kinge's honour and the royalty.\n"
  "\n"
  "To treat of state affairs, Danger <15> stood by the\n"
  "King, and Disdain by the Queen; who cast her eyes\n"
  "haughtily about, sending forth beams that seemed\n"
  "\"shapen like a dart, sharp and piercing, and small and\n"
  "straight of line;\" while her hair shone as gold so fine,\n"
  "\"dishevel, crisp, down hanging at her back a yard in\n"
  "length.\" <16> Amazed and dazzled by her beauty,\n"
  "Philogenet stood perplexed, till he spied a Maid,\n"
  "Philobone -- a chamberwoman of the Queen's -- who\n"
  "asked how and on what errand he came thither.\n"
  "Learning that he had been summoned by Mercury, she\n"
  "told him that he ought to have come of his free will,\n"
  "and that he \"will be shent [rebuked, disgraced]\"\n"
  "because he did not.\n"
  "\n"
  "\"For ye that reign in youth and lustiness,\n"
  "Pamper'd with ease, and jealous in your age,\n"
  "Your duty is, as far as I can guess,\n"
  "To Love's Court to dresse* your voyage,                 *direct, address\n"
  "As soon as Nature maketh you so sage\n"
  "That ye may know a woman from a swan, <17>\n"
  "Or when your foot is growen half a span.\n"
  "\n"
  "\"But since that ye, by wilful negligence,\n"
  "This eighteen year have kept yourself at large,\n"
  "The greater is your trespass and offence,\n"
  "And in your neck you must bear all the charge:\n"
  "For better were ye be withoute barge*                              *boat\n"
  "Amid the sea in tempest and in rain,\n"
  "Than bide here, receiving woe and pain\n"
  "\n"
  "\"That ordained is for such as them absent\n"
  "From Love's Court by yeares long and fele.*                         many\n"
  "I lay* my life ye shall full soon repent;                         *wager\n"
  "For Love will rive your colour, lust, and heal:*                 *health\n"
  "Eke ye must bait* on many a heavy meal:                            *feed\n"
  "*No force,* y-wis; I stirr'd you long agone                  *no matter*\n"
  "To draw to Court,\" quoth little Philobone.\n"
  "\n"
  "\"Ye shall well see how rough and angry face\n"
  "The King of Love will show, when ye him see;\n"
  "By mine advice kneel down and ask him grace,\n"
  "Eschewing* peril and adversity;                                *avoiding\n"
  "For well I wot it will none other be;\n"
  "Comfort is none, nor counsel to your ease;\n"
  "Why will ye then the King of Love displease?\"\n"
  "\n"
  "Thereupon Philogenet professed humble repentance,\n"
  "and willingness to bear all hardship and chastisement\n"
  "for his past offence.\n"
  "\n"
  "These wordes said, she caught me by the lap,*       *edge of the garment\n"
  "And led me forth into a temple round,\n"
  "Both large and wide; and, as my blessed hap\n"
  "And good. adventure was, right soon I found\n"
  "A tabernacle <18> raised from the ground,\n"
  "Where Venus sat, and Cupid by her side;\n"
  "Yet half for dread I gan my visage hide.\n"
  "\n"
  "And eft* again I looked and beheld,                          *afterwards\n"
  "Seeing *full sundry people* in the place,         *people of many sorts*\n"
  "And *mister folk,* and some that might not weld         *craftsmen <19>*\n"
  "Their limbes well, -- me thought a wonder case.                     *use\n"
  "The temple shone with windows all of glass,\n"
  "Bright as the day, with many a fair image;\n"
  "And there I saw the fresh queen of Carthage,\n"
  "\n"
  "Dido, that brent* her beauty for the love                         *burnt\n"
  "Of false Aeneas; and the waimenting*                          *lamenting\n"
  "Of her, Annelide, true as turtle dove\n"
  "To Arcite false; <20> and there was in painting\n"
  "Of many a Prince, and many a doughty King,\n"
  "Whose martyrdom was show'd about the walls;\n"
  "And how that fele* for love had suffer'd falls.**     *many **calamities\n"
  "\n"
  "Philogenet was astonished at the crowd of people that\n"
  "he saw, doing sacrifice to the god and goddess.\n"
  "Philobone informed him that they came from other\n"
  "courts; those who knelt in blue wore the colour in\n"
  "sign of their changeless truth <21>; those in black,\n"
  "who uttered cries of grief, were the sick and dying of\n"
  "love. The priests, nuns, hermits, and friars, and all that\n"
  "sat in white, in russet and in green, \"wailed of their\n"
  "woe;\" and for all people, of every degree, the Court\n"
  "was open and free. While he walked about with\n"
  "Philobone, a messenger from the King entered, and\n"
  "summoned all the new-come folk to the royal\n"
  "presence. Trembling and pale, Philogenet approached\n"
  "the throne of Admetus, and was sternly asked why he\n"
  "came so late to Court. He pleaded that a hundred\n"
  "times he had been at the gate, but had been prevented\n"
  "from entering by failure to see any of his\n"
  "acquaintances, and by shamefacedness. The King\n"
  "pardoned him, on condition that thenceforth he should\n"
  "serve Love; and the poet took oath to do so, \"though\n"
  "Death therefor me thirle [pierce] with his spear.\"\n"
  "When the King had seen all the new-comers, he\n"
  "commanded an officer to take their oaths of\n"
  "allegiance, and show them the Statutes of the Court,\n"
  "which must be observed till death.\n"
  "\n"
  "And, for that I was letter'd, there I read\n"
  "The statutes whole of Love's Court and hail:\n"
  "The first statute that on the book was spread,\n"
  "Was, To be true in thought and deedes all\n"
  "Unto the King of Love, the lord royal;\n"
  "And, to the Queen, as faithful and as kind\n"
  "As I could think with hearte, will, and mind.\n"
  "\n"
  "The second statute, Secretly to keep\n"
  "Counsel* of love, not blowing** ev'rywhere            *secrets **talking\n"
  "All that I know, and let it sink and fleet;*                      *float\n"
  "It may not sound in ev'ry wighte's ear:\n"
  "Exiling slander ay for dread and fear,\n"
  "And to my lady, which I love and serve,\n"
  "Be true and kind, her grace for to deserve.\n"
  "\n"
  "The third statute was clearly writ also,\n"
  "Withoute change to live and die the same,\n"
  "None other love to take, for weal nor woe,\n"
  "For blind delight, for earnest nor for game:\n"
  "Without repent, for laughing or for grame,*            *vexation, sorrow\n"
  "To bide still in full perseverance:\n"
  "All this was whole the Kinge's ordinance.\n"
  "\n"
  "The fourth statute, To *purchase ever to her,*       *promote her cause*\n"
  "And stirre folk to love, and bete* fire                          *kindle\n"
  "On Venus' altar, here about and there,\n"
  "And preach to them of love and hot desire,\n"
  "And tell how love will quite* well their hire:                   *reward\n"
  "This must be kept; and loth me to displease:\n"
  "If love be wroth, pass; for thereby is ease.\n"
  "\n"
  "The fifth statute, Not to be dangerous,*              *fastidious, angry\n"
  "If that a thought would reave* me of my sleep:                  *deprive\n"
  "Nor of a sight to be over squaimous;*                          *desirous\n"
  "And so verily this statute was to keep,\n"
  "To turn and wallow in my bed and weep,\n"
  "When that my lady, of her cruelty,\n"
  "Would from her heart exilen all pity.\n"
  "\n"
  "The sixth statute, It was for me to use\n"
  "Alone to wander, void of company,\n"
  "And on my lady's beauty for to muse,\n"
  "And thinken it *no force* to live or die;       *matter of indifference*\n"
  "And eft again to think* the remedy,                          *think upon\n"
  "How to her grace I might anon attain,\n"
  "And tell my woe unto my sovereign.\n"
  "\n"
  "The sev'nth statute was, To be patient,\n"
  "Whether my lady joyful were or wroth;\n"
  "For wordes glad or heavy, diligent,\n"
  "Whether that she me helde *lefe or loth:*          *in love or loathing*\n"
  "And hereupon I put was to mine oath,\n"
  "Her for to serve, and lowly to obey,\n"
  "And show my cheer,* yea, twenty times a day.                *countenance\n"
  "\n"
  "The eighth statute, to my rememberance,\n"
  "Was, For to speak and pray my lady dear,\n"
  "With hourly labour and great entendance,*                     *attention\n"
  "Me for to love with all her heart entere,*                       *entire\n"
  "And me desire and make me joyful cheer,\n"
  "Right as she is, surmounting every fair;\n"
  "Of beauty well,* and gentle debonair.                      *the fountain\n"
  "\n"
  "The ninth statute, with letters writ of gold,\n"
  "This was the sentence, How that I and all\n"
  "Should ever dread to be too overbold\n"
  "Her to displease; and truly so I shall;\n"
  "But be content for all thing that may fall,\n"
  "And meekly take her chastisement and yerd,*                   *rod, rule\n"
  "And to offend her ever be afear'd.\n"
  "\n"
  "The tenth statute was, Equally* to discern                       *justly\n"
  "Between the lady and thine ability,\n"
  "And think thyself art never like to earn,\n"
  "By right, her mercy nor her equity,\n"
  "But of her grace and womanly pity:\n"
  "For, though thyself be noble in thy strene,*            *strain, descent\n"
  "A thousand fold more noble is thy Queen.\n"
  "\n"
  "Thy life's lady and thy sovereign,\n"
  "That hath thine heart all whole in governance,\n"
  "Thou may'st no wise it take to disdain,\n"
  "To put thee humbly at her ordinance,\n"
  "And give her free the rein of her pleasance;\n"
  "For liberty is thing that women look,*                 *look for, desire\n"
  "And truly else *the matter is a crook.*                *things go wrong*\n"
  "\n"
  "Th' eleventh statute, Thy signes for to know\n"
  "With eye and finger, and with smiles soft,\n"
  "And low to couch, and alway for to show,\n"
  "For dread of spies, for to winken oft:\n"
  "And secretly to bring a sigh aloft,\n"
  "But still beware of over much resort;\n"
  "For that peradventure spoileth all thy sport.\n"
  "\n"
  "The twelfth statute remember to observe:\n"
  "For all the pain thou hast for love and woe,\n"
  "All is too lite* her mercy to deserve,                           *little\n"
  "Thou muste think, where'er thou ride or go;\n"
  "And mortal woundes suffer thou also,\n"
  "All for her sake, and think it well beset*                        *spent\n"
  "Upon thy love, for it may not be bet.*                   *better (spent)\n"
  "\n"
  "The thirteenth statute, Whilom is to think\n"
  "What thing may best thy lady like and please,\n"
  "And in thine hearte's bottom let it sink:\n"
  "Some thing devise, and take for it thine ease,\n"
  "And send it her, that may her heart appease:\n"
  "Some heart, or ring, or letter, or device,\n"
  "Or precious stone; but spare not for no price.\n"
  "\n"
  "The fourteenth statute eke thou shalt assay\n"
  "Firmly to keep, the most part of thy life:\n"
  "Wish that thy lady in thine armes lay,\n"
  "And nightly dream, thou hast thy nighte's wife\n"
  "Sweetly in armes, straining her as blife:*                 *eagerly <22>\n"
  "And, when thou seest it is but fantasy,\n"
  "See that thou sing not over merrily;\n"
  "\n"
  "For too much joy hath oft a woeful end.\n"
  "It *longeth eke this statute for to hold,*     *it belongs to the proper\n"
  "To deem thy lady evermore thy friend,        observance of this statute*\n"
  "And think thyself in no wise a cuckold.\n"
  "In ev'ry thing she doth but as she sho'ld:\n"
  "Construe the best, believe no tales new,\n"
  "For many a lie is told, that seems full true.\n"
  "\n"
  "But think that she, so bounteous and fair,\n"
  "Could not be false: imagine this algate;*                 *at all events\n"
  "And think that wicked tongues would her apair,*                  *defame\n"
  "Sland'ring her name and *worshipful estate,*           *honourable fame*\n"
  "And lovers true to setten at debate:\n"
  "And though thou seest a fault right at thine eye,\n"
  "Excuse it blife, and glose* it prettily.                  *gloss it over\n"
  "\n"
  "The fifteenth statute, Use to swear and stare,\n"
  "And counterfeit a leasing* hardily,**                *falsehood **boldly\n"
  "To save thy lady's honour ev'rywhere,\n"
  "And put thyself for her to fight boldly;\n"
  "Say she is good, virtuous, and ghostly,*                *spiritual, pure\n"
  "Clear of intent, and heart, and thought, and will;\n"
  "And argue not for reason nor for skill\n"
  "\n"
  "Against thy lady's pleasure nor intent,\n"
  "For love will not be counterpled* indeed:         *met with counterpleas\n"
  "Say as she saith, then shalt thou not be shent;*              *disgraced\n"
  "\"The crow is white;\" \"Yea truly, so I rede:\"*                     *judge\n"
  "And aye what thing that she will thee forbid,\n"
  "Eschew all that, and give her sov'reignty,\n"
  "Her appetite to follow in all degree.\n"
  "\n"
  "The sixteenth statute, keep it if thou may: <23>\n"
  "Sev'n times at night thy lady for to please,\n"
  "And sev'n at midnight, sev'n at morrow day,\n"
  "And drink a caudle early for thine ease.\n"
  "Do this, and keep thine head from all disease,\n"
  "And win the garland here of lovers all,\n"
  "That ever came in Court, or ever shall.\n"
  "\n"
  "Full few, think I, this statute hold and keep;\n"
  "But truly this my reason *gives me feel,*       *enables me to perceive*\n"
  "That some lovers should rather fall asleep,\n"
  "Than take on hand to please so oft and weel.*                      *well\n"
  "There lay none oath to this statute adele,*                     *annexed\n"
  "But keep who might *as gave him his corage:*               *as his heart\n"
  "Now get this garland, folk of lusty age!                   inspired him*\n"
  "\n"
  "Now win who may, ye lusty folk of youth,\n"
  "This garland fresh, of flowers red and white,\n"
  "Purple and blue, and colours full uncouth,*                     *strange\n"
  "And I shall crown him king of all delight!\n"
  "In all the Court there was not, to my sight,\n"
  "A lover true, that he was not adread,\n"
  "When he express* had heard the statute read.                    *plainly\n"
  "\n"
  "The sev'nteenth statute, When age approacheth on,\n"
  "And lust is laid, and all the fire is queint,*                 *quenched\n"
  "As freshly then thou shalt begin to fon,*                 *behave fondly\n"
  "And doat in love, and all her image paint\n"
  "In thy remembrance, till thou gin to faint,\n"
  "As in the first season thine heart began:\n"
  "And her desire, though thou nor may nor can\n"
  "\n"
  "Perform thy living actual and lust;\n"
  "Register this in thine rememberance:\n"
  "Eke when thou may'st not keep thy thing from rust,\n"
  "Yet speak and talk of pleasant dalliance;\n"
  "For that shall make thine heart rejoice and dance;\n"
  "And when thou may'st no more the game assay,\n"
  "The statute bids thee pray for them that may.\n"
  "\n"
  "The eighteenth statute, wholly to commend,\n"
  "To please thy lady, is, That thou eschew\n"
  "With sluttishness thyself for to offend;\n"
  "Be jolly, fresh, and feat,* with thinges new,               *dainty <24>\n"
  "Courtly with manner, this is all thy due,\n"
  "Gentle of port, and loving cleanliness;\n"
  "This is the thing that liketh thy mistress.\n"
  "\n"
  "And not to wander like a dulled ass,\n"
  "Ragged and torn, disguised in array,\n"
  "Ribald in speech, or out of measure pass,\n"
  "Thy bound exceeding; think on this alway:\n"
  "For women be of tender heartes ay,\n"
  "And lightly set their pleasure in a place;\n"
  "When they misthink,* they lightly let it pace.            *think wrongly\n"
  "\n"
  "The nineteenth statute, Meat and drink forget:\n"
  "Each other day see that thou fast for love,\n"
  "For in the Court they live withoute meat,\n"
  "Save such as comes from Venus all above;\n"
  "They take no heed, *in pain of great reprove,*         *on pain of great\n"
  "Of meat and drink, for that is all in vain,                    reproach*\n"
  "Only they live by sight of their sov'reign.\n"
  "\n"
  "The twentieth statute, last of ev'ry one,\n"
  "Enrol it in thy hearte's privity;\n"
  "To wring and wail, to turn, and sigh, and groan,\n"
  "When that thy lady absent is from thee;\n"
  "And eke renew the wordes all that she\n"
  "Between you twain hath said, and all the cheer\n"
  "That thee hath made thy life's lady dear.\n"
  "\n"
  "And see thy heart in quiet nor in rest\n"
  "Sojourn, till time thou see thy lady eft,*                        *again\n"
  "But whe'er* she won** by south, or east, or west,       *whether **dwell\n"
  "With all thy force now see it be not left\n"
  "Be diligent, *till time* thy life be reft,         *until the time that*\n"
  "In that thou may'st, thy lady for to see;\n"
  "This statute was of old antiquity.\n"
  "\n"
  "The officer, called Rigour -- who is incorruptible by\n"
  "partiality, favour, prayer, or gold -- made them swear\n"
  "to keep the statutes; and, after taking the oath,\n"
  "Philogenet turned over other leaves of the book,\n"
  "containing the statutes of women. But Rigour sternly\n"
  "bade him forbear; for no man might know the statutes\n"
  "that belong to women.\n"
  "\n"
  "\"In secret wise they kepte be full close;\n"
  "They sound* each one to liberty, my friend;                *tend, accord\n"
  "Pleasant they be, and to their own purpose;\n"
  "There wot* no wight of them, but God and fiend,                   *knows\n"
  "Nor aught shall wit, unto the worlde's end.\n"
  "The queen hath giv'n me charge, in pain to die,\n"
  "Never to read nor see them with mine eye.\n"
  "\n"
  "\"For men shall not so near of counsel be'n\n"
  "With womanhead, nor knowen of their guise,\n"
  "Nor what they think, nor of their wit th'engine;*                 *craft\n"
  "*I me report to* Solomon the wise, <25>           *I refer for proof to*\n"
  "And mighty Samson, which beguiled thrice\n"
  "With Delilah was; he wot that, in a throw,\n"
  "There may no man statute of women know.\n"
  "\n"
  "\"For it peradventure may right so befall,\n"
  "That they be bound by nature to deceive,\n"
  "And spin, and weep, and sugar strew on gall, <26>\n"
  "The heart of man to ravish and to reave,\n"
  "And whet their tongue as sharp as sword or gleve:*        *glaive, sword\n"
  "It may betide this is their ordinance,\n"
  "So must they lowly do their observance,\n"
  "\n"
  "\"And keep the statute given them *of kind,*                  *by nature*\n"
  "Of such as Love hath giv'n them in their life.\n"
  "Men may not wit why turneth every wind,\n"
  "Nor waxe wise, nor be inquisitife\n"
  "To know secret of maid, widow, or wife;\n"
  "For they their statutes have to them reserved,\n"
  "And never man to know them hath deserved.\"\n"
  "\n"
  "Rigour then sent them forth to pay court to Venus,\n"
  "and pray her to teach them how they might serve and\n"
  "please their dames, or to provide with ladies those\n"
  "whose hearts were yet vacant. Before Venus knelt a\n"
  "thousand sad petitioners, entreating her to punish \"the\n"
  "false untrue,\" that had broken their vows, \"barren of\n"
  "ruth, untrue of what they said, now that their lust and\n"
  "pleasure is allay'd.\" But the mourners were in a\n"
  "minority;\n"
  "\n"
  "Yet eft again, a thousand million,\n"
  "Rejoicing, love, leading their life in bliss:\n"
  "They said: \"Venus, redress* of all division,                     *healer\n"
  "Goddess eternal, thy name heried* is!                         *glorified\n"
  "By love's bond is knit all thing, y-wis,*                     *assuredly\n"
  "Beast unto beast, the earth to water wan,*                         *pale\n"
  "Bird unto bird, and woman unto man; <27>\n"
  "\n"
  "\"This is the life of joy that we be in,\n"
  "Resembling life of heav'nly paradise;\n"
  "Love is exiler ay of vice and sin;\n"
  "Love maketh heartes lusty to devise;\n"
  "Honour and grace have they in ev'ry wise,\n"
  "That be to love's law obedient;\n"
  "Love maketh folk benign and diligent;\n"
  "\n"
  "\"Aye stirring them to dreade vice and shame:\n"
  "In their degree it makes them honourable;\n"
  "And sweet it is of love to bear the name,\n"
  "So that his love be faithful, true, and stable:\n"
  "Love pruneth him to seemen amiable;\n"
  "Love hath no fault where it is exercis'd,\n"
  "But sole* with them that have all love despis'd:\"                  *only\n"
  "\n"
  "And they conclude with grateful honours to the goddess\n"
  "-- rejoicing hat they are hers in heart, and all inflamed\n"
  "with her grace and heavenly fear. Philogenet now\n"
  "entreats the goddess to remove his grief; for he also\n"
  "loves, and hotly, only he does not know where --\n"
  "\n"
  "\"Save only this, by God and by my troth;\n"
  "Troubled I was with slumber, sleep, and sloth\n"
  "This other night, and in a vision\n"
  "I saw a woman roamen up and down,\n"
  "\n"
  "\"Of *mean stature,* and seemly to behold,              *middling height*\n"
  "Lusty and fresh, demure of countenance,\n"
  "Young and well shap'd, with haire sheen* as gold,               *shining\n"
  "With eyne as crystal, farced* with pleasance;                   *crammed\n"
  "And she gan stir mine heart a lite* to dance;                    *little\n"
  "But suddenly she vanish gan right there:\n"
  "Thus I may say, I love, and wot* not where.\"                       *know\n"
  "\n"
  "If he could only know this lady, he would serve and obey her\n"
  "with all benignity; but if his destiny were otherwise, he would\n"
  "gladly love and serve his lady, whosoever she might be. He\n"
  "called on Venus for help to possess his queen and heart's life,\n"
  "and vowed daily war with Diana: \"that goddess chaste I keepen\n"
  "[care] in no wise to serve; a fig for all her chastity!\" Then he\n"
  "rose and went his way, passing by a rich and beautiful shrine,\n"
  "which, Philobone informed him, was the sepulchre of Pity. \"A\n"
  "tender creature,\" she said,\n"
  "\n"
  "\"Is shrined there, and Pity is her name.\n"
  "She saw an eagle wreak* him on a fly,                            *avenge\n"
  "And pluck his wing, and eke him, *in his game;*              *for sport*\n"
  "And tender heart of that hath made her die:\n"
  "Eke she would weep, and mourn right piteously,\n"
  "To see a lover suffer great distress.\n"
  "In all the Court was none, as I do guess,\n"
  "\n"
  "\"That could a lover half so well avail,*                           *help\n"
  "Nor of his woe the torment or the rage\n"
  "Aslake;* for he was sure, withoute fail,                        *assuage\n"
  "That of his grief she could the heat assuage.\n"
  "Instead of Pity, speedeth hot Courage\n"
  "The matters all of Court, now she is dead;\n"
  "*I me report in this to womanhead.*         *for evidence I refer to the\n"
  "                                         behaviour of women themselves.*\n"
  "\n"
  "\"For wail, and weep, and cry, and speak, and pray, --\n"
  "Women would not have pity on thy plaint;\n"
  "Nor by that means to ease thine heart convey,\n"
  "But thee receive for their own talent:*                     *inclination\n"
  "And say that Pity caus'd thee, in consent\n"
  "Of ruth,* to take thy service and thy pain,                  *compassion\n"
  "In that thou may'st, to please thy sovereign.\"\n"
  "\n"
  "Philobone now promised to lead Philogenet to \"the fairest lady\n"
  "under sun that is,\" the \"mirror of joy and bliss,\" whose name is\n"
  "Rosial, and \"whose heart as yet is given to no wight;\"\n"
  "suggesting that, as he also was \"with love but light advanc'd,\"\n"
  "he might set this lady in the place of her of whom he had\n"
  "dreamed. Entering a chamber gay, \"there was Rosial, womanly\n"
  "to see;\" and the subtle-piercing beams of her eyes wounded\n"
  "Philogenet to the heart. When he could speak, he threw himself\n"
  "on his knees, beseeching her to cool his fervent woe:\n"
  "\n"
  "For there I took full purpose in my mind,\n"
  "Unto her grace my painful heart to bind.\n"
  "\n"
  "For, if I shall all fully her descrive,*                       *describe\n"
  "Her head was round, by compass of nature;\n"
  "Her hair as gold, she passed all alive,\n"
  "And lily forehead had this creature,\n"
  "With lively *browes flaw,* of colour pure,         *yellow eyebrows <28>\n"
  "Between the which was mean disseverance\n"
  "From ev'ry brow, to show a due distance.\n"
  "\n"
  "Her nose directed straight, even as line,\n"
  "With form and shape thereto convenient,\n"
  "In which the *goddes' milk-white path* doth shine;          *the galaxy*\n"
  "And eke her eyne be bright and orient\n"
  "As is the smaragd,* unto my judgment,                           *emerald\n"
  "Or yet these starres heav'nly, small, and bright;\n"
  "Her visage is of lovely red and white.\n"
  "\n"
  "Her mouth is short, and shut in little space,\n"
  "Flaming somedeal,* not over red I mean,                        *somewhat\n"
  "With pregnant lips, and thick to kiss, percase*           *as it chanced\n"
  "(For lippes thin, not fat, but ever lean,\n"
  "They serve of naught, they be not worth a bean;\n"
  "For if the bass* be full, there is delight;                   *kiss <29>\n"
  "Maximian <30> truly thus doth he write).\n"
  "\n"
  "But to my purpose: I say, white as snow\n"
  "Be all her teeth, and in order they stand\n"
  "Of one stature; and eke her breath, I trow,\n"
  "Surmounteth all odours that e'er I fand*                          *found\n"
  "In sweetness; and her body, face, and hand\n"
  "Be sharply slender, so that, from the head\n"
  "Unto the foot, all is but womanhead.*                *womanly perfection\n"
  "\n"
  "I hold my peace of other thinges hid:\n"
  "Here shall my soul, and not my tongue, bewray;\n"
  "But how she was array'd, if ye me bid,\n"
  "That shall I well discover you and say:\n"
  "A bend* of gold and silk, full fresh and gay,                      *band\n"
  "With hair *in tress, y-broidered* full well,        *plaited in tresses*\n"
  "Right smoothly kempt,* and shining every deal.                   *combed\n"
  "\n"
  "About her neck a flow'r of fresh device\n"
  "With rubies set, that lusty were to see'n;\n"
  "And she in gown was, light and summer-wise,\n"
  "Shapen full well, the colour was of green,\n"
  "With *aureate seint* about her sides clean,            *golden cincture*\n"
  "With divers stones, precious and rich:\n"
  "Thus was she ray'd,* yet saw I ne'er her lich,**         *arrayed **like\n"
  "\n"
  "";
// }

const char poemTheCourtOfLove1[] PGMSECTION = // { // 32307 bytes
  "If Jove had but seen this lady, Calisto and Alcmena had never\n"
  "lain in his arms, nor had he loved the fair Europa, nor Danae,\n"
  "nor Antiope; \"for all their beauty stood in Rosial; she seemed\n"
  "like a thing celestial.\" By and by, Philogenet presented to her his\n"
  "petition for love, which she heard with some haughtiness; she\n"
  "was not, she said, well acquainted with him, she did not know\n"
  "where he dwelt, nor his name and condition. He informed her\n"
  "that \"in art of love he writes,\" and makes songs that may be\n"
  "sung in honour of the King and Queen of Love. As for his name\n"
  "--\n"
  "\n"
  "\"My name? alas, my heart, why mak'st thou strange?*         *why so cold\n"
  "Philogenet I call'd am far and near,                        or distant?*\n"
  "Of Cambridge clerk, that never think to change\n"
  "From you, that with your heav'nly streames* clear        *beams, glances\n"
  "Ravish my heart; and ghost, and all in fere:*              *all together\n"
  "Since at the first I writ my bill* for grace,                  *petition\n"
  "Me thinks I see some mercy in your face;\"\n"
  "\n"
  "And again he humbly pressed his suit. But the lady disdained the\n"
  "idea that, \"for a word of sugar'd eloquence,\" she should have\n"
  "compassion in so little space; \"there come but few who speede\n"
  "here so soon.\" If, as he says, the beams of her eyes pierce and\n"
  "fret him, then let him withdraw from her presence:\n"
  "\n"
  "\"Hurt not yourself, through folly, with a look;\n"
  "I would be sorry so to make you sick!\n"
  "A woman should beware eke whom she took:\n"
  "Ye be a clerk: go searche well my book,\n"
  "If any women be so light* to win:                                  *easy\n"
  "Nay, bide a while, though ye were *all my kin.\"*       *my only kindred*\n"
  "\n"
  "He might sue and serve, and wax pale, and green, and dead,\n"
  "without murmuring in any wise; but whereas he desired her\n"
  "hastily to lean to love, he was unwise, and must cease that\n"
  "language. For some had been at Court for twenty years, and\n"
  "might not obtain their mistresses' favour; therefore she\n"
  "marvelled that he was so bold as to treat of love with her.\n"
  "Philogenet, on this, broke into pitiful lamentation; bewailing the\n"
  "hour in which he was born, and assuring the unyielding lady that\n"
  "the frosty grave and cold must be his bed, unless she relented.\n"
  "\n"
  "With that I fell in swoon, and dead as stone,\n"
  "With colour slain,* and wan as ashes pale;                    *deathlike\n"
  "And by the hand she caught me up anon:\n"
  "\"Arise,\" quoth she; \"what? have ye drunken dwale?* *sleeping potion <31>\n"
  "Why sleepe ye? It is no nightertale.\"*                       *night-time\n"
  "\"Now mercy! sweet,\" quoth I, y-wis afraid;\n"
  "\"What thing,\" quoth she, \"hath made you so dismay'd?\"\n"
  "\n"
  "She said that by his hue she knew well that he was a lover; and\n"
  "if he were secret, courteous, and kind, he might know how all\n"
  "this could be allayed. She would amend all that she had missaid,\n"
  "and set his heart at ease; but he must faithfully keep the statutes,\n"
  "\"and break them not for sloth nor ignorance.\" The lover\n"
  "requests, however, that the sixteenth may be released or\n"
  "modified, for it \"doth him great grievance;\" and she complies.\n"
  "\n"
  "And softly then her colour gan appear,\n"
  "As rose so red, throughout her visage all;\n"
  "Wherefore methinks it is according* her                  *appropriate to\n"
  "That she of right be called Rosial.\n"
  "Thus have I won, with wordes great and small,\n"
  "Some goodly word of her that I love best,\n"
  "And trust she shall yet set mine heart in rest.\n"
  "\n"
  "Rosial now told Philobone to conduct Philogenet all over the\n"
  "Court, and show him what lovers and what officers dwelt there;\n"
  "for he was yet a stranger.\n"
  "\n"
  "And, stalking soft with easy pace, I saw\n"
  "About the king standen all environ,*                        *around <32>\n"
  "Attendance, Diligence, and their fellaw\n"
  "Furtherer, Esperance,* and many one;                               *Hope\n"
  "Dread-to-offend there stood, and not alone;\n"
  "For there was eke the cruel adversair,\n"
  "The lover's foe, that called is Despair;\n"
  "\n"
  "Which unto me spake angrily and fell,*                          *cruelly\n"
  "And said, my lady me deceive shall:\n"
  "\"Trow'st thou,\" quoth she, \"that all that she did tell\n"
  "Is true? Nay, nay, but under honey gall.\n"
  "Thy birth and hers they be no thing egal:*                        *equal\n"
  "Cast off thine heart, <33> for all her wordes white,\n"
  "For in good faith she loves thee but a lite.*                    *little\n"
  "\n"
  "\"And eke remember, thine ability\n"
  "May not compare with her, this well thou wot.\"\n"
  "Yea, then came Hope and said, \"My friend, let be!\n"
  "Believe him not: Despair he gins to doat.\"\n"
  "\"Alas,\" quoth I, \"here is both cold and hot:\n"
  "The one me biddeth love, the other nay;\n"
  "Thus wot I not what me is best to say.\n"
  "\n"
  "\"But well wot I, my lady granted me\n"
  "Truly to be my wounde's remedy;\n"
  "Her gentleness* may not infected be                        *noble nature\n"
  "With doubleness,* this trust I till I die.\"                   *duplicity\n"
  "So cast I t' avoid Despair's company,\n"
  "And take Hope to counsel and to friend.\n"
  "\"Yea, keep that well,\" quoth Philobone, \"in mind.\"\n"
  "\n"
  "And there beside, within a bay window,\n"
  "Stood one in green, full large of breadth and length,\n"
  "His beard as black as feathers of the crow;\n"
  "His name was Lust, of wondrous might and strength;\n"
  "And with Delight to argue there he think'th,\n"
  "For this was alway his opinion,\n"
  "That love was sin: and so he hath begun\n"
  "\n"
  "To reason fast, and *ledge authority:*               *allege authorities\n"
  "\"Nay,\" quoth Delight, \"love is a virtue clear,\n"
  "And from the soul his progress holdeth he:\n"
  "Blind appetite of lust doth often steer,*              *stir (the heart)\n"
  "And that is sin; for reason lacketh there:\n"
  "For thou dost think thy neighbour's wife to win;\n"
  "Yet think it well that love may not be sin;\n"
  "\n"
  "\"For God, and saint, they love right verily,\n"
  "Void of all sin and vice: this know I weel,*                       *well\n"
  "Affection of flesh is sin truly;\n"
  "But very* love is virtue, as I feel;                               *true\n"
  "For very love may frail desire akele:*                             *cool\n"
  "For very love is love withoute sin.\"\n"
  "\"Now stint,\"* quoth Lust, \"thou speak'st not worth a pin.\"        *cease\n"
  "\n"
  "And there I left them in their arguing,\n"
  "Roaming farther into the castle wide,\n"
  "And in a corner Liar stood talking\n"
  "Of leasings* fast, with Flattery there beside;               *falsehoods\n"
  "He said that women *ware attire of pride,                          *wore\n"
  "And men were found of nature variant,\n"
  "And could be false and *showe beau semblant.*          *put on plausible\n"
  "                                                 appearances to deceive*\n"
  "Then Flattery bespake and said, y-wis:\n"
  "\"See, so she goes on pattens fair and feat;*               *pretty, neat\n"
  "It doth right well: what pretty man is this\n"
  "That roameth here? now truly drink nor meat\n"
  "Need I not have, my heart for joy doth beat\n"
  "Him to behold, so is he goodly fresh:\n"
  "It seems for love his heart is tender and nesh.\"*             *soft <34>\n"
  "\n"
  "This is the Court of lusty folk and glad,\n"
  "And well becomes their habit and array:\n"
  "O why be some so sorry and so sad,\n"
  "Complaining thus in black and white and gray?\n"
  "Friars they be, and monkes, in good fay:\n"
  "Alas, for ruth! great dole* it is to see,                        *sorrow\n"
  "To see them thus bewail and sorry be.\n"
  "\n"
  "See how they cry and ring their handes white,\n"
  "For they so soon* went to religion!,                              *young\n"
  "And eke the nuns with veil and wimple plight,*                  *plaited\n"
  "Their thought is, they be in confusion:\n"
  "\"Alas,\" they say, \"we feign perfection, <35>\n"
  "In clothes wide, and lack our liberty;\n"
  "But all the sin must on our friendes be. <36>\n"
  "\n"
  "\"For, Venus wot, we would as fain* as ye,                        *gladly\n"
  "That be attired here and *well beseen,*                  *gaily clothed*\n"
  "Desire man, and love in our degree,'\n"
  "Firm and faithful, right as would the Queen:\n"
  "Our friendes wick', in tender youth and green,\n"
  "Against our will made us religious;\n"
  "That is the cause we mourn and waile thus.\"\n"
  "\n"
  "Then said the monks and friars *in the tide,*         *at the same time*\n"
  "\"Well may we curse our abbeys and our place,\n"
  "Our statutes sharp to sing in copes wide, <37>\n"
  "Chastely to keep us out of love's grace,\n"
  "And never to feel comfort nor solace;*                          *delight\n"
  "Yet suffer we the heat of love's fire,\n"
  "And after some other haply we desire.\n"
  "\n"
  "\"O Fortune cursed, why now and wherefore\n"
  "Hast thou,\" they said, \"bereft us liberty,\n"
  "Since Nature gave us instrument in store,\n"
  "And appetite to love and lovers be?\n"
  "Why must we suffer such adversity,\n"
  "Dian' to serve, and Venus to refuse?\n"
  "Full *often sithe* these matters do us muse.               *many a time*\n"
  "\n"
  "\"We serve and honour, sore against our will,\n"
  "Of chastity the goddess and the queen;\n"
  "*Us liefer were* with Venus bide still,                *we would rather*\n"
  "And have regard for love, and subject be'n\n"
  "Unto these women courtly, fresh, and sheen.*          *bright, beautiful\n"
  "Fortune, we curse thy wheel of variance!\n"
  "Where we were well, thou reavest* our pleasance.\"           *takest away\n"
  "\n"
  "Thus leave I them, with voice of plaint and care,\n"
  "In raging woe crying full piteously;\n"
  "And as I went, full naked and full bare\n"
  "Some I beheld, looking dispiteously,\n"
  "On Poverty that deadly cast their eye;\n"
  "And \"Well-away!\" they cried, and were not fain,\n"
  "For they might not their glad desire attain.\n"
  "\n"
  "For lack of riches worldly and of good,\n"
  "They ban and curse, and weep, and say, \"Alas!\n"
  "That povert' hath us hent,* that whilom stood                    *seized\n"
  "At hearte's ease, and free and in good case!\n"
  "But now we dare not show ourselves in place,\n"
  "Nor us embold* to dwell in company,                  *make bold, venture\n"
  "Where as our heart would love right faithfully.\"\n"
  "\n"
  "And yet againward shrieked ev'ry nun,\n"
  "The pang of love so strained them to cry:\n"
  "\"Now woe the time,\" quoth they, \"that we be boun'!*               *bound\n"
  "This hateful order nice* will do us die!        *into which we foolishly\n"
  "We sigh and sob, and bleeden inwardly,                           entered\n"
  "Fretting ourselves with thought and hard complaint,\n"
  "That nigh for love we waxe wood* and faint.\"                        *mad\n"
  "\n"
  "And as I stood beholding here and there,\n"
  "I was ware of a sort* full languishing,               *a class of people\n"
  "Savage and wild of looking and of cheer,\n"
  "Their mantles and their clothes aye tearing;\n"
  "And oft they were of Nature complaining,\n"
  "For they their members lacked, foot and hand,\n"
  "With visage wry, and blind, I understand.\n"
  "\n"
  "They lacked shape and beauty to prefer\n"
  "Themselves in love: and said that God and Kind*                  *Nature\n"
  "Had forged* them to worshippe the sterre,**            *fashioned **star\n"
  "Venus the bright, and leften all behind\n"
  "His other workes clean and out of mind:\n"
  "\"For other have their full shape and beauty,\n"
  "And we,\" quoth they, \"be in deformity.\"\n"
  "\n"
  "And nigh to them there was a company,\n"
  "That have the Sisters warray'd and missaid,\n"
  "I mean the three of fatal destiny, <38>\n"
  "That be our workers: suddenly abraid,*                          *aroused\n"
  "Out gan they cry as they had been afraid;\n"
  "\"We curse,\" quoth they, \"that ever hath Nature\n"
  "Y-formed us this woeful life t'endure.\"\n"
  "\n"
  "And there eke was Contrite, and gan repent,\n"
  "Confessing whole the wound that Cythere <39>\n"
  "Had with the dart of hot desire him sent,\n"
  "And how that he to love must subject be:\n"
  "Then held he all his scornes vanity,\n"
  "And said that lovers held a blissful life,\n"
  "Young men and old, and widow, maid, and wife.\n"
  "\n"
  "\"Bereave me, Goddess!\" quoth he, \"of thy might,\n"
  "My scornes all and scoffes, that I have\n"
  "No power for to mocken any wight\n"
  "That in thy service dwell: for I did rave;\n"
  "This know I well right now, so God me save,\n"
  "And I shall be the chief post* of thy faith,               *prop, pillar\n"
  "And love uphold, the reverse whoso saith.\"\n"
  "\n"
  "Dissemble stood not far from him in truth,\n"
  "With party* mantle, party hood and hose;                 *parti-coloured\n"
  "And said he had upon his lady ruth,*                               *pity\n"
  "And thus he wound him in, and gan to glose,\n"
  "Of his intent full double, I suppose:\n"
  "In all the world he said he lov'd her weel;\n"
  "But ay me thought he lov'd her *ne'er a deal.*             *never a jot*\n"
  "\n"
  "Eke Shamefastness was there, as I took heed,\n"
  "That blushed red, and durst not be y-know\n"
  "She lover was, for thereof had she dread;\n"
  "She stood and hung her visage down alow;\n"
  "But such a sight it was to see, I trow,\n"
  "As of these roses ruddy on their stalk:\n"
  "There could no wight her spy to speak or talk\n"
  "\n"
  "In love's art, so gan she to abash,\n"
  "Nor durst not utter all her privity:\n"
  "Many a stripe and many a grievous lash\n"
  "She gave to them that woulde lovers be,\n"
  "And hinder'd sore the simple commonalty,\n"
  "That in no wise durst grace and mercy crave,\n"
  "For *were not she,* they need but ask and have;            *but for her*\n"
  "\n"
  "Where if they now approache for to speak,\n"
  "Then Shamefastness *returneth them* again:             *turns them back*\n"
  "They think, \"If we our secret counsel break,\n"
  "Our ladies will have scorn us certain,\n"
  "And peradventure thinke great disdain:\"\n"
  "Thus Shamefastness may bringen in Despair;\n"
  "When she is dead the other will be heir.\n"
  "\n"
  " \"Come forth Avaunter! now I ring thy bell!\" <40>\n"
  "I spied him soon; to God I make avow,*                       *confession\n"
  "He looked black as fiendes do in Hell:\n"
  "\"The first,\" quoth he, \"that ever I did wow,*                       *woo\n"
  "*Within a word she came,* I wot not how,               *she was won with\n"
  "So that in armes was my lady free,                        a single word*\n"
  "And so have been a thousand more than she.\n"
  "\n"
  "\"In England, Britain,* Spain, and Picardy,                     *Brittany\n"
  "Artois, and France, and up in high Holland,\n"
  "In Burgoyne,* Naples, and in Italy,                            *Burgundy\n"
  "Navarre, and Greece, and up in heathen land,\n"
  "Was never woman yet that would withstand\n"
  "To be at my commandment when I wo'ld:\n"
  "I lacked neither silver coin nor gold.\n"
  "\n"
  "\"And there I met with this estate and that;\n"
  "And her I broach'd, and her, and her, I trow:\n"
  "Lo! there goes one of mine; and, wot ye what?\n"
  "Yon fresh attired have I laid full low;\n"
  "And such one yonder eke right well I know;\n"
  "I kept the statute <41> when we lay y-fere:*                   *together\n"
  "And yet* yon same hath made me right good cheer.\"                  *also\n"
  "\n"
  "Thus hath Avaunter blowen ev'rywhere\n"
  "All that he knows, and more a thousand fold;\n"
  "His ancestry of kin was to Lier,*                                  *Liar\n"
  "For first he maketh promise for to hold\n"
  "His lady's counsel, and it not unfold; --\n"
  "Wherefore, the secret when he doth unshit,*                    *disclose\n"
  "Then lieth he, that all the world may wit.*                        *know\n"
  "\n"
  "For falsing so his promise and behest,*                           *trust\n"
  "I wonder sore he hath such fantasy;\n"
  "He lacketh wit, I trow, or is a beast,\n"
  "That can no bet* himself with reason guy**               *better **guide\n"
  "By mine advice, Love shall be contrary\n"
  "To his avail,* and him eke dishonour,                         *advantage\n"
  "So that in Court he shall no more sojour.*              *sojourn, remain\n"
  "\n"
  "\"Take heed,\" quoth she, this little Philobone,\n"
  "\"Where Envy rocketh in the corner yond,*                         *yonder\n"
  "And sitteth dark; and ye shall see anon\n"
  "His lean body, fading both face and hand;\n"
  "Himself he fretteth,* as I understand                          devoureth\n"
  "(Witness of Ovid Metamorphoseos); <42>\n"
  "The lover's foe he is, I will not glose.*                    *gloss over\n"
  "\n"
  "\"For where a lover thinketh *him promote,*          *to promote himself*\n"
  "Envy will grudge, repining at his weal;\n"
  "It swelleth sore about his hearte's root,\n"
  "That in no wise he cannot live in heal;*                         *health\n"
  "And if the faithful to his lady steal,\n"
  "Envy will noise and ring it round about,\n"
  "And say much worse than done is, out of doubt.\"\n"
  "\n"
  "And Privy Thought, rejoicing of himself, --\n"
  "Stood not far thence in habit marvellous;\n"
  "\"Yon is,\" thought I, \"some spirit or some elf,\n"
  "His subtile image is so curious:\n"
  "How is,\" quoth I, \"that he is shaded thus\n"
  "With yonder cloth, I n'ot* of what color?\"                     *know not\n"
  "And near I went and gan *to lear and pore,*            *to ascertain and\n"
  "                                                         gaze curiously*\n"
  "And frained* him a question full hard.                            *asked\n"
  "\"What is,\" quoth I, \"the thing thou lovest best?\n"
  "Or what is boot* unto thy paines hard?                           *remedy\n"
  "Me thinks thou livest here in great unrest,\n"
  "Thou wand'rest aye from south to east and west,\n"
  "And east to north; as far as I can see,\n"
  "There is no place in Court may holde thee.\n"
  "\n"
  "\"Whom followest thou? where is thy heart y-set?\n"
  "But *my demand assoil,* I thee require.\"            *answer my question*\n"
  "\"Me thought,\" quoth he, \"no creature may let*                    *hinder\n"
  "Me to be here, and where as I desire;\n"
  "For where as absence hath out the fire,\n"
  "My merry thought it kindleth yet again,\n"
  "That bodily, me thinks, with *my sov'reign*                    *my lady*\n"
  "\n"
  "\"I stand, and speak, and laugh, and kiss, and halse;*           *embrace\n"
  "So that my thought comforteth me full oft:\n"
  "I think, God wot, though all the world be false,\n"
  "I will be true; I think also how soft\n"
  "My lady is in speech, and this on loft\n"
  "Bringeth my heart with joy and great gladness;\n"
  "This privy thought allays my heaviness.\n"
  "\n"
  "\"And what I think, or where, to be, no man\n"
  "In all this Earth can tell, y-wis, but I:\n"
  "And eke there is no swallow swift, nor swan\n"
  "So wight* of wing, nor half so yern** can fly;         *nimble **eagerly\n"
  "For I can be, and that right suddenly,\n"
  "In Heav'n, in Hell, in Paradise, and here,\n"
  "And with my lady, when I will desire.\n"
  "\n"
  "\"I am of counsel far and wide, I wot,\n"
  "With lord and lady, and their privity\n"
  "I wot it all; but, be it cold or hot,\n"
  "They shall not speak without licence of me.\n"
  "I mean, in such as seasonable* be,                              *prudent\n"
  "Tho* first the thing is thought within the heart,                  *when\n"
  "Ere any word out from the mouth astart.\"*                        *escape\n"
  "\n"
  "And with the word Thought bade farewell and yede:*            *went away\n"
  "Eke forth went I to see the Courte's guise,\n"
  "And at the door came in, so God me speed,\n"
  "Two courtiers of age and of assise*                                *size\n"
  "Like high, and broad, and, as I me advise,\n"
  "The Golden Love and Leaden Love <43> they hight:*           *were called\n"
  "The one was sad, the other glad and light.\n"
  "\n"
  "At this point there is a hiatus in the poem, which abruptly ceases\n"
  "to narrate the tour of Philogenet and Philobone round the\n"
  "Court, and introduces us again to Rosial, who is speaking thus\n"
  "to her lover, apparently in continuation of a confession of love:\n"
  "\n"
  "\"Yes! draw your heart, with all your force and might,\n"
  "To lustiness, and be as ye have said.\"\n"
  "\n"
  "She admits that she would have given him no drop of favour,\n"
  "but that she saw him \"wax so dead of countenance;\" then Pity\n"
  "\"out of her shrine arose from death to life,\" whisperingly\n"
  "entreating that she would do him some pleasance. Philogenet\n"
  "protests his gratitude to Pity, his faithfulness to Rosial; and the\n"
  "lady, thanking him heartily, bids him abide with her till the\n"
  "season of May, when the King of Love and all his company will\n"
  "hold his feast fully royally and well. \"And there I bode till that\n"
  "the season fell.\"\n"
  "\n"
  "On May Day, when the lark began to rise,\n"
  "To matins went the lusty nightingale,\n"
  "Within a temple shapen hawthorn-wise;\n"
  "He might not sleep in all the nightertale,*                  *night-time\n"
  "But \"Domine\" <44> gan he cry and gale,*                        *call out\n"
  "\"My lippes open, Lord of Love, I cry,\n"
  "And let my mouth thy praising now bewry.\"*                   *show forth\n"
  "\n"
  "The eagle sang \"Venite,\" <45> bodies all,\n"
  "And let us joy to love that is our health.\"\n"
  "And to the desk anon they gan to fall,\n"
  "And who came late he pressed in by stealth\n"
  "Then said the falcon, \"Our own heartes' wealth,\n"
  "'Domine Dominus noster,' <46> I wot,\n"
  "Ye be the God that do* us burn thus hot.\"                          *make\n"
  "\n"
  "\"Coeli enarrant,\" <47> said the popinjay,*                       *parrot\n"
  "\"Your might is told in Heav'n and firmament.\"\n"
  "And then came in the goldfinch fresh and gay,\n"
  "And said this psalm with heartly glad intent,\n"
  "\"Domini est terra;\" <48> this Latin intent,*                      *means\n"
  "The God of Love hath earth in governance:\n"
  "And then the wren began to skip and dance.\n"
  "\n"
  "\"Jube Domine; <49> O Lord of Love, I pray\n"
  "Command me well this lesson for to read;\n"
  "This legend is of all that woulde dey*                              *die\n"
  "Martyrs for love; God yet their soules speed!\n"
  "And to thee, Venus, sing we, *out of dread,*             *without doubt*\n"
  "By influence of all thy virtue great,\n"
  "Beseeching thee to keep us in our heat.\"\n"
  "\n"
  "The second lesson robin redbreast sang,\n"
  "\"Hail to the God and Goddess of our lay!\"*                *law, religion\n"
  "And to the lectern amorously he sprang:\n"
  "\"Hail now,\" quoth be, \"O fresh season of May,\n"
  "*Our moneth glad that singen on the spray!*      *glad month for us that\n"
  "Hail to the flowers, red, and white, and blue,      sing upon the bough*\n"
  "Which by their virtue maken our lust new!\"\n"
  "\n"
  "The third lesson the turtle-dove took up,\n"
  "And thereat laugh'd the mavis* in a scorn:                    *blackbird\n"
  "He said, \"O God, as might I dine or sup,\n"
  "This foolish dove will give us all a horn!\n"
  "There be right here a thousand better born,\n"
  "To read this lesson, which as well as he,\n"
  "And eke as hot, can love in all degree.\"\n"
  "\n"
  "The turtle-dove said, \"Welcome, welcome May,\n"
  "Gladsome and light to lovers that be true!\n"
  "I thank thee, Lord of Love, that doth purvey\n"
  "For me to read this lesson all *of due;*                   *in due form*\n"
  "For, in good sooth, *of corage* I pursue             *with all my heart*\n"
  "To serve my make* till death us must depart:\"                      *mate\n"
  "And then \"Tu autem\" <50> sang he all apart.\n"
  "\n"
  "\"Te Deum amoris\" <51> sang the throstel* cock:                   *thrush\n"
  "Tubal <52> himself, the first musician,\n"
  "With key of harmony could not unlock\n"
  "So sweet a tune as that the throstel can:\n"
  "\"The Lord of Love we praise,\" quoth he than,*                      *then\n"
  "And so do all the fowles great and lite;*                        *little\n"
  "\"Honour we May, in false lovers' despite.\"\n"
  "\n"
  "\"Dominus regnavit,\" <53> said the peacock there,\n"
  "\"The Lord of Love, that mighty prince, y-wis,\n"
  "He is received here and ev'rywhere:\n"
  "Now Jubilate <54> sing:\" \"What meaneth this?\"\n"
  "Said then the linnet; \"welcome, Lord of bliss!\"\n"
  "Out start the owl with \"Benedicite,\" <55>\n"
  "\"What meaneth all this merry fare?\"* quoth he.              *doing, fuss\n"
  "\n"
  "\"Laudate,\" <56> sang the lark with voice full shrill;\n"
  "And eke the kite \"O admirabile;\" <57>\n"
  "This quire* will through mine eares pierce and thrill;            *choir\n"
  "But what? welcome this May season,\" quoth he;\n"
  "\"And honour to the Lord of Love must be,\n"
  "That hath this feast so solemn and so high:\"\n"
  "\"Amen,\" said all; and so said eke the pie.*                      *magpie\n"
  "\n"
  "And forth the cuckoo gan proceed anon,\n"
  "With \"Benedictus\" <58> thanking God in haste,\n"
  "That in this May would visit them each one,\n"
  "And gladden them all while the feast shall last:\n"
  "And therewithal a-laughter* out he brast;\"**        *in laughter **burst\n"
  "\"I thanke God that I should end the song,\n"
  "And all the service which hath been so long.\"\n"
  "\n"
  "Thus sang they all the service of the feast,\n"
  "And that was done right early, to my doom;*                    *judgment\n"
  "And forth went all the Court, both *most and least,*    *great and small\n"
  "To fetch the flowers fresh, and branch and bloom;\n"
  "And namely* hawthorn brought both page and groom,            *especially\n"
  "With freshe garlands party* blue and white, <59>         *parti-coloured\n"
  "And then rejoiced in their great delight.\n"
  "\n"
  "Eke each at other threw the flowers bright,\n"
  "The primerose, the violet, and the gold;\n"
  "So then, as I beheld the royal sight,\n"
  "My lady gan me suddenly behold,\n"
  "And with a true love, plighted many a fold,\n"
  "She smote me through the very heart *as blive;*            *straightway*\n"
  "And Venus yet I thank I am alive.\n"
  "\n"
  "Explicit*                                                       *The End\n"
  "\n"
  "\n"
  "Notes to The Court of Love\n"
  "\n"
  "\n"
  "1. So the Man of Law, in the prologue to his Tale, is made to\n"
  "say that Chaucer \"can but lewedly (ignorantly or imperfectly) on\n"
  "metres and on rhyming craftily.\" But the humility of those\n"
  "apologies is not justified by the care and finish of his earlier\n"
  "poems.\n"
  "\n"
  "2. Born: burnish, polish: the poet means, that his verses do not\n"
  "display the eloquence or brilliancy of Cicero in setting forth his\n"
  "subject-matter.\n"
  "\n"
  "3. Galfrid: Geoffrey de Vinsauf to whose treatise on poetical\n"
  "composition a less flattering allusion is made in The Nun's\n"
  "Priest's Tale. See note 33 to that Tale.\n"
  "\n"
  "4. Stirp: race, stock; Latin, \"stirps.\"\n"
  "\n"
  "5. Calliope is the epic muse -- \"sister\" to the other eight.\n"
  "\n"
  "6. Melpomene was the tragic muse.\n"
  "\n"
  "7. The same is said of Griselda, in The Clerk's Tale; though she\n"
  "was of tender years, \"yet in the breast of her virginity there was\n"
  "inclos'd a sad and ripe corage\"\n"
  "\n"
  "8. The confusion which Chaucer makes between Cithaeron and\n"
  "Cythera, has already been remarked.  See note 41 to the\n"
  "Knight's Tale.\n"
  "\n"
  "9. Balais: Bastard rubies; said to be so called from Balassa, the\n"
  "Asian country where they were found. Turkeis: turquoise\n"
  "stones.\n"
  "\n"
  "10. Spenser, in his description of the House of Busirane, speaks\n"
  "of the sad distress into which Phoebus was plunged by Cupid, in\n"
  "revenge for the betrayal of \"his mother's wantonness, when she\n"
  "with Mars was meint [mingled] in joyfulness\"\n"
  "\n"
  "11. Alcestis, daughter of Pelias, was won to wife by Admetus,\n"
  "King of Pherae, who complied with her father's demand that he\n"
  "should come to claim her in a chariot drawn by lions and boars.\n"
  "By the aid of Apollo -- who tended the flocks of Admetus\n"
  "during his banishment from heaven -- the suitor fulfilled the\n"
  "condition; and Apollo further induced the Moirae or Fates to\n"
  "grant that Admetus should never die, if his father, mother, or\n"
  "wife would die for him. Alcestis devoted herself in his stead;\n"
  "and, since each had made great efforts or sacrifices for love, the\n"
  "pair are fitly placed as king and queen in the Court of Love.\n"
  "\n"
  "12. In the prologue to the \"Legend of Good Women,\" Chaucer\n"
  "says that behind the God of Love, upon the green, he \"saw\n"
  "coming in ladies nineteen;\" but the stories of only nine good\n"
  "women are there told. In the prologue to The Man of Law's\n"
  "Tale, sixteen ladies are named as having their stories written in\n"
  "the \"Saints' Legend of Cupid\" -- now known as the \"Legend of\n"
  "Good Women\" -- (see note 5 to the Prologue to the Man of\n"
  "Law's Tale); and in the \"Retractation,\" at the end of the Parson's\n"
  "Tale, the \"Book of the Twenty-five Ladies\" is enumerated\n"
  "among the works of which the poet repents -- but there \"xxv\" is\n"
  "supposed to have been by some copyist written for \"xix.\"\n"
  "\n"
  "13. fele: many; German, \"viele.\"\n"
  "\n"
  "14. Arras: tapestry of silk, made at Arras, in France.\n"
  "\n"
  "15. Danger, in the Provencal Courts of Love, was the\n"
  "allegorical personification of the husband; and Disdain suitably\n"
  "represents the lover's corresponding difficulty from the side of\n"
  "the lady.\n"
  "\n"
  "16. In The Knight's Tale, Emily's yellow hair is braided in a\n"
  "tress, or plait, that hung a yard long behind her back; so that,\n"
  "both as regards colour and fashion, a singular resemblance\n"
  "seems to have existed between the female taste of 1369 and that\n"
  "of 1869.\n"
  "\n"
  "17. In an old monkish story -- reproduced by Boccaccio, and\n"
  "from him by La Fontaine in the Tale called \"Les Oies de Frere\n"
  "Philippe\"  -- a young man is brought up without sight or\n"
  "knowledge of women, and, when he sees them on a visit to the\n"
  "city, he is told that they are geese.\n"
  "\n"
  "18. Tabernacle: A shrine or canopy of stone, supported by\n"
  "pillars.\n"
  "\n"
  "19. Mister folk:  handicraftsmen, or tradesmen, who have\n"
  "learned \"mysteries.\"\n"
  "\n"
  "20. The loves \"Of Queen Annelida and False Arcite\" formed the\n"
  "subject of a short unfinished poem by Chaucer, which was\n"
  "afterwards worked up into The Knight's Tale.\n"
  "\n"
  "21. Blue was the colour of truth. See note 36 to the Squire's\n"
  "Tale.\n"
  "\n"
  "22. Blife: quickly, eagerly; for \"blive\" or \"belive.\"\n"
  "\n"
  "23. It will be seen afterwards that Philogenet does not relish it,\n"
  "and pleads for its relaxation.\n"
  "\n"
  "24. Feat: dainty, neat, handsome; the same as \"fetis,\" oftener\n"
  "used in Chaucer; the adverb \"featly\" is still used, as applied to\n"
  "dancing, &c.\n"
  "\n"
  "25. Solomon was beguiled by his heathenish wives to forsake\n"
  "the worship of the true God; Samson fell a victim to the wiles of\n"
  "Delilah.\n"
  "\n"
  "26. Compare the speech of Proserpine to Pluto, in The\n"
  "Merchant's Tale.\n"
  "\n"
  "27. See note 91 to the Knight's Tale for a parallel.\n"
  "\n"
  "28. Flaw: yellow; Latin, \"flavus,\" French, \"fauve.\"\n"
  "\n"
  "29. Bass: kiss; French, \"baiser;\" and hence the more vulgar\n"
  "\"buss.\"\n"
  "\n"
  "30. Maximian: Cornelius Maximianus Gallus flourished in the\n"
  "time of the Emperor Anastasius; in one of his elegies, he\n"
  "professed a preference for flaming and somewhat swelling lips,\n"
  "which, when he tasted them, would give him full kisses.\n"
  "\n"
  "31. Dwale: sleeping potion, narcotic. See note 19 to the Reeve's\n"
  "Tale.\n"
  "\n"
  "32. Environ: around; French, \"a l'environ.\"\n"
  "\n"
  "33. Cast off thine heart: i.e.  from confidence in her.\n"
  "\n"
  "34. Nesh: soft, delicate; Anglo-Saxon, \"nese.\"\n"
  "\n"
  "35. Perfection: Perfectly holy life, in the performance of vows\n"
  "of poverty, chastity, obedience, and other modes of mortifying\n"
  "the flesh.\n"
  "\n"
  "36. All the sin must on our friendes be: who made us take the\n"
  "vows before they knew our own dispositions, or ability, to keep\n"
  "them.\n"
  "\n"
  "37. Cope: The large vestment worn in singing the service in the\n"
  "choir. In Chaucer's time it seems to have been a distinctively\n"
  "clerical piece of dress; so, in the prologue to The Monk's Tale,\n"
  "the Host, lamenting that so stalwart a man as the Monk should\n"
  "have gone into religion, exclaims, \"Alas! why wearest thou so\n"
  "wide a cope?\"\n"
  "\n"
  "38. The three of fatal destiny: The three Fates.\n"
  "\n"
  "39. Cythere:  Cytherea  --  Venus, so called from the name of\n"
  "the island, Cythera, into which her worship was first introduced\n"
  "from Phoenicia.\n"
  "\n"
  "40. Avaunter: Boaster; Philobone calls him out.\n"
  "\n"
  "41. The statute: i.e. the 16th.\n"
  "\n"
  "42. \"Metamorphoses\" Lib. ii. 768 et seqq., where a general\n"
  "description of Envy is given.\n"
  "\n"
  "43. Golden Love and Leaden Love represent successful and\n"
  "unsuccessful love; the first kindled by Cupid's golden darts, the\n"
  "second by his leaden arrows.\n"
  "\n"
  "44. \"Domine, labia mea aperies -- et os meam annunciabit\n"
  "laudem tuam\" (\"Lord, open my lips -- and my mouth will\n"
  "announce your praise\") Psalms li. 15, was the verse with which\n"
  "Matins began. The stanzas which follow contain a paraphrase of\n"
  "the matins for Trinity Sunday, allegorically setting forth the\n"
  "doctrine that love is the all-controlling influence in the\n"
  "government of the\n"
  "universe.\n"
  "\n"
  "45. \"Venite, exultemus,\" (\"Come, let us rejoice\") are the first\n"
  "words of Psalm xcv. called the \"Invitatory.\"\n"
  "\n"
  "46. \"Domine Dominus noster:\" The opening words of Psalm\n"
  "viii.; \"O Lord our Lord.\"\n"
  "\n"
  "47. \"Coeli enarrant:\" Psalm xix. 1; \"The heavens declare (thy\n"
  "glory).\"\n"
  "\n"
  "48. \"Domini est terra\": Psalm xxiv. I; \"The earth is the Lord's\n"
  "and the fulness thereof.\" The first \"nocturn\" is now over, and\n"
  "the lessons from Scripture follow.\n"
  "\n"
  "49. \"Jube, Domine:\" \"Command, O Lord;\" from Matthew xiv.\n"
  "28, where Peter, seeing Christ walking on the water, says\n"
  "\"Lord, if it be thou, bid me come to thee on the water.\"\n"
  "\n"
  "50: \"Tu autem:\" the formula recited by the reader at the end of\n"
  "each lesson; \"Tu autem, Domine, miserere nobis.\" (\"But do\n"
  "thou, O Lord, have pity on us!\")\n"
  "\n"
  "51. \"Te Deum Amoris:\" \"Thee, God of Love (we praise).\"\n"
  "\n"
  "52. Not Tubal, who was the worker in metals; but Jubal, his\n"
  "brother, \"who was the father of all such as handle the harp and\n"
  "organ\" (Genesis iv. 21).\n"
  "\n"
  "53. \"Dominus regnavit:\"  Psalm xciii. 1, \"The Lord reigneth.\"\n"
  "With this began the \"Laudes,\" or morning service of praise.\n"
  "\n"
  "54. \"Jubilate:\" Psalm c. 1, \"Make a joyful noise unto the Lord.\"\n"
  "\n"
  "55. \"Benedicite:\" \"Bless ye the Lord;\" the opening of the Song\n"
  "of the Three Children\n"
  "\n"
  "56. \"Laudate:\" Psalm cxlvii.; \"Praise ye the Lord.\"\n"
  "\n"
  "57. \"O admirabile:\" Psalm viii 1; \"O Lord our God, how\n"
  "excellent is thy name.\"\n"
  "\n"
  "58. \"Benedictus\": The first word of the Song of Zacharias\n"
  "(Luke i. 68); \"Blessed be the Lord God of Israel\"\n"
  "\n"
  "59. In The Knight's Tale we have exemplifications of the\n"
  "custom of gathering and wearing flowers and branches on May\n"
  "Day; where Emily, \"doing observance to May,\" goes into the\n"
  "garden at sunrise and gathers flowers, \"party white and red, to\n"
  "make a sotel garland for her head\"; and again, where Arcite\n"
  "rides to the fields \"to make him a garland of the greves; were it\n"
  "of woodbine, or of hawthorn leaves\"\n"
  "\n"
  "\n"
  "\n"
  "";
// }

const char poemTheCuckooAndTheNightingale[] PGMSECTION = // { // 19628 bytes
  "                 THE CUCKOO AND THE NIGHTINGALE.\n"
  "\n"
  "\n"
  "[THE noble vindication of true love, as an exalting, purifying,\n"
  "and honour-conferring power, which Chaucer has made in \"The\n"
  "Court of Love,\" is repeated in \"The Cuckoo and the\n"
  "Nightingale.\" At the same time, the close of the poem leads up\n"
  "to \"The Assembly of Fowls;\" for, on the appeal of the\n"
  "Nightingale, the dispute between her and the Cuckoo, on the\n"
  "merits and blessings of love, is referred to a parliament of birds,\n"
  "to be held on the morrow after Saint Valentine's Day. True, the\n"
  "assembly of the feathered tribes described by Chaucer, though\n"
  "held on Saint Valentine's Day, and engaged in the discussion of\n"
  "a controversy regarding love, is not occupied with the particular\n"
  "cause which in the present poem the Nightingale appeals to the\n"
  "parliament. But \"The Cuckoo and the Nightingale\" none the less\n"
  "serves as a link between the two poems; indicating as it does the\n"
  "nature of those controversies, in matters subject to the supreme\n"
  "control of the King and Queen of Love, which in the subsequent\n"
  "poem we find the courtiers, under the guise of birds, debating in\n"
  "full conclave and under legal forms. Exceedingly simple in\n"
  "conception, and written in a metre full of musical irregularity\n"
  "and forcible freedom, \"The Cuckoo and the Nightingale\" yields\n"
  "in vividness, delicacy, and grace to none of Chaucer's minor\n"
  "poems. We are told that the poet, on the third night of May, is\n"
  "sleepless, and rises early in the morning, to try if he may hear\n"
  "the Nightingale sing. Wandering by a brook-side, he sits down\n"
  "on the flowery lawn, and ere long, lulled by the sweet melody of\n"
  "many birds and the well-according music of the stream, he falls\n"
  "into a kind of doze -- \"not all asleep, nor fully waking.\" Then\n"
  "(an evil omen) he hears the Cuckoo sing before the Nightingale;\n"
  "but soon he hears the Nightingale request the Cuckoo to\n"
  "remove far away, and leave the place to birds that can sing. The\n"
  "Cuckoo enters into a defence of her song, which becomes a\n"
  "railing accusation against Love and a recital of the miseries\n"
  "which Love's servants endure; the Nightingale vindicates Love\n"
  "in a lofty and tender strain, but is at last overcome with sorrow\n"
  "by the bitter words of the Cuckoo, and calls on the God of\n"
  "Love for help. On this the poet starts up, and, snatching a stone\n"
  "from the brook, throws it at the Cuckoo, who flies away full\n"
  "fast. The grateful Nightingale promises that, for this service, she\n"
  "will be her champion's singer all that May; she warns him\n"
  "against believing the Cuckoo, the foe of Love; and then, having\n"
  "sung him one of her new songs, she flies away to all the other\n"
  "birds that are in that dale, assembles them, and demands that\n"
  "they should do her right upon the Cuckoo. By one assent it is\n"
  "agreed that a parliament shall be held, \"the morrow after Saint\n"
  "Valentine's Day,\" under a maple before the window of Queen\n"
  "Philippa at Woodstock, when judgment shall be passed upon\n"
  "the Cuckoo; then the Nightingale flies into a hawthorn, and\n"
  "sings a lay of love so loud that the poet awakes. The five-line\n"
  "stanza, of which the first, second, and fifth lines agree in one\n"
  "rhyme, the third and fourth in another, is peculiar to this poem;\n"
  "and while the prevailing measure is the decasyllabic line used in\n"
  "the \"Canterbury Tales,\" many of the lines have one or two\n"
  "syllables less. The poem is given here without abridgement.]\n"
  "(Transcriber's note: Modern scholars believe that Chaucer was\n"
  "not the author of this poem)\n"
  "\n"
  "\n"
  "THE God of Love, ah! benedicite,\n"
  "How mighty and how great a lord is he! <1>\n"
  "For he can make of lowe heartes high,\n"
  "And of high low, and like for to die,\n"
  "And harde heartes he can make free.\n"
  "\n"
  "He can make, within a little stound,*                            *moment\n"
  "Of sicke folke whole, and fresh, and sound,\n"
  "And of the whole he can make sick;\n"
  "He can bind, and unbinden eke,\n"
  "What he will have bounden or unbound.\n"
  "\n"
  "To tell his might my wit may not suffice;\n"
  "For he can make of wise folk full nice,* --                     *foolish\n"
  "For he may do all that he will devise, --\n"
  "And lither* folke to destroye vice,                       *idle, vicious\n"
  "And proude heartes he can make agrise.*                         *tremble\n"
  "\n"
  "Shortly, all that ever he will he may;\n"
  "Against him dare no wight say nay;\n"
  "For he can glad and grieve *whom him liketh.*          *whom he pleases*\n"
  "And who that he will, he laugheth or siketh,*                   *sigheth\n"
  "And most his might he sheddeth ever in May.\n"
  "\n"
  "For every true gentle hearte free,\n"
  "That with him is, or thinketh for to be,\n"
  "Against May now shall have some stirring,*                      *impulse\n"
  "Either to joy, or else to some mourning,\n"
  "In no season so much, as thinketh me.\n"
  "\n"
  "For when that they may hear the birdes sing,\n"
  "And see the flowers and the leaves spring,\n"
  "That bringeth into hearte's remembrance\n"
  "A manner ease, *medled with grievance,*            *mingled with sorrow*\n"
  "And lusty thoughtes full of great longing.\n"
  "\n"
  "And of that longing cometh heaviness,\n"
  "And thereof groweth greate sickeness,\n"
  "And <2> for the lack of that that they desire:\n"
  "And thus in May be heartes set on fire,\n"
  "So that they brennen* forth in great distress.                     *burn\n"
  "\n"
  "I speake this of feeling truely;\n"
  "If I be old and unlusty,\n"
  "Yet I have felt the sickness thorough May\n"
  "*Both hot and cold, an access ev'ry day,*         *every day a hot and a\n"
  "How sore, y-wis, there wot no wight but I.                     cold fit*\n"
  "\n"
  "I am so shaken with the fevers white,\n"
  "Of all this May sleep I but lite;*                               *little\n"
  "And also it is not like* unto me                               *pleasing\n"
  "That any hearte shoulde sleepy be,\n"
  "In whom that Love his fiery dart will smite,\n"
  "\n"
  "But as I lay this other night waking,\n"
  "I thought how lovers had a tokening,*                      *significance\n"
  "And among them it was a common tale,\n"
  "That it were good to hear the nightingale\n"
  "Rather than the lewd cuckoo sing.\n"
  "\n"
  "And then I thought, anon* it was day,                          *whenever\n"
  "I would go somewhere to assay\n"
  "If that I might a nightingale hear;\n"
  "For yet had I none heard of all that year,\n"
  "And it was then the thirde night of May.\n"
  "\n"
  "And anon as I the day espied,\n"
  "No longer would I in my bed abide;\n"
  "But to a wood that was fast by,\n"
  "I went forth alone boldely,\n"
  "And held the way down by a brooke's side,\n"
  "\n"
  "Till I came to a laund* of white and green,                        *lawn\n"
  "So fair a one had I never in been;\n"
  "The ground was green, *y-powder'd with daisy,*     *strewn with daisies*\n"
  "The flowers and the *greves like high,*      *bushes of the same height*\n"
  "All green and white; was nothing elles seen.\n"
  "\n"
  "There sat I down among the faire flow'rs,\n"
  "And saw the birdes trip out of their bow'rs,\n"
  "There as they rested them alle the night;\n"
  "They were so joyful of the daye's light,\n"
  "They began of May for to do honours.\n"
  "\n"
  "They coud* that service all by rote;                               *knew\n"
  "There was many a lovely note!\n"
  "Some sange loud as they had plain'd,\n"
  "And some in other manner voice feign'd,\n"
  "And some all out with the full throat.\n"
  "\n"
  "They proined* them, and made them right gay,     *preened their feathers\n"
  "And danc'd and leapt upon the spray;\n"
  "And evermore two and two in fere,*                             *together\n"
  "Right so as they had chosen them to-year*                     *this year\n"
  "In Feverere* upon Saint Valentine's Day.                       *February\n"
  "\n"
  "And the river that I sat upon,*                                  *beside\n"
  "It made such a noise as it ran,\n"
  "Accordant* with the birde's harmony,                  *keeping time with\n"
  "Me thought it was the beste melody\n"
  "That might be heard of any man.\n"
  "\n"
  "And for delight, I wote never how,\n"
  "I fell in such a slumber and a swow, --                           *swoon\n"
  "Not all asleep, nor fully waking, --\n"
  "And in that swow me thought I hearde sing\n"
  "The sorry bird, the lewd cuckow;\n"
  "\n"
  "And that was on a tree right faste by.\n"
  "But who was then *evil apaid* but I?                       *dissatisfied\n"
  "\"Now God,\" quoth I, \"that died on the crois,*                     *cross\n"
  "Give sorrow on thee, and on thy lewed voice!\n"
  "Full little joy have I now of thy cry.\"\n"
  "\n"
  "And as I with the cuckoo thus gan chide,\n"
  "I heard, in the next bush beside,\n"
  "A nightingale so lustily sing,\n"
  "That her clear voice she made ring\n"
  "Through all the greenwood wide.\n"
  "\n"
  "\"Ah, good Nightingale,\" quoth I then,\n"
  "\"A little hast thou been too long hen;*                   *hence, absent\n"
  "For here hath been the lewd cuckow,\n"
  "And sung songs rather* than hast thou:                           *sooner\n"
  "I pray to God that evil fire her bren!\"*                           *burn\n"
  "\n"
  "But now I will you tell a wondrous thing:\n"
  "As long as I lay in that swooning,\n"
  "Me thought I wist what the birds meant,\n"
  "And what they said, and what was their intent\n"
  "And of their speech I hadde good knowing.\n"
  "\n"
  "There heard I the nightingale say:\n"
  "\"Now, good Cuckoo, go somewhere away,\n"
  "And let us that can singe dwelle here;\n"
  "For ev'ry wight escheweth* thee to hear,                          *shuns\n"
  "Thy songes be so elenge,* in good fay.\"**               *strange **faith\n"
  "\n"
  "\"What,\" quoth she, \"what may thee all now\n"
  "It thinketh me, I sing as well as thou,\n"
  "For my song is both true and plain,\n"
  "Although I cannot crakel* so in vain,                  *sing tremulously\n"
  "As thou dost in thy throat, I wot ne'er how.\n"
  "\n"
  "\"And ev'ry wight may understande me,\n"
  "But, Nightingale, so may they not do thee,\n"
  "For thou hast many a nice quaint* cry;                          *foolish\n"
  "I have thee heard say, 'ocy, ocy;' <3>\n"
  "How might I know what that should be?\"\n"
  "\n"
  "\"Ah fool,\" quoth she, \"wost thou not what it is?\n"
  "When that I say, 'ocy, ocy,' y-wis,\n"
  "Then mean I that I woulde wonder fain\n"
  "That all they were shamefully slain,                                *die\n"
  "That meanen aught againe love amiss.\n"
  "\n"
  "\"And also I would that all those were dead,\n"
  "That thinke not in love their life to lead,\n"
  "For who so will the god of Love not serve,\n"
  "I dare well say he is worthy to sterve,*                            *die\n"
  "And for that skill,* 'ocy, ocy,' I grede.\"**               *reason **cry\n"
  "\n"
  "\"Ey!\" quoth the cuckoo, \"this is a quaint* law,                 *strange\n"
  "That every wight shall love or be to-draw!*              *torn to pieces\n"
  "But I forsake alle such company;\n"
  "For mine intent is not for to die,\n"
  "Nor ever, while I live, *on Love's yoke to draw.*      *to put on love's\n"
  "                                                                   yoke*\n"
  "\"For lovers be the folk that be alive,\n"
  "That most disease have, and most unthrive,*                  *misfortune\n"
  "And most endure sorrow, woe, and care,\n"
  "And leaste feelen of welfare:\n"
  "What needeth it against the truth to strive?\"\n"
  "\n"
  "\"What?\" quoth she, \"thou art all out of thy mind!\n"
  "How mightest thou in thy churlishness find\n"
  "To speak of Love's servants in this wise?\n"
  "For in this world is none so good service\n"
  "To ev'ry wight that gentle is of kind;\n"
  "\n"
  "\"For thereof truly cometh all gladness,\n"
  "All honour and all gentleness,\n"
  "Worship, ease, and all hearte's lust,*                         *pleasure\n"
  "Perfect joy, and full assured trust,\n"
  "Jollity, pleasance, and freshness,\n"
  "\n"
  "\"Lowlihead, largess, and courtesy,\n"
  "Seemelihead, and true company,\n"
  "Dread of shame for to do amiss;\n"
  "For he that truly Love's servant is,\n"
  "Were lother* to be shamed than to die.                   *more reluctant\n"
  "\n"
  "\"And that this is sooth that I say,\n"
  "In that belief I will live and dey;\n"
  "And, Cuckoo, so I rede* that thou, do y-wis.\"                   *counsel\n"
  "\"Then,\" quoth he, \"let me never have bliss,\n"
  "If ever I to that counsail obey!\n"
  "\n"
  "\"Nightingale, thou speakest wondrous fair,\n"
  "But, for all that, is the sooth contrair;\n"
  "For love is in young folk but rage,\n"
  "And in old folk a great dotage;\n"
  "Who most it useth, moste shall enpair.*                     *suffer harm\n"
  "\n"
  "\"For thereof come disease and heaviness,\n"
  "Sorrow and care, and many a great sickness,\n"
  "Despite, debate, anger, envy,\n"
  "Depraving,* shame, untrust, and jealousy,     *loss of fame or character\n"
  "Pride, mischief, povert', and woodness.*                        *madness\n"
  "\n"
  "\"Loving is an office of despair,\n"
  "And one thing is therein that is not fair;\n"
  "For who that gets of love a little bliss,\n"
  "*But if he be away therewith, y-wis,\n"
  "He may full soon of age have his hair.*                   *see note <5>*\n"
  "\n"
  "\"And, Nightingale, therefore hold thee nigh;\n"
  "For, 'lieve me well, for all thy quainte cry,\n"
  "If thou be far or longe from thy make,*                            *mate\n"
  "Thou shalt be as other that be forsake,\n"
  "And then thou shalt hoten* as do I.\"                          *be called\n"
  "\n"
  "\"Fie,\" quoth she, \"on thy name and on thee!\n"
  "The god of Love let thee never the!*                             *thrive\n"
  "For thou art worse a thousand fold than wood,*                      *mad\n"
  "For many one is full worthy and full good,\n"
  "That had been naught, ne hadde Love y-be.\n"
  "\n"
  "\"For evermore Love his servants amendeth,\n"
  "And from all evile taches* them defendeth,                    *blemishes\n"
  "And maketh them to burn right in a fire,\n"
  "In truth and in worshipful* desire,                          *honourable\n"
  "And, when him liketh, joy enough them sendeth.\"\n"
  "\n"
  "\"Thou Nightingale,\" he said, \"be still!\n"
  "For Love hath no reason but his will;\n"
  "For ofttime untrue folk he easeth,\n"
  "And true folk so bitterly displeaseth,\n"
  "That for default of grace* he lets them spill.\"**    *favour **be ruined\n"
  "\n"
  "Then took I of the nightingale keep,\n"
  "How she cast a sigh out of her deep,\n"
  "And said, \"Alas, that ever I was bore!\n"
  "I can for teen* not say one worde more;\"                *vexation, grief\n"
  "And right with that word she burst out to weep.\n"
  "\n"
  "\"Alas!\" quoth she, \"my hearte will to-break\n"
  "To heare thus this lewd bird speak\n"
  "Of Love, and of his worshipful service.\n"
  "Now, God of Love, thou help me in some wise,\n"
  "That I may on this cuckoo be awreak!\"*                         *revenged\n"
  "\n"
  "Methought then I start up anon,\n"
  "And to the brook I ran and got a stone,\n"
  "And at the cuckoo heartly cast;\n"
  "And for dread he flew away full fast,\n"
  "And glad was I when he was gone.\n"
  "\n"
  "And evermore the cuckoo, as he flay,*                              *flew\n"
  "He saide, \"Farewell, farewell, popinjay,\"\n"
  "As though he had scorned, thought me;\n"
  "But ay I hunted him from the tree,\n"
  "Until he was far out of sight away.\n"
  "\n"
  "And then came the nightingale to me,\n"
  "And said, \"Friend, forsooth I thank thee\n"
  "That thou hast lik'd me to rescow;*                              *rescue\n"
  "And one avow to Love make I now,\n"
  "That all this May I will thy singer be.\"\n"
  "\n"
  "I thanked her, and was right *well apaid:*                    *satisfied\n"
  "\"Yea,\" quoth she, \"and be thou not dismay'd,\n"
  "Though thou have heard the cuckoo *erst than* me; <6>            *before\n"
  "For, if I live, it shall amended be\n"
  "The next May, if I be not afraid.\n"
  "\n"
  "\"And one thing I will rede* thee also,\n"
  "Believe thou not the cuckoo, the love's foe,\n"
  "For all that he hath said is strong leasing.\"*                *falsehood\n"
  "\"Nay,\" quoth I, \"thereto shall nothing me bring\n"
  "For love, and it hath done me much woe.\"\n"
  "\n"
  "\"Yea? Use,\" quoth she, \"this medicine,\n"
  "Every day this May ere thou dine:\n"
  "Go look upon the fresh daisy,\n"
  "And, though thou be for woe in point to die,\n"
  "That shall full greatly less thee of thy pine.*                  *sorrow\n"
  "\n"
  "\"And look alway that thou be good and true,\n"
  "And I will sing one of my songes new\n"
  "For love of thee, as loud as I may cry:\"\n"
  "And then she began this song full high:\n"
  "\"I shrew* all them that be of love untrue.\"                       *curse\n"
  "\n"
  "And when she had sung it to the end,\n"
  "\"Now farewell,\" quoth she, \"for I must wend,*                        *go\n"
  " And, God of Love, that can right well and may,\n"
  "As much joy sende thee this day,\n"
  "As any lover yet he ever send!\"\n"
  "\n"
  "Thus took the nightingale her leave of me.\n"
  "I pray to God alway with her be,\n"
  "And joy of love he send her evermore,\n"
  "And shield us from the cuckoo and his lore;\n"
  "For there is not so false a bird as he.\n"
  "\n"
  "Forth she flew, the gentle nightingale,\n"
  "To all the birdes that were in that dale,\n"
  "And got them all into a place in fere,*                        *together\n"
  "And besought them that they would hear\n"
  "Her disease,* and thus began her tale.              *distress, grievance\n"
  "\n"
  "\"Ye witte* well, it is not for to hide,                            *know\n"
  "How the cuckoo and I fast have chide,*                       *quarrelled\n"
  "Ever since that it was daylight;\n"
  "I pray you all that ye do me right\n"
  "On that foul false unkind bride.\"*                                 *bird\n"
  "\n"
  "Then spake one bird for all, by one assent:\n"
  "\"This matter asketh good advisement;\n"
  "For we be fewe birdes here in fere,\n"
  "And sooth it is, the cuckoo is not here,\n"
  "And therefore we will have a parlement.\n"
  "\n"
  "\"And thereat shall the eagle be our lord,\n"
  "And other peers that been *of record,*        *of established authority*\n"
  "And the cuckoo shall be *after sent;*                          *summoned\n"
  "There shall be given the judgment,\n"
  "Or else we shall finally *make accord.*                  *be reconciled*\n"
  "\n"
  "\"And this shall be, withoute nay,*                        *contradiction\n"
  "The morrow after Saint Valentine's Day,\n"
  "Under a maple that is fair and green,\n"
  "Before the chamber window of the Queen, <7>\n"
  "At Woodstock upon the green lay.\"*                                 *lawn\n"
  "\n"
  "She thanked them, and then her leave took,\n"
  "And into a hawthorn by that brook,\n"
  "And there she sat and sang upon that tree,\n"
  "*\"Term of life love hath withhold me;\"*             *love hath me in her\n"
  "So loude, that I with that song awoke.              service all my life*\n"
  "\n"
  "Explicit.*                                                      *The End\n"
  "\n"
  "\n"
  "The Author to His Book.\n"
  "\n"
  "O LEWD book! with thy foul rudeness,\n"
  "Since thou hast neither beauty nor eloquence,\n"
  "Who hath thee caus'd or giv'n the hardiness\n"
  "For to appear in my lady's presence?\n"
  "I am full sicker* thou know'st her benevolence,                 *certain\n"
  "Full agreeable to all her abying,*                                *merit\n"
  "For of all good she is the best living.\n"
  "\n"
  "Alas! that thou ne haddest worthiness,\n"
  "To show to her some pleasant sentence,\n"
  "Since that she hath, thorough her gentleness,\n"
  "Accepted thee servant to her dign reverence!\n"
  "O! me repenteth that I n'had science,\n"
  "And leisure als', t'make thee more flourishing,\n"
  "For of all good she is the best living.\n"
  "\n"
  "Beseech her meekly with all lowliness,\n"
  "Though I be ferre* from her in absence,                             *far\n"
  "To think on my truth to her and steadfastness,\n"
  "And to abridge of my sorrows the violence,\n"
  "Which caused is whereof knoweth your sapience;*                  *wisdom\n"
  "She like among to notify me her liking,\n"
  "For of all good she is the best living.\n"
  "\n"
  "Explicit.\n"
  "\n"
  "\n"
  "L'Envoy; To the Author's Lady.\n"
  "\n"
  "Aurore of gladness, day of lustiness,\n"
  "Lucern* at night with heav'nly influence                           *lamp\n"
  "Illumin'd, root of beauty and goodness,\n"
  "Suspires* which I effund** in silence!               *sighs **pour forth\n"
  "Of grace I beseech, allege* let your writing                    *declare\n"
  "Now of all good, since ye be best living.\n"
  "\n"
  "Explicit.\n"
  "\n"
  "\n"
  "Notes to the Cuckoo and the Nightingale\n"
  "\n"
  "\n"
  "1. These two lines occur also in The Knight's Tale; they\n"
  "commence the speech of Theseus on the love follies of Palamon\n"
  "and Arcite, whom the Duke has just found fighting in the forest.\n"
  "\n"
  "2. A stronger reading is \"all.\"\n"
  "\n"
  "3. \"Ocy, ocy,\" is supposed to come from the Latin \"occidere,\"\n"
  "to kill; or rather the old French, \"occire,\" \"occis,\" denoting the\n"
  "doom which the nightingale imprecates or supplicates on all\n"
  "who do offence to Love.\n"
  "\n"
  "4. Grede: cry; Italian, \"grido.\"\n"
  "\n"
  "5.\"But if he be away therewith, y-wis,\n"
  "He may full soon of age have his hair\":\n"
  "Unless he be always fortunate in love pursuits, he may full soon\n"
  "have gray hair, through his anxieties.\n"
  "\n"
  "6. It was of evil omen to hear the cuckoo before the nightingale\n"
  "or any other bird.\n"
  "\n"
  "7. The Queen: Philippa of Hainault, wife of Edward III.\n"
  "\n"
  "\n"
  "\n"
  "";
// }

const char poemTheAssemblyOfFowls0[] PGMSECTION = // { // 27112 bytes
  "                     THE ASSEMBLY OF FOWLS.\n"
  "\n"
  "\n"
  "[In \"The Assembly of Fowls\" -- which Chaucer's \"Retractation\"\n"
  "describes as \"The Book of Saint Valentine's Day, or of the\n"
  "Parliament of Birds\" -- we are presented with a picture of the\n"
  "mediaeval \"Court of Love\" far closer to the reality than we find\n"
  "in Chaucer's poem which bears that express title. We have a\n"
  "regularly constituted conclave or tribunal, under a president\n"
  "whose decisions are final. A difficult question is proposed for\n"
  "the consideration and judgment of the Court -- the disputants\n"
  "advancing and vindicating their claims in person. The attendants\n"
  "upon the Court, through specially chosen mouthpieces, deliver\n"
  "their opinions on the cause; and finally a decision is\n"
  "authoritatively pronounced by the president -- which, as in\n"
  "many of the cases actually judged before the Courts of Love in\n"
  "France, places the reasonable and modest wish of a sensitive\n"
  "and chaste lady above all the eagerness of her lovers, all the\n"
  "incongruous counsels of representative courtiers. So far,\n"
  "therefore, as the poem reproduces the characteristic features of\n"
  "procedure in those romantic Middle Age halls of amatory\n"
  "justice, Chaucer's \"Assembly of Fowls\" is his real \"Court of\n"
  "Love;\" for although, in the castle and among the courtiers of\n"
  "Admetus and Alcestis, we have all the personages and\n"
  "machinery necessary for one of those erotic contentions, in the\n"
  "present poem we see the personages and the machinery actually\n"
  "at work, upon another scene and under other guises. The\n"
  "allegory which makes the contention arise out of the loves, and\n"
  "proceed in the assembly, of the feathered race, is quite in\n"
  "keeping with the fanciful yet nature-loving spirit of the poetry\n"
  "of Chaucer's time, in which the influence of the Troubadours\n"
  "was still largely present. It is quite in keeping, also, with the\n"
  "principles that regulated the Courts, the purpose of which was\n"
  "more to discuss and determine the proper conduct of love\n"
  "affairs, than to secure conviction or acquittal, sanction or\n"
  "reprobation, in particular cases -- though the jurisdiction and\n"
  "the judgments of such assemblies often closely concerned\n"
  "individuals. Chaucer introduces us to his main theme through\n"
  "the vestibule of a fancied dream -- a method which be\n"
  "repeatedly employs with great relish, as for instance in \"The\n"
  "House of Fame.\" He has spent the whole day over Cicero's\n"
  "account of the Dream of Scipio (Africanus the Younger); and,\n"
  "having gone to bed, he dreams that Africanus the Elder appears\n"
  "to him -- just as in the book he appeared to his namesake -- and\n"
  "carries him into a beautiful park, in which is a fair garden by a\n"
  "river-side. Here the poet is led into a splendid temple, through a\n"
  "crowd of courtiers allegorically representing the various\n"
  "instruments, pleasures, emotions, and encouragements of Love;\n"
  "and in the temple Venus herself is found, sporting with her\n"
  "porter Richess. Returning into the garden, he sees the Goddess\n"
  "of Nature seated on a hill of flowers; and before her are\n"
  "assembled all the birds -- for it is Saint Valentine's Day, when\n"
  "every fowl chooses her mate. Having with a graphic touch\n"
  "enumerated and described the principal birds, the poet sees that\n"
  "on her hand Nature bears a female eagle of surpassing loveliness\n"
  "and virtue, for which three male eagles advance contending\n"
  "claims. The disputation lasts all day; and at evening the\n"
  "assembled birds, eager to be gone with their mates, clamour for\n"
  "a decision. The tercelet, the goose, the cuckoo, and the turtle --\n"
  "for birds of prey, water-fowl, worm-fowl, and seed-fowl\n"
  "respectively -- pronounce their verdicts on the dispute, in\n"
  "speeches full of character and humour; but Nature refers the\n"
  "decision between the three claimants to the female eagle herself,\n"
  "who prays that she may have a year's respite. Nature grants the\n"
  "prayer, pronounces judgment accordingly, and dismisses the\n"
  "assembly; and after a chosen choir has sung a roundel in honour\n"
  "of the Goddess, all the birds fly away, and the poet awakes. It is\n"
  "probable that Chaucer derived the idea of the poem from a\n"
  "French source; Mr Bell gives the outline of a fabliau, of which\n"
  "three versions existed, and in which a contention between two\n"
  "ladies regarding the merits of their respective lovers, a knight\n"
  "and a clerk, is decided by Cupid in a Court composed of birds,\n"
  "which assume their sides according to their different natures.\n"
  "Whatever the source of the idea, its management, and the whole\n"
  "workmanship of the poem, especially in the more humorous\n"
  "passages, are essentially Chaucer's own.]\n"
  "\n"
  "\n"
  "THE life so short, the craft so long to learn,\n"
  "Th'assay so hard, so sharp the conquering,\n"
  "The dreadful joy, alway that *flits so yern;*           *fleets so fast*\n"
  "All this mean I by* Love, that my feeling             *with reference to\n"
  "Astoneth* with his wonderful working,                            *amazes\n"
  "So sore, y-wis, that, when I on him think,\n"
  "Naught wit I well whether I fleet* or sink,                       *float\n"
  "\n"
  "For *all be* that I know not Love indeed,             *albeit, although*\n"
  "Nor wot how that he *quiteth folk their hire,*         *rewards folk for\n"
  "Yet happeth me full oft in books to read                  their service*\n"
  "Of his miracles, and of his cruel ire;\n"
  "There read I well, he will be lord and sire;\n"
  "I dare not saye, that his strokes be sore;\n"
  "But God save such a lord! I can no more.\n"
  "\n"
  "Of usage, what for lust and what for lore,\n"
  "On bookes read I oft, as I you told.\n"
  "But wherefore speak I alle this? Not yore\n"
  "Agone, it happed me for to behold\n"
  "Upon a book written with letters old;\n"
  "And thereupon, a certain thing to learn,\n"
  "The longe day full fast I read and yern.*                       *eagerly\n"
  "\n"
  "For out of the old fieldes, as men saith,\n"
  "Cometh all this new corn, from year to year;\n"
  "And out of olde bookes, in good faith,\n"
  "Cometh all this new science that men lear.*                       *learn\n"
  "But now to purpose as of this mattere:\n"
  "To reade forth it gan me so delight,\n"
  "That all the day me thought it but a lite.*                *little while\n"
  "\n"
  "This book, of which I make mention,\n"
  "Entitled was right thus, as I shall tell;\n"
  "\"Tullius, of the Dream of Scipion:\" <1>\n"
  "Chapters seven it had, of heav'n, and hell,\n"
  "And earth, and soules that therein do dwell;\n"
  "Of which, as shortly as I can it treat,\n"
  "Of his sentence I will you say the great.*               *important part\n"
  "\n"
  "First telleth it, when Scipio was come\n"
  "To Africa, how he met Massinisse,\n"
  "That him for joy in armes hath y-nome.*                       *taken <2>\n"
  "Then telleth he their speech, and all the bliss\n"
  "That was between them till the day gan miss.*                      *fail\n"
  "And how his ancestor Africane so dear\n"
  "Gan in his sleep that night to him appear.\n"
  "\n"
  "Then telleth it, that from a starry place\n"
  "How Africane hath him Carthage y-shew'd,\n"
  "And warned him before of all his grace, <3>\n"
  "And said him, what man, learned either lewd,*                  *ignorant\n"
  "That loveth *common profit,* well y-thew'd,       *the public advantage*\n"
  "He should unto a blissful place wend,*                               *go\n"
  "Where as the joy is without any end.\n"
  "\n"
  "Then asked he,* if folk that here be dead       *i.e. the younger Scipio\n"
  "Have life, and dwelling, in another place?\n"
  "And Africane said, \"Yea, withoute dread;\"*                        *doubt\n"
  "And how our present worldly lives' space\n"
  "Meant but a manner death, <4> what way we trace;\n"
  "And rightful folk should go, after they die,\n"
  "To Heav'n; and showed him the galaxy.\n"
  "\n"
  "Then show'd he him the little earth that here is,\n"
  "*To regard* the heaven's quantity;                   *by comparison with\n"
  "And after show'd he him the nine spheres; <5>\n"
  "And after that the melody heard he,\n"
  "That cometh of those spheres thrice three,\n"
  "That wells of music be and melody\n"
  "In this world here, and cause of harmony.\n"
  "\n"
  "Then said he him, since earthe was so lite,*                      *small\n"
  "And full of torment and of *harde grace,*                  *evil fortune\n"
  "That he should not him in this world delight.\n"
  "Then told he him, in certain yeares' space,\n"
  "That ev'ry star should come into his place,\n"
  "Where it was first; and all should *out of mind,*   *perish from memory*\n"
  "That in this world is done of all mankind.\n"
  "\n"
  "Then pray'd him Scipio, to tell him all\n"
  "The way to come into that Heaven's bliss;\n"
  "And he said: \"First know thyself immortal,\n"
  "And look aye busily that thou work and wiss*              *guide affairs\n"
  "To common profit, and thou shalt not miss\n"
  "To come swiftly unto that place dear,\n"
  "That full of bliss is, and of soules clear.*                  *noble <6>\n"
  "\n"
  "\"And breakers of the law, the sooth to sayn,\n"
  "And likerous* folk, after that they be dead,                  *lecherous\n"
  "Shall whirl about the world always in pain,\n"
  "Till many a world be passed, *out of dread;*             *without doubt*\n"
  "And then, forgiven all their wicked deed,\n"
  "They shalle come unto that blissful place,\n"
  "To which to come God thee sende grace!\"\n"
  "\n"
  "The day gan failen, and the darke night,\n"
  "That reaveth* beastes from their business,                  *taketh away\n"
  "Berefte me my book for lack of light,\n"
  "And to my bed I gan me for to dress,*                           *prepare\n"
  "Full fill'd of thought and busy heaviness;\n"
  "For both I hadde thing which that I n'old,*                   *would not\n"
  "And eke I had not that thing that I wo'ld.\n"
  "\n"
  "But, finally, my spirit at the last,\n"
  "Forweary* of my labour all that day,                    *utterly wearied\n"
  "Took rest, that made me to sleepe fast;\n"
  "And in my sleep I mette,* as that I say,                        *dreamed\n"
  "How Africane, right in the *self array*                      *same garb*\n"
  "That Scipio him saw before that tide,*                             *time\n"
  "Was come, and stood right at my bedde's side.\n"
  "\n"
  "The weary hunter, sleeping in his bed,\n"
  "To wood again his mind goeth anon;\n"
  "The judge dreameth how his pleas be sped;\n"
  "The carter dreameth how his cartes go'n;\n"
  "The rich of gold, the knight fights with his fone;*                *foes\n"
  "The sicke mette he drinketh of the tun; <7>\n"
  "The lover mette he hath his lady won.\n"
  "\n"
  "I cannot say, if that the cause were,\n"
  "For* I had read of Africane beforn,                             *because\n"
  "That made me to mette that he stood there;\n"
  "But thus said he; \"Thou hast thee so well borne\n"
  "In looking of mine old book all to-torn,\n"
  "Of which Macrobius *raught not a lite,*            *recked not a little*\n"
  "That *somedeal of thy labour would I quite.\"*    *I would reward you for\n"
  "                                                    some of your labour*\n"
  "Cytherea, thou blissful Lady sweet!\n"
  "That with thy firebrand dauntest *when thee lest,*     *when you please*\n"
  "That madest me this sweven* for to mette,                         *dream\n"
  "Be thou my help in this, for thou may'st best!\n"
  "As wisly* as I saw the north-north-west, <8>                     *surely\n"
  "When I began my sweven for to write,\n"
  "So give me might to rhyme it and endite.*                    *write down\n"
  "\n"
  "This foresaid Africane me hent* anon,                              *took\n"
  "And forth with him unto a gate brought\n"
  "Right of a park, walled with greene stone;\n"
  "And o'er the gate, with letters large y-wrought,\n"
  "There were verses written, as me thought,\n"
  "On either half, of full great difference,\n"
  "Of which I shall you say the plain sentence.*                   *meaning\n"
  "\n"
  "\"Through me men go into the blissful place <9>\n"
  "Of hearte's heal and deadly woundes' cure;\n"
  "Through me men go unto the well of grace;\n"
  "Where green and lusty May shall ever dure;\n"
  "This is the way to all good adventure;\n"
  "Be glad, thou reader, and thy sorrow off cast;\n"
  "All open am I; pass in and speed thee fast.\"\n"
  "\n"
  "\"Through me men go,\" thus spake the other side,\n"
  "\"Unto the mortal strokes of the spear,\n"
  "Of which disdain and danger is the guide;\n"
  "There never tree shall fruit nor leaves bear;\n"
  "This stream you leadeth to the sorrowful weir,\n"
  "Where as the fish in prison is all dry; <10>\n"
  "Th'eschewing is the only remedy.\"\n"
  "\n"
  "These verses of gold and azure written were,\n"
  "On which I gan astonish'd to behold;\n"
  "For with that one increased all my fear,\n"
  "And with that other gan my heart to bold;*                 *take courage\n"
  "That one me het,* that other did me cold;                        *heated\n"
  "No wit had I, for error,* for to choose           *perplexity, confusion\n"
  "To enter or fly, or me to save or lose.\n"
  "\n"
  "Right as betwixten adamantes* two                               *magnets\n"
  "Of even weight, a piece of iron set,\n"
  "Ne hath no might to move to nor fro;\n"
  "For what the one may hale,* the other let;**         *attract **restrain\n"
  "So far'd I, that *n'ist whether me was bet*     *knew not whether it was\n"
  "T' enter or leave, till Africane, my guide,               better for me*\n"
  "Me hent* and shov'd in at the gates wide.                        *caught\n"
  "\n"
  "And said, \"It standeth written in thy face,\n"
  "Thine error,* though thou tell it not to me;      *perplexity, confusion\n"
  "But dread thou not to come into this place;\n"
  "For this writing *is nothing meant by* thee,         *does not refer to*\n"
  "Nor by none, but* he Love's servant be;                          *unless\n"
  "For thou of Love hast lost thy taste, I guess,\n"
  "As sick man hath of sweet and bitterness.\n"
  "\n"
  "\"But natheless, although that thou be dull,\n"
  "That thou canst not do, yet thou mayest see;\n"
  "For many a man that may not stand a pull,\n"
  "Yet likes it him at wrestling for to be,\n"
  "And deeme* whether he doth bet,** or he;                 *judge **better\n"
  "And, if thou haddest cunning* to endite,                          *skill\n"
  "I shall thee showe matter *of to write.\"*               *to write about*\n"
  "\n"
  "With that my hand in his he took anon,\n"
  "Of which I comfort caught,* and went in fast.                      *took\n"
  "But, Lord! so I was glad and  well-begone!*                   *fortunate\n"
  "For *over all,* where I my eyen cast,                       *everywhere*\n"
  "Were trees y-clad with leaves that ay shall last,\n"
  "Each in his kind, with colour fresh and green\n"
  "As emerald, that joy it was to see'n.\n"
  "\n"
  "The builder oak; and eke the hardy ash;\n"
  "The pillar elm, the coffer unto carrain;\n"
  "The box, pipe tree; the holm, to whippe's lash\n"
  "The sailing fir; the cypress death to plain;\n"
  "The shooter yew; the aspe for shaftes plain;\n"
  "Th'olive of peace, and eke the drunken vine;\n"
  "The victor palm; the laurel, too, divine. <11>\n"
  "\n"
  "A garden saw I, full of blossom'd boughes,\n"
  "Upon a river, in a greene mead,\n"
  "Where as sweetness evermore enow is,\n"
  "With flowers white, blue, yellow, and red,\n"
  "And colde welle* streames, nothing dead,                       *fountain\n"
  "That swamme full of smalle fishes light,\n"
  "With finnes red, and scales silver bright.\n"
  "\n"
  "On ev'ry bough the birdes heard I sing,\n"
  "With voice of angels in their harmony,\n"
  "That busied them their birdes forth to bring;\n"
  "The pretty conies* to their play gan hie;               *rabbits **haste\n"
  "And further all about I gan espy\n"
  "The dreadful* roe, the buck, the hart, and hind,                  *timid\n"
  "Squirrels, and beastes small, of gentle kind.*                   *nature\n"
  "\n"
  "Of instruments of stringes in accord\n"
  "Heard I so play a ravishing sweetness,\n"
  "That God, that Maker is of all and Lord,\n"
  "Ne hearde never better, as I guess:\n"
  "Therewith a wind, unneth* it might be less,                    *scarcely\n"
  "Made in the leaves green a noise soft,\n"
  "Accordant* the fowles' song on loft.**          *in keeping with **above\n"
  "\n"
  "Th'air of the place so attemper* was,                              *mild\n"
  "That ne'er was there grievance* of hot nor cold;              *annoyance\n"
  "There was eke ev'ry wholesome spice and grass,\n"
  "Nor no man may there waxe sick nor old:\n"
  "Yet* was there more joy a thousand fold                        *moreover\n"
  "Than I can tell, or ever could or might;\n"
  "There ever is clear day, and never night.\n"
  "\n"
  "Under a tree, beside a well, I sey*                                 *saw\n"
  "Cupid our lord his arrows forge and file;*                       *polish\n"
  "And at his feet his bow all ready lay;\n"
  "And well his daughter temper'd, all the while,\n"
  "The heades in the well; and with her wile*                   *cleverness\n"
  "She couch'd* them after, as they shoulde serve        *arranged in order\n"
  "Some for to slay, and some to wound and kerve.*              *carve, cut\n"
  "\n"
  "Then was I ware of Pleasance anon right,\n"
  "And of Array, and Lust, and Courtesy,\n"
  "And of the Craft, that can and hath the might\n"
  "To do* by force a wight to do folly;                               *make\n"
  "Disfigured* was she, I will not lie;                          *disguised\n"
  "And by himself, under an oak, I guess,\n"
  "Saw I Delight, that stood with Gentleness.\n"
  "\n"
  "Then saw I Beauty, with a nice attire,\n"
  "And Youthe, full of game and jollity,\n"
  "Foolhardiness, Flattery, and Desire,\n"
  "Messagerie, and Meed, and other three; <12>\n"
  "Their names shall not here be told for me:\n"
  "And upon pillars great of jasper long\n"
  "I saw a temple of brass y-founded strong.\n"
  "\n"
  "And [all] about the temple danc'd alway\n"
  "Women enough, of whiche some there were\n"
  "Fair of themselves, and some of them were gay\n"
  "In kirtles* all dishevell'd went they there;                     *tunics\n"
  "That was their office* ever, from year to year;        *duty, occupation\n"
  "And on the temple saw I, white and fair,\n"
  "Of doves sitting many a thousand pair. <13>\n"
  "\n"
  "Before the temple door, full soberly,\n"
  "Dame Peace sat, a curtain in her hand;\n"
  "And her beside, wonder discreetely,\n"
  "Dame Patience sitting there I fand,*                              *found\n"
  "With face pale, upon a hill of sand;\n"
  "And althernext, within and eke without,\n"
  "Behest,* and Art, and of their folk a rout.**           *Promise **crowd\n"
  "\n"
  "Within the temple, of sighes hot as fire\n"
  "I heard a swough,* that gan aboute ren,**                  *murmur **run\n"
  "Which sighes were engender'd with desire,\n"
  "That made every hearte for to bren*                                *burn\n"
  "Of newe flame; and well espied I then,\n"
  "That all the cause of sorrows that they dree*                    *endure\n"
  "Came of the bitter goddess Jealousy.\n"
  "\n"
  "The God Priapus <14> saw I, as I went\n"
  "Within the temple, in sov'reign place stand,\n"
  "In such array, as when the ass him shent* <15>                   *ruined\n"
  "With cry by night, and with sceptre in hand:\n"
  "Full busily men gan assay and fand*                           *endeavour\n"
  "Upon his head to set, of sundry hue,\n"
  "Garlandes full of freshe flowers new.\n"
  "\n"
  "And in a privy corner, in disport,\n"
  "Found I Venus and her porter Richess,\n"
  "That was full noble and hautain* of her port;              *haughty <16>\n"
  "Dark was that place, but afterward lightness\n"
  "I saw a little, unneth* it might be less;                      *scarcely\n"
  "And on a bed of gold she lay to rest,\n"
  "Till that the hote sun began to west.*         *decline towards the wesr\n"
  "\n"
  "Her gilded haires with a golden thread\n"
  "Y-bounden were, untressed,* as she lay;                           *loose\n"
  "And naked from the breast unto the head\n"
  "Men might her see; and, soothly for to say,\n"
  "The remnant cover'd, welle to my pay,*                *satisfaction <17>\n"
  "Right with a little kerchief of Valence;<18>\n"
  "There was no thicker clothe of defence.\n"
  "\n"
  "The place gave a thousand savours swoot;*                         *sweet\n"
  "And Bacchus, god of wine, sat her beside;\n"
  "And Ceres next, that *doth of hunger boot;*<19>        *relieves hunger*\n"
  "And, as I said, amiddes* lay Cypride, <20>                 *in the midst\n"
  "To whom on knees the younge folke cried\n"
  "To be their help: but thus I let her lie,\n"
  "And farther in the temple gan espy,\n"
  "\n"
  "<See note 21 for the stories of the lovers in\n"
  "the next two stanzas>\n"
  "\n"
  "That, in despite of Diana the chaste,\n"
  "Full many a bowe broke hung on the wall,\n"
  "Of maidens, such as go their time to waste\n"
  "In her service: and painted over all\n"
  "Of many a story, of which I touche shall\n"
  "A few, as of Calist', and Atalant',\n"
  "And many a maid, of which the name I want.*                 *do not have\n"
  "\n"
  "Semiramis, Canace, and Hercules,\n"
  "Biblis, Dido, Thisbe and Pyramus,\n"
  "Tristram, Isoude, Paris, and Achilles,\n"
  "Helena, Cleopatra, Troilus,\n"
  "Scylla, and eke the mother of Romulus;\n"
  "All these were painted on the other side,\n"
  "And all their love, and in what plight they died.\n"
  "\n"
  "When I was come again into the place\n"
  "That I of spake, that was so sweet and green,\n"
  "Forth walk'd I then, myselfe to solace:\n"
  "Then was I ware where there sat a queen,\n"
  "That, as of light the summer Sunne sheen\n"
  "Passeth the star, right so *over measure*        *out of all proportion*\n"
  "She fairer was than any creature.\n"
  "\n"
  "And in a lawn, upon a hill of flowers,\n"
  "Was set this noble goddess of Nature;\n"
  "Of branches were her halles and her bowers\n"
  "Y-wrought, after her craft and her measure;\n"
  "Nor was there fowl that comes of engendrure\n"
  "That there ne were prest,* in her presence,                  *ready <22>\n"
  "To *take her doom,* and give her audience.        *receive her decision*\n"
  "\n"
  "For this was on Saint Valentine's Day,\n"
  "When ev'ry fowl cometh to choose her make,*                        *mate\n"
  "Of every kind that men thinken may;\n"
  "And then so huge a noise gan they make,\n"
  "That earth, and sea, and tree, and ev'ry lake,\n"
  "So full was, that unnethes* there was space                    *scarcely\n"
  "For me to stand, so full was all the place.\n"
  "\n"
  "And right as Alain, in his Plaint of Kind, <23>\n"
  "Deviseth* Nature of such array and face;                     *describeth\n"
  "In such array men mighte her there find.\n"
  "This noble Emperess, full of all grace,\n"
  "Bade ev'ry fowle take her owen place,\n"
  "As they were wont alway, from year to year,\n"
  "On Saint Valentine's Day to stande there.\n"
  "\n"
  "That is to say, the *fowles of ravine*                   *birds of prey*\n"
  "Were highest set, and then the fowles smale,\n"
  "That eaten as them Nature would incline;\n"
  "As worme-fowl, of which I tell no tale;\n"
  "But waterfowl sat lowest in the dale,\n"
  "And fowls that live by seed sat on the green,\n"
  "And that so many, that wonder was to see'n.\n"
  "\n"
  "There mighte men the royal eagle find,\n"
  "That with his sharpe look pierceth the Sun;\n"
  "And other eagles of a lower kind,\n"
  "Of which that *clerkes well devise con;*            *which scholars well\n"
  "There was the tyrant with his feathers dun                 can describe*\n"
  "And green, I mean the goshawk, that doth pine*               *cause pain\n"
  "To birds, for his outrageous ravine.*                  *slaying, hunting\n"
  "\n"
  "The gentle falcon, that with his feet distraineth*               *grasps\n"
  "The kinge's hand; <24> the hardy* sperhawk eke,                    *pert\n"
  "The quaile's foe; the merlion <25> that paineth\n"
  "Himself full oft the larke for to seek;\n"
  "There was the dove, with her eyen meek;\n"
  "The jealous swan, against* his death that singeth;   *in anticipation of\n"
  "The owl eke, that of death the bode* bringeth.                     *omen\n"
  "\n"
  "The crane, the giant, with his trumpet soun';\n"
  "The thief the chough; and eke the chatt'ring pie;\n"
  "The scorning jay; <26> the eel's foe the heroun;\n"
  "The false lapwing, full of treachery; <27>\n"
  "The starling, that the counsel can betray;\n"
  "The tame ruddock,* and the coward kite;                 *robin-redbreast\n"
  "The cock, that horologe* is of *thorpes lite.*  *clock *little villages*\n"
  "\n"
  "The sparrow, Venus' son; <28> the nightingale,\n"
  "That calleth forth the freshe leaves new; <29>\n"
  "The swallow, murd'rer of the bees smale,\n"
  "That honey make of flowers fresh of hue;\n"
  "The wedded turtle, with his hearte true;\n"
  "The peacock, with his angel feathers bright; <30>\n"
  "The pheasant, scorner of the cock by night; <31>\n"
  "\n"
  "The waker goose; <32> the cuckoo ever unkind; <33>\n"
  "The popinjay,* full of delicacy;                                 *parrot\n"
  "The drake, destroyer of his owen kind; <34>\n"
  "The stork, the wreaker* of adultery; <35>                       *avenger\n"
  "The hot cormorant, full of gluttony; <36>\n"
  "The raven and the crow, with voice of care; <37>\n"
  "The throstle old;* and the frosty fieldfare.<38>             *long-lived\n"
  "\n"
  "What should I say? Of fowls of ev'ry kind\n"
  "That in this world have feathers and stature,\n"
  "Men mighten in that place assembled find,\n"
  "Before that noble goddess of Nature;\n"
  "And each of them did all his busy cure*                     *care, pains\n"
  "Benignely to choose, or for to take,\n"
  "By her accord,* his formel <39> or his make.**           *consent **mate\n"
  "\n"
  "But to the point. Nature held on her hand\n"
  "A formel eagle, of shape the gentilest\n"
  "That ever she among her workes fand,\n"
  "The most benign, and eke the goodliest;\n"
  "In her was ev'ry virtue at its rest,*                     *highest point\n"
  "So farforth that Nature herself had bliss\n"
  "To look on her, and oft her beak to kiss.\n"
  "\n"
  "Nature, the vicar of th'Almighty Lord, --\n"
  "That hot, cold, heavy, light, and moist, and dry,\n"
  "Hath knit, by even number of accord, --\n"
  "In easy voice began to speak, and say:\n"
  "\"Fowles, take heed of my sentence,\"* I pray;         *opinion, discourse\n"
  "And for your ease, in furth'ring of your need,\n"
  "As far as I may speak, I will me speed.\n"
  "\n"
  "\"Ye know well how, on Saint Valentine's Day,\n"
  "By my statute, and through my governance,\n"
  "Ye choose your mates, and after fly away\n"
  "With them, as I you *pricke with pleasance;*     *inspire with pleasure*\n"
  "But natheless, as by rightful ordinance,\n"
  "May I not let,* for all this world to win,                       *hinder\n"
  "But he that most is worthy shall begin.\n"
  "\n"
  "\"The tercel eagle, as ye know full weel,*                          *well\n"
  "The fowl royal, above you all in degree,\n"
  "The wise and worthy, secret, true as steel,\n"
  "The which I formed have, as ye may see,\n"
  "In ev'ry part, as it best liketh me, --\n"
  "It needeth not his shape you to devise,* --                    *describe\n"
  "He shall first choose, and speaken *in his guise.*      *in his own way*\n"
  "\n"
  "\"And, after him, by order shall ye choose,\n"
  "After your kind, evereach as you liketh;\n"
  "And as your hap* is, shall ye win or lose;                      *fortune\n"
  "But which of you that love most entriketh,*              *entangles <40>\n"
  "God send him her that sorest for him siketh.\"*                  *sigheth\n"
  "And therewithal the tercel gan she call,\n"
  "And said, \"My son, the choice is to thee fall.\n"
  "\n"
  "\"But natheless, in this condition\n"
  "Must be the choice of ev'reach that is here,\n"
  "That she agree to his election,\n"
  "Whoso he be, that shoulde be her fere;*                       *companion\n"
  "This is our usage ay, from year to year;\n"
  "And whoso may at this time have this grace,\n"
  "*In blissful time* he came into this place.\"           *in a happy hour*\n"
  "With head inclin'd, and with full humble cheer,*              *demeanour\n"
  "\n"
  "This royal tercel spake, and tarried not:\n"
  "\"Unto my sov'reign lady, and not my fere,*                    *companion\n"
  "I chose and choose, with will, and heart, and thought,\n"
  "The formel on your hand, so well y-wrought,\n"
  "Whose I am all, and ever will her serve,\n"
  "Do what her list, to do me live or sterve.*                         *die\n"
  "\n"
  "\"Beseeching her of mercy and of grace,\n"
  "As she that is my lady sovereign,\n"
  "Or let me die here present in this place,\n"
  "For certes long may I not live in pain;\n"
  "*For in my heart is carven ev'ry vein:*       *every vein in my heart is\n"
  "Having regard only unto my truth,                     wounded with love*\n"
  "My deare heart, have on my woe some ruth.*                         *pity\n"
  "\n"
  "\"And if that I be found to her untrue,\n"
  "Disobeisant,* or wilful negligent,                          *disobedient\n"
  "Avaunter,* or *in process* love a new,         *braggart  *in the course\n"
  "I pray to you, this be my judgement,                            of time*\n"
  "That with these fowles I be all to-rent,*                *torn to pieces\n"
  "That ilke* day that she me ever find                               *same\n"
  "To her untrue, or in my guilt unkind.\n"
  "\n"
  "";
// }

const char poemTheAssemblyOfFowls1[] PGMSECTION = // { // 27147 bytes
  "\"And since none loveth her so well as I,\n"
  "Although she never of love me behet,*                          *promised\n"
  "Then ought she to be mine, through her mercy;\n"
  "For *other bond can I none on her knit;*   *I can bind her no other way*\n"
  "For weal or for woe, never shall I let*                     *cease, fail\n"
  "To serve her, how far so that she wend;*                             *go\n"
  "Say what you list, my tale is at an end.\"\n"
  "\n"
  "Right as the freshe redde rose new\n"
  "Against the summer Sunne colour'd is,\n"
  "Right so, for shame, all waxen gan the hue\n"
  "Of this formel, when she had heard all this;\n"
  "*Neither she answer'd well, nor said amiss,*      *she answered nothing,\n"
  "So sore abashed was she, till Nature                 either well or ill*\n"
  "Said, \"Daughter, dread you not, I you assure.\"*        *confirm, support\n"
  "\n"
  "Another tercel eagle spake anon,\n"
  "Of lower kind, and said that should not be;\n"
  "\"I love her better than ye do, by Saint John!\n"
  "Or at the least I love her as well as ye,\n"
  "And longer have her serv'd in my degree;\n"
  "And if she should have lov'd for long loving,\n"
  "To me alone had been the guerdoning.*                            *reward\n"
  "\n"
  "\"I dare eke say, if she me finde false,\n"
  "Unkind, janglere,* rebel in any wise,                          *boastful\n"
  "Or jealous, *do me hange by the halse;*            *hang me by the neck*\n"
  "And but* I beare me in her service                               *unless\n"
  "As well ay as my wit can me suffice,\n"
  "From point to point, her honour for to save,\n"
  "Take she my life and all the good I have.\"\n"
  "\n"
  "A thirde tercel eagle answer'd tho:*                               *then\n"
  "\"Now, Sirs, ye see the little leisure here;\n"
  "For ev'ry fowl cries out to be ago\n"
  "Forth with his mate, or with his lady dear;\n"
  "And eke Nature herselfe will not hear,\n"
  "For tarrying her, not half that I would say;\n"
  "And but* I speak, I must for sorrow dey.**                 *unless **die\n"
  "\n"
  "Of long service avaunt* I me no thing,                            *boast\n"
  "But as possible is me to die to-day,\n"
  "For woe, as he that hath been languishing\n"
  "This twenty winter; and well happen may\n"
  "A man may serve better, and *more to pay,*      *with more satisfaction*\n"
  "In half a year, although it were no more.\n"
  "Than some man doth that served hath *full yore.*       *for a long time*\n"
  "\n"
  "\"I say not this by me for that I can\n"
  "Do no service that may my lady please;\n"
  "But I dare say, I am her truest man,*                 *liegeman, servant\n"
  "*As to my doom,* and fainest would her please;          *in my judgement\n"
  "*At shorte words,* until that death me seize,              *in one word*\n"
  "I will be hers, whether I wake or wink.\n"
  "And true in all that hearte may bethink.\"\n"
  "\n"
  "Of all my life, since that day I was born,\n"
  "*So gentle plea,* in love or other thing,          *such noble pleading*\n"
  "Ye hearde never no man me beforn;\n"
  "Whoso that hadde leisure and cunning*                             *skill\n"
  "For to rehearse their cheer and their speaking:\n"
  "And from the morrow gan these speeches last,\n"
  "Till downward went the Sunne wonder fast.\n"
  "\n"
  "The noise of fowles for to be deliver'd*             *set free to depart\n"
  "So loude rang, \"Have done and let us wend,\"*                         *go\n"
  "That well ween'd I the wood had all to-shiver'd:*        *been shaken to\n"
  "\"Come off!\" they cried; \"alas! ye will us shend!*          pieces* *ruin\n"
  "When will your cursed pleading have an end?\n"
  "How should a judge either party believe,\n"
  "For yea or nay, withouten any preve?\"*                            *proof\n"
  "\n"
  "The goose, the duck, and the cuckoo also,\n"
  "So cried \"keke, keke,\" \"cuckoo,\" \"queke queke,\" high,\n"
  "That through mine ears the noise wente tho.*                       *then\n"
  "The goose said then, \"All this n'is worth a fly!\n"
  "But I can shape hereof a remedy;\n"
  "And I will say my verdict, fair and swith,*                    *speedily\n"
  "For water-fowl, whoso be wroth or blith.\"*                         *glad\n"
  "\n"
  "\"And I for worm-fowl,\" said the fool cuckow;\n"
  "For I will, of mine own authority,\n"
  "For common speed,* take on me the charge now;                 *advantage\n"
  "For to deliver us is great charity.\"\n"
  "\"Ye may abide a while yet, pardie,\"*                             *by God\n"
  "Quoth then the turtle; \"if it be your will\n"
  "A wight may speak, it were as good be still.\n"
  "\n"
  "\"I am a seed-fowl, one th'unworthiest,\n"
  "That know I well, and the least of cunning;\n"
  "But better is, that a wight's tongue rest,\n"
  "Than *entremette him of* such doing                   *meddle with* <41>\n"
  "Of which he neither rede* can nor sing;                         *counsel\n"
  "And who it doth, full foul himself accloyeth,*             *embarrasseth\n"
  "For office uncommanded oft annoyeth.\"\n"
  "\n"
  "Nature, which that alway had an ear\n"
  "To murmur of the lewedness behind,\n"
  "With facond* voice said, \"Hold your tongues there,     *eloquent, fluent\n"
  "And I shall soon, I hope, a counsel find,\n"
  "You to deliver, and from this noise unbind;\n"
  "I charge of ev'ry flock* ye shall one call,               *class of fowl\n"
  "To say the verdict of you fowles all.\"\n"
  "\n"
  "The tercelet* said then in this mannere;                      *male hawk\n"
  "\"Full hard it were to prove it by reason,\n"
  "Who loveth best this gentle formel here;\n"
  "For ev'reach hath such replication,*                              *reply\n"
  "That by skilles* may none be brought adown;                   *arguments\n"
  "I cannot see that arguments avail;\n"
  "Then seemeth it that there must be battaile.\"\n"
  "\n"
  "\"All ready!\" quoth those eagle tercels tho;*                       *then\n"
  "\"Nay, Sirs!\" quoth he; \"if that I durst it say,\n"
  "Ye do me wrong, my tale is not y-do,*                              *done\n"
  "For, Sirs, -- and *take it not agrief,* I pray, --     *be not offended*\n"
  "It may not be as ye would, in this way:\n"
  "Ours is the voice that have the charge in hand,\n"
  "And *to the judges' doom ye muste stand.*          *ye must abide by the\n"
  "                                                       judges' decision*\n"
  "\"And therefore 'Peace!' I say; as to my wit,\n"
  "Me woulde think, how that the worthiest\n"
  "Of knighthood, and had longest used it,\n"
  "Most of estate, of blood the gentilest,\n"
  "Were fitting most for her, *if that her lest;*          *if she pleased*\n"
  "And, of these three she knows herself, I trow,*                 *am sure\n"
  "Which that he be; for it is light* to know.\"                       *easy\n"
  "\n"
  "The water-fowles have their heades laid\n"
  "Together, and *of short advisement,*          *after brief deliberation*\n"
  "When evereach his verdict had y-said\n"
  "They saide soothly all by one assent,\n"
  "How that \"The goose with the *facond gent,*          *refined eloquence*\n"
  "That so desired to pronounce our need,*                         business\n"
  "Shall tell our tale;\" and prayed God her speed.\n"
  "\n"
  "And for those water-fowles then began\n"
  "The goose to speak. and in her cackeling\n"
  "She saide, \"Peace, now! take keep* ev'ry man,                      *heed\n"
  "And hearken what reason I shall forth bring;\n"
  "My wit is sharp, I love no tarrying;\n"
  "I say I rede him, though he were my brother,\n"
  "But* she will love him, let him love another!\"                   *unless\n"
  "\n"
  "\"Lo! here a perfect reason of a goose!\"\n"
  "Quoth the sperhawke.  \"Never may she the!*                       *thrive\n"
  "Lo such a thing 'tis t'have a tongue loose!\n"
  "Now, pardie: fool, yet were it bet* for thee                     *better\n"
  "Have held thy peace, than show'd thy nicety;*               *foolishness\n"
  "It lies not in his wit, nor in his will,\n"
  "But sooth is said, a fool cannot be still.\"\n"
  "\n"
  "The laughter rose of gentle fowles all;\n"
  "And right anon the seed-fowls chosen had\n"
  "The turtle true, and gan her to them call,\n"
  "And prayed her to say the *soothe sad*                   *serious truth*\n"
  "Of this mattere, and asked what she rad;*                    *counselled\n"
  "And she answer'd, that plainly her intent\n"
  "She woulde show, and soothly what she meant.\n"
  "\n"
  "\"Nay! God forbid a lover shoulde change!\"\n"
  "The turtle said, and wax'd for shame all red:\n"
  "\"Though that his lady evermore be strange,*                  *disdainful\n"
  "Yet let him serve her ay, till he be dead;\n"
  "For, sooth, I praise not the goose's rede*                      *counsel\n"
  "For, though she died, I would none other make;*                    *mate\n"
  "I will be hers till that the death me take.\"\n"
  "\n"
  "*\"Well bourded!\"* quoth the ducke, \"by my hat!          *a pretty joke!*\n"
  "That men should loven alway causeless,\n"
  "Who can a reason find, or wit, in that?\n"
  "Danceth he merry, that is mirtheless?\n"
  "Who shoulde *reck of that is reckeless?*           *care for one who has\n"
  "Yea! queke yet,\" quoth the duck, \"full well and fair!   no care for him*\n"
  "There be more starres, God wot, than a pair!\"  <42>\n"
  "\n"
  "\"Now fy, churl!\" quoth the gentle tercelet,\n"
  "\"Out of the dunghill came that word aright;\n"
  "Thou canst not see which thing is well beset;\n"
  "Thou far'st by love, as owles do by light,--\n"
  "The day them blinds, full well they see by night;\n"
  "Thy kind is of so low a wretchedness,\n"
  "That what love is, thou caust not see nor guess.\"\n"
  "\n"
  "Then gan the cuckoo put him forth in press,*               *in the crowd\n"
  "For fowl that eateth worm, and said belive:*                    *quickly\n"
  "\"So I,\" quoth he, \"may have my mate in peace,\n"
  "I recke not how longe that they strive.\n"
  "Let each of them be solain* all their life;                 *single <43>\n"
  "This is my rede,* since they may not accord;                    *counsel\n"
  "This shorte lesson needeth not record.\"\n"
  "\n"
  "\"Yea, have the glutton fill'd enough his paunch,\n"
  "Then are we well!\" saide the emerlon;*                           *merlin\n"
  "\"Thou murd'rer of the heggsugg,* on the branch            *hedge-sparrow\n"
  "That brought thee forth, thou most rueful glutton, <44>\n"
  "Live thou solain, worme's corruption!\n"
  "*For no force is to lack of thy nature;*     *the loss of a bird of your\n"
  "Go! lewed be thou, while the world may dare!\"      depraved nature is no\n"
  "                                                      matter of regret.*\n"
  "\"Now peace,\" quoth Nature, \"I commande here;\n"
  "For I have heard all your opinion,\n"
  "And in effect yet be we ne'er the nere.*                         *nearer\n"
  "But, finally, this is my conclusion, --\n"
  "That she herself shall have her election\n"
  "Of whom her list, whoso be *wroth or blith;*             *angry or glad*\n"
  "Him that she chooseth, he shall her have as swith.*             *quickly\n"
  "\n"
  "\"For since it may not here discussed be\n"
  "Who loves her best, as said the tercelet,\n"
  "Then will I do this favour t' her, that she\n"
  "Shall have right him on whom her heart is set,\n"
  "And he her, that his heart hath on her knit:\n"
  "This judge I, Nature, for* I may not lie                        *because\n"
  "To none estate; I *have none other eye.*          *can see the matter in\n"
  "                                                         no other light*\n"
  "\"But as for counsel for to choose a make,\n"
  "If I were Reason, [certes] then would I\n"
  "Counsaile you the royal tercel take,\n"
  "As saith the tercelet full skilfully,*                       *reasonably\n"
  "As for the gentilest, and most worthy,\n"
  "Which I have wrought so well to my pleasance,\n"
  "That to you it ought be *a suffisance.\"*          *to your satisfaction*\n"
  "\n"
  "With dreadful* voice the formel her answer'd:                *frightened\n"
  "\"My rightful lady, goddess of Nature,\n"
  "Sooth is, that I am ever under your yerd,*           *rod, or government\n"
  "As is every other creature,\n"
  "And must be yours, while that my life may dure;\n"
  "And therefore grante me my firste boon,*                         *favour\n"
  "And mine intent you will I say right soon.\"\n"
  "\n"
  "\"I grant it you,\" said she; and right anon\n"
  "This formel eagle spake in this degree:*                         *manner\n"
  "\"Almighty queen, until this year be done\n"
  "I aske respite to advise me;\n"
  "And after that to have my choice all free;\n"
  "This is all and some that I would speak and say;\n"
  "Ye get no more, although ye *do me dey.*                       *slay me*\n"
  "\n"
  "\"I will not serve Venus, nor Cupide,\n"
  "For sooth as yet, by no manner [of] way.\"\n"
  "\"Now since it may none other ways betide,\"*                      *happen\n"
  "Quoth Dame Nature, \"there is no more to say;\n"
  "Then would I that these fowles were away,\n"
  "Each with his mate, for longer tarrying here.\"\n"
  "And said them thus, as ye shall after hear.\n"
  "\n"
  "\"To you speak I, ye tercels,\" quoth Nature;\n"
  "\"Be of good heart, and serve her alle three;\n"
  "A year is not so longe to endure;\n"
  "And each of you *pain him* in his degree                        *strive*\n"
  "For to do well, for, God wot, quit is she\n"
  "From you this year, what after so befall;\n"
  "This *entremess is dressed* for you all.\"             *dish is prepared*\n"
  "\n"
  "And when this work y-brought was to an end,\n"
  "To ev'ry fowle Nature gave his make,\n"
  "By *even accord,* and on their way they wend:           *fair agreement*\n"
  "And, Lord! the bliss and joye that they make!\n"
  "For each of them gan other in his wings take,\n"
  "And with their neckes each gan other wind,*              *enfold, caress\n"
  "Thanking alway the noble goddess of Kind.\n"
  "\n"
  "But first were chosen fowles for to sing,--\n"
  "As year by year was alway their usance,* --                      *custom\n"
  "To sing a roundel at their departing,\n"
  "To do to Nature honour and pleasance;\n"
  "The note, I trowe, maked was in France;\n"
  "The wordes were such as ye may here find\n"
  "The nexte verse, as I have now in mind:\n"
  "\n"
  "Qui bien aime, tard oublie. <45>\n"
  "\n"
  "\"Now welcome summer, with thy sunnes soft,\n"
  "That hast these winter weathers overshake *         *dispersed, overcome\n"
  "Saint Valentine, thou art full high on loft,\n"
  "Which driv'st away the longe nightes blake;*                      *black\n"
  "Thus singe smalle fowles for thy sake:\n"
  "Well have they cause for to gladden* oft,           *be glad, make mirth\n"
  "Since each of them recover'd hath his make;*                       *mate\n"
  "Full blissful may they sing when they awake.\"\n"
  "\n"
  "And with the shouting, when their song was do,*                    *done\n"
  "That the fowls maden at their flight away,\n"
  "I woke, and other bookes took me to,\n"
  "To read upon; and yet I read alway.\n"
  "I hope, y-wis, to reade so some day,\n"
  "That I shall meete something for to fare\n"
  "The bet;* and thus to read I will not spare.                     *better\n"
  "\n"
  "\n"
  "Explicit.*                                                      *the end\n"
  "\n"
  "\n"
  "Notes to The Assembly of Fowls\n"
  "\n"
  "\n"
  "1. \"The Dream of Scipio\" -- \"Somnium Scipionis\" -- occupies\n"
  "most of the sixth book of Cicero's \"Republic;\" which, indeed, as\n"
  "it has come down to us, is otherwise imperfect. Scipio\n"
  "Africanus Minor is represented as relating a dream which he had\n"
  "when, in B.C. 149, he went to Africa as military tribune to the\n"
  "fourth legion. He had talked long and earnestly of his adoptive\n"
  "grandfather with Massinissa, King of Numidia, the intimate\n"
  "friend of the great Scipio; and at night his illustrious ancestor\n"
  "appeared to him in a vision, foretold the overthrow of Carthage\n"
  "and all his other triumphs, exhorted him to virtue and patriotism\n"
  "by the assurance of rewards in the next world, and discoursed\n"
  "to him concerning the future state and the immortality of the\n"
  "soul. Macrobius, about AD. 500, wrote a Commentary upon the\n"
  "\"Somnium Scipionis,\" which was a favourite book in the Middle\n"
  "Ages. See note 17 to The Nun's Priest's Tale.\n"
  "\n"
  "2. Y-nome: taken; past participle of \"nime,\" from Anglo-Saxon,\n"
  "\"niman,\" to take.\n"
  "\n"
  "3. His grace: the favour which the gods would show him, in\n"
  "delivering Carthage into his hands.\n"
  "\n"
  "4. \"Vestra vero, quae dicitur, vita mors est.\" (\"Truly, as is said,\n"
  "your life is a death\")\n"
  "\n"
  "5. The nine spheres are God, or the highest heaven, constraining\n"
  "and containing all the others; the Earth, around which the\n"
  "planets and the highest heaven revolve; and the seven planets:\n"
  "the revolution of all producing the \"music of the spheres.\"\n"
  "\n"
  "6. Clear: illustrious, noble; Latin, \"clarus.\"\n"
  "\n"
  "7. The sicke mette he drinketh of the tun: The sick man dreams\n"
  "that he drinks wine, as one in health.\n"
  "\n"
  "8. The significance of the poet's looking to the NNW is not\n"
  "plain; his window may have faced that way.\n"
  "\n"
  "9. The idea of the twin gates, leading to the Paradise and the\n"
  "Hell of lovers, may have been taken from the description of the\n"
  "gates of dreams in the Odyssey and the Aeneid; but the iteration\n"
  "of \"Through me men go\" far more directly suggests the legend\n"
  "on Dante's gate of Hell:--\n"
  "\n"
  "Per me si va nella citta dolente,\n"
  "Per me si va nell' eterno dolore;\n"
  "Per me si va tra la perduta gente.\n"
  "\n"
  "(\"Through me is the way to the city of sorrow,\n"
  "Through me is the way to eternal suffering;\n"
  "Through me is the way of the lost people\")\n"
  "\n"
  "The famous line, \"Lasciate ogni speranza, voi che entrate\" --\n"
  "\"All hope abandon, ye who enter here\" -- is evidently\n"
  "paraphrased in Chaucer's words \"Th'eschewing is the only\n"
  "remedy;\" that is, the sole hope consists in the avoidance of that\n"
  "dismal gate.\n"
  "\n"
  "10. A powerful though homely description of torment; the\n"
  "sufferers being represented as fish enclosed in a weir from\n"
  "which all the water has been withdrawn.\n"
  "\n"
  "11. Compare with this catalogue raisonne of trees the ampler\n"
  "list given by Spenser in \"The Faerie Queen,\" book i. canto i. In\n"
  "several instances, as in \"the builder oak\" and \"the sailing pine,\"\n"
  "the later poet has exactly copied the words of the earlier.\n"
  "The builder oak: In the Middle Ages the oak was as\n"
  "distinctively the building timber on land, as it subsequently\n"
  "became for the sea.\n"
  "The pillar elm:  Spenser explains this in paraphrasing it into \"the\n"
  "vineprop elm\" -- because it was planted as a pillar or  prop to\n"
  "the vine; it is called \"the coffer unto carrain,\" or \"carrion,\"\n"
  "because coffins for the dead were made from it.\n"
  "The box, pipe tree: the box tree was used for making pipes or horns.\n"
  "Holm: the holly, used for whip-handles.\n"
  "The sailing fir: Because ships' masts and spars were made of its\n"
  "wood.\n"
  "The cypress death to plain: in Spenser's imitation, \"the cypress\n"
  "funeral.\"\n"
  "The shooter yew: yew wood was used for bows.\n"
  "The aspe for shaftes plain: of the aspen, or black poplar, arrows\n"
  "were made.\n"
  "The laurel divine: So called, either because it was Apollo's\n"
  "tree -- Horace says that Pindar is \"laurea donandus Apollinari\" (\"to\n"
  "be given Apollo's laurel\") -- or because the honour which it\n"
  "signified, when placed on the head of a poet or conqueror, lifted\n"
  "a man as it were into the rank of the gods.\n"
  "\n"
  "12. If Chaucer had any special trio of courtiers in his mind when\n"
  "he excluded so many names, we may suppose them to be\n"
  "Charms, Sorcery, and Leasings who, in The Knight's Tale, come\n"
  "after Bawdry and Riches -- to whom Messagerie (the carrying\n"
  "of messages) and Meed (reward, bribe) may correspond.\n"
  "\n"
  "13. The dove was the bird sacred to Venus; hence Ovid\n"
  "enumerates the peacock of Juno, Jove's armour bearing bird,\n"
  "\"Cythereiadasque columbas\" (\"And the Cythereian doves\") --\n"
  "\"Metamorphoses. xv. 386\n"
  "\n"
  "14. Priapus:  fitly endowed with a place in the Temple of Love,\n"
  "as being the embodiment of the principle of fertility in flocks\n"
  "and the fruits of the earth. See note 23 to the Merchant's Tale.\n"
  "\n"
  "15. Ovid, in the \"Fasti\" (i. 433), describes the confusion of\n"
  "Priapus when, in the night following a feast of sylvan and\n"
  "Bacchic deities, the braying of the ass of Silenus wakened the\n"
  "company to detect the god in a furtive amatory expedition.\n"
  "\n"
  "16. Hautain: haughty, lofty; French, \"hautain.\"\n"
  "\n"
  "17. Well to my pay: Well to my satisfaction; from French,\n"
  "\"payer,\" to pay, satisfy; the same word often occurs, in the\n"
  "phrases \"well apaid,\" and \"evil apaid.\"\n"
  "\n"
  "18. Valentia, in Spain, was famed for the fabrication of fine and\n"
  "transparent stuffs.\n"
  "\n"
  "19. The obvious reference is to the proverbial \"Sine Cerere et\n"
  "Libero friget Venus,\" (\"Love is frozen without freedom and\n"
  "food\") quoted in Terence, \"Eunuchus,\" act iv. scene v.\n"
  "\n"
  "20. Cypride: Venus; called \"Cypria,\" or \"Cypris,\" from the\n"
  "island of Cyprus, in which her worship was especially\n"
  "celebrated.\n"
  "\n"
  "21. Callisto, daughter of Lycaon, was seduced by Jupiter,\n"
  "turned into a bear by Diana, and placed afterwards, with her\n"
  "son, as the Great Bear among the stars.\n"
  "Atalanta challenged Hippomenes, a Boetian youth, to a race in\n"
  "which the prize was her hand in marriage -- the penalty of\n"
  "failure, death by her hand. Venus gave Hippomenes three\n"
  "golden apples, and he won by dropping them one at a time\n"
  "because Atalanta stopped to pick them up.\n"
  "Semiramis was Queen of Ninus, the mythical founder of\n"
  "Babylon; Ovid mentions her, along with Lais, as a type of\n"
  "voluptuousness, in his \"Amores,\" 1.5, 11.\n"
  "Canace, daughter of Aeolus, is named in the prologue to The\n"
  "Man of Law's Tale as one of the ladies whose \"cursed stories\"\n"
  "Chaucer refrained from writing. She loved her brother\n"
  "Macareus, and was slain by her father.\n"
  "Hercules was conquered by his love for Omphale, and spun\n"
  "wool for her in a woman's dress, while she wore his lion's skin.\n"
  "Biblis vainly pursued her brother Caunus with her love, till she\n"
  "was changed to a fountain; Ovid, \"Metamorphoses.\" lib. ix.\n"
  "Thisbe and Pyramus: the Babylonian lovers, whose death,\n"
  "through the error of Pyramus in fancying that a lion had slain his\n"
  "mistress, forms the theme of the interlude in the \"Midsummer\n"
  "Night's Dream.\"\n"
  "Sir Tristram was one of the most famous among the knights of\n"
  "King Arthur, and La Belle Isoude was his mistress. Their story\n"
  "is mixed up with the Arthurian romance; but it was also the\n"
  "subject of separate treatment, being among the most popular of\n"
  "the Middle Age legends.\n"
  "Achilles is reckoned among Love's conquests, because,\n"
  "according to some traditions, he loved Polyxena, the daughter\n"
  "of Priam, who was promised to him if he consented to join the\n"
  "Trojans; and, going without arms into Apollo's temple at\n"
  "Thymbra, he was there slain by Paris.\n"
  "Scylla: Love-stories are told of two maidens of this name; one\n"
  "the daughter of Nisus, King of Megara, who, falling in love with\n"
  "Minos when he besieged the city, slew  her father by pulling\n"
  "out the golden hair which grew on the top of his head, and on\n"
  "which  which his life and kingdom depended. Minos won the\n"
  "city, but rejected her love in horror. The other Scylla, from\n"
  "whom the rock opposite Charybdis was named, was a beautiful\n"
  "maiden, beloved by the sea-god Glaucus, but changed into a\n"
  "monster through the jealousy and enchantments of Circe.\n"
  "The mother of Romulus:  Silvia, daughter and only living child\n"
  "of Numitor, whom her uncle Amulius made a vestal virgin, to\n"
  "preclude the possibility that his brother's descendants could\n"
  "wrest from him the kingdom of Alba Longa. But the maiden\n"
  "was violated by Mars as she went to bring water from a\n"
  "fountain; she bore Romulus and Remus; and she was drowned\n"
  "in the Anio, while the cradle with the children was carried down\n"
  "the stream in safety to the Palatine Hill, where the she-wolf\n"
  "adopted them.\n"
  "\n"
  "22. Prest: ready; French, \"pret.\"\n"
  "\n"
  "23. Alanus de Insulis, a Sicilian poet and orator of the twelfth\n"
  "century, who wrote a book \"De Planctu Naturae\" -- \"The\n"
  "Complaint of Nature.\"\n"
  "\n"
  "24. The falcon was borne on the hand by the highest\n"
  "personages, not merely in actual sport, but to be caressed and\n"
  "petted, even on occasions of ceremony, Hence also it is called\n"
  "the \"gentle\" falcon -- as if its high birth and breeding gave it a\n"
  "right to august society.\n"
  "\n"
  "25. The merlion: elsewhere in the same poem called \"emerlon;\"\n"
  "French, \"emerillon;\" the merlin, a small hawk carried by ladies.\n"
  "\n"
  "26. The scorning jay: scorning humbler birds, out of pride of his\n"
  "fine plumage.\n"
  "\n"
  "27. The false lapwing: full of stratagems and pretences to divert\n"
  "approaching danger from the nest where her young ones are.\n"
  "\n"
  "28. The sparrow, Venus' son: Because sacred to Venus.\n"
  "\n"
  "29. Coming with the spring, the nightingale is charmingly said\n"
  "to call forth the new leaves.\n"
  "\n"
  "30. Many-coloured wings, like those of peacocks, were often\n"
  "given to angels in paintings of the Middle Ages; and in\n"
  "accordance with this fashion Spenser represents the Angel that\n"
  "guarded Sir Guyon (\"Faerie Queen,\" book ii. canto vii.) as\n"
  "having wings \"decked with diverse plumes, like painted jay's.\"\n"
  "\n"
  "31. The pheasant, scorner of the cock by night:  The meaning of\n"
  "this passage is not very plain; it has been supposed, however, to\n"
  "refer to the frequent breeding of pheasants at night with\n"
  "domestic poultry in the farmyard -- thus scorning the sway of\n"
  "the cock, its rightful monarch.\n"
  "\n"
  "32. The waker goose:  Chaucer evidently alludes to the passage\n"
  "in Ovid describing the crow of Apollo, which rivalled the\n"
  "spotless doves, \"Nec servataris vigili Capitolia voce cederet\n"
  "anseribus\" -- \"nor would it yield (in whiteness) to the geese\n"
  "destined with wakeful or vigilant voice to save the Capitol\"\n"
  "(\"Metam.,\" ii. 538) when about to be surprised by the Gauls in\n"
  "a night attack.\n"
  "\n"
  "33. The cuckoo ever unkind: the significance of this epithet is\n"
  "amply explained by the poem of \"The Cuckoo and the\n"
  "Nightingale.\"\n"
  "\n"
  "34. The drake, destroyer: of the ducklings -- which, if not\n"
  "prevented, he will kill wholesale.\n"
  "\n"
  "35. The stork is conspicuous for faithfulness to all family\n"
  "obligations, devotion to its young, and care of its parent birds in\n"
  "their old age. Mr Bell quotes from Bishop Stanley's \"History of\n"
  "Birds\" a little story which peculiarly justifies the special\n"
  "character Chaucer has given: --  \"A French surgeon, at Smyrna,\n"
  "wishing to procure a stork, and finding great difficulty, on\n"
  "account of the extreme veneration in which they are held by the\n"
  "Turks, stole all the eggs out of a nest, and replaced them with\n"
  "those of a hen: in process of time the young chickens came\n"
  "forth, much to the astonishment of Mr and Mrs Stork. In a\n"
  "short time Mr S. went off, and was not seen for two or three\n"
  "days, when he returned with an immense crowd of his\n"
  "companions, who all assembled in the place, and formed a\n"
  "circle, taking no notice of the numerous spectators whom so\n"
  "unusual an occurrence had collected. Mrs Stork was brought\n"
  "forward into the midst of the circle, and, after some\n"
  "consultation, the whole flock fell upon her and tore her to\n"
  "pieces; after which they immediately dispersed, and the nest was\n"
  "entirely abandoned.\"\n"
  "\n"
  "36. The cormorant feeds upon fish, so voraciously, that when\n"
  "the stomach is crammed it will often have the gullet and bill\n"
  "likewise full, awaiting the digestion of the rest.\n"
  "\n"
  "37. So called from the evil omens supposed to be afforded by\n"
  "their harsh cries.\n"
  "\n"
  "38. The fieldfare visits this country only in hard wintry weather.\n"
  "\n"
  "39. \"Formel,\" strictly or originally applied to the female of the\n"
  "eagle and hawk, is here used generally of the female of all birds;\n"
  "\"tercel\" is the corresponding word applied to the male.\n"
  "\n"
  "40. Entriketh: entangles, ensnares; french, \"intriguer,\" to\n"
  "perplex; hence \"intricate.\"\n"
  "\n"
  "41. Entremette him of: meddle with; French, ' entremettre,\" to\n"
  "interfere.\n"
  "\n"
  "42. The duck exhorts the contending lovers to be of light heart\n"
  "and sing, for abundance of other ladies were at their command.\n"
  "\n"
  "43. Solain: single, alone; the same word originally as \"sullen.\"\n"
  "\n"
  "44. The cuckoo is distinguished by its habit of laying its eggs in\n"
  "the nests of other and smaller birds, such as the hedge-sparrow\n"
  "(\"heggsugg\"); and its young, when hatched, throw the eggs or\n"
  "nestlings of the true parent bird out of the nest, thus engrossing\n"
  "the mother's entire care. The crime on which the emerlon\n"
  "comments so sharply, is explained by the migratory habits of the\n"
  "cuckoo, which prevent its bringing up its own young; and\n"
  "nature has provided facilities for the crime, by furnishing the\n"
  "young bird with a peculiarly strong and broad back, indented by\n"
  "a hollow in which the sparrow's egg is lifted till it is thrown out\n"
  "of the nest.\n"
  "\n"
  "45. \"Who well loves, late forgets;\" the refrain of the roundel\n"
  "inculcates the duty of constancy, which has been imposed on\n"
  "the three tercels by the decision of the Court.\n"
  "\n"
  "\n"
  "\n"
  "";
// }

const char poemTheFlowerAndTheLeaf0[] PGMSECTION = // { // 18610 bytes
  "                     THE FLOWER AND THE LEAF\n"
  "\n"
  "\n"
  "[\"The Flower and the Leaf\" is pre-eminently one of those\n"
  "poems by which Chaucer may be triumphantly defended against\n"
  "the charge of licentious coarseness, that, founded upon his\n"
  "faithful representation of the manners, customs, and daily life\n"
  "and speech of his own time, in \"The Canterbury Tales,\" are\n"
  "sweepingly advanced against his works at large. In an allegory --\n"
  "rendered perhaps somewhat cumbrous by the detail of chivalric\n"
  "ceremonial, and the heraldic minuteness, which entered so liberally\n"
  "into poetry, as into the daily life of the classes for whom poetry\n"
  "was then written -- Chaucer beautifully enforces the lasting\n"
  "advantages of purity, valour, and faithful love, and the fleeting\n"
  "and disappointing character of mere idle pleasure, of sloth\n"
  "and listless retirement from the battle of life. In the\n"
  "\"season sweet\" of spring, which the great singer of Middle Age\n"
  "England loved so well, a gentle woman is supposed to seek\n"
  "sleep in vain, to rise \"about the springing of the gladsome day,\"\n"
  "and, by an unfrequented path in a pleasant grove, to arrive at an\n"
  "arbour. Beside the arbour stands a medlar-tree, in which a\n"
  "Goldfinch sings passing sweetly; and the Nightingale answers\n"
  "from a green laurel tree, with so merry and ravishing a note,\n"
  "that the lady resolves to proceed no farther, but sit down on the\n"
  "grass to listen. Suddenly the sound of many voices singing\n"
  "surprises her; and she sees \"a world of ladies\" emerge from a\n"
  "grove, clad in white, and wearing garlands of laurel, of agnus\n"
  "castus, and woodbind. One, who wears a crown and bears a\n"
  "branch of agnus castus in her hand, begins a roundel, in honour\n"
  "of the Leaf, which all the others take up, dancing and singing in\n"
  "the meadow before the arbour. Soon, to the sound of\n"
  "thundering trumps, and attended by a splendid and warlike\n"
  "retinue, enter nine knights, in white, crowned like the ladies;\n"
  "and after they have jousted an hour and more, they alight and\n"
  "advance to the ladies. Each dame takes a knight by the hand;\n"
  "and all incline reverently to the laurel tree, which they\n"
  "encompass, singing of love, and dancing. Soon, preceded by a\n"
  "band of minstrels, out of the open field comes a lusty company\n"
  "of knights and ladies in green, crowned with chaplets of\n"
  "flowers; and they do reverence to a tuft of flowers in the middle\n"
  "of the meadow, while one of their number sings a bergerette in\n"
  "praise of the daisy. But now it is high noon; the sun waxes\n"
  "fervently hot; the flowers lose their beauty, and wither with the\n"
  "heat; the ladies in green are scorched, the knights faint for lack\n"
  "of shade. Then a strong wind beats down all the flowers, save\n"
  "such as are protected by the leaves of hedges and groves; and a\n"
  "mighty storm of rain and hail drenches the ladies and knights,\n"
  "shelterless in the now flowerless meadow. The storm overpast,\n"
  "the company in white, whom the laurel-tree has safely shielded\n"
  "from heat and storm, advance to the relief of the others; and\n"
  "when their clothes have been dried, and their wounds from sun\n"
  "and storm healed, all go together to sup with the Queen in\n"
  "white -- on whose hand, as they pass by the arbour, the\n"
  "Nightingale perches, while the Goldfinch flies to the Lady of the\n"
  "Flower. The pageant gone, the gentlewoman quits the arbour,\n"
  "and meets a lady in white, who, at her request, unfolds the\n"
  "hidden meaning of all that she has seen; \"which,\" says Speght\n"
  "quaintly, \"is this: They which honour the Flower, a thing fading\n"
  "with every blast, are such as look after beauty and worldly\n"
  "pleasure. But they that honour the Leaf, which abideth with the\n"
  "root, notwithstanding the frosts and winter storms, are they\n"
  "which follow Virtue and during qualities, without regard of\n"
  "worldly respects.\" Mr Bell, in his edition, has properly noticed\n"
  "that there is no explanation of the emblematical import of the\n"
  "medlar-tree, the goldfinch, and the nightingale. \"But,\" he says,\n"
  "\"as the fruit of the medlar, to use Chaucer's own expression (see\n"
  "Prologue to the Reeve's Tale), is rotten before it is ripe, it may\n"
  "be the emblem of sensual pleasure, which palls before it confers\n"
  "real enjoyment. The goldfinch is remarkable for the beauty of its\n"
  "plumage, the sprightliness of its movements, and its gay,\n"
  "tinkling song, and may be supposed to represent the showy and\n"
  "unsubstantial character of frivolous pleasures. The nightingale's\n"
  "sober outward appearance and impassioned song denote greater\n"
  "depth of feeling.\" The poem throughout is marked by the purest\n"
  "and loftiest moral tone; and it amply deserved Dryden's special\n"
  "recommendation, \"both for the invention and the moral.\" It is\n"
  "given without abridgement.]\n"
  "(Transcriber's note: Modern scholars believe that Chaucer was\n"
  "not the author of this poem)\n"
  "\n"
  "WHEN that Phoebus his car of gold so high\n"
  "Had whirled up the starry sky aloft,\n"
  "And in the Bull <1> enter'd certainly;\n"
  "When showers sweet of rain descended soft,\n"
  "Causing the grounde, fele* times and oft,                          *many\n"
  "Up for to give many a wholesome air,\n"
  "And every plain was y-clothed fair\n"
  "\n"
  "With newe green, and maketh smalle flow'rs\n"
  "To springe here and there in field and mead;\n"
  "So very good and wholesome be the show'rs,\n"
  "That they renewe what was old and dead\n"
  "In winter time; and out of ev'ry seed\n"
  "Springeth the herbe, so that ev'ry wight\n"
  "Of thilke* season waxeth glad and light.                           *this\n"
  "\n"
  "And I, so glad of thilke season sweet,\n"
  "Was *happed thus* upon a certain night,             *thus circumstanced*\n"
  "As I lay in my bed, sleep full unmeet*               *unfit, uncompliant\n"
  "Was unto me; but why that I not might\n"
  "Rest, I not wist; for there n'as* earthly wight,                *was not\n"
  "As I suppose, had more hearte's ease\n"
  "Than I, for I n'had* sickness nor disease.**         *had not **distress\n"
  "\n"
  "Wherefore I marvel greatly of myself,\n"
  "That I so long withoute sleepe lay;\n"
  "And up I rose three houres after twelf,\n"
  "About the springing of the [gladsome] day;\n"
  "And on I put my gear* and mine array,                          *garments\n"
  "And to a pleasant grove I gan to pass,\n"
  "Long ere the brighte sun uprisen was;\n"
  "\n"
  "In which were oakes great, straight as a line,\n"
  "Under the which the grass, so fresh of hue,\n"
  "Was newly sprung; and an eight foot or nine\n"
  "Every tree well from his fellow grew,\n"
  "With branches broad, laden with leaves new,\n"
  "That sprangen out against the sunne sheen;\n"
  "Some very red;<2> and some a glad light green;\n"
  "\n"
  "Which, as me thought, was right a pleasant sight.\n"
  "And eke the birdes' songes for to hear\n"
  "Would have rejoiced any earthly wight;\n"
  "And I, that could not yet, in no mannere,\n"
  "Heare the nightingale of* all the year,<3>                       *during\n"
  "Full busy hearkened with heart and ear,\n"
  "If I her voice perceive could anywhere.\n"
  "\n"
  "And at the last a path of little brede*                         *breadth\n"
  "I found, that greatly had not used be;\n"
  "For it forgrowen* was with grass and weed,                    *overgrown\n"
  "That well unneth* a wight mighte see:                          *scarcely\n"
  "Thought I, \"This path some whither goes, pardie!\"*          *of a surety\n"
  "And so I follow'd [it], till it me brought\n"
  "To a right pleasant arbour, well y-wrought,\n"
  "\n"
  "That benched  was, and [all] with turfes new\n"
  "Freshly y-turf'd, <4> whereof the greene grass,\n"
  "So small, so thick, so short, so fresh of hue,\n"
  "That most like to green wool, I wot, it was;\n"
  "The hedge also, that *yeden in compass,*           *went all around <5>*\n"
  "And closed in all the greene herbere,*                           *arbour\n"
  "With sycamore was set and eglatere,*             *eglantine, sweet-briar\n"
  "\n"
  "Wreathed *in fere* so well and cunningly,                     *together*\n"
  "That ev'ry branch and leaf grew *by measure,*                *regularly*\n"
  "Plain as a board, of *a height by and by:*         *the same height side\n"
  "I saw never a thing, I you ensure,                              by side*\n"
  "So well y-done; for he that took the cure*                  *pains, care\n"
  "To maken it, I trow did all his pain\n"
  "To make it pass all those that men have seen.\n"
  "\n"
  "And shapen was this arbour, roof and all,\n"
  "As is a pretty parlour; and also\n"
  "The hedge as thick was as a castle wall,\n"
  "That whoso list without to stand or go,\n"
  "Though he would all day pryen to and fro,\n"
  "He should not see if there were any wight\n"
  "Within or no; but one within well might\n"
  "\n"
  "Perceive all those that wente there without\n"
  "Into the field, that was on ev'ry side\n"
  "Cover'd with corn and grass; that out of doubt,\n"
  "Though one would seeken all the worlde wide,\n"
  "So rich a fielde could not be espied\n"
  "Upon no coast, *as of the quantity;*                  *for its abundance\n"
  "For of all goode thing there was plenty.                   or fertility*\n"
  "\n"
  "And I, that all this pleasant sight [did] see,\n"
  "Thought suddenly I felt so sweet an air\n"
  "Of the eglentere, that certainly\n"
  "There is no heart, I deem, in such despair,\n"
  "Nor yet with thoughtes froward and contrair\n"
  "So overlaid, but it should soon have boot,*             *remedy, relief*\n"
  "If it had ones felt this *savour swoot.*                   *sweet smell*\n"
  "\n"
  "And as I stood, and cast aside mine eye,\n"
  "I was ware of the fairest medlar tree\n"
  "That ever yet in all my life I seye,*                               *saw\n"
  "As full of blossoms as it mighte be;\n"
  "Therein a goldfinch leaping prettily\n"
  "From bough to bough; and as him list he eat\n"
  "Here and there of the buds and flowers sweet.\n"
  "\n"
  "And to the arbour side was adjoining\n"
  "This fairest tree, of which I have you told;\n"
  "And at the last the bird began to sing\n"
  "(When he had eaten what he eate wo'ld)\n"
  "So passing sweetly, that by many fold\n"
  "It was more pleasant than I could devise;*               *tell, describe\n"
  "And, when his song was ended in this wise,\n"
  "\n"
  "The nightingale with so merry a note\n"
  "Answered him, that all the woode rung,\n"
  "So suddenly, that, *as it were a sote,*                *like a fool <6>*\n"
  "I stood astound'; so was I with the song\n"
  "Thorough ravished, that, *till late and long,*         *for a long time*\n"
  "I wist not in what place I was, nor where;\n"
  "Again, me thought, she sung e'en by mine ear.\n"
  "\n"
  "Wherefore I waited about busily\n"
  "On ev'ry side, if that I might her see;\n"
  "And at the last I gan full well espy\n"
  "Where she sat in a fresh green laurel tree,\n"
  "On the further side, even right by me,\n"
  "That gave so passing a delicious smell,\n"
  "*According to* the eglantere full well.                  *blending with*\n"
  "\n"
  "Whereof I had so inly great pleasure,\n"
  "That, as me thought, I surely ravish'd was\n"
  "Into Paradise, where [as] my desire\n"
  "Was for to be, and no farther to pass,\n"
  "As for that day; and on the sweete grass\n"
  "I sat me down; for, *as for mine intent,*                   *to my mind*\n"
  "The birde's song was more *convenient,*       *appropriate to my humour*\n"
  "\n"
  "And more pleasant to me, by many fold,\n"
  "Than meat, or drink, or any other thing;\n"
  "Thereto the arbour was so fresh and cold,\n"
  "The wholesome savours eke so comforting,\n"
  "That, as I deemed, since the beginning\n"
  "Of the world was [there] never seen *ere than*             *before then*\n"
  "So pleasant a ground of none earthly man.\n"
  "\n"
  "And as I sat, the birdes heark'ning thus,\n"
  "Me thought that I heard voices suddenly,\n"
  "The most sweetest and most delicious\n"
  "That ever any wight, I *trow truely,*                   *verily believe*\n"
  "Heard in their life; for the harmony\n"
  "And sweet accord was in so good musike,\n"
  "That the voices to angels' most were like.\n"
  "\n"
  "At the last, out of a grove even by,\n"
  "That was right goodly, and pleasant to sight,\n"
  "I saw where there came, singing lustily,\n"
  "A world of ladies; but to tell aright\n"
  "Their greate beauty, lies not in my might,\n"
  "Nor their array; nevertheless I shall\n"
  "Tell you a part, though I speak not of all.\n"
  "\n"
  "In surcoats* white, of velvet well fitting,                 *upper robes\n"
  "They were clad, and the seames each one,\n"
  "As it were a mannere [of] garnishing,\n"
  "Was set with emeraldes, one and one,\n"
  "*By and by;* but many a riche stone                           *in a row*\n"
  "Was set upon the purfles,* out of doubt,              *embroidered edges\n"
  "Of collars, sleeves, and traines round about;\n"
  "\n"
  "As greate pearles, round and orient,*                         *brilliant\n"
  "And diamondes fine, and rubies red,\n"
  "And many another stone, of which I went*                  *cannot recall\n"
  "The names now; and ev'reach on her head\n"
  "[Had] a rich fret* of gold, which, without dread,**        *band **doubt\n"
  "Was full of stately* riche stones set;                  *valuable, noble\n"
  "And ev'ry lady had a chapelet\n"
  "\n"
  "Upon her head of branches fresh and green, <7>\n"
  "So well y-wrought, and so marvellously,\n"
  "That it was a right noble sight to see'n;\n"
  "Some of laurel, and some full pleasantly\n"
  "Had chapelets of woodbine; and sadly,*                         *sedately\n"
  "Some of agnus castus <8> wearen also\n"
  "Chapelets fresh; but there were many of tho'*                     *those\n"
  "\n"
  "That danced and eke sung full soberly;\n"
  "And all they went *in manner of compass;*                  *in a circle*\n"
  "But one there went, in mid the company,\n"
  "Sole by herself; but all follow'd the pace\n"
  "That she kept, whose heavenly figur'd face\n"
  "So pleasant was, and her well shap'd person,\n"
  "That in beauty she pass'd them ev'ry one.\n"
  "\n"
  "And more richly beseen, by many fold,\n"
  "She was also in ev'ry manner thing:\n"
  "Upon her head, full pleasant to behold,\n"
  "A crown of golde, rich for any king;\n"
  "A branch of agnus castus eke bearing\n"
  "In her hand, and to my sight truely\n"
  "She Lady was of all that company.\n"
  "\n"
  "And she began a roundell <9> lustily,\n"
  "That \"Suse le foyle, devers moi,\" men call,\n"
  "\"Siene et mon joly coeur est endormy;\" <10>\n"
  "And then the company answered all,\n"
  "With voices sweet entuned, and so small,*                          *fine\n"
  "That me thought it the sweetest melody\n"
  "That ever I heard in my life, soothly.*                           *truly\n"
  "\n"
  "And thus they came, dancing and singing,\n"
  "Into the middest of the mead each one,\n"
  "Before the arbour where I was sitting;\n"
  "And, God wot, me thought I was well-begone,*                  *fortunate\n"
  "For then I might advise* them one by one,                      *consider\n"
  "Who fairest was, who best could dance or sing,\n"
  "Or who most womanly was in all thing.\n"
  "\n"
  "They had not danced but a *little throw,*                   *short time*\n"
  "When that I hearde far off, suddenly,\n"
  "So great a noise of thund'ring trumpets blow,\n"
  "As though it should departed* have the sky;                *rent, divide\n"
  "And after that, within a while, I sigh,*                            *saw\n"
  "From the same grove, where the ladies came out,\n"
  "Of men of armes coming such a rout,*                            *company\n"
  "\n"
  "As* all the men on earth had been assembled                       *as if\n"
  "Unto that place, well horsed for the nonce*                    *occasion\n"
  "Stirring so fast, that all the earthe trembled\n"
  "But for to speak of riches, and of stones,\n"
  "And men and horse, I trow the large ones*                   *i.e. jewels\n"
  "Of Prester John, <11> nor all his treasury,\n"
  "Might not unneth* have bought the tenth party**           *hardly **part\n"
  "\n"
  "Of their array: whoso list heare more,\n"
  "I shall rehearse so as I can a lite.*                            *little\n"
  "Out of the grove, that I spake of before,\n"
  "I saw come first, all in their cloakes white,\n"
  "A company, that wore, for their delight,\n"
  "Chapelets fresh of oake cerrial, <12>\n"
  "Newly y-sprung; and trumpets* were they all.                 *trumpeters\n"
  "\n"
  "On ev'ry trump hanging a broad bannere\n"
  "Of fine tartarium <13> was, full richly beat;*    *embroidered with gold\n"
  "Every trumpet his lord's armes bare;\n"
  "About their necks, with greate pearles set,\n"
  "[Were] collars broad; for cost they would not let,*      *be hindered by\n"
  "As it would seem, for their scutcheons each one\n"
  "Were set about with many a precious stone.\n"
  "\n"
  "Their horses' harness was all white also.\n"
  "And after them next, in one company,\n"
  "Came kinges at armes and no mo',\n"
  "In cloakes of white cloth with gold richly;\n"
  "Chaplets of green upon their heads on high;\n"
  "The crownes that they on their scutcheons bare\n"
  "Were set with pearl, and ruby, and sapphire,\n"
  "\n"
  "And eke great diamondes many one:\n"
  "But all their horse harness, and other gear,\n"
  "Was in a suit according, ev'ry one,\n"
  "As ye have heard the foresaid trumpets were;\n"
  "And, by seeming, they *were nothing to lear,*     *had nothing to learn*\n"
  "And their guiding they did all mannerly.*                     *perfectly\n"
  "And after them came a great company\n"
  "\n"
  "Of heraldes and pursuivantes eke,\n"
  "Arrayed in clothes of white velvet;\n"
  "And, hardily,* they were no thing to seek,                     assuredly\n"
  "How they on them shoulde the harness set:\n"
  "And ev'ry man had on a chapelet;\n"
  "Scutcheones and eke harness, indeed,\n"
  "They had *in suit of* them that 'fore them yede.*   *corresponding with*\n"
  "                                                                   *went\n"
  "Next after them in came, in armour bright,\n"
  "All save their heades, seemly knightes nine,\n"
  "And ev'ry clasp and nail, as to my sight,\n"
  "Of their harness was of red golde fine;\n"
  "With cloth of gold, and furred with ermine,\n"
  "Were the trappures* of their steedes strong,                  *trappings\n"
  "Both wide and large, that to the grounde hung.\n"
  "\n"
  "And ev'ry boss of bridle and paytrel*               *horse's breastplate\n"
  "That they had on, was worth, as I would ween,\n"
  "A thousand pound; and on their heades, well\n"
  "Dressed, were crownes of the laurel green,\n"
  "The beste made that ever I had seen;\n"
  "And ev'ry knight had after him riding\n"
  "Three henchemen* upon him awaiting.                               *pages\n"
  "\n"
  "Of which ev'ry [first], on a short truncheon,*                    *staff\n"
  "His lorde's helmet bare, so richly dight,*                      *adorned\n"
  "That the worst of them was worthy the ranson*                    *ransom\n"
  "Of any king; the second a shielde bright\n"
  "Bare at his back; the thirde bare upright\n"
  "A mighty spear, full sharp y-ground and keen;\n"
  "And ev'ry childe* ware of leaves green                             *page\n"
  "\n"
  "A freshe chaplet on his haires bright;\n"
  "And cloakes white of fine velvet they ware\n"
  "Their steedes trapped and arrayed right,\n"
  "Without difference, as their lordes' were;\n"
  "And after them, on many a fresh courser,\n"
  "There came of armed knightes such a rout,*               *company, crowd\n"
  "That they bespread the large field about.\n"
  "\n"
  "And all they waren, after their degrees,\n"
  "Chapelets newe made of laurel green,\n"
  "Some of the oak, and some of other trees;\n"
  "Some in their handes bare boughes sheen,*                        *bright\n"
  "Some of laurel, and some of oakes keen,\n"
  "Some of hawthorn, and some of the woodbind,\n"
  "And many more which I had not in mind.\n"
  "\n"
  "And so they came, their horses fresh stirring\n"
  "With bloody soundes of their trumpets loud;\n"
  "There saw I many an *uncouth disguising*           *strange manoeuvring*\n"
  "In the array of these knightes proud;\n"
  "And at the last, as evenly as they could,\n"
  "They took their place in middest of the mead,\n"
  "And ev'ry knight turned his horse's head\n"
  "\n"
  "";
// }

const char poemTheFlowerAndTheLeaf1[] PGMSECTION = // { // 18884 bytes
  "To his fellow, and lightly laid a spear\n"
  "Into the rest; and so the jousts began\n"
  "On ev'ry part aboute, here and there;\n"
  "Some brake his spear, some threw down horse and man;\n"
  "About the field astray the steedes ran;\n"
  "And, to behold their rule and governance,*                      *conduct\n"
  "I you ensure, it was a great pleasuance.\n"
  "\n"
  "And so the joustes last'* an hour and more;                      *lasted\n"
  "But those that crowned were in laurel green\n"
  "Wonne the prize; their dintes* were so sore,                    *strokes\n"
  "That there was none against them might sustene:\n"
  "And the jousting was alle left off clean,\n"
  "And from their horse the nine alight' anon,\n"
  "And so did all the remnant ev'ry one.\n"
  "\n"
  "And forth they went together, twain and twain,\n"
  "That to behold it was a worthy sight,\n"
  "Toward the ladies on the greene plain,\n"
  "That sang and danced as I said now right;\n"
  "The ladies, as soon as they goodly might,\n"
  "They brake off both the song and eke the dance,\n"
  "And went to meet them with full glad semblance.*            *air, aspect\n"
  "\n"
  "And ev'ry lady took, full womanly,\n"
  "By th'hand a knight, and so forth right they yede*                 *went\n"
  "Unto a fair laurel that stood fast by,\n"
  "With leaves lade the boughs of greate brede;*                   *breadth\n"
  "And, to my doom,* there never was, indeed,                     *judgment\n"
  "Man that had seene half so fair a tree;\n"
  "For underneath it there might well have be*                        *been\n"
  "\n"
  "A hundred persons, *at their own pleasance,*        *in perfect comfort*\n"
  "Shadowed from the heat of Phoebus bright,\n"
  "So that they shoulde have felt no grievance*                  *annoyance\n"
  "Of rain nor haile that them hurte might.\n"
  "The savour eke rejoice would any wight\n"
  "That had been sick or melancholious,\n"
  "It was so very good and virtuous.*              *full of healing virtues\n"
  "\n"
  "And with great rev'rence they inclined low\n"
  "Unto the tree so sweet and fair of hue;*                     *appearance\n"
  "And after that, within a *little throw,*                    *short time*\n"
  "They all began to sing and dance of new,\n"
  "Some song of love, some *plaining of untrue,*              *complaint of\n"
  "Environing* the tree that stood upright;                 unfaithfulness*\n"
  "And ever went a lady and a knight.                          *going round\n"
  "\n"
  "And at the last I cast mine eye aside,\n"
  "And was ware of a lusty company\n"
  "That came roaming out of the fielde wide;\n"
  "[And] hand in hand a knight and a lady;\n"
  "The ladies all in surcoats, that richly\n"
  "Purfiled* were with many a riche stone;          *trimmed at the borders\n"
  "And ev'ry knight of green ware mantles on,\n"
  "\n"
  "Embroider'd well, so as the surcoats were;\n"
  "And ev'reach had a chaplet on her head\n"
  "(Which did right well upon the shining hair),\n"
  "Maked of goodly flowers, white and red.\n"
  "The knightes eke, that they in hande led,\n"
  "In suit of them ware chaplets ev'ry one,\n"
  "And them before went minstrels many one,\n"
  "\n"
  "As harpes, pipes, lutes, and psaltry,\n"
  "All [clad] in green; and, on their heades bare,\n"
  "Of divers flowers, made full craftily\n"
  "All in a suit, goodly chaplets they ware;\n"
  "And so dancing into the mead they fare.\n"
  "In mid the which they found a tuft that was\n"
  "All overspread with flowers in compass*             *around, in a circle\n"
  "\n"
  "Whereunto they inclined ev'ry one,\n"
  "With great reverence, and that full humbly\n"
  "And at the last there then began anon\n"
  "A lady for to sing right womanly,\n"
  "A bargaret, <14> in praising the daisy.\n"
  "For, as me thought, among her notes sweet,\n"
  "She saide: \"Si douce est la margarete.\"<15>\n"
  "\n"
  "Then alle they answered her in fere*                           *together\n"
  "So passingly well, and so pleasantly,\n"
  "That it was a [most] blissful noise to hear.\n"
  "But, I n'ot* how, it happen'd suddenly                         *know not\n"
  "As about noon the sun so fervently\n"
  "Wax'd hote, that the pretty tender flow'rs\n"
  "Had lost the beauty of their fresh colours,\n"
  "\n"
  "Forshrunk* with heat; the ladies eke to-brent,**	*shrivelled **very burnt\n"
  "That they knew not where they might them bestow;\n"
  "The knightes swelt,* for lack of shade nigh shent**	*fainted **destroyed\n"
  "And after that, within a little throw,\n"
  "The wind began so sturdily to blow,\n"
  "That down went all the flowers ev'ry one,\n"
  "So that in all the mead there left not one;\n"
  "\n"
  "Save such as succour'd were among the leaves\n"
  "From ev'ry storm that mighte them assail,\n"
  "Growing under the hedges and thick greves;*              *groves, boughs\n"
  "And after that there came a storm of hail\n"
  "And rain in fere,* so that withoute fail                       *together\n"
  "The ladies nor the knights had not one thread\n"
  "Dry on them, so dropping was [all] their weed.*                *clothing\n"
  "\n"
  "And when the storm was passed clean away,\n"
  "Those in the white, that stood under the tree,\n"
  "They felt no thing of all the great affray\n"
  "That they in green without *had in y-be:*                  *had been in*\n"
  "To them they went for ruth, and for pity,\n"
  "Them to comfort after their great disease;*                     *trouble\n"
  "So fain* they were the helpless for to ease.                *glad, eager\n"
  "\n"
  "Then I was ware how one of them in green\n"
  "Had on a crowne, rich and well sitting;*                       *becoming\n"
  "Wherefore I deemed well she was a queen,\n"
  "And those in green on her were awaiting.*                 *in attendance\n"
  "The ladies then in white that were coming\n"
  "Toward them, and the knightes eke *in fere,*                  *together*\n"
  "Began to comfort them, and make them cheer.\n"
  "\n"
  "The queen in white, that was of great beauty,\n"
  "Took by the hand the queen that was in green,\n"
  "And saide: \"Sister, I have great pity\n"
  "Of your annoy, and of your troublous teen,*               *injury, grief\n"
  "Wherein you and your company have been\n"
  "So long, alas! and if that it you please\n"
  "To go with me, I shall you do the ease,\n"
  "\n"
  "\"In all the pleasure that I can or may;\"\n"
  "Whereof the other, humbly as she might,\n"
  "Thanked her; for in right evil array\n"
  "She was, with storm and heat, I you behight;*                    *assure\n"
  "Arid ev'ry lady then anon aright,\n"
  "That were in white, one of them took in green\n"
  "By the hand; which when that the knights had seen,\n"
  "\n"
  "In like mannere each of them took a knight\n"
  "Y-clad in green, and forth with them they fare\n"
  "Unto a hedge, where that they anon right,\n"
  "To make their joustes,<16> they would not spare\n"
  "Boughes to hewe down, and eke trees square,\n"
  "Wherewith they made them stately fires great,\n"
  "To dry their clothes, that were wringing wet.\n"
  "\n"
  "And after that, of herbes that there grew,\n"
  "They made, for blisters of the sun's burning,\n"
  "Ointmentes very good, wholesome, and new,\n"
  "Wherewith they went the sick fast anointing;\n"
  "And after that they went about gath'ring\n"
  "Pleasant salades, which they made them eat,\n"
  "For to refresh their great unkindly heat.\n"
  "\n"
  "The Lady of the Leaf then gan to pray\n"
  "Her of the Flower (for so, to my seeming,\n"
  "They should be called, as by their array),\n"
  "To sup with her; and eke, for anything,\n"
  "That she should with her all her people bring;\n"
  "And she again in right goodly mannere\n"
  "Thanked her fast of her most friendly cheer;\n"
  "\n"
  "Saying plainely, that she would obey,\n"
  "With all her heart, all her commandement:\n"
  "And then anon, without longer delay,\n"
  "The Lady of the Leaf hath one y-sent\n"
  "To bring a palfrey, *after her intent,*          *according to her wish*\n"
  "Arrayed well in fair harness of gold;\n"
  "For nothing lack'd, that *to him longe sho'ld.*   *should belong to him*\n"
  "\n"
  "And, after that, to all her company\n"
  "She made to purvey* horse and ev'rything                        *provide\n"
  "That they needed; and then full lustily,\n"
  "Ev'n by the arbour where I was sitting,\n"
  "They passed all, so merrily singing,\n"
  "That it would have comforted any wight.\n"
  "But then I saw a passing wondrous sight;\n"
  "\n"
  "For then the nightingale, that all the day\n"
  "Had in the laurel sat, and did her might\n"
  "The whole service to sing longing to May,\n"
  "All suddenly began to take her flight;\n"
  "And to the Lady of the Leaf forthright\n"
  "She flew, and set her on her hand softly;\n"
  "Which was a thing I marvell'd at greatly.\n"
  "\n"
  "The goldfinch eke, that from the medlar tree\n"
  "Was fled for heat into the bushes cold,\n"
  "Unto the Lady of the Flower gan flee,\n"
  "And on her hand he set him as he wo'ld,\n"
  "And pleasantly his winges gan to fold;\n"
  "And for to sing they *pain'd them* both, as sore  *made great exertions*\n"
  "As they had done *of all* the day before.                        *during\n"
  "\n"
  "And so these ladies rode forth *a great pace,*                 *rapidly*\n"
  "And all the rout of knightes eke in fere;\n"
  "And I, that had seen all this *wonder case,*         *wondrous incident*\n"
  "Thought that I would assay in some mannere\n"
  "To know fully the truth of this mattere,\n"
  "And what they were that rode so pleasantly;\n"
  "And when they were the arbour passed by,\n"
  "\n"
  "I *dress'd me forth,* and happ'd to meet anon             *issued forth*\n"
  "A right fair lady, I do you ensure;*                             *assure\n"
  "And she came riding by herself alone,\n"
  "All in white; [then] with semblance full demure\n"
  "I her saluted, and bade good adventure*                         *fortune\n"
  "Might her befall, as I could most humbly;\n"
  "And she answer'd: \"My daughter, gramercy!\"*           *great thanks <17>\n"
  "\n"
  "\"Madame,\" quoth I, \"if that I durst enquere\n"
  "Of you, I would fain, of that company,\n"
  "Wit what they be that pass'd by this herbere?\n"
  "And she again answered right friendly:\n"
  "\"My faire daughter, all that pass'd hereby\n"
  "In white clothing, be servants ev'ry one\n"
  "Unto the Leaf; and I myself am one.\n"
  "\n"
  "\"See ye not her that crowned is,\" quoth she\n"
  "\"[Clad] all in white?\" -- \"Madame,\" then quoth I, \"yes:\"\n"
  "\"That is Dian', goddess of chastity;\n"
  "And for because that she a maiden is,\n"
  "In her hande the branch she beareth this,\n"
  "That agnus castus <8> men call properly;\n"
  "And all the ladies in her company,\n"
  "\n"
  "\"Which ye see of that herbe chaplets wear,\n"
  "Be such as have kept alway maidenhead:\n"
  "And all they that of laurel chaplets bear,\n"
  "Be such as hardy* were in manly deed,  --                    *courageous\n"
  "Victorious name which never may be dead!\n"
  "And all they were so *worthy of their hand*           *valiant in fight*\n"
  "In their time, that no one might them withstand,\n"
  "\n"
  "\"And those that weare chaplets on their head\n"
  "Of fresh woodbind, be such as never were\n"
  "To love untrue in word, in thought, nor deed,\n"
  "But ay steadfast; nor for pleasance, nor fear,\n"
  "Though that they should their heartes all to-tear,*     *rend in pieces*\n"
  "Would never flit,* but ever were steadfast,                      *change\n"
  "*Till that their lives there asunder brast.\"*           *till they died*\n"
  "\n"
  "\"Now fair Madame,\" quoth I, \"yet would I pray\n"
  "Your ladyship, if that it mighte be,\n"
  "That I might knowe, by some manner way\n"
  "(Since that it hath liked your beauty,\n"
  "The truth of these ladies for to tell me),\n"
  "What that these knightes be in rich armour,\n"
  "And what those be in green and wear the flow'r?\n"
  "\n"
  "\"And why that some did rev'rence to that tree,\n"
  "And some unto the plot of flowers fair?\"\n"
  "\"With right good will, my daughter fair,\" quoth she,\n"
  "\"Since your desire is good and debonair;*             *gentle, courteous\n"
  "The nine crowned be *very exemplair*                 *the true examples*\n"
  "Of all honour longing to chivalry;\n"
  "And those certain be call'd The Nine Worthy, <18>\n"
  "\n"
  "\"Which ye may see now riding all before,\n"
  "That in their time did many a noble deed,\n"
  "And for their worthiness full oft have bore\n"
  "The crown of laurel leaves upon their head,\n"
  "As ye may in your olde bookes read;\n"
  "And how that he that was a conquerour\n"
  "Had by laurel alway his most honour.\n"
  "\n"
  "\"And those that beare boughes in their hand\n"
  "Of the precious laurel so notable,\n"
  "Be such as were, I will ye understand,\n"
  "Most noble Knightes of the Rounde Table,<19>\n"
  "And eke the Douceperes honourable; <20>\n"
  "Whiche they bear in sign of victory,\n"
  "As witness of their deedes mightily.\n"
  "\n"
  "\"Eke there be knightes old <21> of the Garter,\n"
  "That in their time did right worthily;\n"
  "And the honour they did to the laurer*                      *laurel <22>\n"
  "Is for* by it they have their laud wholly,                      *because\n"
  "Their triumph eke, and martial glory;\n"
  "Which unto them is more perfect richess\n"
  "Than any wight imagine can, or guess.\n"
  "\n"
  "\"For one leaf given of that noble tree\n"
  "To any wight that hath done worthily,\n"
  "An'* it be done so as it ought to be,                                *if\n"
  "Is more honour than any thing earthly;\n"
  "Witness of Rome, that founder was truly\n"
  "Of alle knighthood and deeds marvellous;\n"
  "Record I take of Titus Livius.\" <23>\n"
  "\n"
  "And as for her that crowned is in green,\n"
  "It is Flora, of these flowers goddess;\n"
  "And all that here on her awaiting be'n,\n"
  "It are such folk that loved idleness,\n"
  "And not delighted in no business,\n"
  "But for to hunt and hawk, and play in meads,\n"
  "And many other such-like idle deeds.\n"
  "\n"
  "\"And for the great delight and the pleasance\n"
  "They have to the flow'r, and so rev'rently\n"
  "They unto it do such obeisance\n"
  "As ye may see.\" \"Now, fair Madame,\"quoth I,\n"
  "\"If I durst ask, what is the cause, and why,\n"
  "That knightes have the ensign* of honour                       *insignia\n"
  "Rather by the leaf than by the flow'r?\"\n"
  "\n"
  "\"Soothly, daughter,\" quoth she, \"this is the troth:\n"
  "For knights should ever be persevering,\n"
  "To seek honour, without feintise* or sloth,               *dissimulation\n"
  "From well to better in all manner thing:\n"
  "In sign of which, with leaves aye lasting\n"
  "They be rewarded after their degree,\n"
  "Whose lusty green may not appaired* be,               *impaired, decayed\n"
  "\n"
  "\"But ay keeping their beauty fresh and green;\n"
  "For there is no storm that may them deface,\n"
  "Nor hail nor snow, nor wind nor frostes keen;\n"
  "Wherefore they have this property and grace:\n"
  "And for the flow'r, within a little space,\n"
  "Wolle* be lost, so simple of nature                                *will\n"
  "They be, that they no grievance* may endure;           *injury, hardship\n"
  "\n"
  "\"And ev'ry storm will blow them soon away,\n"
  "Nor they laste not but for a season;\n"
  "That is the cause, the very truth to say,\n"
  "That they may not, by no way of reason,\n"
  "Be put to no such occupation.\"\n"
  "\"Madame,\" quoth I, \"with all my whole service\n"
  "I thank you now, in my most humble wise;\n"
  "\n"
  "\"For now I am ascertain'd thoroughly\n"
  "Of ev'ry thing that I desir'd to know.\"\n"
  "\"I am right glad that I have said, soothly,\n"
  "Aught to your pleasure, if ye will me trow,\"*                   *believe\n"
  "Quoth she again; \"but to whom do ye owe\n"
  "Your service? and which wolle* ye honour,                          *will\n"
  "Tell me, I pray, this year, the Leaf or the Flow'r?\"\n"
  "\n"
  "\"Madame,\" quoth I, \"though I be least worthy,\n"
  "Unto the Leaf I owe mine observance:\"\n"
  "\"That is,\" quoth she, \"right well done, certainly;\n"
  "And I pray God, to honour you advance,\n"
  "And keep you from the wicked remembrance\n"
  "Of Malebouche,* and all his cruelty;                       *Slander <24>\n"
  "And all that good and well-condition'd be.\n"
  "\n"
  "\"For here may I no longer now abide;\n"
  "I must follow the greate company,\n"
  "That ye may see yonder before you ride.\"\n"
  "And forthwith, as I coulde, most humbly\n"
  "I took my leave of her, and she gan hie*                          *haste\n"
  "After them as fast as she ever might;\n"
  "And I drew homeward, for it was nigh night,\n"
  "\n"
  "And put all that I had seen in writing,\n"
  "Under support of them that list it read. <25>\n"
  "O little book! thou art so uncunning,*                        *unskilful\n"
  "How dar'st thou put thyself in press, <26> for dread?\n"
  "It is wonder that thou waxest not red!\n"
  "Since that thou know'st full lite* who shall behold              *little\n"
  "Thy rude language, full *boistously unfold.*     *unfolded in homely and\n"
  "                                                     unpolished fashion*\n"
  "\n"
  "\n"
  "Explicit.*                                                      *The End\n"
  "\n"
  "\n"
  "Notes to the Flower and the Leaf\n"
  "\n"
  "\n"
  "1. The Bull: the sign of Taurus, which the sun enters\n"
  "in May.\n"
  "\n"
  "2. The young oak leaves are red or ashen coloured.\n"
  "\n"
  "3. Chaucer here again refers to the superstition,\n"
  "noticed in \"The Cuckoo and the Nightingale,\" that it\n"
  "was of good omen to hear the nightingale before the\n"
  "cuckoo upon the advent of both with spring.\n"
  "\n"
  "4. The arbour was furnished with seats, which had\n"
  "been newly covered with turf.\n"
  "\n"
  "5. \"Yede\" or \"yead,\" is the old form of go.\n"
  "\n"
  "6. Sote: fool -- French \"sot.\"\n"
  "\n"
  "7. See note 59 to The Court of Love\n"
  "\n"
  "8. Agnus castus:  the chaste-tree; a kind of willow.\n"
  "\n"
  "9. Roundell:  French, \"rondeau;\" a song that comes\n"
  "round again to the verse with which it opened, or that\n"
  "is taken up in turn by each of the singers.\n"
  "\n"
  "10.  In modern French form, \"Sous la feuille, devers\n"
  "moi, son et mon joli coeur est endormi\" -- \"Under the\n"
  "foliage, towards me, his and my jolly heart is gone to\n"
  "sleep.\"\n"
  "\n"
  "11. Prester John: The half-mythical Eastern potentate,\n"
  "who is now supposed to have been, not a Christian\n"
  "monarch of Abyssinia, but the head of the Indian\n"
  "empire before Zenghis Khan's conquest.\n"
  "\n"
  "12. Oak cerrial: of the species of oak which Pliny, in\n"
  "his \"Natural History,\" calls \"cerrus.\"\n"
  "\n"
  "13. Tartarium: Cloth of Tars, or of Tortona.\n"
  "\n"
  "14. Bargaret: bergerette, or pastoral song.\n"
  "\n"
  "15. \"Si douce est la margarete.\": \"So sweet is the\n"
  "daisy\" (\"la marguerite\").\n"
  "\n"
  "16. To make their joustes:  the meaning is not very\n"
  "obvious; but in The Knight's Tale \"jousts and array\"\n"
  "are in some editions made part of the adornment of\n"
  "the Temple of Venus; and as the word \"jousts\" would\n"
  "there carry the general meaning of \"preparations\" to\n"
  "entertain or please a lover, in the present case it may\n"
  "have a similar force.\n"
  "\n"
  "17. Gramercy:  \"grand merci,\" French; great thanks.\n"
  "\n"
  "18. The Nine Worthies, who at our day survive in the\n"
  "Seven Champions of Christendom. The Worthies\n"
  "were favourite subjects for representation at popular\n"
  "festivals or in masquerades.\n"
  "\n"
  "19. The famous Knights of King Arthur, who, being\n"
  "all esteemed equal in valour and noble qualities, sat at\n"
  "a round table, so that none should seem to have\n"
  "precedence over the rest.\n"
  "\n"
  "20. The twelve peers of Charlemagne (les douze\n"
  "pairs), chief among whom were Roland and Oliver.\n"
  "\n"
  "21. Chaucer speaks as if, at least for the purposes of\n"
  "his poetry, he believed that Edward III. did not\n"
  "establish a new, but only revived an old, chivalric\n"
  "institution, when be founded the Order of the Garter.\n"
  "\n"
  "22. Laurer: laurel-tree; French, \"laurier.\"\n"
  "\n"
  "23.  The meaning is: \"Witness the practice of Rome,\n"
  "that was the founder of all knighthood and marvellous\n"
  "deeds; and I refer for corroboration to Titus Livius\"  --\n"
  "who, in several passages, has mentioned the laurel\n"
  "crown as the highest military honour. For instance, in\n"
  "1. vii. c. 13, Sextus Tullius, remonstrating for the\n"
  "army against the inaction in which it is kept, tells the\n"
  "Dictator Sulpicius, \"Duce te vincere cupimus; tibi\n"
  "lauream insignem deferre; tecum triumphantes urbem\n"
  "inire.\" (\"Commander, we want you to conquer; to\n"
  "bring you the laurel insignia; to enter the city with you\n"
  "in triumph\")\n"
  "\n"
  "24. Malebouche:  Slander, personified under the title\n"
  "of Evil-mouth  -- Italian, \"Malbocca;\" French,\n"
  "\"Malebouche.\"\n"
  "\n"
  "25. Under support of them that list it read: the phrase\n"
  "means --  trusting to the goodwill of my reader.\n"
  "\n"
  "26. In press:  into a crowd, into the press of\n"
  "competitors for favour; not, it need hardly be said,\n"
  "\"into the press\" in the modern sense -- printing was\n"
  "not invented for a century after this was written.\n"
  "\n"
  "\n"
  "\n"
  "";
// }

const char poemTheHouseOfFame0[] PGMSECTION = // { // 27649 bytes
  "                       THE HOUSE OF FAME\n"
  "\n"
  "\n"
  "[Thanks partly to Pope's brief and elegant paraphrase, in his\n"
  "\"Temple of Fame,\" and partly to the familiar force of the style\n"
  "and the satirical significance of the allegory, \"The House of\n"
  "Fame\" is among the best known and relished of Chaucer's minor\n"
  "poems. The octosyllabic measure in which it is written -- the\n"
  "same which the author of \"Hudibras\" used with such admirable\n"
  "effect -- is excellently adapted for the vivid descriptions, the\n"
  "lively sallies of humour and sarcasm, with which the poem\n"
  "abounds; and when the poet actually does get to his subject, he\n"
  "treats it with a zest, and a corresponding interest on the part of\n"
  "the reader, which are scarcely surpassed by the best of The\n"
  "Canterbury Tales. The poet, however, tarries long on the way\n"
  "to the House of Fame; as Pope says in his advertisement, the\n"
  "reader who would compare his with Chaucer's poem, \"may\n"
  "begin with [Chaucer's] third Book of Fame, there being nothing\n"
  "in the two first books that answers to their title.\" The first book\n"
  "opens with a kind of prologue (actually so marked and called in\n"
  "earlier editions) in which the author speculates on the causes of\n"
  "dreams; avers that never any man had such a dream as he had\n"
  "on the tenth of December; and prays the God of Sleep to help\n"
  "him to interpret the dream, and the Mover of all things to\n"
  "reward or afflict those readers who take the dream well or ill.\n"
  "Then he relates that, having fallen asleep, he fancied himself\n"
  "within a temple of glass -- the abode of Venus -- the walls of\n"
  "which were painted with the story of Aeneas. The paintings are\n"
  "described at length; and then the poet tells us that, coming out\n"
  "of the temple, he found himself on a vast sandy plain, and saw\n"
  "high in heaven an eagle, that began to descend towards him.\n"
  "With the prologue, the first book numbers 508 lines; of which\n"
  "192 only -- more than are actually concerned with or directly\n"
  "lead towards the real subject of the poem -- are given here. The\n"
  "second book, containing 582 lines, of which 176 will be found\n"
  "in this edition, is wholly devoted to the voyage from the Temple\n"
  "of Venus to the House of Fame, which the dreamer\n"
  "accomplishes in the eagle's claws. The bird has been sent by\n"
  "Jove to do the poet some \"solace\" in reward of his labours for\n"
  "the cause of Love; and during the transit through the air the\n"
  "messenger discourses obligingly and learnedly with his human\n"
  "burden on the theory of sound, by which all that is spoken must\n"
  "needs reach the House of Fame; and on other matters suggested\n"
  "by their errand and their observations by the way. The third\n"
  "book (of 1080 lines, only a score of which, just at the outset,\n"
  "have been omitted) brings us to the real pith of the poem. It\n"
  "finds the poet close to the House of Fame, built on a rock of ice\n"
  "engraved with names, many of which are half-melted away.\n"
  "Entering the gorgeous palace, he finds all manner of minstrels\n"
  "and historians; harpers, pipers, and trumpeters of fame;\n"
  "magicians, jugglers, sorcerers, and many others. On a throne of\n"
  "ruby sits the goddess, seeming at one moment of but a cubit's\n"
  "stature, at the next touching heaven; and at either hand, on\n"
  "pillars, stand the great authors who \"bear up the name\" of\n"
  "ancient nations. Crowds of people enter the hall from all regions\n"
  "of earth, praying the goddess to give them good or evil fame,\n"
  "with and without their own deserts; and they receive answers\n"
  "favourable, negative, or contrary, according to the caprice of\n"
  "Fame. Pursuing his researches further, out of the region of\n"
  "reputation or fame proper into that of tidings or rumours, the\n"
  "poet is led, by a man who has entered into conversation with\n"
  "him, to a vast whirling house of twigs, ever open to the arrival\n"
  "of tidings, ever full of murmurings, whisperings, and clatterings,\n"
  "coming from the vast crowds that fill it -- for every rumour,\n"
  "every piece of news, every false report, appears there in the\n"
  "shape of the person who utters it, or passes it on, down in earth.\n"
  "Out at the windows innumerable, the tidings pass to Fame, who\n"
  "gives to each report its name and duration; and in the house\n"
  "travellers, pilgrims, pardoners, couriers, lovers, &c., make a\n"
  "huge clamour. But here the poet meets with a man \"of great\n"
  "authority,\" and, half afraid, awakes; skilfully  -- whether by\n"
  "intention, fatigue, or accident -- leaving the reader disappointed\n"
  "by the nonfulfilment of what seemed to be promises of further\n"
  "disclosures. The poem, not least in the passages the omission of\n"
  "which has been dictated by the exigencies of the present\n"
  "volume, is full of testimony to the vast acquaintance of Chaucer\n"
  "with learning ancient and modern; Ovid, Virgil, Statius, are\n"
  "equally at his command to illustrate his narrative or to furnish\n"
  "the ground-work of his descriptions; while architecture, the\n"
  "Arabic numeration, the theory of sound, and the effects of\n"
  "gunpowder, are only a few among the topics of his own time of\n"
  "which the poet treats with the ease of proficient knowledge.\n"
  "Not least interesting are the vivid touches in which Chaucer\n"
  "sketches the routine of his laborious and almost recluse daily\n"
  "life; while the strength, individuality, and humour that mark the\n"
  "didactic portion of the poem prove that \"The House of Fame\"\n"
  "was one of the poet's riper productions.]\n"
  "\n"
  "\n"
  "GOD turn us ev'ry dream to good!\n"
  "For it is wonder thing, by the Rood,*                         *Cross <1>\n"
  "To my witte, what causeth swevens,*                              *dreams\n"
  "Either on morrows or on evens;\n"
  "And why th'effect followeth of some,\n"
  "And of some it shall never come;\n"
  "Why this is an avision\n"
  "And this a revelation;\n"
  "Why this a dream, why that a sweven,\n"
  "And not to ev'ry man *like even;*                                *alike*\n"
  "Why this a phantom, why these oracles,\n"
  "I n'ot; but whoso of these miracles\n"
  "The causes knoweth bet than I,\n"
  "Divine* he; for I certainly                                      *define\n"
  "*Ne can them not,* nor ever think                     *do not know them*\n"
  "To busy my wit for to swink*                                     *labour\n"
  "To know of their significance\n"
  "The genders, neither the distance\n"
  "Of times of them, nor the causes\n"
  "For why that this more than that cause is;\n"
  "Or if folke's complexions\n"
  "Make them dream of reflections;\n"
  "Or elles thus, as others sayn,\n"
  "For too great feebleness of the brain\n"
  "By abstinence, or by sickness,\n"
  "By prison, strife, or great distress,\n"
  "Or elles by disordinance*                                   *derangement\n"
  "Of natural accustomance;*                                  *mode of life\n"
  "That some men be too curious\n"
  "In study, or melancholious,\n"
  "Or thus, so inly full of dread,\n"
  "That no man may them *boote bede;*                  *afford them relief*\n"
  "Or elles that devotion\n"
  "Of some, and contemplation,\n"
  "Causeth to them such dreames oft;\n"
  "Or that the cruel life unsoft\n"
  "Of them that unkind loves lead,\n"
  "That often hope much or dread,\n"
  "That purely their impressions\n"
  "Cause them to have visions;\n"
  "Or if that spirits have the might\n"
  "To make folk to dream a-night;\n"
  "Or if the soul, of *proper kind,*                       *its own nature*\n"
  "Be so perfect as men find,\n"
  "That it forewot* what is to come,                             *foreknows\n"
  "And that it warneth all and some\n"
  "Of ev'reach of their adventures,\n"
  "By visions, or by figures,\n"
  "But that our fleshe hath no might\n"
  "To understanden it aright,\n"
  "For it is warned too darkly;\n"
  "But why the cause is, not wot I.\n"
  "Well worth of this thing greate clerks, <2>\n"
  "That treat of this and other works;\n"
  "For I of none opinion\n"
  "Will as now make mention;\n"
  "But only that the holy Rood\n"
  "Turn us every dream to good.\n"
  "For never since that I was born,\n"
  "Nor no man elles me beforn,\n"
  "Mette,* as I trowe steadfastly,                                 *dreamed\n"
  "So wonderful a dream as I,\n"
  "The tenthe day now of December;\n"
  "The which, as I can it remember,\n"
  "I will you tellen ev'ry deal.*                                     *whit\n"
  "\n"
  "But at my beginning, truste weel,*                                 *well\n"
  "I will make invocation,\n"
  "With special devotion,\n"
  "Unto the god of Sleep anon,\n"
  "That dwelleth in a cave of stone, <3>\n"
  "Upon a stream that comes from Lete,\n"
  "That is a flood of hell unsweet,\n"
  "Beside a folk men call Cimmerie;\n"
  "There sleepeth ay this god unmerry,\n"
  "With his sleepy thousand sones,\n"
  "That alway for to sleep their won* is;                     *wont, custom\n"
  "And to this god, that I *of read,*                             *tell of*\n"
  "Pray I, that he will me speed\n"
  "My sweven for to tell aright,\n"
  "If ev'ry dream stands in his might.\n"
  "And he that Mover is of all\n"
  "That is, and was, and ever shall,\n"
  "So give them joye that it hear,\n"
  "Of alle that they dream to-year;*                             *this year\n"
  "And for to standen all in grace*                                 *favour\n"
  "Of their loves, or in what place\n"
  "That them were liefest* for to stand,                      *most desired\n"
  "And shield them from povert' and shand,*                          *shame\n"
  "And from ev'ry unhap and disease,\n"
  "And send them all that may them please,\n"
  "That take it well, and scorn it not,\n"
  "Nor it misdeemen* in their thought,                            *misjudge\n"
  "Through malicious intention;\n"
  "And whoso, through presumption.\n"
  "Or hate, or scorn, or through envy,\n"
  "Despite, or jape,* or villainy,                                 *jesting\n"
  "Misdeem it, pray I Jesus God,\n"
  "That dream he barefoot, dream he shod,\n"
  "That ev'ry harm that any man\n"
  "Hath had since that the world began,\n"
  "Befall him thereof, ere he sterve,*                                 *die\n"
  "And grant that he may it deserve,*                         *earn, obtain\n"
  "Lo! with such a conclusion\n"
  "As had of his avision\n"
  "Croesus, that was the king of Lyde,<4>\n"
  "That high upon a gibbet died;\n"
  "This prayer shall he have of me;\n"
  "I am *no bet in charity.*                           *no more charitable*\n"
  "\n"
  "Now hearken, as I have you said,\n"
  "What that I mette ere I abraid,*                                  *awoke\n"
  "Of December the tenthe day;\n"
  "When it was night to sleep I lay,\n"
  "Right as I was wont for to do'n,\n"
  "And fell asleepe wonder soon,\n"
  "As he that *weary was for go*<5>                  *was weary from going*\n"
  "On pilgrimage miles two\n"
  "To the corsaint* Leonard,                                 *relics of <6>\n"
  "To make lithe that erst was hard.\n"
  "But, as I slept, me mette I was\n"
  "Within a temple made of glass;\n"
  "In which there were more images\n"
  "Of gold, standing in sundry stages,\n"
  "And more riche tabernacles,\n"
  "And with pierrie* more pinnacles,                                  *gems\n"
  "And more curious portraitures,\n"
  "And *quainte manner* of figures                          *strange kinds*\n"
  "Of golde work, than I saw ever.\n"
  "But, certainly, I wiste* never                                     *knew\n"
  "Where that it was, but well wist I\n"
  "It was of Venus readily,\n"
  "This temple; for in portraiture\n"
  "I saw anon right her figure\n"
  "Naked floating in a sea, <7>\n"
  "And also on her head, pardie,\n"
  "Her rose garland white and red,\n"
  "And her comb to comb her head,\n"
  "Her doves, and Dan Cupido,\n"
  "Her blinde son, and Vulcano, <8>\n"
  "That in his face was full brown.\n"
  "\n"
  "As he \"roamed up and down,\" the dreamer saw on the wall a\n"
  "tablet of brass inscribed with the opening lines of the Aeneid;\n"
  "while the whole story of Aeneas was told in the \"portraitures\"\n"
  "and gold work. About three hundred and fifty lines are devoted\n"
  "to the description; but they merely embody Virgil's account of\n"
  "Aeneas' adventures from the destruction of Troy to his arrival in\n"
  "Italy; and the only characteristic passage is the following\n"
  "reflection, suggested by the death of Dido for her perfidious but\n"
  "fate-compelled guest:\n"
  "\n"
  "Lo! how a woman doth amiss,\n"
  "To love him that unknowen is!\n"
  "For, by Christ, lo! thus it fareth,\n"
  "It is not all gold that glareth.*                              *glitters\n"
  "For, all so brook I well my head,\n"
  "There may be under goodlihead*                          *fair appearance\n"
  "Cover'd many a shrewed* vice;                                    *cursed\n"
  "Therefore let no wight be so nice*                              *foolish\n"
  "To take a love only for cheer,*                                   *looks\n"
  "Or speech, or for friendly mannere;\n"
  "For this shall ev'ry woman find,\n"
  "That some man, *of his pure kind,*               *by force of his nature\n"
  "Will showen outward the fairest,\n"
  "Till he have caught that which him lest;*                       *pleases\n"
  "And then anon will causes find,\n"
  "And sweare how she is unkind,\n"
  "Or false, or privy* double was.                                *secretly\n"
  "All this say I by* Aeneas                             *with reference to\n"
  "And Dido, and her *nice lest,*                        *foolish pleasure*\n"
  "That loved all too soon a guest;\n"
  "Therefore I will say a proverb,\n"
  "That he that fully knows the herb\n"
  "May safely lay it to his eye;\n"
  "Withoute dread,* this is no lie.                                  *doubt\n"
  "\n"
  "When the dreamer had seen all the sights in the temple, he\n"
  "became desirous to know who had worked all those wonders,\n"
  "and in what country he was; so he resolved to go out at the\n"
  "wicket, in search of somebody who might tell him.\n"
  "\n"
  "When I out at the doores came,\n"
  "I fast aboute me beheld;\n"
  "Then saw I but a large feld,*                              *open country\n"
  "As far as that I mighte see,\n"
  "WIthoute town, or house, or tree,\n"
  "Or bush, or grass, or ered* land,                          *ploughed <9>\n"
  "For all the field was but of sand,\n"
  "As small* as men may see it lie                                    *fine\n"
  "In the desert of Libye;\n"
  "Nor no manner creature\n"
  "That is formed by Nature,\n"
  "There saw I, me to *rede or wiss.*                    *advise or direct*\n"
  "\"O Christ!\" thought I, \"that art in bliss,\n"
  "From *phantom and illusion*                   *vain fancy and deception*\n"
  "Me save!\" and with devotion\n"
  "Mine eyen to the heav'n I cast.\n"
  "Then was I ware at the last\n"
  "That, faste by the sun on high,\n"
  "*As kennen might I* with mine eye,          *as well as I might discern*\n"
  "Me thought I saw an eagle soar,\n"
  "But that it seemed muche more*                                   *larger\n"
  "Than I had any eagle seen;\n"
  "This is as sooth as death, certain,\n"
  "It was of gold, and shone so bright,\n"
  "That never saw men such a sight,\n"
  "But if* the heaven had y-won,                                    *unless\n"
  "All new from God, another sun;\n"
  "So shone the eagle's feathers bright:\n"
  "And somewhat downward gan it light.*                    *descend, alight\n"
  "\n"
  "The Second Book opens with a brief invocation of Venus and\n"
  "of Thought; then it proceeds:\n"
  "\n"
  "This eagle, of which I have you told,\n"
  "That shone with feathers as of gold,\n"
  "Which that so high began to soar,\n"
  "I gan beholde more and more,\n"
  "To see her beauty and the wonder;\n"
  "But never was there dint of thunder,\n"
  "Nor that thing that men calle foudre,*                      *thunderbolt\n"
  "That smote sometimes a town to powder,\n"
  "And in his swifte coming brenn'd,*                               *burned\n"
  "That so swithe* gan descend,                                    *rapidly\n"
  "As this fowl, when that it beheld\n"
  "That I a-roam was in the feld;\n"
  "And with his grim pawes strong,\n"
  "Within his sharpe nailes long,\n"
  "Me, flying, at a swap* he hent,**                         *swoop *seized\n"
  "And with his sours <10> again up went,\n"
  "Me carrying in his clawes stark*                                 *strong\n"
  "As light as I had been a lark,\n"
  "How high, I cannot telle you,\n"
  "For I came up, I wist not how.\n"
  "\n"
  "The poet faints through bewilderment and fear; but the eagle,\n"
  "speaking with the voice of a man, recalls him to himself, and\n"
  "comforts him by the assurance that what now befalls him is for\n"
  "his instruction and profit. Answering the poet's unspoken\n"
  "inquiry whether he is not to die otherwise, or whether Jove will\n"
  "him stellify, the eagle says that he has been sent by Jupiter out\n"
  "of his \"great ruth,\"\n"
  "\n"
  "\"For that thou hast so truely\n"
  "So long served ententively*                         *with attentive zeal\n"
  "His blinde nephew* Cupido,                                     *grandson\n"
  "And faire Venus also,\n"
  "Withoute guuerdon ever yet,\n"
  "And natheless hast set thy wit\n"
  "(Although that in thy head full lite* is)                        *little\n"
  "To make bookes, songs, and ditties,\n"
  "In rhyme or elles in cadence,\n"
  "As thou best canst, in reverence\n"
  "Of Love, and of his servants eke,\n"
  "That have his service sought, and seek,\n"
  "And pained thee to praise his art,\n"
  "Although thou haddest never part; <11>\n"
  "Wherefore, all so God me bless,\n"
  "Jovis holds it great humbless,\n"
  "And virtue eke, that thou wilt make\n"
  "A-night full oft thy head to ache,\n"
  "In thy study so thou writest,\n"
  "And evermore of love enditest,\n"
  "In honour of him and praisings,\n"
  "And in his folke's furtherings,\n"
  "And in their matter all devisest,*                              *relates\n"
  "And not him nor his folk despisest,\n"
  "Although thou may'st go in the dance\n"
  "Of them that him list not advance.\n"
  "Wherefore, as I said now, y-wis,\n"
  "Jupiter well considers this;\n"
  "And also, beausire,* other things;                             *good sir\n"
  "That is, that thou hast no tidings\n"
  "Of Love's folk, if they be glad,\n"
  "Nor of naught elles that God made;\n"
  "And not only from far country\n"
  "That no tidings come to thee,\n"
  "But of thy very neighebours,\n"
  "That dwellen almost at thy doors,\n"
  "Thou hearest neither that nor this.\n"
  "For when thy labour all done is,\n"
  "And hast y-made thy reckonings, <12>\n"
  "Instead of rest and newe things,\n"
  "Thou go'st home to thy house anon,\n"
  "And, all so dumb as any stone,\n"
  "Thou sittest at another book,\n"
  "Till fully dazed* is thy look;                                  *blinded\n"
  "And livest thus as a hermite\n"
  "Although thine abstinence is lite.\"* <13>                        *little\n"
  "\n"
  "Therefore has Jove appointed the eagle to take the poet to the\n"
  "House of Fame, to do him some pleasure in recompense for his\n"
  "devotion to Cupid; and he will hear, says the bird,\n"
  "\n"
  "\"When we be come there as I say,\n"
  "More wondrous thinges, dare I lay,*                                 *bet\n"
  "Of Love's folke more tidings,\n"
  "Both *soothe sawes and leasings;*                *true sayings and lies*\n"
  "And more loves new begun,\n"
  "And long y-served loves won,\n"
  "And more loves casually\n"
  "That be betid,* no man knows why,                    *happened by chance\n"
  "But as a blind man starts a hare;\n"
  "And more jollity and welfare,\n"
  "While that they finde *love of steel,*              *love true as steel*\n"
  "As thinketh them, and over all weel;\n"
  "More discords, and more jealousies,\n"
  "More murmurs, and more novelties,\n"
  "And more dissimulations,\n"
  "And feigned reparations;\n"
  "And more beardes, in two hours,\n"
  "Withoute razor or scissours\n"
  "Y-made, <14> than graines be of sands;\n"
  "And eke more holding in hands,*                              *embracings\n"
  "And also more renovelances*                                   *renewings\n"
  "Of old *forleten acquaintances;*          *broken-off acquaintanceships*\n"
  "More love-days,<15> and more accords,*                       *agreements\n"
  "Than on instruments be chords;\n"
  "And eke of love more exchanges\n"
  "Than ever cornes were in granges.\"*                               *barns\n"
  "\n"
  "The poet can scarcely believe that, though Fame had all the pies\n"
  "[magpies] and all the spies in a kingdom, she should hear so\n"
  "much; but the eagle proceeds to prove that she can.\n"
  "\n"
  "First shalt thou heare where she dwelleth;\n"
  "And, so as thine own booke telleth, <16>\n"
  "Her palace stands, as I shall say,\n"
  "Right ev'n in middes of the way\n"
  "Betweene heav'n, and earth, and sea,\n"
  "That whatsoe'er in all these three\n"
  "Is spoken, *privy or apert,*                        *secretly or openly*\n"
  "The air thereto is so overt,*                                     *clear\n"
  "And stands eke in so just* a place,                            *suitable\n"
  "That ev'ry sound must to it pace,\n"
  "Or whatso comes from any tongue,\n"
  "Be it rowned,* read, or sung,                                 *whispered\n"
  "Or spoken in surety or dread,*                                    *doubt\n"
  "Certain *it must thither need.\"*              *it must needs go thither*\n"
  "\n"
  "The eagle, in a long discourse, demonstrates that, as all natural\n"
  "things have a natural place towards which they move by natural\n"
  "inclination, and as sound is only broken air, so every sound\n"
  "must come to Fame's House, \"though it were piped of a mouse\"\n"
  "-- on the same principle by which every part of a mass of water\n"
  "is affected by the casting in of a stone. The poet is all the while\n"
  "borne upward, entertained with various information by the bird;\n"
  "which at last cries out --\n"
  "\n"
  "\"Hold up thy head, for all is well!\n"
  "Saint Julian, lo! bon hostel! <17>\n"
  "See here the House of Fame, lo\n"
  "May'st thou not heare that I do?\"\n"
  "\"What?\" quoth I. \"The greate soun',\"\n"
  "Quoth he, \"that rumbleth up and down\n"
  "In Fame's House, full of tidings,\n"
  "Both of fair speech and of chidings,\n"
  "And of false and sooth compouned;*                  *compounded, mingled\n"
  "Hearken well; it is not rowned.*                              *whispered\n"
  "Hearest thou not the greate swough?\"*                    *confused sound\n"
  "\"Yes, pardie!\" quoth I, \"well enough.\"\n"
  "And what sound is it like?\" quoth he\n"
  "\"Peter! the beating of the sea,\"\n"
  "Quoth I, \"against the rockes hollow,\n"
  "When tempests do the shippes swallow.\n"
  "And let a man stand, out of doubt,\n"
  "A mile thence, and hear it rout.*                                  *roar\n"
  "Or elles like the last humbling*                 *dull low distant noise\n"
  "After the clap of a thund'ring,\n"
  "When Jovis hath the air y-beat;\n"
  "But it doth me for feare sweat.\"\n"
  "\"Nay, dread thee not thereof,\" quoth he;\n"
  "\"It is nothing will bite thee,\n"
  "Thou shalt no harme have, truly.\"\n"
  "\n"
  "And with that word both he and I\n"
  "As nigh the place arrived were,\n"
  "As men might caste with a spear.\n"
  "I wist not how, but in a street\n"
  "He set me fair upon my feet,\n"
  "And saide: \"Walke forth apace,\n"
  "And take *thine adventure or case,*                  *thy chance of what\n"
  "That thou shalt find in Fame's place.\"                       may befall*\n"
  "\"Now,\" quoth I, \"while we have space\n"
  "To speak, ere that I go from thee,\n"
  "For the love of God, as telle me,\n"
  "In sooth, that I will of thee lear,*                              *learn\n"
  "If this noise that I hear\n"
  "Be, as I have heard thee tell,\n"
  "Of folk that down in earthe dwell,\n"
  "And cometh here in the same wise\n"
  "As I thee heard, ere this, devise?\n"
  "And that there living body n'is*                                 *is not\n"
  "In all that house that yonder is,\n"
  "That maketh all this loude fare?\"*                          *hubbub, ado\n"
  "\"No,\" answered he, \"by Saint Clare,\n"
  "And all *so wisly God rede me;*                           *so surely god\n"
  "But one thing I will warne thee,                               guide me*\n"
  "Of the which thou wilt have wonder.\n"
  "Lo! to the House of Fame yonder,\n"
  "Thou know'st how cometh ev'ry speech;\n"
  "It needeth not thee eft* to teach.                                *again\n"
  "But understand now right well this;\n"
  "When any speech y-comen is\n"
  "Up to the palace, anon right\n"
  "It waxeth* like the same wight**                       *becomes **person\n"
  "Which that the word in earthe spake,\n"
  "Be he cloth'd in red or black;\n"
  "And so weareth his likeness,\n"
  "And speaks the word, that thou wilt guess*                        *fancy\n"
  "That it the same body be,\n"
  "Whether man or woman, he or she.\n"
  "And is not this a wondrous thing?\"\n"
  "\"Yes,\" quoth I then, \"by Heaven's king!\"\n"
  "And with this word, \"Farewell,\" quoth he,\n"
  "And here I will abide* thee,                                   *wait for\n"
  "And God of Heaven send thee grace\n"
  "Some good to learen* in this place.\"                              *learn\n"
  "And I of him took leave anon,\n"
  "And gan forth to the palace go'n.\n"
  "\n"
  "At the opening of the Third Book, Chaucer briefly invokes\n"
  "Apollo's guidance, and entreats him, because \"the rhyme is light\n"
  "and lewd,\" to \"make it somewhat agreeable, though some verse\n"
  "fail in a syllable.\" If the god answers the prayer, the poet\n"
  "promises to kiss the next laurel-tree <18> he sees; and he\n"
  "proceeds:\n"
  "\n"
  "When I was from this eagle gone,\n"
  "I gan behold upon this place;\n"
  "And certain, ere I farther pace,\n"
  "I will you all the shape devise*                               *describe\n"
  "Of house and city; and all the wise\n"
  "How I gan to this place approach,\n"
  "That stood upon so high a roche,*                             *rock <19>\n"
  "Higher standeth none in Spain;\n"
  "But up I climb'd with muche pain,\n"
  "And though to climbe *grieved me,*              *cost me painful effort*\n"
  "Yet I ententive* was to see,                                  *attentive\n"
  "And for to pore* wondrous low,                             *gaze closely\n"
  "If I could any wise know\n"
  "What manner stone this rocke was,\n"
  "For it was like a thing of glass,\n"
  "But that it shone full more clear\n"
  "But of what congealed mattere\n"
  "It was, I wist not readily,\n"
  "But at the last espied I,\n"
  "And found that it was *ev'ry deal*                            *entirely*\n"
  "A rock of ice, and not of steel.\n"
  "Thought I, \"By Saint Thomas of Kent, <20>\n"
  "This were a feeble fundament*                                *foundation\n"
  "*To builden* a place so high;                         *on which to build\n"
  "He ought him lite* to glorify                                    *little\n"
  "That hereon built, God so me save!\"\n"
  "\n"
  "Then saw I all the half y-grave <21>\n"
  "With famous folke's names fele,*                                   *many\n"
  "That hadde been in muche weal,*                            *good fortune\n"
  "And their fames wide y-blow.\n"
  "But well unnethes* might I know                                *scarcely\n"
  "Any letters for to read\n"
  "Their names by; for out of dread*                                 *doubt\n"
  "They were almost off thawed so,\n"
  "That of the letters one or two\n"
  "Were molt* away of ev'ry name,                                   *melted\n"
  "So unfamous was wox* their fame;                                 *become\n"
  "But men say, \"What may ever last?\"\n"
  "Then gan I in my heart to cast*                              *conjecture\n"
  "That they were molt away for heat,\n"
  "And not away with stormes beat;\n"
  "For on the other side I sey*                                        *saw\n"
  "Of this hill, that northward lay,\n"
  "How it was written full of names\n"
  "Of folke that had greate fames\n"
  "Of olde times, and yet they were\n"
  "As fresh as men had writ them there\n"
  "The selfe day, right ere that hour\n"
  "That I upon them gan to pore.\n"
  "But well I wiste what it made;*                                   *meant\n"
  "It was conserved with the shade,\n"
  "All the writing which I sigh,*                                      *saw\n"
  "Of a castle that stood on high;\n"
  "And stood eke on so cold a place,\n"
  "That heat might it not deface.*                         *injure, destroy\n"
  "\n"
  "Then gan I on this hill to go'n,\n"
  "And found upon the cop* a won,**                    *summit <22> **house\n"
  "That all the men that be alive\n"
  "Have not the *cunning to descrive*                   *skill to describe*\n"
  "The beauty of that like place,\n"
  "Nor coulde *caste no compass*                      *find no contrivance*\n"
  "Such another for to make,\n"
  "That might of beauty be its make,*                         *match, equal\n"
  "Nor one so wondrously y-wrought,\n"
  "That it astonieth yet my thought,\n"
  "And maketh all my wit to swink,*                                 *labour\n"
  "Upon this castle for to think;\n"
  "So that the greate beauty,\n"
  "Cast,* craft, and curiosity,                                  *ingenuity\n"
  "Ne can I not to you devise;*                                   *describe\n"
  "My witte may me not suffice.\n"
  "But natheless all the substance\n"
  "I have yet in my remembrance;\n"
  "For why, me thoughte, by Saint Gile,\n"
  "Alle was of stone of beryle,\n"
  "Bothe the castle and the tow'r,\n"
  "And eke the hall, and ev'ry bow'r,*                             *chamber\n"
  "Withoute pieces or joinings,\n"
  "But many subtile compassings,*                             *contrivances\n"
  "As barbicans* and pinnacles,                               *watch-towers\n"
  "Imageries and tabernacles,\n"
  "I saw; and eke full of windows,\n"
  "As flakes fall in greate snows.\n"
  "And eke in each of the pinnacles\n"
  "Were sundry habitacles,*                           *apartments or niches\n"
  "In which stooden, all without,\n"
  "Full the castle all about,\n"
  "Of all manner of minstrales\n"
  "And gestiours,<23> that telle tales\n"
  "Both of weeping and of game,*                                     *mirth\n"
  "Of all that longeth unto Fame.\n"
  "\n"
  "";
// }

const char poemTheHouseOfFame1[] PGMSECTION = // { // 27657 bytes
  "There heard I play upon a harp,\n"
  "That sounded bothe well and sharp,\n"
  "Him, Orpheus, full craftily;\n"
  "And on this side faste by\n"
  "Satte the harper Arion,<24>\n"
  "And eke Aeacides Chiron <25>\n"
  "And other harpers many a one,\n"
  "And the great Glasgerion; <26>\n"
  "And smalle harpers, with their glees,*                      *instruments\n"
  "Satten under them in sees,*                                       *seats\n"
  "And gan on them upward to gape,\n"
  "And counterfeit them as an ape,\n"
  "Or as *craft counterfeiteth kind.*             *art counterfeits nature*\n"
  "Then saw I standing them behind,\n"
  "Afar from them, all by themselve,\n"
  "Many thousand times twelve,\n"
  "That made loude minstrelsies\n"
  "In cornmuse and eke in shawmies, <27>\n"
  "And in many another pipe,\n"
  "That craftily began to pipe,\n"
  "Both in dulcet <28> and in reed,\n"
  "That be at feastes with the bride.\n"
  "And many a flute and lilting horn,\n"
  "And pipes made of greene corn,\n"
  "As have these little herde-grooms,*                       *shepherd-boys\n"
  "That keepe beastes in the brooms.\n"
  "There saw I then Dan Citherus,\n"
  "And of Athens Dan Pronomus, <29>\n"
  "And Marsyas <30> that lost his skin,\n"
  "Both in the face, body, and chin,\n"
  "For that he would envyen, lo!\n"
  "To pipe better than Apollo.\n"
  "There saw I famous, old and young,\n"
  "Pipers of alle Dutche tongue, <31>\n"
  "To learne love-dances and springs,\n"
  "Reyes, <32> and these strange things.\n"
  "Then saw I in another place,\n"
  "Standing in a large space,\n"
  "Of them that make bloody* soun',                                *martial\n"
  "In trumpet, beam,* and clarioun;                              *horn <33>\n"
  "For in fight and blood-sheddings\n"
  "Is used gladly clarionings.\n"
  "There heard I trumpe Messenus. <34>\n"
  "Of whom speaketh Virgilius.\n"
  "There heard I Joab trump also, <35>\n"
  "Theodamas, <36> and other mo',\n"
  "And all that used clarion\n"
  "In Catalogne and Aragon,\n"
  "That in their times famous were\n"
  "To learne, saw I trumpe there.\n"
  "There saw I sit in other sees,\n"
  "Playing upon sundry glees,\n"
  "Whiche that I cannot neven,*                                       *name\n"
  "More than starres be in heaven;\n"
  "Of which I will not now rhyme,\n"
  "For ease of you, and loss of time:\n"
  "For time lost, this knowe ye,\n"
  "By no way may recover'd be.\n"
  "\n"
  "There saw I play jongelours,*                             *jugglers <37>\n"
  "Magicians, and tregetours,<38>\n"
  "And Pythonesses, <39>  charmeresses,\n"
  "And old witches, and sorceresses,\n"
  "That use exorcisations,\n"
  "And eke subfumigations; <40>\n"
  "And clerkes* eke, which knowe well                             *scholars\n"
  "All this magic naturel,\n"
  "That craftily do their intents,\n"
  "To make, in certain ascendents, <41>\n"
  "Images, lo! through which magic\n"
  "To make a man be whole or sick.\n"
  "There saw I the queen Medea, <42>\n"
  "And Circes <43> eke, and Calypsa.<44>\n"
  "There saw I Hermes Ballenus, <45>\n"
  "Limote, <46> and eke Simon Magus. <47>\n"
  "There saw I, and knew by name,\n"
  "That by such art do men have fame.\n"
  "There saw I Colle Tregetour <46>\n"
  "Upon a table of sycamore\n"
  "Play an uncouth* thing to tell;                           *strange, rare\n"
  "I saw him carry a windmell\n"
  "Under a walnut shell.\n"
  "Why should I make longer tale\n"
  "Of all the people I there say,*                                     *saw\n"
  "From hence even to doomesday?\n"
  "\n"
  "When I had all this folk behold,\n"
  "And found me *loose, and not y-hold,*      *at liberty and unrestrained*\n"
  "And I had mused longe while\n"
  "Upon these walles of beryle,\n"
  "That shone lighter than any glass,\n"
  "And made *well more* than it was                           *much greater\n"
  "To seemen ev'rything, y-wis,\n"
  "As kindly* thing of Fame it is; <48>                            *natural\n"
  "I gan forth roam until I fand*                                    *found\n"
  "The castle-gate on my right hand,\n"
  "Which all so well y-carven was,\n"
  "That never such another n'as;*                                  *was not\n"
  "And yet it was by Adventure*                                     *chance\n"
  "Y-wrought, and not by *subtile cure.*                      *careful art*\n"
  "It needeth not you more to tell,\n"
  "To make you too longe dwell,\n"
  "Of these gates' flourishings,\n"
  "Nor of compasses,* nor carvings,                                *devices\n"
  "Nor how they had in masonries,\n"
  "As corbets, <49> full of imageries.\n"
  "But, Lord! so fair it was to shew,\n"
  "For it was all with gold behew.*                               *coloured\n"
  "But in I went, and that anon;\n"
  "There met I crying many a one\n"
  "\"A largess! largess! <50> hold up well!\n"
  "God save the Lady of this pell,*                                 *palace\n"
  "Our owen gentle Lady Fame,\n"
  "And them that will to have name\n"
  "Of us!\" Thus heard I cryen all,\n"
  "And fast they came out of the hall,\n"
  "And shooke *nobles and sterlings,*                           *coins <51>\n"
  "And some y-crowned were as kings,\n"
  "With crownes wrought fall of lozenges;\n"
  "And many ribands, and many fringes,\n"
  "Were on their clothes truely\n"
  "Then at the last espied I\n"
  "That pursuivantes and herauds,*                                 *heralds\n"
  "That cry riche folke's lauds,*                                  *praises\n"
  "They weren all; and ev'ry man\n"
  "Of them, as I you telle can,\n"
  "Had on him throwen a vesture\n"
  "Which that men call a coat-armure, <52>\n"
  "Embroidered wondrously rich,\n"
  "As though there were *naught y-lich;*                  *nothing like it*\n"
  "But naught will I, so may I thrive,\n"
  "*Be aboute to descrive*                 *concern myself with describing*\n"
  "All these armes that there were,\n"
  "That they thus on their coates bare,\n"
  "For it to me were impossible;\n"
  "Men might make of them a bible\n"
  "Twenty foote thick, I trow.\n"
  "For, certain, whoso coulde know\n"
  "Might there all the armes see'n\n"
  "Of famous folk that have been\n"
  "In Afric', Europe, and Asie,\n"
  "Since first began the chivalry.\n"
  "\n"
  "Lo! how should I now tell all this?\n"
  "Nor of the hall eke what need is\n"
  "To telle you that ev'ry wall\n"
  "Of it, and floor, and roof, and all,\n"
  "Was plated half a foote thick\n"
  "Of gold, and that was nothing wick',*                       *counterfeit\n"
  "But for to prove in alle wise\n"
  "As fine as ducat of Venise, <53>\n"
  "Of which too little in my pouch is?\n"
  "And they were set as thick of nouches*                        *ornaments\n"
  "Fine, of the finest stones fair,\n"
  "That men read in the Lapidaire, <54>\n"
  "As grasses growen in a mead.\n"
  "But it were all too long to read*                               *declare\n"
  "The names; and therefore I pass.\n"
  "But in this rich and lusty place,\n"
  "That Fame's Hall y-called was,\n"
  "Full muche press of folk there n'as,*                           *was not\n"
  "Nor crowding for too muche press.\n"
  "But all on high, above a dais,\n"
  "Set on a see* imperial, <55>                                       *seat\n"
  "That made was of ruby all,\n"
  "Which that carbuncle is y-call'd,\n"
  "I saw perpetually install'd\n"
  "A feminine creature;\n"
  "That never formed by Nature\n"
  "Was such another thing y-sey.*                                     *seen\n"
  "For altherfirst,* sooth to say,                            *first of all\n"
  "Me thoughte that she was so lite,*                               *little\n"
  "That the length of a cubite\n"
  "Was longer than she seem'd to be;\n"
  "But thus soon in a while she\n"
  "Herself then wonderfully stretch'd,\n"
  "That with her feet the earth she reach'd,\n"
  "And with her head she touched heaven,\n"
  "Where as shine the starres seven. <56>\n"
  "And thereto* eke, as to my wit,                                *moreover\n"
  "I saw a greater wonder yet,\n"
  "Upon her eyen to behold;\n"
  "But certes I them never told.\n"
  "For *as fele eyen* hadde she,                             *as many eyes*\n"
  "As feathers upon fowles be,\n"
  "Or were on the beastes four\n"
  "That Godde's throne gan honour,\n"
  "As John writ in th'Apocalypse. <57>\n"
  "Her hair, that *oundy was and crips,*              *wavy <58> and crisp*\n"
  "As burnish'd gold it shone to see;\n"
  "And, sooth to tellen, also she\n"
  "Had all so fele* upstanding ears,                                  *many\n"
  "And tongues, as on beasts be hairs;\n"
  "And on her feet waxen saw I\n"
  "Partridges' winges readily.<59>\n"
  "But, Lord! the pierrie* and richess                     *gems, jewellery\n"
  "I saw sitting on this goddess,\n"
  "And the heavenly melody\n"
  "Of songes full of harmony,\n"
  "I heard about her throne y-sung,\n"
  "That all the palace walles rung!\n"
  "(So sung the mighty Muse, she\n"
  "That called is Calliope,\n"
  "And her eight sisteren* eke,                                    *sisters\n"
  "That in their faces seeme meek);\n"
  "And evermore eternally\n"
  "They sang of Fame as then heard I:\n"
  "\"Heried* be thou and thy name,                                  *praised\n"
  "Goddess of Renown and Fame!\"\n"
  "Then was I ware, lo! at the last,\n"
  "As I mine eyen gan upcast,\n"
  "That this ilke noble queen\n"
  "On her shoulders gan sustene*                                   *sustain\n"
  "Both the armes, and the name\n"
  "Of those that hadde large fame;\n"
  "Alexander, and Hercules,\n"
  "That with a shirt his life lese.* <60>                             *lost\n"
  "Thus found I sitting this goddess,\n"
  "In noble honour and richess;\n"
  "Of which I stint* a while now,                  *refrain (from speaking)\n"
  "Of other things to telle you.\n"
  "\n"
  "Then saw I stand on either side,\n"
  "Straight down unto the doores wide,\n"
  "From the dais, many a pillere\n"
  "Of metal, that shone not full clear;\n"
  "But though they were of no richess,\n"
  "Yet were they made for great nobless,\n"
  "And in them greate sentence.*                              *significance\n"
  "And folk of digne* reverence,                             *worthy, lofty\n"
  "Of which *I will you telle fand,*               *I will try to tell you*\n"
  "Upon the pillars saw I stand.\n"
  "Altherfirst, lo! there I sigh*                                      *saw\n"
  "Upon a pillar stand on high,\n"
  "That was of lead and iron fine,\n"
  "Him of the secte Saturnine, <61>\n"
  "The Hebrew Josephus the old,\n"
  "That of Jewes' gestes* told;                            *deeds of braver\n"
  "And he bare on his shoulders high\n"
  "All the fame up of Jewry.\n"
  "And by him stooden other seven,\n"
  "Full wise and worthy for to neven,*                                *name\n"
  "To help him bearen up the charge,*                               *burden\n"
  "It was so heavy and so large.\n"
  "And, for they writen of battailes,\n"
  "As well as other old marvailes,\n"
  "Therefore was, lo! this pillere,\n"
  "Of which that I you telle here,\n"
  "Of lead and iron both, y-wis;\n"
  "For iron Marte's metal is, <62>\n"
  "Which that god is of battaile;\n"
  "And eke the lead, withoute fail,\n"
  "Is, lo! the metal of Saturn,\n"
  "That hath full large wheel* to turn.                              *orbit\n"
  "Then stoode forth, on either row,\n"
  "Of them which I coulde know,\n"
  "Though I them not by order tell,\n"
  "To make you too longe dwell.\n"
  "These, of the which I gin you read,\n"
  "There saw I standen, out of dread,\n"
  "Upon an iron pillar strong,\n"
  "That painted was all endelong*                      *from top to bottom*\n"
  "With tiger's blood in ev'ry place,\n"
  "The Tholosan that highte Stace, <63>\n"
  "That bare of Thebes up the name\n"
  "Upon his shoulders, and the fame\n"
  "Also of cruel Achilles.\n"
  "And by him stood, withoute lease,*                            *falsehood\n"
  "Full wondrous high on a pillere\n"
  "Of iron, he, the great Homere;\n"
  "And with him Dares and Dytus, <64>\n"
  "Before, and eke he, Lollius, <65>\n"
  "And Guido eke de Colempnis, <66>\n"
  "And English Gaufrid <67> eke, y-wis.\n"
  "And each of these, as I have joy,\n"
  "Was busy for to bear up Troy;\n"
  "So heavy thereof was the fame,\n"
  "That for to bear it was no game.\n"
  "But yet I gan full well espy,\n"
  "Betwixt them was a little envy.\n"
  "One said that Homer made lies,\n"
  "Feigning in his poetries,\n"
  "And was to the Greeks favourable;\n"
  "Therefore held he it but a fable.\n"
  "Then saw I stand on a pillere\n"
  "That was of tinned iron clear,\n"
  "Him, the Latin poet Virgile,\n"
  "That borne hath up a longe while\n"
  "The fame of pious Aeneas.\n"
  "And next him on a pillar was\n"
  "Of copper, Venus' clerk Ovide,\n"
  "That hath y-sowen wondrous wide\n"
  "The greate god of Love's fame.\n"
  "And there he bare up well his name\n"
  "Upon this pillar all so high,\n"
  "As I might see it with mine eye;\n"
  "For why? this hall whereof I read\n"
  "Was waxen in height, and length, and bread,*                    *breadth\n"
  "Well more by a thousand deal*                                     *times\n"
  "Than it was erst, that saw I weel.\n"
  "Then saw I on a pillar by,\n"
  "Of iron wrought full sternely,\n"
  "The greate poet, Dan Lucan,\n"
  "That on his shoulders bare up than,\n"
  "As high as that I might it see,\n"
  "The fame of Julius and Pompey; <68>\n"
  "And by him stood all those clerks\n"
  "That write of Rome's mighty works,\n"
  "That if I would their names tell,\n"
  "All too longe must I dwell.\n"
  "And next him on a pillar stood\n"
  "Of sulphur, like as he were wood,*                                  *mad\n"
  "Dan Claudian, <69> the sooth to tell,\n"
  "That bare up all the fame of hell,\n"
  "Of Pluto, and of Proserpine,\n"
  "That queen is of *the darke pine*               *the dark realm of pain*\n"
  "Why should I telle more of this?\n"
  "The hall was alle fulle, y-wis,\n"
  "Of them that writen olde gests,*               *histories of great deeds\n"
  "As be on trees rookes' nests;\n"
  "But it a full confus'd mattere\n"
  "Were all these gestes for to hear,\n"
  "That they of write, and how they hight.*                     *are called\n"
  "\n"
  " But while that I beheld this sight,\n"
  "I heard a noise approache blive,*                               *quickly\n"
  "That far'd* as bees do in a hive,                                  *went\n"
  "Against their time of outflying;\n"
  "Right such a manner murmuring,\n"
  "For all the world, it seem'd to me.\n"
  "Then gan I look about, and see\n"
  "That there came entering the hall\n"
  "A right great company withal,\n"
  "And that of sundry regions,\n"
  "Of all kinds and conditions\n"
  "That dwell in earth under the moon,\n"
  "Both poor and rich; and all so soon\n"
  "As they were come into the hall,\n"
  "They gan adown on knees to fall,\n"
  "Before this ilke* noble queen,                                     *same\n"
  "And saide, \"Grant us, Lady sheen,*                       *bright, lovely\n"
  "Each of us of thy grace a boon.\"*                                *favour\n"
  "And some of them she granted soon,\n"
  "And some she warned* well and fair,                             *refused\n"
  "And some she granted the contrair*                             *contrary\n"
  "Of their asking utterly;\n"
  "But this I say you truely,\n"
  "What that her cause was, I n'ist;*                   *wist not, know not\n"
  "For of these folk full well I wist,\n"
  "They hadde good fame each deserved,\n"
  "Although they were diversely served.\n"
  "Right as her sister, Dame Fortune,\n"
  "Is wont to serven *in commune.*                      *commonly, usually*\n"
  "\n"
  "Now hearken how she gan to pay\n"
  "Them that gan of her grace to pray;\n"
  "And right, lo! all this company\n"
  "Saide sooth,* and not a lie.                                      *truth\n"
  "\"Madame,\" thus quoth they, \"we be\n"
  "Folk that here beseeche thee\n"
  "That thou grant us now good fame,\n"
  "And let our workes have good name\n"
  "In full recompensatioun\n"
  "Of good work, give us good renown\n"
  "\"I warn* it you,\" quoth she anon;                                *refuse\n"
  "\"Ye get of me good fame none,\n"
  "By God! and therefore go your way.\"\n"
  "\"Alas,\" quoth they, \"and well-away!\n"
  "Tell us what may your cause be.\"\n"
  "\"For that it list* me not,\" quoth she,                          *pleases\n"
  "No wight shall speak of you, y-wis,\n"
  "Good nor harm, nor that nor this.\"\n"
  "\n"
  "And with that word she gan to call\n"
  "Her messenger, that was in hall,\n"
  "And bade that he should faste go'n,\n"
  "Upon pain to be blind anon,\n"
  "For Aeolus, the god of wind;\n"
  "\"In Thrace there ye shall him find,\n"
  "And bid him bring his clarioun,\n"
  "That is full diverse of his soun',\n"
  "And it is called Cleare Laud,\n"
  "With which he wont is to heraud*                               *proclaim\n"
  "Them that me list y-praised be,\n"
  "And also bid him how that he\n"
  "Bring eke his other clarioun,\n"
  "That hight* Slander in ev'ry town,                            *is called\n"
  "With which he wont is to diffame*                     *defame, disparage\n"
  "Them that me list, and do them shame.\"\n"
  "This messenger gan faste go'n,\n"
  "And found where, in a cave of stone,\n"
  "In a country that highte Thrace,\n"
  "This Aeolus, *with harde grace,*               *Evil favour attend him!*\n"
  "Helde the windes in distress,*                               *constraint\n"
  "And gan them under him to press,\n"
  "That they began as bears to roar,\n"
  "He bound and pressed them so sore.\n"
  "This messenger gan fast to cry,\n"
  "\"Rise up,\" quoth he, \"and fast thee hie,\n"
  "Until thou at my Lady be,\n"
  "And take thy clarions eke with thee,\n"
  "And speed thee forth.\" And he anon\n"
  "Took to him one that hight Triton, <70>\n"
  "His clarions to beare tho,*                                        *then\n"
  "And let a certain winde go,\n"
  "That blew so hideously and high,\n"
  "That it lefte not a sky*                                     *cloud <71>\n"
  "In all the welkin* long and broad.                                  *sky\n"
  "This Aeolus nowhere abode*                                      *delayed\n"
  "Till he was come to Fame's feet,\n"
  "And eke the man that Triton hete,*                            *is called\n"
  "And there he stood as still as stone.\n"
  "\n"
  "And therewithal there came anon\n"
  "Another huge company\n"
  "Of goode folk, and gan to cry,\n"
  "\"Lady, grant us goode fame,\n"
  "And let our workes have that name,\n"
  "Now in honour of gentleness;\n"
  "And all so God your soule bless;\n"
  "For we have well deserved it,\n"
  "Therefore is right we be well quit.\"*                          *requited\n"
  "\"As thrive I,\" quoth she, \"ye shall fail;\n"
  "Good workes shall you not avail\n"
  "To have of me good fame as now;\n"
  "But, wot ye what, I grante you.\n"
  "That ye shall have a shrewde* fame,                        *evil, cursed\n"
  "And wicked los,* and worse name,                        *reputation <72>\n"
  "Though ye good los have well deserv'd;\n"
  "Now go your way, for ye be serv'd.\n"
  "And now, Dan Aeolus,\" quoth she,\n"
  "\"Take forth thy trump anon, let see,\n"
  "That is y-called Slander light,\n"
  "And blow their los, that ev'ry wight\n"
  "Speak of them harm and shrewedness,*                 *wickedness, malice\n"
  "Instead of good and worthiness;\n"
  "For thou shalt trump all the contrair\n"
  "Of that they have done, well and fair.\"\n"
  "Alas! thought I, what adventures*                       *(evil) fortunes\n"
  "Have these sorry creatures,\n"
  "That they, amonges all the press,\n"
  "Should thus be shamed guilteless?\n"
  "But what! it muste needes be.\n"
  "What did this Aeolus, but he\n"
  "Took out his blacke trump of brass,\n"
  "That fouler than the Devil was,\n"
  "And gan this trumpet for to blow,\n"
  "As all the world 't would overthrow.\n"
  "Throughout every regioun\n"
  "Went this foule trumpet's soun',\n"
  "As swift as pellet out of gun\n"
  "When fire is in the powder run.\n"
  "And such a smoke gan out wend,*                                      *go\n"
  "Out of this foule trumpet's end,\n"
  "Black, blue, greenish, swart,* and red,                      *black <73>\n"
  "As doth when that men melt lead,\n"
  "Lo! all on high from the tewell;*                          *chimney <74>\n"
  "And thereto* one thing saw I well,                                 *also\n"
  "That the farther that it ran,\n"
  "The greater waxen it began,\n"
  "As doth the river from a well,*                                *fountain\n"
  "And it stank as the pit of hell.\n"
  "Alas! thus was their shame y-rung,\n"
  "And guilteless, on ev'ry tongue.\n"
  "\n"
  "Then came the thirde company,\n"
  "And gan up to the dais to hie,*                                  *hasten\n"
  "And down on knees they fell anon,\n"
  "And saide, \"We be ev'ry one\n"
  "Folk that have full truely\n"
  "Deserved fame right fully,\n"
  "And pray you that it may be know\n"
  "Right as it is, and forth y-blow.\"\n"
  "\"I grante,\" quoth she, \"for me list\n"
  "That now your goode works be wist;*                               *known\n"
  "And yet ye shall have better los,\n"
  "In despite of all your foes,\n"
  "Than worthy* is, and that anon.                                 *merited\n"
  "Let now,\" quoth she, \"thy trumpet go'n,\n"
  "Thou Aeolus, that is so black,\n"
  "And out thine other trumpet take,\n"
  "That highte Laud, and blow it so\n"
  "That through the world their fame may go,\n"
  "Easily and not too fast,\n"
  "That it be knowen at the last.\"\n"
  "\"Full gladly, Lady mine,\" he said;\n"
  "And out his trump of gold he braid*                        *pulled forth\n"
  "Anon, and set it to his mouth,\n"
  "And blew it east, and west, and south,\n"
  "And north, as loud as any thunder,\n"
  "That ev'ry wight had of it wonder,\n"
  "So broad it ran ere that it stent.*                              *ceased\n"
  "And certes all the breath that went\n"
  "Out of his trumpet's mouthe smell'd\n"
  "As* men a pot of balme held                                       *as if\n"
  "Among a basket full of roses;\n"
  "This favour did he to their loses.*                         *reputations\n"
  "\n"
  "And right with this I gan espy\n"
  "Where came the fourthe company.\n"
  "But certain they were wondrous few;\n"
  "And gan to standen in a rew,*                                       *row\n"
  "And saide, \"Certes, Lady bright,\n"
  "We have done well with all our might,\n"
  "But we *not keep* to have fame;                                *care not\n"
  "Hide our workes and our name,\n"
  "For Godde's love! for certes we\n"
  "Have surely done it for bounty,*                       *goodness, virtue\n"
  "And for no manner other thing.\"\n"
  "\"I grante you all your asking,\"\n"
  "Quoth she; \"let your workes be dead.\"\n"
  "\n"
  "With that I turn'd about my head,\n"
  "And saw anon the fifthe rout,*                                  *company\n"
  "That to this Lady gan to lout,*                                *bow down\n"
  "And down on knees anon to fall;\n"
  "And to her then besoughten all\n"
  "To hide their good workes eke,\n"
  "And said, they gave* not a leek                                   *cared\n"
  "For no fame, nor such renown;\n"
  "For they for contemplatioun\n"
  "And Godde's love had y-wrought,\n"
  "Nor of fame would they have aught.\n"
  "\"What!\" quoth she, \"and be ye wood?\n"
  "And *weene ye* for to do good,                           *do ye imagine*\n"
  "And for to have of that no fame?\n"
  "*Have ye despite* to have my name?                       *do ye despise*\n"
  "Nay, ye shall lie every one!\n"
  "Blow thy trump, and that anon,\"\n"
  "Quoth she, \"thou Aeolus, I hote,*                               *command\n"
  "And ring these folkes works by note,\n"
  "That all the world may of it hear.\"\n"
  "And he gan blow their los* so clear                          *reputation\n"
  "Within his golden clarioun,\n"
  "That through the worlde went the soun',\n"
  "All so kindly, and so soft,\n"
  "That their fame was blown aloft.\n"
  "\n"
  "And then came the sixth company,\n"
  "And gunnen* fast on Fame to cry;                                  *began\n"
  "Right verily in this mannere\n"
  "They saide; \"Mercy, Lady dear!\n"
  "To telle certain as it is,\n"
  "We have done neither that nor this,\n"
  "But idle all our life hath be;*                                    *been\n"
  "But natheless yet praye we\n"
  "That we may have as good a fame,\n"
  "And great renown, and knowen* name,                          *well-known\n"
  "As they that have done noble gests,*                             *feats.\n"
  "And have achieved all their quests,*               *enterprises; desires\n"
  "As well of Love, as other thing;\n"
  "All* was us never brooch, nor ring,                            *although\n"
  "Nor elles aught from women sent,\n"
  "Nor ones in their hearte meant\n"
  "To make us only friendly cheer,\n"
  "But mighte *teem us upon bier;*                *might lay us on our bier\n"
  "Yet let us to the people seem              (by their adverse demeanour)*\n"
  "Such as the world may of us deem,*                                *judge\n"
  "That women loven us for wood.*                                    *madly\n"
  "It shall us do as muche good,\n"
  "And to our heart as much avail,\n"
  "The counterpoise,* ease, and travail,                      *compensation\n"
  "As we had won it with labour;\n"
  "For that is deare bought honour,\n"
  "*At the regard of* our great ease.                  *in comparison with*\n"
  "*And yet* ye must us more please;                          *in addition*\n"
  "Let us be holden eke thereto\n"
  "Worthy, and wise, and good also,\n"
  "And rich, and happy unto love,\n"
  "For Godde's love, that sits above;\n"
  "Though we may not the body have\n"
  "Of women, yet, so God you save,\n"
  "Let men glue* on us the name;                                    *fasten\n"
  "Sufficeth that we have the fame.\"\n"
  "\"I grante,\" quoth she, \"by my troth;\n"
  "Now Aeolus, withoute sloth,\n"
  "Take out thy trump of gold,\" quoth she,\n"
  "\"And blow as they have asked me,\n"
  "That ev'ry man ween* them at ease,                              *believe\n"
  "Although they go in full *bad leas.\"*                     *sorry plight*\n"
  "This Aeolus gan it so blow,\n"
  "That through the world it was y-know.\n"
  "\n"
  "Then came the seventh rout anon,\n"
  "And fell on knees ev'ry one,\n"
  "And saide, \"Lady, grant us soon\n"
  "The same thing, the same boon,\n"
  "Which *this next folk* you have done.\"       *the people just before us*\n"
  "\"Fy on you,\" quoth she, \"ev'ry one!\n"
  "Ye nasty swine, ye idle wretches,\n"
  "Full fill'd of rotten slowe tetches!*                    *blemishes <75>\n"
  "What? false thieves! ere ye would\n"
  "*Be famous good,* and nothing n'ould                    *have good fame*\n"
  "Deserve why, nor never raught,*                *recked, cared (to do so)\n"
  "Men rather you to hangen ought.\n"
  "For ye be like the sleepy cat,\n"
  "That would have fish; but, know'st thou what?\n"
  "He woulde no thing wet his claws.\n"
  "Evil thrift come to your jaws,\n"
  "And eke to mine, if I it grant,\n"
  "Or do favour you to avaunt.*                           *boast your deeds\n"
  "Thou Aeolus, thou King of Thrace,\n"
  "Go, blow this folk a *sorry grace,\"*                           *disgrace\n"
  "Quoth she, \"anon; and know'st thou how?\n"
  "As I shall telle thee right now,\n"
  "Say, these be they that would honour\n"
  "Have, and do no kind of labour,\n"
  "Nor do no good, and yet have laud,\n"
  "And that men ween'd that Belle Isaude <76>\n"
  "*Could them not of love wern;*          *could not refuse them her love*\n"
  "And yet she that grinds at the quern*                         *mill <77>\n"
  "Is all too good to ease their heart.\"\n"
  "This Aeolus anon upstart,\n"
  "And with his blacke clarioun\n"
  "He gan to blazen out a soun'\n"
  "As loud as bellows wind in hell;\n"
  "And eke therewith, the sooth to tell,\n"
  "This sounde was so full of japes,*                                *jests\n"
  "As ever were mows* in apes;                                    *grimaces\n"
  "And that went all the world about,\n"
  "That ev'ry wight gan on them shout,\n"
  "And for to laugh as they were wood;*                                *mad\n"
  "*Such game found they in their hood.* <78>      *so were they ridiculed*\n"
  "\n"
  "Then came another company,\n"
  "That hadde done the treachery,\n"
  "The harm, and the great wickedness,\n"
  "That any hearte coulde guess;\n"
  "And prayed her to have good fame,\n"
  "And that she would do them no shame,\n"
  "But give them los and good renown,\n"
  "And *do it blow* in clarioun.                     *cause it to be blown*\n"
  "\"Nay, wis!\" quoth she, \"it were a vice;\n"
  "All be there in me no justice,\n"
  "Me liste not to do it now,\n"
  "Nor this will I grant to you.\"\n"
  "\n"
  "Then came there leaping in a rout,*                               *crowd\n"
  "And gan to clappen* all about                             *strike, knock\n"
  "Every man upon the crown,\n"
  "That all the hall began to soun';\n"
  "And saide; \"Lady lefe* and dear,                                  *loved\n"
  "We be such folk as ye may hear.\n"
  "To tellen all the tale aright,\n"
  "We be shrewes* every wight,                      *wicked, impious people\n"
  "And have delight in wickedness,\n"
  "As goode folk have in goodness,\n"
  "And joy to be y-knowen shrews,\n"
  "And full of vice and *wicked thews;*                    *evil qualities*\n"
  "Wherefore we pray you *on a row,*                         *all together*\n"
  "That our fame be such y-know\n"
  "In all things right as it is.\"\n"
  "\"I grant it you,\" quoth she, \"y-wis.\n"
  "But what art thou that say'st this tale,\n"
  "That wearest on thy hose a pale,*                       *vertical stripe\n"
  "And on thy tippet such a bell?\"\n"
  "\"Madame,\" quoth he, \"sooth to tell,\n"
  "I am *that ilke shrew,* y-wis,                         *the same wretch*\n"
  "That burnt the temple of Isidis,\n"
  "In Athenes, lo! that city.\" <79>\n"
  "\"And wherefore didst thou so?\" quoth she.\n"
  "\"By my thrift!\" quoth he, \"Madame,\n"
  "I woulde fain have had a name\n"
  "As other folk had in the town;\n"
  "Although they were of great renown\n"
  "For their virtue and their thews,*                       *good qualities\n"
  "Thought I, as great fame have shrews\n"
  "(Though it be naught) for shrewdeness,\n"
  "As good folk have for goodeness;\n"
  "And since I may not have the one,\n"
  "The other will I not forgo'n.\n"
  "So for to gette *fame's hire,*                      *the reward of fame*\n"
  "The temple set I all afire.\n"
  "*Now do our los be blowen swithe,\n"
  "As wisly be thou ever blithe.\"*                           *see note <80>\n"
  "\"Gladly,\" quoth she; \"thou Aeolus,\n"
  "Hear'st thou what these folk prayen us?\"\n"
  "\"Madame, I hear full well,\" quoth he,\n"
  "\"And I will trumpen it, pardie!\"\n"
  "And took his blacke trumpet fast,\n"
  "And gan to puffen and to blast,\n"
  "Till it was at the worlde's end.\n"
  "\n"
  "";
// }

const char poemTheHouseOfFame2[] PGMSECTION = // { // 27772 bytes
  "With that I gan *aboute wend,*                                    *turn*\n"
  "For one that stood right at my back\n"
  "Me thought full goodly* to me spake,                *courteously, fairly\n"
  "And saide, \"Friend, what is thy name?\n"
  "Art thou come hither to have fame?\"\n"
  "\"Nay, *for soothe,* friend!\" quoth I;                           *surely*\n"
  "\"I came not hither, *grand mercy,*                        *great thanks*\n"
  "For no such cause, by my head!\n"
  "Sufficeth me, as I were dead,\n"
  "That no wight have my name in hand.\n"
  "I wot myself best how I stand,\n"
  "For what I dree,* or what I think,                               *suffer\n"
  "I will myself it alle drink,\n"
  "Certain, for the more part,\n"
  "As far forth as I know mine art.\"\n"
  "\"What doest thou here, then,\" quoth he.\n"
  "Quoth I, \"That will I telle thee;\n"
  "The cause why I stande here,\n"
  "Is some new tidings for to lear,*                                 *learn\n"
  "Some newe thing, I know not what,\n"
  "Tidings either this or that,\n"
  "Of love, or suche thinges glad.\n"
  "For, certainly, he that me made\n"
  "To come hither, said to me\n"
  "I shoulde bothe hear and see\n"
  "In this place wondrous things;\n"
  "But these be not such tidings\n"
  "As I meant of.\" \"No?\" quoth he.\n"
  "And I answered, \"No, pardie!\n"
  "For well I wot ever yet,\n"
  "Since that first I hadde wit,\n"
  "That some folk have desired fame\n"
  "Diversely, and los, and name;\n"
  "But certainly I knew not how\n"
  "Nor where that Fame dwelled, ere now\n"
  "Nor eke of her description,\n"
  "Nor also her condition,\n"
  "Nor *the order of her doom,*            *the principle of her judgments*\n"
  "Knew I not till I hither come.\"\n"
  "\"Why, then, lo! be these tidings,\n"
  "That thou nowe hither brings,\n"
  "That thou hast heard?\" quoth he to me.\n"
  "\"But now *no force,* for well I see                          *no matter*\n"
  "What thou desirest for to lear.\"\n"
  "Come forth, and stand no longer here.\n"
  "And I will thee, withoute dread,*                                 *doubt\n"
  "Into another place lead,\n"
  "Where thou shalt hear many a one.\"\n"
  "\n"
  "Then gan I forth with him to go'n\n"
  "Out of the castle, sooth to say.\n"
  "Then saw I stand in a vally,\n"
  "Under the castle faste by,\n"
  "A house, that domus Daedali,\n"
  "That Labyrinthus <81> called is,\n"
  "N'as* made so wondrously, y-wis,                                *was not\n"
  "Nor half so quaintly* was y-wrought.                          *strangely\n"
  "And evermore, as swift as thought,\n"
  "This quainte* house aboute went,                                *strange\n"
  "That nevermore it *stille stent;*                       *ceased to move*\n"
  "And thereout came so great a noise,\n"
  "That had it stooden upon Oise, <82>\n"
  "Men might have heard it easily\n"
  "To Rome, I *trowe sickerly.*                       *confidently believe*\n"
  "And the noise which I heard,\n"
  "For all the world right so it far'd\n"
  "As doth the routing* of the stone                        *rushing noise*\n"
  "That from the engine<83> is let go'n.\n"
  "And all this house of which I read*                            *tell you\n"
  "Was made of twigges sallow,* red,                                *willow\n"
  "And green eke, and some were white,\n"
  "Such as men *to the cages twight,*                  *pull to make cages*\n"
  "Or maken of  these panniers,\n"
  "Or elles hutches or dossers;*                              *back-baskets\n"
  "That, for the swough* and for the twigs,                  *rushing noise\n"
  "This house was all so full of gigs,*                     *sounds of wind\n"
  "And all so full eke of chirkings,*                            *creakings\n"
  "And of many other workings;\n"
  "And eke this house had of entries\n"
  "As many as leaves be on trees,\n"
  "In summer when that they be green,\n"
  "And on the roof men may yet see'n\n"
  "A thousand holes, and well mo',\n"
  "To let the soundes oute go.\n"
  "And by day *in ev'ry tide*                                 *continually*\n"
  "Be all the doores open wide,\n"
  "And by night each one unshet;*                             *unshut, open\n"
  "Nor porter there is none to let*                                 *hinder\n"
  "No manner tidings in to pace;\n"
  "Nor ever rest is in that place,\n"
  "That it n'is* fill'd full of tidings,                            *is not\n"
  "Either loud, or of whisperings;\n"
  "And ever all the house's angles\n"
  "Are full of *rownings and of jangles,*     *whisperings and chatterings*\n"
  "Of wars, of peace, of marriages,\n"
  "Of rests, of labour, of voyages,\n"
  "Of abode, of death, of life,\n"
  "Of love, of hate, accord, of strife,\n"
  "Of loss, of lore, and of winnings,\n"
  "Of health, of sickness, of buildings,\n"
  "Of faire weather and tempests,\n"
  "Of qualm* of folkes and of beasts;                             *sickness\n"
  "Of divers transmutations\n"
  "Of estates and of regions;\n"
  "Of trust, of dread,* of jealousy,                                 *doubt\n"
  "Of wit, of cunning, of folly,\n"
  "Of plenty, and of great famine,\n"
  "Of *cheap, of dearth,* and of ruin;     *cheapness & dearness (of food)*\n"
  "Of good or of mis-government,\n"
  "Of fire, and diverse accident.\n"
  "And lo! this house of which I write,\n"
  "*Sicker be ye,* it was not lite;*                    *be assured* *small\n"
  "For it was sixty mile of length,\n"
  "All* was the timber of no strength;                            *although\n"
  "Yet it is founded to endure,\n"
  "*While that it list to Adventure,*               *while fortune pleases*\n"
  "That is the mother of tidings,\n"
  "As is the sea of wells and springs;\n"
  "And it was shapen like a cage.\n"
  "\"Certes,\" quoth I, \"in all mine age,*                              *life\n"
  "Ne'er saw I such a house as this.\"\n"
  "\n"
  "And as I wonder'd me, y-wis,\n"
  "Upon this house, then ware was I\n"
  "How that mine eagle, faste by,\n"
  "Was perched high upon a stone;\n"
  "And I gan straighte to him go'n,\n"
  "And saide thus; \"I praye thee\n"
  "That thou a while abide* me,                                   *wait for\n"
  "For Godde's love, and let me see\n"
  "What wonders in this place be;\n"
  "For yet parauntre* I may lear**                    *peradventure **learn\n"
  "Some good thereon, or somewhat hear,\n"
  "That *lefe me were,* ere that I went.\"             *were pleasing to me*\n"
  "\"Peter! that is mine intent,\"\n"
  "Quoth he to me; \"therefore I dwell;*                              *tarry\n"
  "But, certain, one thing I thee tell,\n"
  "That, but* I bringe thee therein,                                *unless\n"
  "Thou shalt never *can begin*                                   *be able*\n"
  "To come into it, out of doubt,\n"
  "So fast it whirleth, lo! about.\n"
  "But since that Jovis, of his grace,\n"
  "As I have said, will thee solace\n"
  "Finally with these ilke* things,                                   *same\n"
  "These uncouth sightes and tidings,\n"
  "To pass away thy heaviness,\n"
  "Such ruth* hath he of thy distress                           *compassion\n"
  "That thou suff'rest debonairly,*                                 *gently\n"
  "And know'st thyselven utterly\n"
  "Desperate of alle bliss,\n"
  "Since that Fortune hath made amiss\n"
  "The fruit of all thy hearte's rest\n"
  "Languish, and eke *in point to brest;*        *on the point of breaking*\n"
  "But he, through his mighty merite,\n"
  "Will do thee ease, all be it lite,*                              *little\n"
  "And gave express commandement,\n"
  "To which I am obedient,\n"
  "To further thee with all my might,\n"
  "And wiss* and teache thee aright,                                *direct\n"
  "Where thou may'st moste tidings hear,\n"
  "Shalt thou anon many one lear.\"\n"
  "\n"
  "And with this word he right anon\n"
  "Hent* me up betwixt his tone,**                           *caught **toes\n"
  "And at a window in me brought,\n"
  "That in this house was, as me thought;\n"
  "And therewithal me thought it stent,*                           *stopped\n"
  "And nothing it aboute went;\n"
  "And set me in the floore down.\n"
  "But such a congregatioun\n"
  "Of folk, as I saw roam about,\n"
  "Some within and some without,\n"
  "Was never seen, nor shall be eft,*                     *again, hereafter\n"
  "That, certes, in the world n' is* left                           *is not\n"
  "So many formed by Nature,\n"
  "Nor dead so many a creature,\n"
  "That well unnethes* in that place                              *scarcely\n"
  "Had I a foote breadth of space;\n"
  "And ev'ry wight that I saw there\n"
  "Rown'd* evereach in other's ear                               *whispered\n"
  "A newe tiding privily,\n"
  "Or elles told all openly\n"
  "Right thus, and saide, \"Know'st not thou\n"
  "What is betid,* lo! righte now?\"                               *happened\n"
  "\"No,\" quoth he; \"telle me what.\"\n"
  "And then he told him this and that,\n"
  "And swore thereto, that it was sooth;\n"
  "\"Thus hath he said,\" and \"Thus he do'th,\"\n"
  "And \"Thus shall 't be,\" and \"Thus heard I say\n"
  "\"That shall be found, that dare I lay;\"*                          *wager\n"
  "That all the folk that is alive\n"
  "Have not the cunning to descrive*                              *describe\n"
  "The thinges that I hearde there,\n"
  "What aloud, and what in th'ear.\n"
  "But all the wonder most was this;\n"
  "When one had heard a thing, y-wis,\n"
  "He came straight to another wight,\n"
  "And gan him tellen anon right\n"
  "The same tale that to him was told,\n"
  "Or it a furlong way was old, <84>\n"
  "And gan somewhat for to eche*                                  *eke, add\n"
  "To this tiding in his speech,\n"
  "More than it ever spoken was.\n"
  "And not so soon departed n'as*                                      *was\n"
  "He from him, than that he met\n"
  "With the third; and *ere he let\n"
  "Any stound,* he told him als';                *without delaying a momen*\n"
  "Were the tidings true or false,\n"
  "Yet would he tell it natheless,\n"
  "And evermore with more increase\n"
  "Than it was erst.* Thus north and south                        *at first\n"
  "Went ev'ry tiding from mouth to mouth,\n"
  "And that increasing evermo',\n"
  "As fire is wont to *quick and go*             *become alive, and spread*\n"
  "From a spark y-sprung amiss,\n"
  "Till all a city burnt up is.\n"
  "And when that it was full up-sprung,\n"
  "And waxen* more on ev'ry tongue                               *increased\n"
  "Than e'er it was, it went anon\n"
  "Up to a window out to go'n;\n"
  "Or, but it mighte thereout pass,\n"
  "It gan creep out at some crevass,*                       *crevice, chink\n"
  "And fly forth faste for the nonce.\n"
  "And sometimes saw I there at once\n"
  "*A leasing, and a sad sooth saw,*            *a falsehood and an earnest\n"
  "That gan *of adventure* draw                     true saying* *by chance\n"
  "Out at a window for to pace;\n"
  "And when they metten in that place,\n"
  "They were checked both the two,\n"
  "And neither of them might out go;\n"
  "For other so they gan *to crowd,*            *push, squeeze, each other*\n"
  "Till each of them gan cryen loud,\n"
  "\"Let me go first!\" -- \"Nay, but let me!\n"
  "And here I will ensure thee,\n"
  "With vowes, if thou wilt do so,\n"
  "That I shall never from thee go,\n"
  "But be thine owen sworen brother!\n"
  "We will us medle* each with other,                               *mingle\n"
  "That no man, be he ne'er so wroth,\n"
  "Shall have one of us two, but both\n"
  "At ones, as *beside his leave,*                     *despite his desire*\n"
  "Come we at morning or at eve,\n"
  "Be we cried or *still y-rowned.\"*                    *quietly whispered*\n"
  "Thus saw I false and sooth, compouned,*                      *compounded\n"
  "Together fly for one tiding.\n"
  "Then out at holes gan to wring*                       *squeeze, struggle\n"
  "Every tiding straight to Fame;\n"
  "And she gan give to each his name\n"
  "After her disposition,\n"
  "And gave them eke duration,\n"
  "Some to wax and wane soon,\n"
  "As doth the faire white moon;\n"
  "And let them go. There might I see\n"
  "Winged wonders full fast flee,\n"
  "Twenty thousand in a rout,*                                     *company\n"
  "As Aeolus them blew about.\n"
  "And, Lord! this House in alle times\n"
  "Was full of shipmen and pilgrimes, <85>\n"
  "With *scrippes bretfull of leasings,*    *wallets brimful of falsehoods*\n"
  "Entremedled with tidings*                                  *true stories\n"
  "And eke alone by themselve.\n"
  "And many thousand times twelve\n"
  "Saw I eke of these pardoners,<86>\n"
  "Couriers, and eke messengers,\n"
  "With boistes* crammed full of lies                                *boxes\n"
  "As ever vessel was with lyes.*                             *lees of wine\n"
  "And as I altherfaste* went                               *with all speed\n"
  "About, and did all mine intent\n"
  "Me *for to play and for to lear,*         *to amuse and instruct myself*\n"
  "And eke a tiding for to hear\n"
  "That I had heard of some country,\n"
  "That shall not now be told for me; --\n"
  "For it no need is, readily;\n"
  "Folk can sing it better than I.\n"
  "For all must out, or late or rath,*                                *soon\n"
  "All the sheaves in the lath;*                                 *barn <87>\n"
  "I heard a greate noise withal\n"
  "In a corner of the hall,\n"
  "Where men of love tidings told;\n"
  "And I gan thitherward behold,\n"
  "For I saw running ev'ry wight\n"
  "As fast as that they hadde might,\n"
  "And ev'reach cried, \"What thing is that?\"\n"
  "And some said, \"I know never what.\"\n"
  "And when they were all on a heap,\n"
  "Those behinde gan up leap,\n"
  "And clomb* upon each other fast, <88>                           *climbed\n"
  "And up the noise on high they cast,\n"
  "And trodden fast on others' heels,\n"
  "And stamp'd, as men do after eels.\n"
  "\n"
  "But at the last I saw a man,\n"
  "Which that I not describe can;\n"
  "But that he seemed for to be\n"
  "A man of great authority.\n"
  "And therewith I anon abraid*                                      *awoke\n"
  "Out of my sleepe, half afraid;\n"
  "Rememb'ring well what I had seen,\n"
  "And how high and far I had been\n"
  "In my ghost; and had great wonder\n"
  "Of what the mighty god of thunder\n"
  "Had let me know; and gan to write\n"
  "Like as ye have me heard endite.\n"
  "Wherefore to study and read alway\n"
  "I purpose to do day by day.\n"
  "And thus, in dreaming and in game,\n"
  "Endeth this little book of Fame.\n"
  "\n"
  "Here endeth the Book of Fame\n"
  "\n"
  "\n"
  "Notes to The House of Fame\n"
  "\n"
  "\n"
  "1. Rood: the cross on which Christ was crucified; Anglo-Saxon,\n"
  "\"Rode.\"\n"
  "\n"
  "2. Well worth of this thing greate clerks: Great scholars set\n"
  "much worth upon this thing --  that is, devote much labour,\n"
  "attach much importance, to the subject of dreams.\n"
  "\n"
  "3. The poet briefly refers to the description of the House of\n"
  "Somnus, in Ovid's \"Metamorphoses,\" 1. xi. 592, et seqq.; where\n"
  "the cave of Somnus is said to be \"prope Cimmerios,\" (\"near the\n"
  "Cimmerians\") and \"Saxo tamen exit ab imo Rivus aquae\n"
  "Lethes.\" (\"A stream of Lethe's water issues from the base of the\n"
  "rock\")\n"
  "\n"
  "4. See the account of the vision of Croesus in The Monk's Tale.\n"
  "\n"
  "5. The meaning of the allusion is not clear; but the story of the\n"
  "pilgrims and the peas is perhaps suggested by the line following\n"
  "-- \"to make lithe [soft] what erst was hard.\" St Leonard was the\n"
  "patron of captives.\n"
  "\n"
  "5. Corsaint:  The \"corpus sanctum\" -- the holy body, or relics,\n"
  "preserved in the shrine.\n"
  "\n"
  "7. So, in the Temple of Venus described in The Knight's Tale,\n"
  "the Goddess is represented as \"naked floating in the large sea\".\n"
  "\n"
  "8. Vulcano: Vulcan, the husband of Venus.\n"
  "\n"
  "9. Ered: ploughed; Latin, \"arare,\" Anglo-Saxon, \"erean,\"\n"
  "plough.\n"
  "\n"
  "10. Sours: Soaring ascent; a hawk was said to be \"on the soar\"\n"
  "when he mounted, \"on the sours\" or \"souse\" when he\n"
  "descended on the prey, and took it in flight.\n"
  "\n"
  "11. This is only one among many instances in which Chaucer\n"
  "disclaims the pursuits of love; and the description of his manner\n"
  "of life which follows is sufficient to show that the disclaimer\n"
  "was no mere mock-humble affectation of a gallant.\n"
  "\n"
  "12. This reference, approximately fixing the date at which the\n"
  "poem was composed, points clearly to Chaucer's daily work as\n"
  "Comptroller of the Customs -- a post which he held from 1374\n"
  "to 1386.\n"
  "\n"
  "13. This is a frank enough admission that the poet was fond of\n"
  "good cheer; and the effect of his \"little abstinence\" on his\n"
  "corporeal appearance is humorously described in the Prologue\n"
  "to the Tale of Sir Thopas, where the Host compliments Chaucer\n"
  "on being as well shapen in the waist as himself.\n"
  "\n"
  "14. \"To make the beard\" means to befool or deceive. See note\n"
  "15 to the Reeve's Tale. Precisely the same idea is conveyed in\n"
  "the modern slang word \"shave\" -- meaning a trick or fraud.\n"
  "\n"
  "15. Love-days: see note 21 to the Prologue to the Canterbury\n"
  "Tales.\n"
  "\n"
  "16. If this reference is to any book of Chaucer's in which the\n"
  "House of Fame was mentioned, the book has not come down to\n"
  "us. It has been reasonably supposed, however, that Chaucer\n"
  "means by \"his own book\" Ovid's \"Metamorphoses,\" of which he\n"
  "was evidently very fond; and in the twelfth book of that poem\n"
  "the Temple of Fame is described.\n"
  "\n"
  "17. Saint Julian was the patron of hospitality; so the Franklin, in\n"
  "the Prologue to The Canterbury Tales is said to be \"Saint Julian\n"
  "in his country,\" for his open house and liberal cheer. The eagle,\n"
  "at sight of the House of Fame, cries out \"bon hostel!\" -- \"a fair\n"
  "lodging, a glorious house, by St Julian!\"\n"
  "\n"
  "18. The laurel-tree is sacred to Apollo.  See note 11 to The\n"
  "Assembly of Fowls.\n"
  "\n"
  "19. French, \"roche,\" a rock.\n"
  "\n"
  "20. St. Thomas of Kent:  Thomas a Beckett, whose shrine was\n"
  "at Canterbury.\n"
  "\n"
  "21. The half or side of the rock which was towards the poet,\n"
  "was inscribed with, etc.\n"
  "\n"
  "22. Cop: summit; German, \"kopf\"; the head.\n"
  "\n"
  "23. Gestiours:  tellers of stories; reciters of brave feats or\n"
  "\"gests.\"\n"
  "\n"
  "24. Arion: the celebrated Greek bard and citharist, who, in the\n"
  "seventh century before Christ, lived at the court of Periander,\n"
  "tyrant of Corinth. The story of his preservation by the dolphin,\n"
  "when the covetous sailors forced him to leap into the sea, is\n"
  "well known.\n"
  "\n"
  "25. Chiron the Centaur was renowned for skill in music and the\n"
  "arts, which he owed to the teaching of Apollo and Artemis. He\n"
  "became in turn the instructor of Peleus, Achilles, and other\n"
  "descendants of Aeacus; hence he is called \"Aeacides\" -- because\n"
  "tutor to the Aeacides, and thus, so to speak, of that \"family.\"\n"
  "\n"
  "26. Glasgerion is the subject of a ballad given in \"Percy's\n"
  "Reliques,\" where we are told that\n"
  "\"Glasgerion was a king's own son,\n"
  " And a harper he was good;\n"
  " He harped in the king's chamber,\n"
  " Where cup and candle stood.\"\n"
  "\n"
  "27. Cornemuse: bagpipe; French, \"cornemuse.\" Shawmies:\n"
  "shalms or psalteries; an instrument resembling a harp.\n"
  "\n"
  "28. Dulcet: a kind of pipe, probably corresponding with the\n"
  "\"dulcimer;\" the idea of sweet -- French, \"doux;\" Latin, \"dulcis\"\n"
  "-- is at the root of both words.\n"
  "\n"
  "29. In the early printed editions of Chaucer, the two names are\n"
  "\"Citherus\" and \"Proserus;\" in the manuscript which Mr Bell\n"
  "followed (No. 16 in the Fairfax collection) they are \"Atileris\"\n"
  "and \"Pseustis.\" But neither alternative gives more than the\n"
  "slightest clue to identification. \"Citherus\" has been retained in\n"
  "the text; it may have been employed as an appellative of Apollo,\n"
  "derived from \"cithara,\" the instrument on which he played; and\n"
  "it is not easy to suggest a better substitute for it than \"Clonas\" -\n"
  "- an early Greek poet and musician who flourished six hundred\n"
  "years before Christ. For \"Proserus,\" however, has been\n"
  "substituted \"Pronomus,\" the name of a celebrated Grecian\n"
  "player on the pipe, who taught Alcibiades the flute, and who\n"
  "therefore, although Theban by birth, might naturally be said by\n"
  "the poet to be \"of Athens.\"\n"
  "\n"
  "30. Marsyas: The Phrygian, who, having found the flute of\n"
  "Athena, which played of itself most exquisite music, challenged\n"
  "Apollo to a contest, the victor in which was to do with the\n"
  "vanquished as he pleased. Marsyas was beaten, and Apollo\n"
  "flayed him alive.\n"
  "\n"
  "31. The German (Deutsche) language, in Chaucer's time, had\n"
  "not undergone that marked literary division into German and\n"
  "Dutch which was largely accomplished through the influence of\n"
  "the works of Luther and the other Reformers. Even now, the\n"
  "flute is the favourite musical instrument of the Fatherland; and\n"
  "the devotion of the Germans to poetry and music has been\n"
  "celebrated since the days of Tacitus.\n"
  "\n"
  "32. Reyes: a kind of dance, or song to be accompanied with\n"
  "dancing.\n"
  "\n"
  "33. Beam: horn, trumpet; Anglo-Saxon, \"bema.\"\n"
  "\n"
  "34. Messenus: Misenus, son of Aeolus, the companion and\n"
  "trumpeter of Aeneas, was drowned near the Campanian\n"
  "headland called Misenum after his name. (Aeneid, vi. 162 et\n"
  "seqq.)\n"
  "\n"
  "35. Joab's fame as a trumpeter is founded on two verses in 2\n"
  "Samuel (ii. 28, xx. 22), where we are told that he \"blew a\n"
  "trumpet,\" which all the people of Israel obeyed, in the one case\n"
  "desisting from a pursuit, in the other raising a siege.\n"
  "\n"
  "36. Theodamas or Thiodamas, king of the Dryopes, plays a\n"
  "prominent part in the tenth book of Statius' \"Thebaid.\" Both he\n"
  "and Joab are also mentioned as great trumpeters in The\n"
  "Merchant's Tale.\n"
  "\n"
  "37. Jongelours: jugglers; French, \"jongleur.\"\n"
  "\n"
  "38. Tregetours: tricksters, jugglers. For explanation of this\n"
  "word, see note 14 to the Franklin's tale.\n"
  "\n"
  "39. Pythonesses:  women who, like the Pythia in Apollo's\n"
  "temple at Delphi, were possessed with a spirit of divination or\n"
  "prophecy. The barbarous Latin form of the word was\n"
  "\"Pythonissa\" or \"Phitonissa.\" See note 9 to the Friar's Tale.\n"
  "\n"
  "40. Subfumigations:  a ceremony employed to drive away evil\n"
  "spirits by burning incense; the practice of smoking cattle, corn,\n"
  "&c., has not died out in some country districts.\n"
  "\n"
  "41. In certain ascendents: under certain planetary influences.\n"
  "The next lines recall the alleged malpractices of witches, who\n"
  "tortured little images of wax, in the design of causing the same\n"
  "torments to the person represented -- or, vice versa, treated\n"
  "these images for the cure of hurts or sickness.\n"
  "\n"
  "42. Medea: celebrated for her magical power, through which\n"
  "she restored to youth Aeson, the father of Jason; and caused the\n"
  "death of Jason's wife, Creusa, by sending her a poisoned\n"
  "garment which consumed her to ashes.\n"
  "\n"
  "43. Circes: the sorceress Circe, who changed the companions of\n"
  "Ulysses into swine.\n"
  "\n"
  "44. Calypsa: Calypso, on whose island of Ogygia Ulysses was\n"
  "wrecked. The goddess promised the hero immortality if he\n"
  "remained with her; but he refused, and, after a detention of\n"
  "seven years, she had to let him go.\n"
  "\n"
  "45. Hermes Ballenus: this is supposed to mean Hermes\n"
  "Trismegistus (of whom see note 19 to the Canon's Yeoman's\n"
  "Tale); but the explanation of the word \"Ballenus\" is not quite\n"
  "obvious. The god Hermes of the Greeks (Mercurius of the\n"
  "Romans) had the surname \"Cyllenius,\" from the mountain\n"
  "where he was born -- Mount Cyllene, in Arcadia; and the\n"
  "alteration into \"Ballenus\" would be quite within the range of a\n"
  "copyist's capabilities, while we find in the mythological\n"
  "character of Hermes enough to warrant his being classed with\n"
  "jugglers and magicians.\n"
  "\n"
  "46. Limote and Colle Tregetour seem to have been famous\n"
  "sorcerers or jugglers, but nothing is now known of either.\n"
  "\n"
  "47. Simon Magus: of whom we read in Acts viii. 9, et seqq.\n"
  "\n"
  "48. \"And made well more than it was\n"
  "     To seemen ev'rything, y-wis,\n"
  "     As kindly thing of Fame it is;\"\n"
  "i.e. It is in the nature of fame to exaggerate everything.\n"
  "\n"
  "49. Corbets: the corbels, or capitals of pillars in a Gothic\n"
  "building; they were often carved with fantastic figures and\n"
  "devices.\n"
  "\n"
  "50. A largess!: the cry with which heralds and pursuivants at a\n"
  "tournament acknowledged the gifts or largesses of the knights\n"
  "whose achievements they celebrated.\n"
  "\n"
  "51. Nobles: gold coins of exceptional fineness. Sterlings:\n"
  "sterling coins; not \"luxemburgs\", but stamped and authorised\n"
  "money. See note 9 to the Miller's Tale and note 6 to the\n"
  "Prologue to the Monk's tale.\n"
  "\n"
  "52. Coat-armure: the sleeveless coat or \"tabard,\" on which the\n"
  "arms of the wearer or his lord were emblazoned.\n"
  "\n"
  "53. \"But for to prove in alle wise\n"
  "     As fine as ducat of Venise\"\n"
  "i.e. In whatever way it might be proved or tested, it would be\n"
  "found as fine as a Venetian ducat.\n"
  "\n"
  "54. Lapidaire: a treatise on precious stones.\n"
  "\n"
  "55. See imperial: a seat placed on the dais, or elevated portion\n"
  "of the hall at the upper end, where the lord and the honoured\n"
  "guests sat.\n"
  "\n"
  "56. The starres seven: Septentrion; the Great Bear or Northern\n"
  "Wain, which in this country appears to be at the top of heaven.\n"
  "\n"
  "57. The Apocalypse: The last book of the New Testament, also\n"
  "called Revelations. The four beasts are in chapter iv. 6.\n"
  "\n"
  "58. \"Oundy\" is the French \"ondoye,\" from \"ondoyer,\" to\n"
  "undulate or wave.\n"
  "\n"
  "59. Partridges' wings: denoting swiftness.\n"
  "\n"
  "60. Hercules lost his life with the poisoned shirt of Nessus, sent\n"
  "to him by the jealous Dejanira.\n"
  "\n"
  "61. Of the secte Saturnine: Of the Saturnine school; so called\n"
  "because his history of the Jewish wars narrated many horrors,\n"
  "cruelties, and sufferings, over which Saturn was the presiding\n"
  "deity. See note 71 to the Knight's tale.\n"
  "\n"
  "62. Compare the account of the \"bodies seven\" given by the\n"
  "Canon's Yeoman:\n"
  "\"Sol gold is, and Luna silver we threpe;\n"
  " Mars iron, Mercury quicksilver we clepe;\n"
  " Saturnus lead, and Jupiter is tin,\n"
  " And Venus copper, by my father's kin.\"\n"
  "\n"
  "63. Statius is called a \"Tholosan,\" because by some, among\n"
  "them Dante, he was believed to have been a native of Tolosa,\n"
  "now Toulouse. He wrote the \"Thebais,\" in twelve books, and\n"
  "the \"Achilleis,\" of which only two were finished.\n"
  "\n"
  "64. Dares Phrygius and Dictys Cretensis were the names\n"
  "attached to histories of the Trojan War pretended to have been\n"
  "written immediately after the fall of Troy.\n"
  "\n"
  "65. Lollius:  The unrecognisable author whom Chaucer\n"
  "professes to follow in his \"Troilus and Cressida,\" and who has\n"
  "been thought to mean Boccaccio.\n"
  "\n"
  "66. Guido de Colonna, or de Colempnis, was a native of\n"
  "Messina, who lived about the end of the thirteenth century, and\n"
  "wrote in Latin prose a history including the war of Troy.\n"
  "\n"
  "67. English Gaufrid: Geoffrey of Monmouth, who drew from\n"
  "Troy the original of the British race. See Spenser's \"Faerie\n"
  "Queen,\" book ii. canto x.\n"
  "\n"
  "68. Lucan, in his \"Pharsalia,\" a poem in ten books, recounted\n"
  "the incidents of the war between Caesar and Pompey.\n"
  "\n"
  "69. Claudian of Alexandria, \"the most modern of the ancient\n"
  "poets,\" lived some three centuries after Christ, and among other\n"
  "works wrote three books on \"The Rape of Proserpine.\"\n"
  "\n"
  "70. Triton was a son of Poseidon or Neptune, and represented\n"
  "usually as blowing a trumpet made of a conch or shell; he is\n"
  "therefore introduced by Chaucer as the squire of Aeolus.\n"
  "\n"
  "71. Sky: cloud; Anglo-Saxon, \"scua;\" Greek, \"skia.\"\n"
  "\n"
  "72. Los: reputation. See note 5 to Chaucer's Tale of Meliboeus.\n"
  "\n"
  "73. Swart: black; German, \"schwarz.\"\n"
  "\n"
  "74. Tewell: the pipe, chimney, of the furnace; French \"tuyau.\"\n"
  "In the Prologue to The Canterbury Tales, the Monk's head is\n"
  "described as steaming like a lead furnace.\n"
  "\n"
  "75. Tetches: blemishes, spots; French, \"tache.\"\n"
  "\n"
  "76. For the story of Belle Isaude see note 21 to the Assembly of\n"
  "Fowls.\n"
  "\n"
  "77. Quern:  mill. See note 6 to the Monk's Tale.\n"
  "\n"
  "78. To put an ape into one's hood, upon his head, is to befool\n"
  "him; see the prologue  to the Prioresses's Tale, l.6.\n"
  "\n"
  "79. Obviously Chaucer should have said the temple of Diana, or\n"
  "Artemis (to whom, as Goddess of the Moon, the Egyptian Isis\n"
  "corresponded), at Ephesus. The building, famous for its\n"
  "splendour, was set on fire, in B.C. 356, by Erostatus, merely\n"
  "that he might perpetuate his name.\n"
  "\n"
  "80. \"Now do our los be blowen swithe,\n"
  "     As wisly be thou ever blithe.\" i.e.\n"
  "Cause our renown to be blown abroad quickly, as surely as you\n"
  "wish to be glad.\n"
  "\n"
  "81. The Labyrinth at Cnossus in Crete, constructed by Dedalus\n"
  "for the safe keeping of the Minotaur, the fruit of Pasiphae's\n"
  "unnatural love.\n"
  "\n"
  "82. The river Oise, an affluent of the Seine, in France.\n"
  "\n"
  "83. The engine:  The machines for casting stones, which in\n"
  "Chaucer time served the purpose of great artillery; they were\n"
  "called \"mangonells,\" \"springolds,\" &c.; and resembled in\n"
  "construction the \"ballistae\" and \"catapultae\" of the ancients.\n"
  "\n"
  "84. Or it a furlong way was old:  before it was older than the\n"
  "space of time during which one might walk a furlong; a measure\n"
  "of time often employed by Chaucer.\n"
  "\n"
  "85. Shipmen and pilgrimes: sailors and pilgrims, who seem to\n"
  "have in Chaucer's time amply warranted the proverbial\n"
  "imputation against \"travellers' tales.\"\n"
  "\n"
  "86. Pardoners: of whom Chaucer, in the Prologue to The\n"
  "Canterbury Tales, has given us no flattering typical portrait\n"
  "\n"
  "87. Lath: barn; still used in Lincolnshire and some parts of the\n"
  "north. The meaning is, that the poet need not tell what tidings\n"
  "he wanted to hear, since everything of the kind must some day\n"
  "come out -- as sooner or later every sheaf in the barn must be\n"
  "brought forth (to be threshed).\n"
  "\n"
  "88. A somewhat similar heaping-up of people is de scribed in\n"
  "Spenser's account of the procession of Lucifera (\"The Faerie\n"
  "Queen,\" book i. canto iv.), where, as the royal dame passes to\n"
  "her coach,\n"
  "\"The heaps of people, thronging in the hall,\n"
  " Do ride each other, upon her to gaze.\"\n"
  "\n"
  "\n"
  "\n"
  "";
// }

const char poemTroilusAndCressida0[] PGMSECTION = // { // 31184 bytes
  "TROILUS AND CRESSIDA.\n"
  "\n"
  "\n"
  "[In several respects, the story of \"Troilus and Cressida\" may be\n"
  "regarded as Chaucer's noblest poem. Larger in scale than any\n"
  "other of his individual works -- numbering nearly half as many\n"
  "lines as The Canterbury Tales contain, without reckoning the\n"
  "two in prose -- the conception of the poem is yet so closely and\n"
  "harmoniously worked out, that all the parts are perfectly\n"
  "balanced, and from first to last scarcely a single line is\n"
  "superfluous or misplaced. The finish and beauty of the poem as\n"
  "a work of art, are not more conspicuous than the knowledge of\n"
  "human nature displayed in the portraits of the principal\n"
  "characters. The result is, that the poem is more modern, in form\n"
  "and in spirit, than almost any other work of its author; the\n"
  "chaste style and sedulous polish of the stanzas admit of easy\n"
  "change into the forms of speech now current in England; while\n"
  "the analytical and subjective character of the work gives it, for\n"
  "the nineteenth century reader, an interest of the same kind as\n"
  "that inspired, say, by George Eliot's wonderful study of\n"
  "character in \"Romola.\" Then, above all, \"Troilus and Cressida\"\n"
  "is distinguished by a purity and elevation of moral tone, that\n"
  "may surprise those who judge of Chaucer only by the coarse\n"
  "traits of his time preserved in The Canterbury Tales, or who\n"
  "may expect to find here the Troilus, the Cressida, and the\n"
  "Pandarus of Shakspeare's play. It is to no trivial gallant, no\n"
  "woman of coarse mind and easy virtue, no malignantly\n"
  "subservient and utterly debased procurer, that Chaucer\n"
  "introduces us. His Troilus is a noble, sensitive, generous, pure-\n"
  "souled, manly, magnanimous hero, who is only confirmed and\n"
  "stimulated in all virtue by his love, who lives for his lady, and\n"
  "dies for her falsehood, in a lofty and chivalrous fashion. His\n"
  "Cressida is a stately, self-contained, virtuous, tender-hearted\n"
  "woman, who loves with all the pure strength and trustful\n"
  "abandonment of a generous and exalted nature, and who is\n"
  "driven to infidelity perhaps even less by pressure of\n"
  "circumstances, than by the sheer force of her love, which will go\n"
  "on loving -- loving what it can have, when that which it would\n"
  "rather have is for the time unattainable. His Pandarus is a\n"
  "gentleman, though a gentleman with a flaw in him; a man who,\n"
  "in his courtier-like good-nature, places the claims of\n"
  "comradeship above those of honour, and plots away the virtue\n"
  "of his niece, that he may appease the love-sorrow of his friend;\n"
  "all the time conscious that he is not acting as a gentleman\n"
  "should, and desirous that others should give him that\n"
  "justification which he can get but feebly and diffidently in\n"
  "himself. In fact, the \"Troilus and Cressida\" of Chaucer is the\n"
  "\"Troilus and Cressida\" of Shakespeare transfigured; the\n"
  "atmosphere, the colour, the spirit, are wholly different; the older\n"
  "poet presents us in the chief characters to noble natures, the\n"
  "younger to ignoble natures in all the characters; and the poem\n"
  "with which we have now to do stands at this day among the\n"
  "noblest expositions of love's workings in the human heart and\n"
  "life. It is divided into five books, containing altogether 8246\n"
  "lines. The First Book (1092 lines) tells how Calchas, priest of\n"
  "Apollo, quitting beleaguered Troy, left there his only daughter\n"
  "Cressida; how Troilus, the youngest brother of Hector and son\n"
  "of King Priam, fell in love with her at first sight, at a festival in\n"
  "the temple of Pallas, and sorrowed bitterly for her love; and\n"
  "how his friend, Cressida's uncle, Pandarus, comforted him by\n"
  "the promise of aid in his suit. The Second Book (1757 lines)\n"
  "relates the subtle manoeuvres of Pandarus to induce Cressida to\n"
  "return the love of Troilus; which he accomplishes mainly by\n"
  "touching at once the lady's admiration for his heroism, and her\n"
  "pity for his love-sorrow on her account. The Third Book (1827\n"
  "lines) opens with an account of the first interview between the\n"
  "lovers; ere it closes, the skilful stratagems of Pandarus have\n"
  "placed the pair in each other's arms under his roof, and the\n"
  "lovers are happy in perfect enjoyment of each other's love and\n"
  "trust. In the Fourth Book (1701 lines) the course of true love\n"
  "ceases to run smooth; Cressida is compelled to quit the city, in\n"
  "ransom for Antenor, captured in a skirmish; and she sadly\n"
  "departs to the camp of the Greeks, vowing that she will make\n"
  "her escape, and return to Troy and Troilus within ten days. The\n"
  "Fifth Book (1869 lines) sets out by describing the court which\n"
  "Diomedes, appointed to escort her, pays to Cressida on the way\n"
  "to the camp; it traces her gradual progress from indifference to\n"
  "her new suitor, to incontinence with him, and it leaves the\n"
  "deserted Troilus dead on the field of battle, where he has sought\n"
  "an eternal refuge from the new grief provoked by clear proof of\n"
  "his mistress's infidelity. The polish, elegance, and power of the\n"
  "style, and the acuteness of insight into character, which mark\n"
  "the poem, seem to claim for it a date considerably later than that\n"
  "adopted by those who assign its composition to Chaucer's\n"
  "youth: and the literary allusions and proverbial expressions with\n"
  "which it abounds, give ample evidence that, if Chaucer really\n"
  "wrote it at an early age, his youth must have been precocious\n"
  "beyond all actual record. Throughout the poem there are\n"
  "repeated references to the old authors of Trojan histories who\n"
  "are named in \"The House of Fame\"; but Chaucer especially\n"
  "mentions one Lollius as the author from whom he takes the\n"
  "groundwork of the poem. Lydgate is responsible for the\n"
  "assertion that Lollius meant Boccaccio; and though there is no\n"
  "authority for supposing that the English really meant to\n"
  "designate the Italian poet under that name, there is abundant\n"
  "internal proof that the poem was really founded on the\n"
  "\"Filostrato\" of Boccaccio. But the tone of Chaucer's work is\n"
  "much higher than that of his Italian \"auctour;\" and while in\n"
  "some passages the imitation is very close, in all that is\n"
  "characteristic in \"Troilus and Cressida,\" Chaucer has fairly\n"
  "thrust his models out of sight. In the present edition, it has been\n"
  "possible to give no more than about one-fourth of the poem --\n"
  "274 out of the 1178 seven-line stanzas that compose it; but\n"
  "pains have been taken to convey, in the connecting prose\n"
  "passages, a faithful idea of what is perforce omitted.]\n"
  "\n"
  "\n"
  "THE FIRST BOOK.\n"
  "\n"
  "\n"
  "THE double sorrow <1> of Troilus to tell,\n"
  "That was the King Priamus' son of Troy,\n"
  "In loving how his adventures* fell                             *fortunes\n"
  "From woe to weal, and after* out of joy,                     *afterwards\n"
  "My purpose is, ere I you parte froy.*                              *from\n"
  "Tisiphone,<2> thou help me to indite\n"
  "These woeful words, that weep as I do write.\n"
  "\n"
  "To thee I call, thou goddess of torment!\n"
  "Thou cruel wight, that sorrowest ever in pain;\n"
  "Help me, that am the sorry instrument\n"
  "That helpeth lovers, as I can, to plain.*                      *complain\n"
  "For well it sits,* the soothe for to sayn,                       *befits\n"
  "Unto a woeful wight a dreary fere,*                           *companion\n"
  "And to a sorry tale a sorry cheer.*                         *countenance\n"
  "\n"
  "For I, that God of Love's servants serve,\n"
  "Nor dare to love for mine unlikeliness,* <3>             *unsuitableness\n"
  "Praye for speed,* although I shoulde sterve,**            *success **die\n"
  "So far I am from his help in darkness;\n"
  "But natheless, might I do yet gladness\n"
  "To any lover, or any love avail,*                               *advance\n"
  "Have thou the thank, and mine be the travail.\n"
  "\n"
  "But ye lovers that bathen in gladness,\n"
  "If any drop of pity in you be,\n"
  "Remember you for old past heaviness,\n"
  "For Godde's love, and on adversity\n"
  "That others suffer; think how sometime ye\n"
  "Founde how Love durste you displease;\n"
  "Or elles ye have won it with great ease.\n"
  "\n"
  "And pray for them that been in the case\n"
  "Of Troilus, as ye may after hear,\n"
  "That Love them bring in heaven to solace;*             *delight, comfort\n"
  "And for me pray also, that God so dear\n"
  "May give me might to show, in some mannere,\n"
  "Such pain or woe as Love's folk endure,\n"
  "In Troilus' *unseely adventure*                        *unhappy fortune*\n"
  "\n"
  "And pray for them that eke be despair'd\n"
  "In love, that never will recover'd be;\n"
  "And eke for them that falsely be appair'd*                    *slandered\n"
  "Through wicked tongues, be it he or she:\n"
  "Or thus bid* God, for his benignity,                               *pray\n"
  "To grant them soon out of this world to pace,*                 *pass, go\n"
  "That be despaired of their love's grace.\n"
  "\n"
  "And bid also for them that be at ease\n"
  "In love, that God them grant perseverance,\n"
  "And send them might their loves so to please,\n"
  "That it to them be *worship and pleasance;*        *honour and pleasure*\n"
  "For so hope I my soul best to advance,\n"
  "To pray for them that Love's servants be,\n"
  "And write their woe, and live in charity;\n"
  "\n"
  "And for to have of them compassion,\n"
  "As though I were their owen brother dear.\n"
  "Now listen all with good entention,*                          *attention\n"
  "For I will now go straight to my mattere,\n"
  "In which ye shall the double sorrow hear\n"
  "Of Troilus, in loving of Cresside,\n"
  "And how that she forsook him ere she died.\n"
  "\n"
  "In Troy, during the siege, dwelt \"a lord of great authority, a\n"
  "great divine,\" named Calchas; who, through the oracle of\n"
  "Apollo, knew that Troy should be destroyed. He stole away\n"
  "secretly to the Greek camp, where he was gladly received, and\n"
  "honoured for his skill in divining, of which the besiegers hoped\n"
  "to make use. Within the city there was great anger at the\n"
  "treason of Calchas; and the people declared that he and all his\n"
  "kin were worthy to be burnt. His daughter, whom he had left in\n"
  "the city, a widow and alone, was in great fear for her life.\n"
  "\n"
  "Cressida was this lady's name aright;\n"
  "*As to my doom,* in alle Troy city                      *in my judgment*\n"
  "So fair was none, for over ev'ry wight\n"
  "So angelic was her native beauty,\n"
  "That like a thing immortal seemed she,\n"
  "As sooth a perfect heav'nly creature,\n"
  "That down seem'd sent in scorning of Nature.\n"
  "\n"
  "In her distress, \"well nigh out of her wit for pure fear,\" she\n"
  "appealed for protection to Hector; who, \"piteous of nature,\"\n"
  "and touched by her sorrow and her beauty, assured her of\n"
  "safety, so long as she pleased to dwell in Troy. The siege went\n"
  "on; but they of Troy did not neglect the honour and worship of\n"
  "their deities; most of all of \"the relic hight Palladion, <4> that\n"
  "was their trust aboven ev'ry one.\" In April, \"when clothed is the\n"
  "mead with newe green, of jolly Ver [Spring] the prime,\" the\n"
  "Trojans went to hold the festival of Palladion --  crowding to\n"
  "the temple, \"in all their beste guise,\" lusty knights, fresh ladies,\n"
  "and maidens bright.\n"
  "\n"
  "Among the which was this Cresseida,\n"
  "In widow's habit black; but natheless,\n"
  "Right as our firste letter is now A,\n"
  "In beauty first so stood she makeless;*                       *matchless\n"
  "Her goodly looking gladded all the press;*                        *crowd\n"
  "Was never seen thing to be praised derre,*          *dearer, more worthy\n"
  "Nor under blacke cloud so bright a sterre,*                        *star\n"
  "\n"
  "As she was, as they saiden, ev'ry one\n"
  "That her behelden in her blacke weed;*                          *garment\n"
  "And yet she stood, full low and still, alone,\n"
  "Behind all other folk, *in little brede,*              *inconspicuously*\n"
  "And nigh the door, ay *under shame's drede;*        *for dread of shame*\n"
  "Simple of bearing, debonair* of cheer,                         *gracious\n"
  "With a full sure* looking and mannere.                          *assured\n"
  "\n"
  "Dan Troilus, as he was wont to guide\n"
  "His younge knightes, led them up and down\n"
  "In that large temple upon ev'ry side,\n"
  "Beholding ay the ladies of the town;\n"
  "Now here, now there, for no devotioun\n"
  "Had he to none, to *reave him* his rest,                *deprive him of*\n"
  "But gan to *praise and lacke whom him lest;*       *praise and disparage\n"
  "                                                        whom he pleased*\n"
  "And in his walk full fast he gan to wait*                *watch, observe\n"
  "If knight or squier of his company\n"
  "Gan for to sigh, or let his eyen bait*                             *feed\n"
  "On any woman that he could espy;\n"
  "Then he would smile, and hold it a folly,\n"
  "And say him thus: \"Ah, Lord, she sleepeth soft\n"
  "For love of thee, when as thou turnest oft.\n"
  "\n"
  "\"I have heard told, pardie, of your living,\n"
  "Ye lovers, and your lewed* observance,                *ignorant, foolish\n"
  "And what a labour folk have in winning\n"
  "Of love, and in it keeping with doubtance;*                       *doubt\n"
  "And when your prey is lost, woe and penance;*                 *suffering\n"
  "Oh, very fooles! may ye no thing see?\n"
  "Can none of you aware by other be?\"\n"
  "\n"
  "But the God of Love vowed vengeance on Troilus for that\n"
  "despite, and, showing that his bow was not broken, \"hit him at\n"
  "the full.\"\n"
  "\n"
  "Within the temple went he forth playing,\n"
  "This Troilus, with ev'ry wight about,\n"
  "On this lady and now on that looking,\n"
  "Whether she were of town, or *of without;*       *from beyond the walls*\n"
  "And *upon cas* befell, that through the rout*         *by chance* *crowd\n"
  "His eye pierced, and so deep it went,\n"
  "Till on Cresside it smote, and there it stent;*                  *stayed\n"
  "\n"
  "And suddenly wax'd wonder sore astoned,*                         *amazed\n"
  "And gan her bet* behold in busy wise:                            *better\n"
  "\"Oh, very god!\" <5> thought he; \"where hast thou woned*           *dwelt\n"
  "That art so fair and goodly to devise?*                        *describe\n"
  "Therewith his heart began to spread and rise;\n"
  "And soft he sighed, lest men might him hear,\n"
  "And caught again his former *playing cheer.*         *jesting demeanour*\n"
  "\n"
  "*She was not with the least of her stature,*              *she was tall*\n"
  "But all her limbes so well answering\n"
  "Were to womanhood, that creature\n"
  "Was never lesse mannish in seeming.\n"
  "And eke *the pure wise of her moving*                   *by very the way\n"
  "She showed well, that men might in her guess                  she moved*\n"
  "Honour, estate,* and womanly nobless.                           *dignity\n"
  "\n"
  "Then Troilus right wonder well withal\n"
  "Began to like her moving and her cheer,*                    *countenance\n"
  "Which somedeal dainous* was, for she let fall                *disdainful\n"
  "Her look a little aside, in such mannere\n"
  "Ascaunce* \"What! may I not stande here?\"               *as if to say <6>\n"
  "And after that *her looking gan she light,*       *her expression became\n"
  "That never thought him see so good a sight.               more pleasant*\n"
  "\n"
  "And of her look in him there gan to quicken\n"
  "So great desire, and strong affection,\n"
  "That in his hearte's bottom gan to sticken\n"
  "Of her the fix'd and deep impression;\n"
  "And though he erst* had pored** up and down,        *previously **looked\n"
  "Then was he glad his hornes in to shrink;\n"
  "Unnethes* wist he how to look or wink.                         *scarcely\n"
  "\n"
  "Lo! he that held himselfe so cunning,\n"
  "And scorned them that Love's paines drien,*                      *suffer\n"
  "Was full unware that love had his dwelling\n"
  "Within the subtile streames* of her eyen;                 *rays, glances\n"
  "That suddenly he thought he felte dien,\n"
  "Right with her look, the spirit in his heart;\n"
  "Blessed be Love, that thus can folk convert!\n"
  "\n"
  "She thus, in black, looking to Troilus,\n"
  "Over all things he stoode to behold;\n"
  "But his desire, nor wherefore he stood thus,\n"
  "He neither *cheere made,* nor worde told;    *showed by his countenance*\n"
  "But from afar, *his manner for to hold,*       *to observe due courtesy*\n"
  "On other things sometimes his look he cast,\n"
  "And eft* <7> on her, while that the service last.**      *again **lasted\n"
  "\n"
  "And after this, not fully all awhaped,*                         *daunted\n"
  "Out of the temple all easily be went,\n"
  "Repenting him that ever he had japed*                            *jested\n"
  "Of Love's folk, lest fully the descent\n"
  "Of scorn fell on himself; but what he meant,\n"
  "Lest it were wist on any manner side,\n"
  "His woe he gan dissemble and eke hide.\n"
  "\n"
  "Returning to his palace, he begins hypocritically to smile and\n"
  "jest at Love's servants and their pains; but by and by he has to\n"
  "dismiss his attendants, feigning \"other busy needs.\" Then, alone\n"
  "in his chamber, he begins to groan and sigh, and call up again\n"
  "Cressida's form as he saw her in the temple -- \"making a mirror\n"
  "of his mind, in which he saw all wholly her figure.\" He thinks no\n"
  "travail or sorrow too high a price for the love of such a goodly\n"
  "woman; and, \"full unadvised of his woe coming,\"\n"
  "\n"
  "Thus took he purpose Love's craft to sue,*                       *follow\n"
  "And thought that he would work all privily,\n"
  "First for to hide his desire all *in mew*           *in a cage, secretly\n"
  "From every wight y-born, all utterly,\n"
  "*But he might aught recover'd be thereby;*      *unless he gained by it*\n"
  "Rememb'ring him, that love *too wide y-blow*        *too much spoken of*\n"
  "Yields bitter fruit, although sweet seed be sow.\n"
  "\n"
  "And, over all this, muche more he thought\n"
  "What thing to speak, and what to holden in;\n"
  "And what to arten* her to love, he sought;                *constrain <8>\n"
  "And on a song anon right to begin,\n"
  "And gan loud on his sorrow for to win;*                        *overcome\n"
  "For with good hope he gan thus to assent*                       *resolve\n"
  "Cressida for to love, and not repent.\n"
  "\n"
  "The Song of Troilus. <9>\n"
  "\n"
  "\"If no love is, O God! why feel I so?\n"
  "And if love is, what thing and which is he?\n"
  "If love be good, from whence cometh my woe?\n"
  "If it be wick', a wonder thinketh me\n"
  "Whence ev'ry torment and adversity\n"
  "That comes of love *may to me savoury think:*    *seem acceptable to me*\n"
  "For more I thirst the more that I drink.\n"
  "\n"
  "\"And if I *at mine owen luste bren*                *burn by my own will*\n"
  "From whence cometh my wailing and my plaint?\n"
  "If maugre me,<10> *whereto plain I* then?	*to what avail do I complain?*\n"
  "I wot ner* why, unweary, that I faint.                          *neither\n"
  "O quicke death! O sweete harm so quaint!*                       *strange\n"
  "How may I see in me such quantity,\n"
  "But if that I consent that so it be?\n"
  "\n"
  "\"And if that I consent, I wrongfully\n"
  "Complain y-wis: thus pushed to and fro,\n"
  "All starreless within a boat am I,\n"
  "Middes the sea, betwixte windes two,\n"
  "That in contrary standen evermo'.\n"
  "Alas! what wonder is this malady! --\n"
  "For heat of cold, for cold of heat, I die!\"\n"
  "\n"
  "Devoting himself wholly to the thought of Cressida -- though he\n"
  "yet knew not whether she was woman or goddess -- Troilus, in\n"
  "spite of his royal blood, became the very slave of love. He set at\n"
  "naught every other charge, but to gaze on her as often as he\n"
  "could; thinking so to appease his hot fire, which thereby only\n"
  "burned the hotter. He wrought marvellous feats of arms against\n"
  "the Greeks, that she might like him the better for his renown;\n"
  "then love deprived him of sleep, and made his food his foe; till\n"
  "he had to \"borrow a title of other sickness,\" that men might not\n"
  "know he was consumed with love. Meantime, Cressida gave no\n"
  "sign that she heeded his devotion, or even knew of it; and he\n"
  "was now consumed with a new fear -- lest she loved some other\n"
  "man. Bewailing his sad lot -- ensnared, exposed to the scorn of\n"
  "those whose love he had ridiculed, wishing himself arrived at\n"
  "the port of death, and praying ever that his lady might glad him\n"
  "with some kind look -- Troilus is surprised in his chamber by his\n"
  "friend Pandarus, the uncle of Cressida. Pandarus, seeking to\n"
  "divert his sorrow by making him angry, jeeringly asks whether\n"
  "remorse of conscience, or devotion, or fear of the Greeks, has\n"
  "caused all this ado. Troilus pitifully beseeches his friend to leave\n"
  "him to die alone, for die he must, from a cause which he must\n"
  "keep hidden; but Pandarus argues against Troilus' cruelty in\n"
  "hiding from a friend such a sorrow, and Troilus at last confesses\n"
  "that his malady is love. Pandarus suggests that the beloved\n"
  "object may be such that his counsel might advance his friend's\n"
  "desires; but Troilus scouts the suggestion, saying that Pandarus\n"
  "could never govern himself in love.\n"
  "\n"
  "\"Yea, Troilus, hearken to me,\" quoth Pandare,\n"
  "\"Though I be nice;* it happens often so,                        *foolish\n"
  "That one that access* doth full evil fare,        *in an access of fever\n"
  "By good counsel can keep his friend therefro'.\n"
  "I have my selfe seen a blind man go\n"
  "Where as he fell that looke could full wide;\n"
  "A fool may eke a wise man often guide.\n"
  "\n"
  "\"A whetstone is no carving instrument,\n"
  "But yet it maketh sharpe carving tooles;\n"
  "And, if thou know'st that I have aught miswent,*          *erred, failed\n"
  "Eschew thou that, for such thing to thee school* is.  *schooling, lesson\n"
  "Thus oughte wise men to beware by fooles;\n"
  "If so thou do, thy wit is well bewared;\n"
  "By its contrary is everything declared.\n"
  "\n"
  "\"For how might ever sweetness have been know\n"
  "To him that never tasted bitterness?\n"
  "And no man knows what gladness is, I trow,\n"
  "That never was in sorrow or distress:\n"
  "Eke white by black, by shame eke worthiness,\n"
  "Each set by other, *more for other seemeth,*        *its quality is made\n"
  "As men may see; and so the wise man deemeth.\"            more obvious by\n"
  "                                                           the contrast*\n"
  "Troilus, however, still begs his friend to leave him to mourn in\n"
  "peace, for all his proverbs can avail nothing. But Pandarus\n"
  "insists on plying the lover with wise saws, arguments,\n"
  "reproaches; hints that, if he should die of love, his lady may\n"
  "impute his death to fear of the Greeks; and finally induces\n"
  "Troilus to admit that the well of all his woe, his sweetest foe, is\n"
  "called Cressida. Pandarus breaks into praises of the lady, and\n"
  "congratulations of his friend for so well fixing his heart; he\n"
  "makes Troilus utter a formal confession of his sin in jesting at\n"
  "lovers and bids him think well that she of whom rises all his\n"
  "woe, hereafter may his comfort be also.\n"
  "\n"
  "\"For thilke* ground, that bears the weedes wick'              *that same\n"
  "Bears eke the wholesome herbes, and full oft\n"
  "Next to the foule nettle, rough and thick,\n"
  "The lily waxeth,* white, and smooth, and soft;                    *grows\n"
  "And next the valley is the hill aloft,\n"
  "And next the darke night is the glad morrow,\n"
  "And also joy is next the fine* of sorrow.\"                  *end, border\n"
  "\n"
  "Pandarus holds out to Troilus good hope of achieving his\n"
  "desire; and tells him that, since he has been converted from his\n"
  "wicked rebellion against Love, he shall be made the best post of\n"
  "all Love's law, and most grieve Love's enemies. Troilus gives\n"
  "utterance to a hint of fear; but he is silenced by Pandarus with\n"
  "another proverb --  \"Thou hast full great care, lest that the carl\n"
  "should fall out of the moon.\" Then the lovesick youth breaks\n"
  "into a joyous boast that some of the Greeks shall smart; he\n"
  "mounts his horse, and plays the lion in the field; while Pandarus\n"
  "retires to consider how he may best recommend to his niece the\n"
  "suit of Troilus.\n"
  "\n"
  "\n"
  "THE SECOND BOOK.\n"
  "\n"
  "\n"
  "IN the Proem to the Second Book, the poet hails the clear\n"
  "weather that enables him to sail out of those black waves in\n"
  "which his boat so laboured that he could scarcely steer -- that is,\n"
  "\"the tempestuous matter of despair, that Troilus was in; but\n"
  "now of hope the kalendes begin.\" He invokes the aid of Clio;\n"
  "excuses himself to every lover for what may be found amiss in a\n"
  "book which he only translates; and, obviating any lover's\n"
  "objection to the way in which Troilus obtained his lady's grace -\n"
  "- through Pandarus' mediation -- says it seems to him no\n"
  "wonderful thing:\n"
  "\n"
  "\"For ev'ry wighte that to Rome went\n"
  "Held not one path, nor alway one mannere;\n"
  "Eke in some lands were all the game y-shent\n"
  "If that men far'd in love as men do here,\n"
  "As thus, in open dealing and in cheer,\n"
  "In visiting, in form, or saying their saws;*                   *speeches\n"
  "For thus men say: Each country hath its laws.\n"
  "\n"
  "\"Eke scarcely be there in this place three\n"
  "That have in love done or said *like in all;\"*   *alike in all respects*\n"
  "\n"
  "And so that which the poem relates may not please the reader --\n"
  "but it actually was done, or it shall yet be done. The Book sets\n"
  "out with the visit of Pandarus to Cressida:--\n"
  "\n"
  "In May, that mother is of monthes glade,*                          *glad\n"
  "When all the freshe flowers, green and red,\n"
  "Be quick* again, that winter deade made,                          *alive\n"
  "And full of balm is floating ev'ry mead;\n"
  "When Phoebus doth his brighte beames spread\n"
  "Right in the white Bull, so it betid*                          *happened\n"
  "As I shall sing, on Maye's day the thrid, <11>\n"
  "\n"
  "That Pandarus, for all his wise speech,\n"
  "Felt eke his part of Love's shottes keen,\n"
  "That, could he ne'er so well of Love preach,\n"
  "It made yet his hue all day full green;*                           *pale\n"
  "So *shope it,* that him fell that day a teen*      *it happened* *access\n"
  "In love, for which full woe to bed he went,\n"
  "And made ere it were day full many a went.*                *turning <12>\n"
  "\n"
  "The swallow Progne, <13> with a sorrowful lay,\n"
  "When morrow came, gan make her waimenting,*                   *lamenting\n"
  "Why she foshapen* was; and ever lay                         *transformed\n"
  "Pandare a-bed, half in a slumbering,\n"
  "Till she so nigh him made her chittering,\n"
  "How Tereus gan forth her sister take,\n"
  "That with the noise of her he did awake,\n"
  "\n"
  "And gan to call, and dress* him to arise,                       *prepare\n"
  "Rememb'ring him his errand was to do'n\n"
  "From Troilus, and eke his great emprise;\n"
  "And cast, and knew in *good plight* was the Moon     *favourable aspect*\n"
  "To do voyage, and took his way full soon\n"
  "Unto his niece's palace there beside\n"
  "Now Janus, god of entry, thou him guide!\n"
  "\n"
  "Pandarus finds his niece, with two other ladies, in a paved\n"
  "parlour, listening to a maiden who reads aloud the story of the\n"
  "Siege of Thebes. Greeting the company, he is welcomed by\n"
  "Cressida, who tells him that for three nights she has dreamed of\n"
  "him. After some lively talk about the book they had been\n"
  "reading, Pandarus asks his niece to do away her hood, to show\n"
  "her face bare, to lay aside the book, to rise up and dance, \"and\n"
  "let us do to May some observance.\" Cressida cries out, \"God\n"
  "forbid!\" and asks if he is mad -- if that is a widow's life, whom it\n"
  "better becomes to sit in a cave and read of holy saints' lives.\n"
  "Pandarus intimates that he could tell her something which could\n"
  "make her merry; but he refuses to gratify her curiosity; and, by\n"
  "way of the siege and of Hector, \"that was the towne's wall, and\n"
  "Greekes' yerd\" or scourging-rod, the conversation is brought\n"
  "round to Troilus, whom Pandarus highly extols as \"the wise\n"
  "worthy Hector the second.\" She has, she says, already heard\n"
  "Troilus praised for his bravery \"of them that her were liefest\n"
  "praised be\" [by whom it would be most welcome to her to be\n"
  "praised].\n"
  "\n"
  "\"Ye say right sooth, y-wis,\" quoth Pandarus;\n"
  "For yesterday, who so had with him been,\n"
  "Might have wonder'd upon Troilus;\n"
  "For never yet so thick a swarm of been*                            *bees\n"
  "Ne flew, as did of Greekes from him flee'n;\n"
  "And through the field, in ev'ry wighte's ear,\n"
  "There was no cry but 'Troilus is here.'\n"
  "\n"
  "\"Now here, now there, he hunted them so fast,\n"
  "There was but Greekes' blood; and Troilus\n"
  "Now him he hurt, now him adown he cast;\n"
  "Ay where he went it was arrayed thus:\n"
  "He was their death, and shield of life for us,\n"
  "That as that day there durst him none withstand,\n"
  "While that he held his bloody sword in hand.\"\n"
  "\n"
  "Pandarus makes now a show of taking leave, but Cressida\n"
  "detains him, to speak of her affairs; then, the business talked\n"
  "over, he would again go, but first again asks his niece to arise\n"
  "and dance, and cast her widow's garments to mischance,\n"
  "because of the glad fortune that has befallen her. More curious\n"
  "than ever, she seeks to find out Pandarus' secret; but he still\n"
  "parries her curiosity, skilfully hinting all the time at her good\n"
  "fortune, and the wisdom of seizing on it when offered. In the\n"
  "end he tells her that the noble Troilus so loves her, that with her\n"
  "it lies to make him live or die -- but if Troilus dies, Pandarus\n"
  "shall die with him; and then she will have \"fished fair.\" <14> He\n"
  "beseeches mercy for his friend:\n"
  "\n"
  "\"*Woe worth* the faire gemme virtueless! <15>             *evil befall!*\n"
  "Woe worth the herb also that *doth no boot!*     *has no remedial power*\n"
  "Woe worth the beauty that is rutheless!*                      *merciless\n"
  "Woe worth that wight that treads each under foot!\n"
  "And ye that be of beauty *crop and root*                *perfection <16>\n"
  "If therewithal in you there be no ruth,*                           *pity\n"
  "Then is it harm ye live, by my truth!\"\n"
  "\n"
  "Pandarus makes only the slight request that she will show\n"
  "Troilus somewhat better cheer, and receive visits from him, that\n"
  "his life may be saved; urging that, although a man be soon going\n"
  "to the temple, nobody will think that he eats the images; and\n"
  "that \"such love of friends reigneth in all this town.\"\n"
  "\n"
  "Cressida, which that heard him in this wise,\n"
  "Thought: \"I shall feele* what he means, y-wis;\"                    *test\n"
  "\"Now, eme* quoth she, \"what would ye me devise?                   *uncle\n"
  "What is your rede* that I should do of this?\"          *counsel, opinion\n"
  "\"That is well said,\" quoth he;\" certain best it is\n"
  "That ye him love again for his loving,\n"
  "As love for love is *skilful guerdoning.*        *reasonable recompense*\n"
  "\n"
  "\"Think eke how elde* wasteth ev'ry hour                             *age\n"
  "In each of you a part of your beauty;\n"
  "And therefore, ere that age do you devour,\n"
  "Go love, for, old, there will no wight love thee\n"
  "Let this proverb a lore* unto you be:                            *lesson\n"
  "'\"Too late I was ware,\" quoth beauty when it past;\n"
  "And *elde daunteth danger* at the last.'     *old age overcomes disdain*\n"
  "\n"
  "\"The kinge's fool is wont to cry aloud,\n"
  "When that he thinks a woman bears her high,\n"
  "'So longe may ye liven, and all proud,\n"
  "Till crowes' feet be wox* under your eye!                         *grown\n"
  "And send you then a mirror *in to pry*                      *to look in*\n"
  "In which ye may your face see a-morrow!*                 *in the morning\n"
  "*I keep then wishe you no more sorrow.'\"*            *I care to wish you\n"
  "                                                          nothing worse*\n"
  "Weeping, Cressida reproaches her uncle for giving her such\n"
  "counsel; whereupon Pandarus, starting up, threatens to kill\n"
  "himself, and would fain depart, but that his niece detains him,\n"
  "and, with much reluctance, promises to \"make Troilus good\n"
  "cheer in honour.\" Invited by Cressida to tell how first he know\n"
  "her lover's woe, Pandarus then relates two soliloquies which he\n"
  "had accidentally overheard, and in which Troilus had poured\n"
  "out all the sorrow of his passion.\n"
  "\n"
  "With this he took his leave, and home he went\n"
  "Ah! Lord, so was he glad and well-begone!*                        *happy\n"
  "Cresside arose, no longer would she stent,*                        *stay\n"
  "But straight into her chamber went anon,\n"
  "And sat her down, as still as any stone,\n"
  "And ev'ry word gan up and down to wind\n"
  "That he had said, as it came to her mind.\n"
  "\n"
  "And wax'd somedeal astonish'd in her thought,\n"
  "Right for the newe case; but when that she\n"
  "*Was full advised,* then she found right naught   *had fully considered*\n"
  "Of peril, why she should afeared be:\n"
  "For a man may love, of possibility,\n"
  "A woman so, that his heart may to-brest,*                 *break utterly\n"
  "And she not love again, *but if her lest.*     *unless it so please her*\n"
  "\n"
  "";
// }

const char poemTroilusAndCressida1[] PGMSECTION = // { // 31261 bytes
  "But as she sat alone, and thoughte thus,\n"
  "In field arose a skirmish all without;\n"
  "And men cried in the street then:\"\n"
  "Troilus hath right now put to flight the Greekes' rout.\"*          *host\n"
  "With that gan all the meinie* for to shout:      *(Cressida's) household\n"
  "\"Ah! go we see, cast up the lattice wide,\n"
  "For through this street he must to palace ride;\n"
  "\n"
  "\"For other way is from the gates none,\n"
  "Of Dardanus,<18> where open is the chain.\" <19>\n"
  "With that came he, and all his folk anon,\n"
  "An easy pace riding, in *routes twain,*                     *two troops*\n"
  "Right as his *happy day* was, sooth to sayn:         *good fortune <20>*\n"
  "For which men say may not disturbed be\n"
  "What shall betiden* of necessity.                                *happen\n"
  "\n"
  "This Troilus sat upon his bay steed\n"
  "All armed, save his head, full richely,\n"
  "And wounded was his horse, and gan to bleed,\n"
  "For which he rode a pace full softely\n"
  "But such a knightly sighte* truly                                *aspect\n"
  "As was on him, was not, withoute fail,\n"
  "To look on Mars, that god is of Battaile.\n"
  "\n"
  "So like a man of armes, and a knight,\n"
  "He was to see, full fill'd of high prowess;\n"
  "For both he had a body, and a might\n"
  "To do that thing, as well as hardiness;*                        *courage\n"
  "And eke to see him in his gear* him dress,                       *armour\n"
  "So fresh, so young, so wieldy* seemed he,                        *active\n"
  "It was a heaven on him for to see.*                                *look\n"
  "\n"
  "His helmet was to-hewn in twenty places,\n"
  "That by a tissue* hung his back behind;                          *riband\n"
  "His shield to-dashed was with swords and maces,\n"
  "In which men might many an arrow find,\n"
  "That thirled* had both horn, and nerve, and rind; <21>          *pierced\n"
  "And ay the people cried, \"Here comes our joy,\n"
  "And, next his brother, <22> holder up of Troy.\"\n"
  "\n"
  "For which he wax'd a little red for shame,\n"
  "When he so heard the people on him cryen\n"
  "That to behold it was a noble game,\n"
  "How soberly he cast adown his eyen:\n"
  "Cresside anon gan all his cheer espien,\n"
  "And let it in her heart so softly sink,\n"
  "That to herself she said, \"Who gives me drink?\"<23>\n"
  "\n"
  "For of her owen thought she wax'd all red,\n"
  "Rememb'ring her right thus: \"Lo! this is he\n"
  "Which that mine uncle swears he might be dead,\n"
  "But* I on him have mercy and pity:\"                              *unless\n"
  "And with that thought for pure shame she\n"
  "Gan in her head to pull, and that full fast,\n"
  "While he and all the people forth by pass'd.\n"
  "\n"
  "And gan to cast,* and rollen up and down                         *ponder\n"
  "Within her thought his excellent prowess,\n"
  "And his estate, and also his renown,\n"
  "His wit, his shape, and eke his gentleness\n"
  "But most her favour was, for his distress\n"
  "Was all for her, and thought it were ruth\n"
  "To slay such one, if that he meant but truth.\n"
  "\n"
  ".    .    .    .    .    .    .    .    .    .\n"
  "\n"
  "And, Lord! so gan she in her heart argue\n"
  "Of this mattere, of which I have you told\n"
  "And what to do best were, and what t'eschew,\n"
  "That plaited she full oft in many a fold.<24>\n"
  "Now was her hearte warm, now was it cold.\n"
  "And what she thought of, somewhat shall I write,\n"
  "As to mine author listeth to endite.\n"
  "\n"
  "She thoughte first, that Troilus' person\n"
  "She knew by sight, and eke his gentleness;\n"
  "And saide thus: *\"All were it not to do'n,'*           *although it were\n"
  "To grant him love, yet for the worthiness                    impossible*\n"
  "It were honour, with play* and with gladness,    *pleasing entertainment\n"
  "In honesty with such a lord to deal,\n"
  "For mine estate,* and also for his heal.**          *reputation **health\n"
  "\n"
  "\"Eke well I wot* my kinge's son is he;                             *know\n"
  "And, since he hath to see me such delight,\n"
  "If I would utterly his sighte flee,\n"
  "Parauntre* he might have me in despite,                    *peradventure\n"
  "Through which I mighte stand in worse plight. <25>\n"
  "Now were I fool, me hate to purchase*                 *obtain for myself\n"
  "Withoute need, where I may stand in grace,*                      *favour\n"
  "\n"
  "\"In ev'rything, I wot, there lies measure;*              *a happy medium\n"
  "For though a man forbidde drunkenness,\n"
  "He not forbids that ev'ry creature\n"
  "Be drinkeless for alway, as I guess;\n"
  "Eke, since I know for me is his distress,\n"
  "I oughte not for that thing him despise,\n"
  "Since it is so he meaneth in good wise.\n"
  "\n"
  "\"Now set a case, that hardest is, y-wis,\n"
  "Men mighte deeme* that he loveth me;                            *believe\n"
  "What dishonour were it unto me, this?\n"
  "May I *him let of* that? Why, nay, pardie!            *prevent him from*\n"
  "I know also, and alway hear and see,\n"
  "Men love women all this town about;\n"
  "Be they the worse? Why, nay, withoute doubt!\n"
  "\n"
  "\"Nor me to love a wonder is it not;\n"
  "For well wot I myself, so God me speed! --\n"
  "*All would I* that no man wist of this thought --     *although I would*\n"
  "I am one of the fairest, without drede,*                          *doubt\n"
  "And goodlieste, who so taketh heed;\n"
  "And so men say in all the town of Troy;\n"
  "What wonder is, though he on me have joy?\n"
  "\n"
  "\"I am mine owen woman, well at ease,\n"
  "I thank it God, as after mine estate,\n"
  "Right young, and stand untied in *lusty leas,*           *pleasant leash\n"
  "Withoute jealousy, or such debate:                            (of love)*\n"
  "Shall none husband say to me checkmate;\n"
  "For either they be full of jealousy,\n"
  "Or masterful, or love novelty.\n"
  "\n"
  "\"What shall I do? to what fine* live I thus?                        *end\n"
  "Shall I not love, in case if that me lest?\n"
  "What? pardie! I am not religious;<26>\n"
  "And though that I mine hearte set at rest\n"
  "And keep alway mine honour and my name,\n"
  "By all right I may do to me no shame.\"\n"
  "\n"
  "But right as when the sunne shineth bright\n"
  "In March, that changeth oftentime his face,\n"
  "And that a cloud is put with wind to flight,\n"
  "Which overspreads the sun as for a space;\n"
  "A cloudy thought gan through her hearte pace,*                     *pass\n"
  "That overspread her brighte thoughtes all,\n"
  "So that for fear almost she gan to fall.\n"
  "\n"
  "The cloudy thought is of the loss of liberty and security, the\n"
  "stormy life, and the malice of wicked tongues, that love entails:\n"
  "\n"
  "[But] after that her thought began to clear,\n"
  "And saide, \"He that nothing undertakes\n"
  "Nothing achieveth, be him *loth or dear.\"*       *unwilling or desirous*\n"
  "And with another thought her hearte quakes;\n"
  "Then sleepeth hope, and after dread awakes,\n"
  "Now hot, now cold; but thus betwixt the tway*                       *two\n"
  "She rist* her up, and wente forth to play.**     *rose **take recreation\n"
  "\n"
  "Adown the stair anon right then she went\n"
  "Into a garden, with her nieces three,\n"
  "And up and down they made many a went,*              *winding, turn <12>\n"
  "Flexippe and she, Tarke, Antigone,\n"
  "To playe, that it joy was for to see;\n"
  "And other of her women, a great rout,*                            *troop\n"
  "Her follow'd in the garden all about.\n"
  "\n"
  "This yard was large, and railed the alleys,\n"
  "And shadow'd well with blossomy boughes green,\n"
  "And benched new, and sanded all the ways,\n"
  "In which she walked arm and arm between;\n"
  "Till at the last Antigone the sheen*                     *bright, lovely\n"
  "Gan on a Trojan lay to singe clear,\n"
  "That it a heaven was her voice to hear.\n"
  "\n"
  "Antigone's song is of virtuous love for a noble object; and it is\n"
  "singularly fitted to deepen the impression made on the mind of\n"
  "Cressida by the brave aspect of Troilus, and by her own\n"
  "cogitations. The singer, having praised the lover and rebuked\n"
  "the revilers of love, proceeds:\n"
  "\n"
  "\"What is the Sunne worse of his *kind right,*              *true nature*\n"
  "Though that a man, for feebleness of eyen,\n"
  "May not endure to see on it for bright? <27>\n"
  "Or Love the worse, tho' wretches on it cryen?\n"
  "No weal* is worth, that may no sorrow drien;** <28>  *happiness **endure\n"
  "And forthy,* who that hath a head of verre,**    *therefore **glass <29>\n"
  "From cast of stones ware him in the werre. <30>\n"
  "\n"
  "\"But I, with all my heart and all my might,\n"
  "As I have lov'd, will love unto my last\n"
  "My deare heart, and all my owen knight,\n"
  "In which my heart y-growen is so fast,\n"
  "And his in me, that it shall ever last\n"
  "*All dread I* first to love him begin,               *although I feared*\n"
  "Now wot I well there is no pain therein.\"\n"
  "\n"
  "Cressida sighs, and asks Antigone whether there is such bliss\n"
  "among these lovers, as they can fair endite; Antigone replies\n"
  "confidently in the affirmative; and Cressida answers nothing,\n"
  "\"but every worde which she heard she gan to printen in her\n"
  "hearte fast.\" Night draws on:\n"
  "\n"
  "The daye's honour, and the heaven's eye,\n"
  "The nighte's foe, -- all this call I the Sun, --\n"
  "Gan westren* fast, and downward for to wry,**       *go west <31> **turn\n"
  "As he that had his daye's course y-run;\n"
  "And white thinges gan to waxe dun\n"
  "For lack of light, and starres to appear;\n"
  "Then she and all her folk went home in fere.*                *in company\n"
  "\n"
  "So, when it liked her to go to rest,\n"
  "And voided* were those that voiden ought,       *gone out (of the house)\n"
  "She saide, that to sleepe well her lest.*                       *pleased\n"
  "Her women soon unto her bed her brought;\n"
  "When all was shut, then lay she still and thought\n"
  "Of all these things the manner and the wise;\n"
  "Rehearse it needeth not, for ye be wise.\n"
  "\n"
  "A nightingale upon a cedar green,\n"
  "Under the chamber wall where as she lay,\n"
  "Full loude sang against the moone sheen,\n"
  "Parauntre,* in his birde's wise, a lay                        *perchance\n"
  "Of love, that made her hearte fresh and gay;\n"
  "Hereat hark'd* she so long in good intent,                     *listened\n"
  "Till at the last the deade sleep her hent.*                      *seized\n"
  "\n"
  "And as she slept, anon right then *her mette*              *she dreamed*\n"
  "How that an eagle, feather'd white as bone,\n"
  "Under her breast his longe clawes set,\n"
  "And out her heart he rent, and that anon,\n"
  "And did* his heart into her breast to go'n,                      *caused\n"
  "Of which no thing she was *abash'd nor smert;*         *amazed nor hurt*\n"
  "And forth he flew, with hearte left for heart.\n"
  "\n"
  "Leaving Cressida to sleep, the poet returns to Troilus and his\n"
  "zealous friend -- with whose stratagems to bring the two lovers\n"
  "together the remainder of the Second Book is occupied.\n"
  "Pandarus counsels Troilus to write a letter to his mistress,\n"
  "telling her how he \"fares amiss,\" and \"beseeching her of ruth;\"\n"
  "he will bear the letter to his niece; and, if Troilus will ride past\n"
  "Cressida's house, he will find his mistress and his friend sitting\n"
  "at a window. Saluting Pandarus, and not tarrying, his passage\n"
  "will give occasion for some talk of him, which may make his\n"
  "ears glow. With respect to the letter, Pandarus gives some\n"
  "shrewd hints:\n"
  "\n"
  "\"Touching thy letter, thou art wise enough,\n"
  "I wot thou *n'ilt it dignely endite*       *wilt not write it haughtily*\n"
  "Or make it with these argumentes tough,\n"
  "Nor scrivener-like, nor craftily it write;\n"
  "Beblot it with thy tears also a lite;*                           *little\n"
  "And if thou write a goodly word all soft,\n"
  "Though it be good, rehearse it not too oft.\n"
  "\n"
  "\"For though the beste harper *pon live*                           *alive\n"
  "Would on the best y-sounded jolly harp\n"
  "That ever was, with all his fingers five\n"
  "Touch ay one string, or *ay one warble harp,*     *always play one tune*\n"
  "Were his nailes pointed ne'er so sharp,\n"
  "He shoulde maken ev'ry wight to dull*                     *to grow bored\n"
  "To hear his glee, and of his strokes full.\n"
  "\n"
  "\"Nor jompre* eke no discordant thing y-fere,**        *jumble **together\n"
  "As thus, to use termes of physic;\n"
  "In love's termes hold of thy mattere\n"
  "The form alway, and *do that it be like;*           *make it consistent*\n"
  "For if a painter woulde paint a pike\n"
  "With ass's feet, and head it as an ape,<32>\n"
  "It *'cordeth not,* so were it but a jape.\"           *is not harmonious*\n"
  "\n"
  "Troilus writes the letter, and next morning Pandarus bears it to\n"
  "Cressida. She refuses to receive \"scrip or bill that toucheth such\n"
  "mattere;\" but he thrusts it into her bosom, challenging her to\n"
  "throw it away. She retains it, takes the first opportunity of\n"
  "escaping to her chamber to read it, finds it wholly good, and,\n"
  "under her uncle's dictation, endites a reply telling her lover that\n"
  "she will not make herself bound in love; \"but as his sister, him\n"
  "to please, she would aye fain [be glad] to do his heart an ease.\"\n"
  "Pandarus, under pretext of inquiring who is the owner of the\n"
  "house opposite, has gone to the window; Cressida takes her\n"
  "letter to him there, and tells him that she never did a thing with\n"
  "more pain than write the words to which he had constrained\n"
  "her. As they sit side by side, on a stone of jasper, on a cushion\n"
  "of beaten gold, Troilus rides by, in all his goodliness. Cressida\n"
  "waxes \"as red as rose,\" as she sees him salute humbly, \"with\n"
  "dreadful cheer, and oft his hues mue [change];\" she likes \"all\n"
  "y-fere, his person, his array, his look, his cheer, his goodly\n"
  "manner, and his gentleness;\" so that, however she may have\n"
  "been before, \"to goode hope now hath she caught a thorn, she\n"
  "shall not pull it out this nexte week.\" Pandarus, striking the iron\n"
  "when it is hot, asks his niece to grant Troilus an interview; but\n"
  "she strenuously declines, for fear of scandal, and because it is all\n"
  "too soon to allow him so great a liberty -- her purpose being to\n"
  "love him unknown of all, \"and guerdon [reward] him with\n"
  "nothing but with sight.\" Pandarus has other intentions; and,\n"
  "while Troilus writes daily letters with increasing love, he\n"
  "contrives the means of an interview. Seeking out Deiphobus,\n"
  "the brother of Troilus, he tells him that Cressida is in danger of\n"
  "violence from Polyphete, and asks protection for her.\n"
  "Deiphobus gladly complies, promises the protection of Hector\n"
  "and Helen, and goes to invite Cressida to dinner on the morrow.\n"
  "Meantime Pandarus instructs Troilus to go to the house of\n"
  "Deiphobus, plead an access of his fever for remaining all night,\n"
  "and keep his chamber next day. \"Lo,\" says the crafty promoter\n"
  "of love, borrowing a phrase from the hunting-field; \"Lo, hold\n"
  "thee at thy tristre [tryst <33>] close, and I shall well the deer\n"
  "unto thy bowe drive.\" Unsuspicious of stratagem, Cressida\n"
  "comes to dinner; and at table, Helen, Pandarus, and others,\n"
  "praise the absent Troilus, until \"her heart laughs\" for very pride\n"
  "that she has the love of such a knight. After dinner they speak\n"
  "of Cressida's business; all confirm Deiphobus' assurances of\n"
  "protection and aid; and Pandarus suggests that, since Troilus is\n"
  "there, Cressida shall herself tell him her case. Helen and\n"
  "Deiphobus alone accompany Pandarus to Troilus' chamber;\n"
  "there Troilus produces some documents relating to the public\n"
  "weal, which Hector has sent for his opinion; Helen and\n"
  "Deiphobus, engrossed in perusal and discussion, roam out of\n"
  "the chamber, by a stair, into the garden; while Pandarus goes\n"
  "down to the hall, and, pretending that his brother and Helen are\n"
  "still with Troilus, brings Cressida to her lover. The Second\n"
  "Book leaves Pandarus whispering in his niece's ear counsel to\n"
  "be merciful and kind to her lover, that hath for her such pain;\n"
  "while Troilus lies \"in a kankerdort,\" <34> hearing the\n"
  "whispering without, and wondering what he shall say for this\n"
  "\"was the first time that he should her pray of love; O! mighty\n"
  "God! what shall he say?\"\n"
  "\n"
  "\n"
  "THE THIRD BOOK.\n"
  "\n"
  "\n"
  "To the Third Book is prefixed a beautiful invocation of Venus,\n"
  "under the character of light:\n"
  "\n"
  "O Blissful light, of which the beames clear\n"
  "Adornen all the thirde heaven fair!\n"
  "O Sunne's love, O Jove's daughter dear!\n"
  "Pleasance of love, O goodly debonair,*             *lovely and gracious*\n"
  "In gentle heart ay* ready to repair!**         *always **enter and abide\n"
  "O very* cause of heal** and of gladness,                 *true **welfare\n"
  "Y-heried* be thy might and thy goodness!                        *praised\n"
  "\n"
  "In heav'n and hell, in earth and salte sea.\n"
  "Is felt thy might, if that I well discern;\n"
  "As man, bird, beast, fish, herb, and greene tree,\n"
  "They feel in times, with vapour etern, <35>\n"
  "God loveth, and to love he will not wern                          forbid\n"
  "And in this world no living creature\n"
  "Withoute love is worth, or may endure. <36>\n"
  "\n"
  "Ye Jove first to those effectes glad,\n"
  "Through which that thinges alle live and be,\n"
  "Commended; and him amorous y-made\n"
  "Of mortal thing; and as ye list,* ay ye                         *pleased\n"
  "Gave him, in love, ease* or adversity,                         *pleasure\n"
  "And in a thousand formes down him sent\n"
  "For love in earth; and *whom ye list he hent.*       *he seized whom you\n"
  "                                                                 wished*\n"
  "Ye fierce Mars appeasen of his ire,\n"
  "And as you list ye make heartes dign* <37>                       *worthy\n"
  "Algates* them that ye will set afire,                     *at all events\n"
  "They dreade shame, and vices they resign\n"
  "Ye do* him courteous to be, and benign;                     *make, cause\n"
  "And high or low, after* a wight intendeth,                 *according as\n"
  "The joyes that he hath your might him sendeth.\n"
  "\n"
  "Ye holde realm and house in unity;\n"
  "Ye soothfast* cause of friendship be also;                         *true\n"
  "Ye know all thilke *cover'd quality*                      *secret power*\n"
  "Of thinges which that folk on wonder so,\n"
  "When they may not construe how it may go\n"
  "She loveth him, or why he loveth her,\n"
  "As why this fish, not that, comes to the weir.*<38>           *fish-trap\n"
  "\n"
  "Knowing that Venus has set a law in the universe, that whoso\n"
  "strives with her shall have the worse, the poet prays to be\n"
  "taught to describe some of the joy that is felt in her service; and\n"
  "the Third Book opens with an account of the scene between\n"
  "Troilus and Cressida:\n"
  "\n"
  "Lay all this meane while Troilus\n"
  "Recording* his lesson in this mannere;                       *memorizing\n"
  "*\"My fay!\"* thought he, \"thus will I say, and thus;       *by my faith!*\n"
  "Thus will I plain* unto my lady dear;                    *make my plaint\n"
  "That word is good; and this shall be my cheer\n"
  "This will I not forgetten in no wise;\"\n"
  "God let him worken as he can devise.\n"
  "\n"
  "And, Lord! so as his heart began to quap,*                  *quake, pant\n"
  "Hearing her coming, and *short for to sike;*          *make short sighs*\n"
  "And Pandarus, that led her by the lap,*                           *skirt\n"
  "Came near, and gan in at the curtain pick,*                        *peep\n"
  "And saide: \"God do boot* alle sick!                  *afford a remedy to\n"
  "See who is here you coming to visite;\n"
  "Lo! here is she that is *your death to wite!\"*	*to blame for your death*\n"
  "\n"
  "Therewith it seemed as he wept almost.\n"
  "\"Ah! ah! God help!\" quoth Troilus ruefully;\n"
  "\"Whe'er* me be woe, O mighty God, thou know'st!                 *whether\n"
  "Who is there? for I see not truely.\"\n"
  "\"Sir,\" quoth Cresside, \"it is Pandare and I;\n"
  "\"Yea, sweete heart? alas, I may not rise\n"
  "To kneel and do you honour in some wise.\"\n"
  "\n"
  "And dressed him upward, and she right tho*                         *then\n"
  "Gan both her handes soft upon him lay.\n"
  "\"O! for the love of God, do ye not so\n"
  "To me,\" quoth she; \"ey! what is this to say?\n"
  "For come I am to you for causes tway;*                              *two\n"
  "First you to thank, and of your lordship eke\n"
  "Continuance* I woulde you beseek.\"**               *protection **beseech\n"
  "\n"
  "This Troilus, that heard his lady pray\n"
  "Him of lordship, wax'd neither quick nor dead;\n"
  "Nor might one word for shame to it say, <39>\n"
  "Although men shoulde smiten off his head.\n"
  "But, Lord! how he wax'd suddenly all red!\n"
  "And, Sir, his lesson, that he *ween'd have con,*        *thought he knew\n"
  "To praye her, was through his wit y-run.                       by heart*\n"
  "\n"
  "Cresside all this espied well enow, --\n"
  "For she was wise, -- and lov'd him ne'er the less,\n"
  "All n'ere he malapert, nor made avow,\n"
  "Nor was so bold to sing a foole's mass;<40>\n"
  "But, when his shame began somewhat to pass,\n"
  "His wordes, as I may my rhymes hold,\n"
  "I will you tell, as teache bookes old.\n"
  "\n"
  "In changed voice, right for his very dread,\n"
  "Which voice eke quak'd, and also his mannere\n"
  "Goodly* abash'd, and now his hue is red,                     *becomingly\n"
  "Now pale, unto Cresside, his lady dear,\n"
  "With look downcast, and humble *yielden cheer,*        *submissive face*\n"
  "Lo! *altherfirste word that him astert,*        *the first word he said*\n"
  "Was twice: \"Mercy, mercy, my dear heart!\"\n"
  "\n"
  "And stent* a while; and when he might *out bring,*      *stopped *speak*\n"
  "The nexte was: \"God wote, for I have,\n"
  "*As farforthly as I have conning,*                 *as far as I am able*\n"
  "Been youres all, God so my soule save,\n"
  "And shall, till that I, woeful wight, *be grave;*                  *die*\n"
  "And though I dare not, cannot, to you plain,\n"
  "Y-wis, I suffer not the lesse pain.\n"
  "\n"
  "\"This much as now, O womanlike wife!\n"
  "I may *out bring,* and if it you displease,                  *speak out*\n"
  "That shall I wreak* upon mine owne life,                         *avenge\n"
  "Right soon, I trow, and do your heart an ease,\n"
  "If with my death your heart I may appease:\n"
  "But, since that ye have heard somewhat say,\n"
  "Now reck I never how soon that I dey.\"                              *die\n"
  "\n"
  "Therewith his manly sorrow to behold\n"
  "It might have made a heart of stone to rue;\n"
  "And Pandare wept as he to water wo'ld, <41>\n"
  "And saide, \"Woe-begone* be heartes true,\"              *in woeful plight\n"
  "And procur'd* his niece ever new and new,                         *urged\n"
  "\"For love of Godde, make *of him an end,*          *put him out of pain*\n"
  "Or slay us both at ones, ere we wend.\"*                              *go\n"
  "\n"
  "\"Ey! what?\" quoth she; \"by God and by my truth,\n"
  "I know not what ye woulde that I say;\"\n"
  "\"Ey! what?\" quoth he; \"that ye have on him ruth,*                  *pity\n"
  "For Godde's love, and do him not to dey.\"                           *die\n"
  "\"Now thenne thus,\" quoth she, \"I would him pray\n"
  "To telle me the *fine of his intent;*                *end of his desire*\n"
  "Yet wist* I never well what that he meant.\"                        *knew\n"
  "\n"
  "\"What that I meane, sweete hearte dear?\"\n"
  "Quoth Troilus, \"O goodly, fresh, and free!\n"
  "That, with the streames* of your eyne so clear,          *beams, glances\n"
  "Ye woulde sometimes *on me rue and see,*      *take pity and look on me*\n"
  "And then agreen* that I may be he,                    *take in good part\n"
  "Withoute branch of vice, in any wise,\n"
  "In truth alway to do you my service,\n"
  "\n"
  "\"As to my lady chief, and right resort,\n"
  "With all my wit and all my diligence;\n"
  "And for to have, right as you list, comfort;\n"
  "Under your yerd,* equal to mine offence,              *rod, chastisement\n"
  "As death, if that *I breake your defence;*                  *do what you\n"
  "And that ye deigne me so much honour,                       forbid <42>*\n"
  "Me to commanden aught in any hour.\n"
  "\n"
  "\"And I to be your very humble, true,\n"
  "Secret, and in my paines patient,\n"
  "And evermore desire, freshly new,\n"
  "To serven, and be alike diligent,\n"
  "And, with good heart, all wholly your talent\n"
  "Receive in gree,* how sore that me smart;                      *gladness\n"
  "Lo, this mean I, mine owen sweete heart.\"\n"
  "\n"
  ".    .    .    .    .    .    .    .    .    .\n"
  "\n"
  "With that she gan her eyen on him* cast, <43>                  *Pandarus\n"
  "Full easily and full debonairly,*                            *graciously\n"
  "*Advising her,* and hied* not too fast,             *considering* **went\n"
  "With ne'er a word, but said him softely,\n"
  "\"Mine honour safe, I will well truely,\n"
  "And in such form as ye can now devise,\n"
  "Receive him* fully to my service;                               *Troilus\n"
  "\n"
  "\"Beseeching him, for Godde's love, that he\n"
  "Would, in honour of truth and gentleness,\n"
  "As I well mean, eke meane well to me;\n"
  "And mine honour, with *wit and business,*              *wisdom and zeal*\n"
  "Aye keep; and if I may do him gladness,\n"
  "From henceforth, y-wis I will not feign:\n"
  "Now be all whole, no longer do ye plain.\n"
  "\n"
  "\"But, natheless, this warn I you,\" quoth she,\n"
  "\"A kinge's son although ye be, y-wis,\n"
  "Ye shall no more have sovereignety\n"
  "Of me in love, than right in this case is;\n"
  "Nor will I forbear, if ye do amiss,\n"
  "To wrathe* you, and, while that ye me serve,       *be angry with, chide\n"
  "To cherish you, *right after ye deserve.*               *as you deserve*\n"
  "\n"
  "\"And shortly, deare heart, and all my knight,\n"
  "Be glad, and drawe you to lustiness,*                          *pleasure\n"
  "And I shall truely, with all my might,\n"
  "Your bitter turnen all to sweeteness;\n"
  "If I be she that may do you gladness,\n"
  "For ev'ry woe ye shall recover a bliss:\"\n"
  "And him in armes took, and gan him kiss.\n"
  "\n"
  "Pandarus, almost beside himself for joy, falls on his knees to\n"
  "thank Venus and Cupid, declaring that for this miracle he hears\n"
  "all the bells ring; then, with a warning to be ready at his call to\n"
  "meet at his house, he parts the lovers, and attends Cressida\n"
  "while she takes leave of the household -- Troilus all the time\n"
  "groaning at the deceit practised on his brother and Helen. When\n"
  "he has got rid of them by feigning weariness, Pandarus returns\n"
  "to the chamber, and spends the night with him in converse. The\n"
  "zealous friend begins to speak \"in a sober wise\" to Troilus,\n"
  "reminding him of his love-pains now all at an end.\n"
  "\n"
  "\"So that through me thou standest now in way\n"
  "To fare well; I say it for no boast;\n"
  "And know'st thou why? For, shame it is to say,\n"
  "For thee have I begun a game to play,\n"
  "Which that I never shall do eft* for other,**           *again **another\n"
  "Although he were a thousand fold my brother.\n"
  "\n"
  "\"That is to say, for thee I am become,\n"
  "Betwixte game and earnest, such a mean*               *means, instrument\n"
  "As make women unto men to come;\n"
  "Thou know'st thyselfe what that woulde mean;\n"
  "For thee have I my niece, of vices clean,*                 *pure, devoid\n"
  "So fully made thy gentleness* to trust,              *nobility of nature\n"
  "That all shall be right *as thyselfe lust.*              *as you please*\n"
  "\n"
  "\"But God, that *all wot,* take I to witness,          *knows everything*\n"
  "That never this for covetise* I wrought,                  *greed of gain\n"
  "But only to abridge* thy distress,                                *abate\n"
  "For which well nigh thou diedst, as me thought;\n"
  "But, goode brother, do now as thee ought,\n"
  "For Godde's love, and keep her out of blame;\n"
  "Since thou art wise, so save thou her name.\n"
  "\n"
  "\"For, well thou know'st, the name yet of her,\n"
  "Among the people, as who saith hallow'd is;\n"
  "For that man is unborn, I dare well swear,\n"
  "That ever yet wist* that she did amiss;                            *knew\n"
  "But woe is me, that I, that cause all this,\n"
  "May thinke that she is my niece dear,\n"
  "And I her eme,* and traitor eke y-fere.**          *uncle <17> **as well\n"
  "\n"
  "\"And were it wist that I, through mine engine,*       *arts, contrivance\n"
  "Had in my niece put this fantasy*                                 *fancy\n"
  "To do thy lust,* and wholly to be thine,                       *pleasure\n"
  "Why, all the people would upon it cry,\n"
  "And say, that I the worste treachery\n"
  "Did in this case, that ever was begun,\n"
  "And she fordone,* and thou right naught y-won.\"                  *ruined\n"
  "\n"
  "Therefore, ere going a step further, Pandarus prays Troilus to\n"
  "give him pledges of secrecy, and impresses on his mind the\n"
  "mischiefs that flow from vaunting in affairs of love. \"Of\n"
  "kind,\"[by his very nature] he says, no vaunter is to be believed:\n"
  "\n"
  "\"For a vaunter and a liar all is one;\n"
  "As thus: I pose* a woman granteth me                    *suppose, assume\n"
  "Her love, and saith that other will she none,\n"
  "And I am sworn to holden it secre,\n"
  "And, after, I go tell it two or three;\n"
  "Y-wis, I am a vaunter, at the least,\n"
  "And eke a liar, for I break my hest.*<44>                       *promise\n"
  "\n"
  "\"Now looke then, if they be not to blame,\n"
  "Such manner folk; what shall I call them, what?\n"
  "That them avaunt of women, and by name,\n"
  "That never yet behight* them this nor that,              *promised (much\n"
  "Nor knowe them no more than mine old hat?                  less granted)\n"
  "No wonder is, so God me sende heal,*                         *prosperity\n"
  "Though women dreade with us men to deal!\n"
  "\n"
  "\"I say not this for no mistrust of you,\n"
  "Nor for no wise men, but for fooles nice;*                   *silly <45>\n"
  "And for the harm that in the world is now,\n"
  "As well for folly oft as for malice;\n"
  "For well wot I, that in wise folk that vice\n"
  "No woman dreads, if she be well advised;\n"
  "For wise men be by fooles' harm chastised.\"*      *corrected, instructed\n"
  "\n"
  "So Pandarus begs Troilus to keep silent, promises to be true all\n"
  "his days, and assures him that he shall have all that he will in the\n"
  "love of Cressida: \"thou knowest what thy lady granted thee; and\n"
  "day is set the charters up to make.\"\n"
  "\n"
  "Who mighte telle half the joy and feast\n"
  "Which that the soul of Troilus then felt,\n"
  "Hearing th'effect of Pandarus' behest?\n"
  "His olde woe, that made his hearte swelt,*                   *faint, die\n"
  "Gan then for joy to wasten and to melt,\n"
  "And all the reheating <46> of his sighes sore\n"
  "At ones fled, he felt of them no more.\n"
  "\n"
  "But right so as these *holtes and these hayes,*       *woods and hedges*\n"
  "That have in winter deade been and dry,\n"
  "Reveste them in greene, when that May is,\n"
  "When ev'ry *lusty listeth* best to play;         *pleasant (one) wishes*\n"
  "Right in that selfe wise, sooth to say,\n"
  "Wax'd suddenly his hearte full of joy,\n"
  "That gladder was there never man in Troy.\n"
  "\n"
  "Troilus solemnly swears that never, \"for all the good that God\n"
  "made under sun,\" will he reveal what Pandarus asks him to keep\n"
  "secret; offering to die a thousand times, if need were, and to\n"
  "follow his friend as a slave all his life, in proof of his gratitude.\n"
  "\n"
  "\"But here, with all my heart, I thee beseech,\n"
  "That never in me thou deeme* such folly                           *judge\n"
  "As I shall say; me thoughte, by thy speech,\n"
  "That this which thou me dost for company,*                   *friendship\n"
  "I shoulde ween it were a bawdery;*                      *a bawd's action\n"
  "*I am not wood, all if I lewed be;*                *I am not mad, though\n"
  "It is not one, that wot I well, pardie!                  I be unlearned*\n"
  "\n"
  "\"But he that goes for gold, or for richess,\n"
  "On such messages, call him *as thee lust;*             *what you please*\n"
  "And this that thou dost, call it gentleness,\n"
  "Compassion, and fellowship, and trust;\n"
  "Depart it so, for widewhere is wist\n"
  "How that there is diversity requer'd\n"
  "Betwixte thinges like, as I have lear'd. <47>\n"
  "\n"
  "\"And that thou know I think it not nor ween,*                   *suppose\n"
  "That this service a shame be or a jape,             *subject for jeering\n"
  "I have my faire sister Polyxene,\n"
  "Cassandr', Helene, or any of the frape;*                       *set <48>\n"
  "Be she never so fair, or well y-shape,\n"
  "Telle me which thou wilt of ev'ry one,\n"
  "To have for thine, and let me then alone.\"\n"
  "\n"
  "Then, beseeching Pandarus soon to perform out the great\n"
  "enterprise of crowning his love for Cressida, Troilus bade his\n"
  "friend good night. On the morrow Troilus burned as the fire, for\n"
  "hope and pleasure; yet \"he not forgot his wise governance [self-\n"
  "control];\"\n"
  "\n"
  "But in himself with manhood gan restrain\n"
  "Each rakel* deed, and each unbridled cheer,**          *rash **demeanour\n"
  "That alle those that live, sooth to sayn,\n"
  "Should not have wist,* by word or by mannere,                 *suspicion\n"
  "What that he meant, as touching this mattere;\n"
  "From ev'ry wight as far as is the cloud\n"
  "He was, so well dissimulate he could.\n"
  "\n"
  "And all the while that I now devise*                  *describe, narrate\n"
  "This was his life: with all his fulle might,\n"
  "By day he was in Marte's high service,\n"
  "That is to say, in armes as a knight;\n"
  "And, for the moste part, the longe night\n"
  "He lay, and thought how that he mighte serve\n"
  "His lady best, her thank* for to deserve.                     *gratitude\n"
  "\n"
  "";
// }

const char poemTroilusAndCressida2[] PGMSECTION = // { // 31150 bytes
  "I will not swear, although he laye soft,\n"
  "That in his thought he n'as somewhat diseas'd;*                *troubled\n"
  "Nor that he turned on his pillows oft,\n"
  "And would of that him missed have been seis'd;*               *possessed\n"
  "But in such case men be not alway pleas'd,\n"
  "For aught I wot, no more than was he;\n"
  "That can I deem* of possibility.                                  *judge\n"
  "\n"
  "But certain is, to purpose for to go,\n"
  "That in this while, as written is in gest,*              *the history of\n"
  "He saw his lady sometimes, and also                         these events\n"
  "She with him spake, when that she *durst and lest;*  *dared and pleased*\n"
  "And, by their both advice,* as was the best,               *consultation\n"
  "*Appointed full warily* in this need,        *made careful preparations*\n"
  "So as they durst, how far they would proceed.\n"
  "\n"
  "But it was spoken in *so short a wise,   *so briefly, and always in such\n"
  "In such await alway, and in such fear,       vigilance and fear of being\n"
  "Lest any wight divinen or devise*                   found out by anyone*\n"
  "Would of their speech, or to it lay an ear,\n"
  "*That all this world them not so lefe were,*      *they wanted more than\n"
  "As that Cupido would them grace send              anything in the world*\n"
  "To maken of their speeches right an end.\n"
  "\n"
  "But thilke little that they spake or wrought,\n"
  "His wise ghost* took ay of all such heed,                        *spirit\n"
  "It seemed her he wiste what she thought\n"
  "Withoute word, so that it was no need\n"
  "To bid him aught to do, nor aught forbid;\n"
  "For which she thought that love, all* came it late,            *although\n"
  "Of alle joy had open'd her the gate.\n"
  "\n"
  "Troilus, by his discretion, his secrecy, and his devotion, made\n"
  "ever a deeper lodgment in Cressida's heart; so that she thanked\n"
  "God twenty thousand times that she had met with a man who,\n"
  "as she felt, \"was to her a wall of steel, and shield from ev'ry\n"
  "displeasance;\" while Pandarus ever actively fanned the fire. So\n"
  "passed a \"time sweet\" of tranquil and harmonious love the only\n"
  "drawback being, that the lovers might not often meet, \"nor\n"
  "leisure have, their speeches to fulfil.\" At last Pandarus found an\n"
  "occasion for bringing them together at his house unknown to\n"
  "anybody, and put his plan in execution.\n"
  "\n"
  "For he, with great deliberation,\n"
  "Had ev'ry thing that hereto might avail*                  *be of service\n"
  "Forecast, and put in execution,\n"
  "And neither left for cost nor for travail;*                      *effort\n"
  "Come if them list, them shoulde nothing fail,\n"
  "*Nor for to be in aught espied there,\n"
  "That wiste he an impossible were.*           *he knew it was impossible*\n"
  "                                    that they could be discovered there*\n"
  "And dreadeless* it clear was in the wind                  *without doubt\n"
  "Of ev'ry pie, and every let-game; <49>\n"
  "Now all is well, for all this world is blind,\n"
  "In this mattere, bothe fremd* and tame; <50>                       *wild\n"
  "This timber is all ready for to frame;\n"
  "Us lacketh naught, but that we weete* wo'ld                        *know\n"
  "A certain hour in which we come sho'ld. <51>\n"
  "\n"
  "Troilus had informed his household, that if at any time he was\n"
  "missing, he had gone to worship at a certain temple of Apollo,\n"
  "\"and first to see the holy laurel quake, or that the godde spake\n"
  "out of the tree.\" So, at the changing of the moon, when \"the\n"
  "welkin shope him for to rain,\" [when the sky was preparing to\n"
  "rain] Pandarus went to invite his niece to supper; solemnly\n"
  "assuring her that Troilus was out of the town -- though all the\n"
  "time he was safely shut up, till midnight, in \"a little stew,\"\n"
  "whence through a hole he joyously watched the arrival of his\n"
  "mistress and her fair niece Antigone, with half a score of her\n"
  "women. After supper Pandaras did everything to amuse his\n"
  "niece; \"he sung, he play'd, he told a tale of Wade;\" <52> at last\n"
  "she would take her leave; but\n"
  "\n"
  "The bente Moone with her hornes pale,\n"
  "Saturn, and Jove, in Cancer joined were, <53>\n"
  "That made such a rain from heav'n avail,*                       *descend\n"
  "That ev'ry manner woman that was there\n"
  "Had of this smoky rain <54> a very fear;\n"
  "At which Pandarus laugh'd, and saide then\n"
  "\"Now were it time a lady to go hen!\"*                             *hence\n"
  "\n"
  "He therefore presses Cressida to remain all night; she complies\n"
  "with a good grace; and after the sleeping cup has gone round,\n"
  "all retire to their chambers -- Cressida, that she may not be\n"
  "disturbed by the rain and thunder, being lodged in the \"inner\n"
  "closet\" of Pandarus, who, to lull suspicion, occupies the outer\n"
  "chamber, his niece's women sleeping in the intermediate\n"
  "apartment. When all is quiet, Pandarus liberates Troilus, and by\n"
  "a secret passage brings him to the chamber of Cressida; then,\n"
  "going forward alone to his niece, after calming her fears of\n"
  "discovery, he tells her that her lover has \"through a gutter, by a\n"
  "privy went,\" [a secret passage] come to his house in all this rain,\n"
  "mad with grief because a friend has told him that she loves\n"
  "Horastes. Suddenly cold about her heart, Cressida promises that\n"
  "on the morrow she will reassure her lover; but Pandarus scouts\n"
  "the notion of delay, laughs to scorn her proposal to send her\n"
  "ring in pledge of her truth, and finally, by pitiable accounts of\n"
  "Troilus' grief, induces her to receive him and reassure him at\n"
  "once with her own lips.\n"
  "\n"
  "This Troilus full soon on knees him set,\n"
  "Full soberly, right by her bedde's head,\n"
  "And in his beste wise his lady gret*                            *greeted\n"
  "But Lord! how she wax'd suddenly all red,\n"
  "And thought anon how that she would be dead;\n"
  "She coulde not one word aright out bring,\n"
  "So suddenly for his sudden coming.\n"
  "\n"
  "Cressida, though thinking that her servant and her knight should\n"
  "not have doubted her truth, yet sought to remove his jealousy,\n"
  "and offered to submit to any ordeal or oath he might impose;\n"
  "then, weeping, she covered her face, and lay silent. \"But now,\"\n"
  "exclaims the poet --\n"
  "\n"
  "But now help, God, to quenchen all this sorrow!\n"
  "So hope I that he shall, for he best may;\n"
  "For I have seen, of a full misty morrow,*                          *morn\n"
  "Followen oft a merry summer's day,\n"
  "And after winter cometh greene May;\n"
  "Folk see all day, and eke men read in stories,\n"
  "That after sharpe stoures* be victories.           *conflicts, struggles\n"
  "\n"
  "Believing his mistress to be angry, Troilus felt the cramp of\n"
  "death seize on his heart, \"and down he fell all suddenly in\n"
  "swoon.\" Pandarus \"into bed him cast,\" and called on his niece to\n"
  "pull out the thorn that stuck in his heart, by promising that she\n"
  "would \"all forgive.\" She whispered in his ear the assurance that\n"
  "she was not wroth; and at last, under her caresses, he recovered\n"
  "consciousness, to find her arm laid over him, to hear the\n"
  "assurance of her forgiveness, and receive her frequent kisses.\n"
  "Fresh vows and explanations passed; and Cressida implored\n"
  "forgiveness of \"her own sweet heart,\" for the pain she had\n"
  "caused him. Surprised with sudden bliss, Troilus put all in God's\n"
  "hand, and strained his lady fast in his arms. \"What might or may\n"
  "the seely [innocent] larke say, when that the sperhawk\n"
  "[sparrowhawk] hath him in his foot?\"\n"
  "\n"
  "Cressida, which that felt her thus y-take,\n"
  "As write clerkes in their bookes old,\n"
  "Right as an aspen leaf began to quake,\n"
  "When she him felt her in his armes fold;\n"
  "But Troilus, all *whole of cares cold,*   *cured of painful sorrows*<55>\n"
  "Gan thanke then the blissful goddes seven. <56>\n"
  "Thus sundry paines bringe folk to heaven.\n"
  "\n"
  "This Troilus her gan in armes strain,\n"
  "And said, \"O sweet, as ever may I go'n,*                        *prosper\n"
  "Now be ye caught, now here is but we twain,\n"
  "Now yielde you, for other boot* is none.\"                        *remedy\n"
  "To that Cresside answered thus anon,\n"
  "\"N' had I ere now, my sweete hearte dear,\n"
  "*Been yolden,* y-wis, I were now not here!\"             *yielded myself*\n"
  "\n"
  "O sooth is said, that healed for to be\n"
  "Of a fever, or other great sickness,\n"
  "Men muste drink, as we may often see,\n"
  "Full bitter drink; and for to have gladness\n"
  "Men drinken often pain and great distress!\n"
  "I mean it here, as for this adventure,\n"
  "That thorough pain hath founden all his cure.\n"
  "\n"
  "And now sweetnesse seemeth far more sweet,\n"
  "That bitterness assayed* was beforn;                        *tasted <57>\n"
  "For out of woe in blisse now they fleet,*                   *float, swim\n"
  "None such they felte since that they were born;\n"
  "Now is it better than both two were lorn! <58>\n"
  "For love of God, take ev'ry woman heed\n"
  "To worke thus, if it come to the need!\n"
  "\n"
  "Cresside, all quit from ev'ry dread and teen,*                     *pain\n"
  "As she that juste cause had him to trust,\n"
  "Made him such feast,<59> it joy was for to see'n,\n"
  "When she his truth and *intent cleane wist;*            *knew the purity\n"
  "And as about a tree, with many a twist,                  of his purpose*\n"
  "*Bitrent and writhen* is the sweet woodbind,      *plaited and wreathed*\n"
  "Gan each of them in armes other wind.*                *embrace, encircle\n"
  "\n"
  "And as the *new abashed* nightingale,          *newly-arrived and timid*\n"
  "That stinteth,* first when she beginneth sing,                    *stops\n"
  "When that she heareth any *herde's tale,*    *the talking of a shepherd*\n"
  "Or in the hedges any wight stirring;\n"
  "And, after, sicker* out her voice doth ring;                *confidently\n"
  "Right so Cressida, when *her dreade stent,*           *her doubt ceased*\n"
  "Open'd her heart, and told him her intent.*                        *mind\n"
  "\n"
  "And might as he that sees his death y-shapen,*                 *prepared\n"
  "And dien must, *in aught that he may guess,*       *for all he can tell*\n"
  "And suddenly *rescouse doth him escapen,*    *he is rescued and escapes*\n"
  "And from his death is brought *in sickerness;*               *to safety*\n"
  "For all the world, in such present gladness\n"
  "Was Troilus, and had his lady sweet;\n"
  "With worse hap God let us never meet!\n"
  "\n"
  "Her armes small, her straighte back and soft,\n"
  "Her sides longe, fleshly, smooth, and white,\n"
  "He gan to stroke; and good thrift* bade full oft               *blessing\n"
  "On her snow-white throat, her breastes round and lite;*           *small\n"
  "Thus in this heaven he gan him delight,\n"
  "And therewithal a thousand times her kist,\n"
  "That what to do for joy *unneth he wist.*               *he hardly knew*\n"
  "\n"
  "The lovers exchanged vows, and kisses, and embraces, and\n"
  "speeches of exalted love, and rings; Cressida gave to Troilus a\n"
  "brooch of gold and azure, \"in which a ruby set was like a heart;\"\n"
  "and the too short night passed.\n"
  "\n"
  "\"When that the cock, commune astrologer, <60>\n"
  "Gan on his breast to beat, and after crow,\n"
  "And Lucifer, the daye's messenger,\n"
  "Gan for to rise, and out his beames throw;\n"
  "And eastward rose, to him that could it know,\n"
  "Fortuna Major, <61> then anon Cresseide,\n"
  "With hearte sore, to Troilus thus said:\n"
  "\n"
  "\"My hearte's life, my trust, and my pleasance!\n"
  "That I was born, alas! that me is woe,\n"
  "That day of us must make disseverance!\n"
  "For time it is to rise, and hence to go,\n"
  "Or else I am but lost for evermo'.\n"
  "O Night! alas! why n'ilt thou o'er us hove,*                      *hover\n"
  "As long as when Alcmena lay by Jove? <62>\n"
  "\n"
  "\"O blacke Night! as folk in bookes read\n"
  "That shapen* art by God, this world to hide,                  *appointed\n"
  "At certain times, with thy darke weed,*                            *robe\n"
  "That under it men might in rest abide,\n"
  "Well oughte beastes plain, and folke chide,\n"
  "That where as Day with labour would us brest,*          *burst, overcome\n"
  "There thou right flee'st, and deignest* not us rest.*          *grantest\n"
  "\n"
  "\"Thou dost, alas! so shortly thine office,*                        *duty\n"
  "Thou rakel* Night! that God, maker of kind,                 *rash, hasty\n"
  "Thee for thy haste and thine unkinde vice,\n"
  "So fast ay to our hemisphere bind,\n"
  "That never more under the ground thou wind;*              *turn, revolve\n"
  "For through thy rakel hieing* out of Troy                       *hasting\n"
  "Have I forgone* thus hastily my joy!\"                              *lost\n"
  "\n"
  "This Troilus, that with these wordes felt,\n"
  "As thought him then, for piteous distress,\n"
  "The bloody teares from his hearte melt,\n"
  "As he that never yet such heaviness\n"
  "Assayed had out of so great gladness,\n"
  "Gan therewithal Cresside, his lady dear,\n"
  "In armes strain, and said in this mannere:\n"
  "\n"
  "\"O cruel Day! accuser of the joy\n"
  "That Night and Love have stol'n, and *fast y-wrien!*            *closely\n"
  "Accursed be thy coming into Troy!                             concealed*\n"
  "For ev'ry bow'r* hath one of thy bright eyen:                   *chamber\n"
  "Envious Day! Why list thee to espyen?\n"
  "What hast thou lost? Why seekest thou this place?\n"
  "There God thy light so quenche, for his grace!\n"
  "\n"
  "\"Alas! what have these lovers thee aguilt?*    *offended, sinned against\n"
  "Dispiteous* Day, thine be the pains of hell!            *cruel, spiteful\n"
  "For many a lover hast thou slain, and wilt;\n"
  "Thy peering in will nowhere let them dwell:\n"
  "What! proff'rest thou thy light here for to sell?\n"
  "Go sell it them that smalle seales grave!*               *cut devices on\n"
  "We will thee not, us needs no day to have.\"\n"
  "\n"
  "And eke the Sunne, Titan, gan he chide,\n"
  "And said, \"O fool! well may men thee despise!\n"
  "That hast the Dawning <63> all night thee beside,\n"
  "And suff'rest her so soon up from thee rise,\n"
  "For to disease* us lovers in this wise!                           *annoy\n"
  "What! hold* thy bed, both thou, and eke thy Morrow!                *keep\n"
  "I bidde* God so give you bothe sorrow!\"                            *pray\n"
  "\n"
  "The lovers part with many sighs and protestations of\n"
  "unswerving and undying love; Cressida responding to the vows\n"
  "of Troilus with the assurance --\n"
  "\n"
  "\"That first shall Phoebus* falle from his sphere,               *the sun\n"
  "And heaven's eagle be the dove's fere,\n"
  "And ev'ry rock out of his place start,\n"
  "Ere Troilus out of Cressida's heart.\"\n"
  "\n"
  "When Pandarus visits Troilus in his palace later in the day, he\n"
  "warns him not to mar his bliss by any fault of his own:\n"
  "\n"
  "\"For, of Fortune's sharp adversity,\n"
  "The worste kind of infortune is this,\n"
  "A man to have been in prosperity,\n"
  "And it remember when it passed is.<64>\n"
  "Thou art wise enough; forthy,*\" do not amiss;                 *therefore\n"
  "Be not too rakel,* though thou sitte warm;             *rash, over-hasty\n"
  "For if thou be, certain it will thee harm.\n"
  "\n"
  "\"Thou art at ease, and hold thee well therein;\n"
  "For, all so sure as red is ev'ry fire,\n"
  "As great a craft is to keep weal as win; <65>\n"
  "Bridle alway thy speech and thy desire,\n"
  "For worldly joy holds not but by a wire;\n"
  "That proveth well, it breaks all day so oft,\n"
  "Forthy need is to worke with it soft.\"\n"
  "\n"
  "Troilus sedulously observes the counsel; and the lovers have\n"
  "many renewals of their pleasure, and of their bitter chidings of\n"
  "the Day. The effects of love on Troilus are altogether refining\n"
  "and ennobling; as may be inferred from the song which he sung\n"
  "often to Pandarus:\n"
  "\n"
  "The Second Song of Troilus.\n"
  "\n"
  "\"Love, that of Earth and Sea hath governance!\n"
  "Love, that his hestes* hath in Heaven high!                *commandments\n"
  "Love, that with a right wholesome alliance\n"
  "Holds people joined, as him list them guy!*                       *guide\n"
  "Love, that knitteth law and company,\n"
  "And couples doth in virtue for to dwell,\n"
  "Bind this accord, that I have told, and tell!\n"
  "\n"
  "\"That the worlde, with faith which that is stable,\n"
  "Diverseth so, his *stoundes according;*       *according to its seasons*\n"
  "That elementes, that be discordable,*                        *discordant\n"
  "Holden a bond perpetually during;\n"
  "That Phoebus may his rosy day forth bring;\n"
  "And that the Moon hath lordship o'er the night; --\n"
  "All this doth Love, ay heried* be his might!                    *praised\n"
  "\n"
  "\"That the sea, which that greedy is to flowen,\n"
  "Constraineth to a certain ende* so                                *limit\n"
  "His floodes, that so fiercely they not growen\n"
  "To drenchen* earth and all for evermo';                           *drown\n"
  "And if that Love aught let his bridle go,\n"
  "All that now loves asunder shoulde leap,\n"
  "And lost were all that Love holds now *to heap.*         *together <66>*\n"
  "\n"
  "\"So woulde God, that author is of kind,\n"
  "That with his bond Love of his virtue list\n"
  "To cherish heartes, and all fast to bind,\n"
  "That from his bond no wight the way out wist!\n"
  "And heartes cold, them would I that he twist,*                   *turned\n"
  "To make them love; and that him list ay rue*                  *have pity\n"
  "On heartes sore, and keep them that be true.\"\n"
  "\n"
  "But Troilus' love had higher fruits than singing:\n"
  "\n"
  "In alle needes for the towne's werre*                               *war\n"
  "He was, and ay the first in armes dight,*            *equipped, prepared\n"
  "And certainly, but if that bookes err,\n"
  "Save Hector, most y-dread* of any wight;                        *dreaded\n"
  "And this increase of hardiness* and might                       *courage\n"
  "Came him of love, his lady's grace to win,\n"
  "That altered his spirit so within.\n"
  "\n"
  "In time of truce, a-hawking would he ride,\n"
  "Or elles hunt the boare, bear, lioun;\n"
  "The smalle beastes let he go beside;<67>\n"
  "And when he came riding into the town,\n"
  "Full oft his lady, from her window down,\n"
  "As fresh as falcon coming out of mew,*                        *cage <68>\n"
  "Full ready was him goodly to salue.*                             *salute\n"
  "\n"
  "\n"
  "And most of love and virtue was his speech,\n"
  "And *in despite he had all wretchedness*           *he held in scorn all\n"
  "And doubtless no need was him to beseech             despicable actions*\n"
  "To honour them that hadde worthiness,\n"
  "And ease them that weren in distress;\n"
  "And glad was he, if any wight well far'd,\n"
  "That lover was, when he it wist or heard.\n"
  "\n"
  "For he held every man lost unless he were in Love's service;\n"
  "and, so did the power of Love work within him, that he was ay\n"
  "[always] humble and benign, and \"pride, envy, ire, and avarice,\n"
  "he gan to flee, and ev'ry other vice.\"\n"
  "\n"
  "\n"
  "THE FOURTH BOOK\n"
  "\n"
  "\n"
  "A BRIEF Proem to the Fourth Book prepares us for the\n"
  "treachery of Fortune to Troilus; from whom she turned away\n"
  "her bright face, and took of him no heed, \"and cast him clean\n"
  "out of his lady's grace, and on her wheel she set up Diomede.\"\n"
  "Then the narrative describes a skirmish in which the Trojans\n"
  "were worsted, and Antenor, with many of less note, remained in\n"
  "the hands of the Greeks. A truce was proclaimed for the\n"
  "exchange of prisoners; and as soon as Calchas heard the news,\n"
  "he came to the assembly of the Greeks, to \"bid a boon.\" Having\n"
  "gained audience, he reminded the besiegers how he had come\n"
  "from Troy to aid and encourage them in their enterprise; willing\n"
  "to lose all that he had in the city, except his daughter Cressida,\n"
  "whom he bitterly reproached himself for leaving behind. And\n"
  "now, with streaming tears and pitiful prayer, he besought them\n"
  "to exchange Antenor for Cressida; assuring them that the day\n"
  "was at hand when they should have both town and people. The\n"
  "soothsayer's petition was granted; and the ambassadors charged\n"
  "to negotiate the exchange, entering the city, told their errand to\n"
  "King Priam and his parliament.\n"
  "\n"
  "This Troilus was present in the place\n"
  "When asked was for Antenor Cresside;\n"
  "For which to change soon began his face,\n"
  "As he that with the wordes well nigh died;\n"
  "But natheless he no word to it seid;*                              *said\n"
  "Lest men should his affection espy,\n"
  "With manne's heart he gan his sorrows drie;*                     *endure\n"
  "\n"
  "And, full of anguish and of grisly dread,\n"
  "Abode what other lords would to it say,\n"
  "And if they woulde grant, -- as God forbid! --\n"
  "Th'exchange of her, then thought he thinges tway:*                  *two\n"
  "First, for to save her honour; and what way\n"
  "He mighte best th'exchange of her withstand;\n"
  "This cast he then how all this mighte stand.\n"
  "\n"
  "Love made him alle *prest to do her bide,*      *eager to make her stay*\n"
  "And rather die than that she shoulde go;\n"
  "But Reason said him, on the other side,\n"
  "\"Without th'assent of her, do thou not so,\n"
  "Lest for thy worke she would be thy foe;\n"
  "And say, that through thy meddling is y-blow*    *divulged, blown abroad\n"
  "Your bothe love, where it was *erst unknow.\"*       *previously unknown*\n"
  "\n"
  "For which he gan deliberate for the best,\n"
  "That though the lordes woulde that she went,\n"
  "He woulde suffer them grant what *them lest,*             *they pleased*\n"
  "And tell his lady first what that they meant;\n"
  "And, when that she had told him her intent,\n"
  "Thereafter would he worken all so blive,*                      *speedily\n"
  "Though all the world against it woulde strive.\n"
  "\n"
  "Hector, which that full well the Greekes heard,\n"
  "For Antenor how they would have Cresseide,\n"
  "Gan it withstand, and soberly answer'd;\n"
  "\"Sirs, she is no prisoner,\"  he said;\n"
  "\"I know not on you who this charge laid;\n"
  "But, for my part, ye may well soon him tell,\n"
  "We use* here no women for to sell.\"                      *are accustomed\n"
  "\n"
  "The noise of the people then upstart at once,\n"
  "As breme* as blaze of straw y-set on fire              *violent, furious\n"
  "For Infortune* woulde for the nonce                          *Misfortune\n"
  "They shoulde their confusion desire\n"
  "\"Hector,\" quoth they, \"what ghost* may you inspire               *spirit\n"
  "This woman thus to shield, and *do us* lose                *cause us to*\n"
  "Dan Antenor? -- a wrong way now ye choose, --\n"
  "\n"
  "\"That is so wise, and eke so bold baroun;\n"
  "And we have need of folk, as men may see\n"
  "He eke is one the greatest of this town;\n"
  "O Hector! lette such fantasies be!\n"
  "O King Priam!\" quoth they, \"lo! thus say we,\n"
  "That all our will is to forego Cresseide;\"\n"
  "And to deliver Antenor they pray'd.\n"
  "\n"
  "Though Hector often prayed them \"nay,\" it was resolved that\n"
  "Cressida should be given up for Antenor; then the parliament\n"
  "dispersed. Troilus hastened home to his chamber, shut himself\n"
  "up alone, and threw himself on his bed.\n"
  "\n"
  "And as in winter leaves be bereft,\n"
  "Each after other, till the tree be bare,\n"
  "So that there is but bark and branch y-left,\n"
  "Lay Troilus, bereft of each welfare,\n"
  "Y-bounden in the blacke bark of care,\n"
  "Disposed *wood out of his wit to braid,*       *to go out of his senses*\n"
  "*So sore him sat* the changing of Cresseide.        *so ill did he bear*\n"
  "\n"
  "He rose him up, and ev'ry door he shet,*                           *shut\n"
  "And window eke; and then this sorrowful man\n"
  "Upon his bedde's side adown him set,\n"
  "Full like a dead image, pale and wan,\n"
  "And in his breast the heaped woe began\n"
  "Out burst, and he to worken in this wise,\n"
  "In his woodness,* as I shall you devise.**             *madness **relate\n"
  "\n"
  "Right as the wilde bull begins to spring,\n"
  "Now here, now there, y-darted* to the heart,        *pierced with a dart\n"
  "And of his death roareth in complaining;\n"
  "Right so gan he about the chamber start,\n"
  "Smiting his breast aye with his fistes smart;*       *painfully, cruelly\n"
  "His head to the wall, his body to the ground,\n"
  "Full oft he swapt,* himselfe to confound.                *struck, dashed\n"
  "\n"
  "His eyen then, for pity of his heart,\n"
  "Out streameden as swifte welles* tway;                        *fountains\n"
  "The highe sobbes of his sorrow's smart\n"
  "His speech him reft; unnethes* might he say,                   *scarcely\n"
  "\"O Death, alas! *why n'ilt thou do me dey?*            *why will you not\n"
  "Accursed be that day which that Nature                     make me die?*\n"
  "Shope* me to be a living creature!\"                              *shaped\n"
  "\n"
  "Bitterly reviling Fortune, and calling on Love to explain why his\n"
  "happiness with Cressicla should be thus repealed, Troilus\n"
  "declares that, while he lives, he will bewail his misfortune in\n"
  "solitude, and will never see it shine or rain, but will end his\n"
  "sorrowful life in darkness, and die in distress.\n"
  "\n"
  "\"O weary ghost, that errest to and fro!\n"
  "Why n'ilt* thou fly out of the woefulest                       *wilt not\n"
  "Body that ever might on grounde go?\n"
  "O soule, lurking in this woeful nest!\n"
  "Flee forth out of my heart, and let it brest,*                    *burst\n"
  "And follow alway Cresside, thy lady dear!\n"
  "Thy righte place is now no longer here.\n"
  "\n"
  "\"O woeful eyen two! since your disport*                         *delight\n"
  "Was all to see Cressida's eyen bright,\n"
  "What shall ye do, but, for my discomfort,\n"
  "Stande for naught, and weepen out your sight,\n"
  "Since she is quench'd, that wont was you to light?\n"
  "In vain, from this forth, have I eyen tway\n"
  "Y-formed, since your virtue is away!\n"
  "\n"
  "\"O my Cresside! O lady sovereign\n"
  "Of thilke* woeful soule that now cryeth!                           *this\n"
  "Who shall now give comfort to thy pain?\n"
  "Alas! no wight; but, when my hearte dieth,\n"
  "My spirit, which that so unto you hieth,*                     *hasteneth\n"
  "Receive *in gree,* for that shall ay you serve;            *with favour*\n"
  "*Forthy no force is* though the body sterve.*      *therefore no matter*\n"
  "                                                                    *die\n"
  "\"O ye lovers, that high upon the wheel\n"
  "Be set of Fortune, in good adventure,\n"
  "God lene* that ye find ay** love of steel,<69>           *grant **always\n"
  "And longe may your life in joy endure!\n"
  "But when ye come by my sepulture,*                            *sepulchre\n"
  "Remember that your fellow resteth there;\n"
  "For I lov'd eke, though I unworthy were.\n"
  "\n"
  "\"O old, unwholesome, and mislived man,\n"
  "Calchas I mean, alas! what ailed thee\n"
  "To be a Greek, since thou wert born Trojan?\n"
  "O Calchas! which that will my bane* be,                     *destruction\n"
  "In cursed time wert thou born for me!\n"
  "As woulde blissful Jove, for his joy,\n"
  "That I thee hadde where I would in Troy!\"\n"
  "\n"
  "Soon Troilus, through excess of grief, fell into a trance; in\n"
  "which he was found by Pandarus, who had gone almost\n"
  "distracted at the news that Cressida was to be exchanged for\n"
  "Antenor. At his friend's arrival, Troilus \"gan as the snow against\n"
  "the sun to melt;\" the two mingled their tears a while; then\n"
  "Pandarus strove to comfort the woeful lover. He admitted that\n"
  "never had a stranger ruin than this been wrought by Fortune:\n"
  "\n"
  "\"But tell me this, why thou art now so mad\n"
  "To sorrow thus? Why li'st thou in this wise,\n"
  "Since thy desire all wholly hast thou had,\n"
  "So that by right it ought enough suffice?\n"
  "But I, that never felt in my service\n"
  "A friendly cheer or looking of an eye,\n"
  "Let me thus weep and wail until I die. <70>\n"
  "\n"
  "\"And over all this, as thou well wost* thy selve,               *knowest\n"
  "This town is full of ladies all about,\n"
  "And, *to my doom,* fairer than suche twelve             *in my judgment*\n"
  "As ever she was, shall I find in some rout,*                    *company\n"
  "Yea! one or two, withouten any doubt:\n"
  "Forthy* be glad, mine owen deare brother!                     *therefore\n"
  "If she be lost, we shall recover another.\n"
  "\n"
  "\"What! God forbid alway that each pleasance\n"
  "In one thing were, and in none other wight;\n"
  "If one can sing, another can well dance;\n"
  "If this be goodly, she is glad and light;\n"
  "And this is fair, and that can good aright;\n"
  "Each for his virtue holden is full dear,\n"
  "Both heroner, and falcon for rivere. <71>\n"
  "\n"
  "\"And eke as writ Zausis,<72> that was full wise,\n"
  "The newe love out chaseth oft the old,\n"
  "And upon new case lieth new advice; <73>\n"
  "Think eke thy life to save thou art hold;*                        *bound\n"
  "Such fire *by process shall of kinde cold;*          *shall grow cold by\n"
  "For, since it is but casual pleasance,                process of nature*\n"
  "Some case* shall put it out of remembrance.                      *chance\n"
  "\n"
  "\"For, all so sure as day comes after night,\n"
  "The newe love, labour, or other woe,\n"
  "Or elles seldom seeing of a wight,\n"
  "Do old affections all *over go;*                              *overcome*\n"
  "And for thy part, thou shalt have one of tho*                     *those\n"
  "T'abridge with thy bitter paine's smart;\n"
  "Absence of her shall drive her out of heart.\"\n"
  "\n"
  "These wordes said he *for the nones all,*           *only for the nonce*\n"
  "To help his friend, lest he for sorrow died;\n"
  "For, doubteless, to do his woe to fall,*          *make his woe subside*\n"
  "He raughte* not what unthrift** that he said;             *cared **folly\n"
  "But Troilus, that nigh for sorrow died,\n"
  "Took little heed of all that ever he meant;\n"
  "One ear it heard, at th'other out it went.\n"
  "\n"
  "But, at the last, he answer'd and said,\n"
  "\"Friend, This leachcraft, or y-healed thus to be,\n"
  "Were well sitting* if that I were a fiend,                       *recked\n"
  "To traisen* her that true is unto me:                            *betray\n"
  "I pray God, let this counsel never the,*                         *thrive\n"
  "But do me rather sterve* anon right here,                           *die\n"
  "Ere I thus do, as thou me wouldest lear!\"*                        *teach\n"
  "\n"
  "Troilus protests that his lady shall have him wholly hers till\n"
  "death; and, debating the counsels of his friend, declares that\n"
  "even if he would, he could not love another. Then he points out\n"
  "the folly of not lamenting the loss of Cressida because she had\n"
  "been his in ease and felicity --  while Pandarus himself, though\n"
  "he thought it so light to change to and fro in love, had not done\n"
  "busily his might to change her that wrought him all the woe of\n"
  "his unprosperous suit.\n"
  "\n"
  "\"If thou hast had in love ay yet mischance,\n"
  "And canst it not out of thine hearte drive,\n"
  "I that lived in lust* and in pleasance                          *delight\n"
  "With her, as much as creature alive,\n"
  "How should I that forget, and that so blive?*                   *quickly\n"
  "O where hast thou been so long hid in mew,*<74>                    *cage\n"
  "That canst so well and formally argue!\"\n"
  "\n"
  "The lover condemns the whole discourse of his friend as\n"
  "unworthy, and calls on Death, the ender of all sorrows, to come\n"
  "to him and quench his heart with his cold stroke. Then he distils\n"
  "anew in tears, \"as liquor out of alembic;\" and Pandarus is silent\n"
  "for a while, till he bethinks him to recommend to Troilus the\n"
  "carrying off of Cressida. \"Art thou in Troy, and hast no\n"
  "hardiment [daring, boldness] to take a woman which that loveth\n"
  "thee?\"  But Troilus reminds his counsellor that all the war had\n"
  "come from the ravishing of a woman by might (the abduction of\n"
  "Helen by Paris); and that it would not beseem him to withstand\n"
  "his father's grant, since the lady was to be changed for the\n"
  "town's good. He has dismissed the thought of asking Cressida\n"
  "from his father, because that would be to injure her fair fame, to\n"
  "no purpose, for Priam could not overthrow the decision of \"so\n"
  "high a place as parliament;\" while most of all he fears to perturb\n"
  "her heart with violence, to the slander of her name -- for he\n"
  "must hold her honour dearer than himself in every case, as\n"
  "lovers ought of right:\n"
  "\n"
  "\"Thus am I in desire and reason twight:*                        *twisted\n"
  "Desire, for to disturbe her, me redeth;*                     *counseleth\n"
  "And Reason will not, so my hearte dreadeth.\"*               *is in doubt\n"
  "\n"
  "Thus weeping, that he coulde never cease\n"
  "He said, \"Alas! how shall I, wretche, fare?\n"
  "For well feel I alway my love increase,\n"
  "And hope is less and less alway, Pandare!\n"
  "Increasen eke the causes of my care;\n"
  "So well-away! *why n' ill my hearte brest?*                *why will not\n"
  "For us in love there is but little rest.\"               my heart break?*\n"
  "\n"
  "Pandare answered, \"Friend, thou may'st for me\n"
  "Do as thee list;* but had I it so hot,                           *please\n"
  "And thine estate,* she shoulde go with me!                         *rank\n"
  "Though all this town cried on this thing by note,\n"
  "I would not set* all that noise a groat;                          *value\n"
  "For when men have well cried, then will they rown,*             *whisper\n"
  "Eke wonder lasts but nine nights ne'er in town.\n"
  "\n"
  "";
// }

const char poemTroilusAndCressida3[] PGMSECTION = // { // 31189 bytes
  "\"Divine not in reason ay so deep,\n"
  "Nor courteously, but help thyself anon;\n"
  "Bet* is that others than thyselfe weep;                          *better\n"
  "And namely, since ye two be all one,\n"
  "Rise up, for, by my head, she shall not go'n!\n"
  "And rather be in blame a little found,\n"
  "Than sterve* here as a gnat withoute wound!                         *die\n"
  "\n"
  "\"It is no shame unto you, nor no vice,\n"
  "Her to withholde, that ye loveth most;\n"
  "Parauntre* she might holde thee for nice,**      *peradventure **foolish\n"
  "To let her go thus unto the Greeks' host;\n"
  "Think eke, Fortune, as well thyselfe wost,\n"
  "Helpeth the hardy man to his emprise,\n"
  "And weiveth* wretches for their cowardice.                    *forsaketh\n"
  "\n"
  "\"And though thy lady would a lite* her grieve,                   *little\n"
  "Thou shalt thyself thy peace thereafter make;\n"
  "But, as to me, certain I cannot 'lieve\n"
  "That she would it as now for evil take:\n"
  "Why shoulde then for fear thine hearte quake?\n"
  "Think eke how Paris hath, that is thy brother,\n"
  "A love; and why shalt thou not have another?\n"
  "\n"
  "\"And, Troilus, one thing I dare thee swear,\n"
  "That if Cressida, which that is thy lief,*                         *love\n"
  "Now loveth thee as well as thou dost her,\n"
  "God help me so, she will not take agrief*                         *amiss\n"
  "Though thou *anon do boot in* this mischief;           *provide a remedy\n"
  "And if she willeth from thee for to pass,                   immediately*\n"
  "Then is she false, so love her well the lass.*                     *less\n"
  "\n"
  "\"Forthy,* take heart, and think, right as a knight,           *therefore\n"
  "Through love is broken all day ev'ry law;\n"
  "Kithe* now somewhat thy courage and thy might;                     *show\n"
  "Have mercy on thyself, *for any awe;*             *in spite of any fear*\n"
  "Let not this wretched woe thine hearte gnaw;\n"
  "But, manly, set the world on six and seven, <75>\n"
  "And, if thou die a martyr, go to heaven.\"\n"
  "\n"
  "Pandarus promises his friend all aid in the enterprise; it is agreed\n"
  "that Cressida shall be carried off, but only with her own\n"
  "consent; and Pandarus sets out for his niece's house, to arrange\n"
  "an interview. Meantime Cressida has heard the news; and,\n"
  "caring nothing for her father, but everything for Troilus, she\n"
  "burns in love and fear, unable to tell what she shall do.\n"
  "\n"
  "But, as men see in town, and all about,\n"
  "That women use* friendes to visite,                      *are accustomed\n"
  "So to Cresside of women came a rout,*                             *troop\n"
  "For piteous joy, and *weened her delight,*       *thought to please her*\n"
  "And with their tales, *dear enough a mite,*           *not worth a mite*\n"
  "These women, which that in the city dwell,\n"
  "They set them down, and said as I shall tell.\n"
  "\n"
  "Quoth first that one, \"I am glad, truely,\n"
  "Because of you, that shall your father see;\"\n"
  "Another said, \"Y-wis, so am not I,\n"
  "For all too little hath she with us be.\"*                          *been\n"
  "Quoth then the third, \"I hope, y-wis, that she\n"
  "Shall bringen us the peace on ev'ry side;\n"
  "Then, when she goes, Almighty God her guide!\"\n"
  "\n"
  "Those wordes, and those womanishe thinges,\n"
  "She heard them right as though she thennes* were,       *thence; in some\n"
  "For, God it wot, her heart on other thing is;                other place\n"
  "Although the body sat among them there,\n"
  "Her advertence* is always elleswhere;                         *attention\n"
  "For Troilus full fast her soule sought;\n"
  "Withoute word, on him alway she thought.\n"
  "\n"
  "These women that thus weened her to please,\n"
  "Aboute naught gan all their tales spend;\n"
  "Such vanity ne can do her no ease,\n"
  "As she that all this meane while brenn'd\n"
  "Of other passion than that they wend;*                 *weened, supposed\n"
  "So that she felt almost her hearte die\n"
  "For woe, and weary* of that company.                          *weariness\n"
  "\n"
  "For whiche she no longer might restrain\n"
  "Her teares, they began so up to well,\n"
  "That gave signes of her bitter pain,\n"
  "In which her spirit was, and muste dwell,\n"
  "Rememb'ring her from heav'n into which hell\n"
  "She fallen was, since she forwent* the sight                       *lost\n"
  "Of Troilus; and sorrowfully she sight.*                          *sighed\n"
  "\n"
  "And thilke fooles, sitting her about,\n"
  "Weened that she had wept and siked* sore,                        *sighed\n"
  "Because that she should out of that rout*                       *company\n"
  "Depart, and never playe with them more;\n"
  "And they that hadde knowen her of yore\n"
  "Saw her so weep, and thought it kindeness,\n"
  "And each of them wept eke for her distress.\n"
  "\n"
  "And busily they gonnen* her comfort                               *began\n"
  "Of thing, God wot, on which she little thought;\n"
  "And with their tales weened her disport,\n"
  "And to be glad they her besought;\n"
  "But such an ease therewith they in her wrought,\n"
  "Right as a man is eased for to feel,\n"
  "For ache of head, to claw him on his heel.\n"
  "\n"
  "But, after all this nice* vanity,                                 *silly\n"
  "They took their leave, and home they wenten all;\n"
  "Cressida, full of sorrowful pity,\n"
  "Into her chamber up went out of the hall,\n"
  "And on her bed she gan for dead to fall,\n"
  "In purpose never thennes for to rise;\n"
  "And thus she wrought, as I shall you devise.*                   *narrate\n"
  "\n"
  "She rent her sunny hair, wrung her hands, wept, and bewailed\n"
  "her fate; vowing that, since, \"for the cruelty,\" she could handle\n"
  "neither sword nor dart, she would abstain from meat and drink\n"
  "until she died. As she lamented, Pandarus entered, making her\n"
  "complain a thousand times more at the thought of all the joy\n"
  "which he had given her with her lover; but he somewhat\n"
  "soothed her by the prospect of Troilus's visit, and by the\n"
  "counsel to contain her grief when he should come. Then\n"
  "Pandarus went in search of Troilus, whom he found solitary in a\n"
  "temple, as one that had ceased to care for life:\n"
  "\n"
  "For right thus was his argument alway:\n"
  "He said he was but lorne,* well-away!                      *lost, ruined\n"
  "\"For all that comes, comes by necessity;\n"
  "Thus, to be lorn,* it is my destiny.                       *lost, ruined\n"
  "\n"
  "\"For certainly this wot I well,\" he said,\n"
  "\"That foresight of the divine purveyance*                    *providence\n"
  "Hath seen alway me to forgo* Cresseide,                            *lose\n"
  "Since God sees ev'ry thing, *out of doubtance,*          *without doubt*\n"
  "And them disposeth, through his ordinance,\n"
  "In their merites soothly for to be,\n"
  "As they should come by predestiny.\n"
  "\n"
  "\"But natheless, alas! whom shall I 'lieve?\n"
  "For there be greate clerkes* many one                          *scholars\n"
  "That destiny through argumentes preve,                            *prove\n"
  "And some say that needly* there is none,                    *necessarily\n"
  "But that free choice is giv'n us ev'ry one;\n"
  "O well-away! so sly are clerkes old,\n"
  "That I n'ot* whose opinion I may hold. <76>                    *know not\n"
  "\n"
  "\"For some men say, if God sees all beforn,\n"
  "Godde may not deceived be, pardie!\n"
  "Then must it fallen,* though men had it sworn,           *befall, happen\n"
  "That purveyance hath seen before to be;\n"
  "Wherefore I say, that from etern* if he                        *eternity\n"
  "Hath wist* before our thought eke as our deed,                    *known\n"
  "We have no free choice, as these clerkes read.*                *maintain\n"
  "\n"
  "\"For other thought, nor other deed also,\n"
  "Might never be, but such as purveyance,\n"
  "Which may not be deceived never mo',\n"
  "Hath feeled* before, without ignorance;                       *perceived\n"
  "For if there mighte be a variance,\n"
  "To writhen out from Godde's purveying,\n"
  "There were no prescience of thing coming,\n"
  "\n"
  "\"But it were rather an opinion\n"
  "Uncertain, and no steadfast foreseeing;\n"
  "And, certes, that were an abusion,*                            *illusion\n"
  "That God should have no perfect clear weeting,*               *knowledge\n"
  "More than we men, that have *doubtous weening;*        *dubious opinion*\n"
  "But such an error *upon God to guess,*                *to impute to God*\n"
  "Were false, and foul, and wicked cursedness.*                   *impiety\n"
  "\n"
  "\"Eke this is an opinion of some\n"
  "That have their top full high and smooth y-shore, <77>\n"
  "They say right thus, that thing is not to come,\n"
  "For* that the prescience hath seen before                       *because\n"
  "That it shall come; but they say, that therefore\n"
  "That it shall come, therefore the purveyance\n"
  "Wot it before, withouten ignorance.\n"
  "\n"
  "\"And, in this manner, this necessity\n"
  "*Returneth in his part contrary again;*          *reacts in the opposite\n"
  "For needfully behoves it not to be,                           direction*\n"
  "That thilke thinges *fallen in certain,*              *certainly happen*\n"
  "That be purvey'd; but needly, as they sayn,\n"
  "Behoveth it that thinges, which that fall,\n"
  "That they in certain be purveyed all.\n"
  "\n"
  "\"I mean as though I labour'd me in this\n"
  "To inquire which thing cause of which thing be;\n"
  "As, whether that the prescience of God is\n"
  "The certain cause of the necessity\n"
  "Of thinges that to come be, pardie!\n"
  "Or if necessity of thing coming\n"
  "Be cause certain of the purveying.\n"
  "\n"
  "\"But now *enforce I me not* in shewing             *I do not lay stress*\n"
  "How th'order of causes stands; but well wot I,\n"
  "That it behoveth, that the befalling\n"
  "Of thinges wiste* before certainly,                               *known\n"
  "Be necessary, *all seem it not* thereby,     *though it does not appear*\n"
  "That prescience put falling necessair\n"
  "To thing to come, all fall it foul or fair.\n"
  "\n"
  "\"For, if there sit a man yond on a see,*                           *seat\n"
  "Then by necessity behoveth it\n"
  "That certes thine opinion sooth be,\n"
  "That weenest, or conjectest,* that he sit;                 *conjecturest\n"
  "And, furtherover, now againward yet,\n"
  "Lo! right so is it on the part contrary;\n"
  "As thus, -- now hearken, for I will not tarry; --\n"
  "\n"
  "\"I say that if th'opinion of thee\n"
  "Be sooth, for that he sits, then say I this,\n"
  "That he must sitte by necessity;\n"
  "And thus necessity in either is,\n"
  "For in him need of sitting is, y-wis,\n"
  "And, in thee, need of sooth; and thus forsooth\n"
  "There must necessity be in you both.\n"
  "\n"
  "\"But thou may'st say he sits not therefore\n"
  "That thine opinion of his sitting sooth\n"
  "But rather, for the man sat there before,\n"
  "Therefore is thine opinion sooth, y-wis;\n"
  "And I say, though the cause of sooth of this\n"
  "Comes of his sitting, yet necessity\n"
  "Is interchanged both in him and thee.\n"
  "\n"
  "\"Thus in the same wise, out of doubtance,\n"
  "I may well maken, as it seemeth me,\n"
  "My reasoning of Godde's purveyance,\n"
  "And of the thinges that to come be;\n"
  "By whiche reason men may well y-see\n"
  "That thilke* thinges that in earthe fall,**              *those **happen\n"
  "That by necessity they comen all.\n"
  "\n"
  "\"For although that a thing should come, y-wis,\n"
  "Therefore it is purveyed certainly,\n"
  "Not that it comes for it purveyed is;\n"
  "Yet, natheless, behoveth needfully\n"
  "That thing to come be purvey'd truely;\n"
  "Or elles thinges that purveyed be,\n"
  "That they betide* by necessity.                                  *happen\n"
  "\n"
  "\"And this sufficeth right enough, certain,\n"
  "For to destroy our free choice ev'ry deal;\n"
  "But now is this abusion,* to sayn              *illusion, self-deception\n"
  "That falling of the thinges temporel\n"
  "Is cause of Godde's prescience eternel;\n"
  "Now truely that is a false sentence,*                 *opinion, judgment\n"
  "That thing to come should cause his prescience.\n"
  "\n"
  "\"What might I ween, an'* I had such a thought,                       *if\n"
  "But that God purveys thing that is to come,\n"
  "For that it is to come, and elles nought?\n"
  "So might I ween that thinges, all and some,\n"
  "That *whilom be befall and overcome,*                     *have happened\n"
  "Be cause of thilke sov'reign purveyance,                  in times past*\n"
  "That foreknows all, withouten ignorance.\n"
  "\n"
  "\"And over all this, yet say I more thereto, --\n"
  "That right as when I wot there is a thing,\n"
  "Y-wis, that thing must needfully be so;\n"
  "Eke right so, when I wot a thing coming,\n"
  "So must it come; and thus the befalling\n"
  "Of thinges that be wist before the tide,*                          *time\n"
  "They may not be eschew'd* on any side.\"                         *avoided\n"
  "\n"
  "While Troilus was in all this heaviness, disputing with himself in\n"
  "this matter, Pandarus joined him, and told him the result of the\n"
  "interview with Cressida; and at night the lovers met, with what\n"
  "sighs and tears may be imagined. Cressida swooned away, so\n"
  "that Troilus took her for dead; and, having tenderly laid out her\n"
  "limbs, as one preparing a corpse for the bier, he drew his sword\n"
  "to slay himself upon her body. But, as God would, just at that\n"
  "moment she awoke out of her swoon; and by and by the pair\n"
  "began to talk of their prospects. Cressida declared the opinion,\n"
  "supporting it at great length and with many reasons, that there\n"
  "was no cause for half so much woe on either part. Her\n"
  "surrender, decreed by the parliament, could not be resisted; it\n"
  "was quite easy for them soon to meet again; she would bring\n"
  "things about that she should be back in Troy within a week or\n"
  "two; she would take advantage of the constant coming and\n"
  "going while the truce lasted; and the issue would be, that the\n"
  "Trojans would have both her and Antenor; while, to facilitate\n"
  "her return, she had devised a stratagem by which, working on\n"
  "her father's avarice, she might tempt him to desert from the\n"
  "Greek camp back to the city. \"And truly,\" says the poet, having\n"
  "fully reported her plausible speech,\n"
  "\n"
  "And truely, as written well I find,\n"
  "That all this thing was said *of good intent,*               *sincerely*\n"
  "And that her hearte true was and kind\n"
  "Towardes him, and spake right as she meant,\n"
  "And that she starf* for woe nigh when she went,                    *died\n"
  "And was in purpose ever to be true;\n"
  "Thus write they that of her workes knew.\n"
  "\n"
  "This Troilus, with heart and ears y-sprad,*                    *all open\n"
  "Heard all this thing devised to and fro,\n"
  "And verily it seemed that he had\n"
  "*The selfe wit;* but yet to let her go                *the same opinion*\n"
  "His hearte misforgave* him evermo';                             *misgave\n"
  "But, finally, he gan his hearte wrest*                           *compel\n"
  "To truste her, and took it for the best.\n"
  "\n"
  "For which the great fury of his penance*                      *suffering\n"
  "Was quench'd with hope, and therewith them between\n"
  "Began for joy the amorouse dance;\n"
  "And as the birdes, when the sun is sheen,                        *bright\n"
  "Delighten in their song, in leaves green,\n"
  "Right so the wordes that they spake y-fere*                    *together\n"
  "Delighten them, and make their heartes cheer.*                     *glad\n"
  "\n"
  "Yet Troilus was not so well at ease, that he did not earnestly\n"
  "entreat Cressida to observe her promise; for, if she came not\n"
  "into Troy at the set day, he should never have health, honour, or\n"
  "joy; and he feared that the stratagem by which she would try to\n"
  "lure her father back would fail, so that she might be compelled\n"
  "to remain among the Greeks. He would rather have them steal\n"
  "away together, with sufficient treasure to maintain them all their\n"
  "lives; and even if they went in their bare shirt, he had kin and\n"
  "friends elsewhere, who would welcome and honour them.\n"
  "\n"
  "Cressida, with a sigh, right in this wise\n"
  "Answer'd; \"Y-wis, my deare hearte true,\n"
  "We may well steal away, as ye devise,\n"
  "And finde such unthrifty wayes new;\n"
  "But afterward full sore *it will us rue;*            *we will regret it*\n"
  "And help me God so at my moste need\n"
  "As causeless ye suffer all this dread!\n"
  "\n"
  "\"For thilke* day that I for cherishing                        *that same\n"
  "Or dread of father, or of other wight,\n"
  "Or for estate, delight, or for wedding,\n"
  "Be false to you, my Troilus, my knight,\n"
  "Saturne's daughter Juno, through her might,\n"
  "As wood* as Athamante <78> do me dwell                              *mad\n"
  "Eternally in Styx the pit of hell!\n"
  "\n"
  "\"And this, on ev'ry god celestial\n"
  "I swear it you, and eke on each goddess,\n"
  "On ev'ry nymph, and deity infernal,\n"
  "On Satyrs and on Faunes more or less,\n"
  "That *halfe goddes* be of wilderness;                          *demigods\n"
  "And Atropos my thread of life to-brest,*                  *break utterly\n"
  "If I be false! now trow* me if you lest.**             *believe **please\n"
  "\n"
  "\"And thou Simois, <79> that as an arrow clear\n"
  "Through Troy ay runnest downward to the sea,\n"
  "Bear witness of this word that said is here!\n"
  "That thilke day that I untrue be\n"
  "To Troilus, mine owen hearte free,\n"
  "That thou returne backward to thy well,\n"
  "And I with body and soul sink in hell!\"\n"
  "\n"
  "Even yet Troilus was not wholly content, and urged anew his\n"
  "plan of secret flight; but Cressida turned upon him with the\n"
  "charge that he mistrusted her causelessly, and demanded of him\n"
  "that he should be faithful in her absence, else she must die at her\n"
  "return. Troilus promised faithfulness in far simpler and briefer\n"
  "words than Cressida had used.\n"
  "\n"
  "\"Grand mercy, good heart mine, y-wis,\" quoth she;\n"
  "\"And blissful Venus let me never sterve,*                           *die\n"
  "Ere I may stand *of pleasance in degree          in a position to reward\n"
  "To quite him*  that so well can deserve;         him well with pleasure*\n"
  "And while that God my wit will me conserve,\n"
  "I shall so do; so true I have you found,\n"
  "That ay honour to me-ward shall rebound.\n"
  "\n"
  "\"For truste well that your estate* royal,                          *rank\n"
  "Nor vain delight, nor only worthiness\n"
  "Of you in war or tourney martial,\n"
  "Nor pomp, array, nobley, nor eke richess,\n"
  "Ne made me to rue* on your distress;                          *take pity\n"
  "But moral virtue, grounded upon truth,\n"
  "That was the cause I first had on you ruth.*                       *pity\n"
  "\n"
  "\"Eke gentle heart, and manhood that ye had,\n"
  "And that ye had, -- as me thought, -- in despite\n"
  "Every thing that *sounded unto* bad,        *tended unto, accorded with*\n"
  "As rudeness, and peoplish* appetite,                             *vulgar\n"
  "And that your reason bridled your delight;\n"
  "This made, aboven ev'ry creature,\n"
  "That I was yours, and shall while I may dure.\n"
  "\n"
  "\"And this may length of yeares not fordo,*             *destroy, do away\n"
  "Nor remuable* Fortune deface;                                  *unstable\n"
  "But Jupiter, that of his might may do\n"
  "The sorrowful to be glad, so give us grace,\n"
  "Ere nightes ten to meeten in this place,\n"
  "So that it may your heart and mine suffice!\n"
  "And fare now well, for time is that ye rise.\"\n"
  "\n"
  "The lovers took a heart-rending adieu; and Troilus, suffering\n"
  "unimaginable anguish, \"withoute more, out of the chamber\n"
  "went.\"\n"
  "\n"
  "\n"
  "THE FIFTH BOOK.\n"
  "\n"
  "\n"
  "APPROACHE gan the fatal destiny\n"
  "That Jovis hath in disposition,\n"
  "And to you angry Parcae,* Sisters three,                      *The Fates\n"
  "Committeth to do execution;\n"
  "For which Cressida must out of the town,\n"
  "And Troilus shall dwelle forth in pine,*                           *pain\n"
  "Till Lachesis his thread no longer twine.*                        *twist\n"
  "\n"
  "The golden-tressed Phoebus, high aloft,\n"
  "Thries* had alle, with his beames clear,                         *thrice\n"
  "The snowes molt,* and Zephyrus as oft                            *melted\n"
  "Y-brought again the tender leaves green,\n"
  "Since that *the son of Hecuba the queen*                  *Troilus <80>*\n"
  "Began to love her first, for whom his sorrow\n"
  "Was all, that she depart should on the morrow\n"
  "\n"
  "In the morning, Diomede was ready to escort Cressida to the\n"
  "Greek host; and Troilus, seeing him mount his horse, could with\n"
  "difficulty resist an impulse to slay him -- but restrained himself,\n"
  "lest his lady should be also slain in the tumult. When Cressida\n"
  "was ready to go,\n"
  "\n"
  "This Troilus, in guise of courtesy,\n"
  "With hawk on hand, and with a huge rout*                 *retinue, crowd\n"
  "Of knightes, rode, and did her company,\n"
  "Passing alle the valley far without;\n"
  "And farther would have ridden, out of doubt,\n"
  "Full fain,* and woe was him to go so soon,                       *gladly\n"
  "But turn he must, and it was eke to do'n.\n"
  "\n"
  "And right with that was Antenor y-come\n"
  "Out of the Greekes' host, and ev'ry wight\n"
  "Was of it glad, and said he was welcome;\n"
  "And Troilus, *all n'ere his hearte light,*           *although his heart\n"
  "He pained him, with all his fulle might,                  was not light*\n"
  "Him to withhold from weeping at the least;\n"
  "And Antenor he kiss'd and made feast.\n"
  "\n"
  "And therewithal he must his leave take,\n"
  "And cast his eye upon her piteously,\n"
  "And near he rode, his cause* for to make               *excuse, occasion\n"
  "To take her by the hand all soberly;\n"
  "And, Lord! so she gan weepe tenderly!\n"
  "And he full soft and slily gan her say,\n"
  "\"Now hold your day, and *do me not to dey.\"*        *do not make me die*\n"
  "\n"
  "With that his courser turned he about,\n"
  "With face pale, and unto Diomede\n"
  "No word he spake, nor none of all his rout;\n"
  "Of which the son of Tydeus <81> tooke heed,\n"
  "As he that couthe* more than the creed <82>                        *knew\n"
  "In such a craft, and by the rein her hent;*                        *took\n"
  "And Troilus to Troye homeward went.\n"
  "\n"
  "This Diomede, that led her by the bridle,\n"
  "When that he saw the folk of Troy away,\n"
  "Thought, \"All my labour shall not be *on idle,*               *in  vain*\n"
  "If that I may, for somewhat shall I say;\n"
  "For, at the worst, it may yet short our way;\n"
  "I have heard say eke, times twice twelve,\n"
  "He is a fool that will forget himselve.\"\n"
  "\n"
  "But natheless, this thought he well enough,\n"
  "That \"Certainly I am aboute naught,\n"
  "If that I speak of love, or *make it tough;*           *make any violent\n"
  "For, doubteless, if she have in her thought            immediate effort*\n"
  "Him that I guess, he may not be y-brought\n"
  "So soon away; but I shall find a mean,\n"
  "That she *not wit as yet shall* what I mean.\"       *shall not yet know*\n"
  "\n"
  "So he began a general conversation, assured her of not less\n"
  "friendship and honour among the Greeks than she had enjoyed\n"
  "in Troy, and requested of her earnestly to treat him as a brother\n"
  "and accept his service -- for, at last he said, \"I am and shall be\n"
  "ay, while that my life may dure, your own, aboven ev'ry\n"
  "creature.\n"
  "\n"
  "\"Thus said I never e'er now to woman born;\n"
  "For, God mine heart as wisly* gladden so!                        *surely\n"
  "I loved never woman herebeforn,\n"
  "As paramours, nor ever shall no mo';\n"
  "And for the love of God be not my foe,\n"
  "All* can I not to you, my lady dear,                           *although\n"
  "Complain aright, for I am yet to lear.*                           *teach\n"
  "\n"
  "\"And wonder not, mine owen lady bright,\n"
  "Though that I speak of love to you thus blive;*                    *soon\n"
  "For I have heard ere this of many a wight\n"
  "That loved thing he ne'er saw in his live;\n"
  "Eke I am not of power for to strive\n"
  "Against the god of Love, but him obey\n"
  "I will alway, and mercy I you pray.\"\n"
  "\n"
  "Cressida answered his discourses as though she scarcely heard\n"
  "them; yet she thanked him for his trouble and courtesy, and\n"
  "accepted his offered friendship -- promising to trust him, as well\n"
  "she might. Then she alighted from her steed, and, with her heart\n"
  "nigh breaking, was welcomed to the embrace of her father.\n"
  "Meanwhile Troilus, back in Troy, was lamenting with tears the\n"
  "loss of his love, despairing of his or her ability to survive the ten\n"
  "days, and spending the night in wailing, sleepless tossing, and\n"
  "troublous dreams. In the morning he was visited by Pandarus,\n"
  "to whom he gave directions for his funeral; desiring that the\n"
  "powder into which his heart was burned should be kept in a\n"
  "golden urn, and given to Cressida. Pandarus renewed his old\n"
  "counsels and consolations, reminded his friend that ten days\n"
  "were a short time to wait, argued against his faith in evil\n"
  "dreams, and urged him to take advantage of the truce, and\n"
  "beguile the time by a visit to King Sarpedon (a Lycian Prince\n"
  "who had come to aid the Trojans). Sarpedon entertained them\n"
  "splendidly; but no feasting, no pomp, no music of instruments,\n"
  "no singing of fair ladies, could make up for the absence of\n"
  "Cressida to the desolate Troilus, who was for ever poring upon\n"
  "her old letters, and recalling her loved form. Thus he \"drove to\n"
  "an end\" the fourth day, and would have then returned to Troy,\n"
  "but for the remonstrances of Pandarus, who asked if they had\n"
  "visited Sarpedon only to fetch fire? At last, at the end of a\n"
  "week, they returned to Troy; Troilus hoping to find Cressida\n"
  "again in the city, Pandarus entertaining a scepticism which he\n"
  "concealed from his friend. The morning after their return,\n"
  "Troilus was impatient till he had gone to the palace of Cressida;\n"
  "but when he found her doors all closed, \"well nigh for sorrow\n"
  "adown he gan to fall.\"\n"
  "\n"
  "Therewith, when he was ware, and gan behold\n"
  "How shut was ev'ry window of the place,\n"
  "As frost him thought his hearte *gan to cold;*      *began to grow cold*\n"
  "For which, with changed deadly pale face,\n"
  "Withoute word, he forth began to pace;\n"
  "And, as God would, he gan so faste ride,\n"
  "That no wight of his countenance espied.\n"
  "\n"
  "Then said he thus: \"O palace desolate!\n"
  "O house of houses, *whilom beste hight!*          *formerly called best*\n"
  "O palace empty and disconsolate!\n"
  "O thou lantern, of which quench'd is the light!\n"
  "O palace, whilom day, that now art night!\n"
  "Well oughtest thou to fall, and I to die,\n"
  "Since she is gone that wont was us to guy!*                 *guide, rule\n"
  "\n"
  "\"O palace, whilom crown of houses all,\n"
  "Illumined with sun of alle bliss!\n"
  "O ring, from which the ruby is out fall!\n"
  "O cause of woe, that cause hast been of bliss!\n"
  "Yet, since I may no bet, fain would I kiss\n"
  "Thy colde doores, durst I for this rout;\n"
  "And farewell shrine, of which the saint is out!\"\n"
  "\n"
  ".   .   .   .   .   .   .   .   .   .   .\n"
  "\n"
  "From thence forth he rideth up and down,\n"
  "And ev'ry thing came him to remembrance,\n"
  "As he rode by the places of the town,\n"
  "In which he whilom had all his pleasance;\n"
  "\"Lo! yonder saw I mine own lady dance;\n"
  "And in that temple, with her eyen clear,\n"
  "Me caughte first my righte lady dear.\n"
  "\n"
  "\"And yonder have I heard full lustily\n"
  "My deare hearte laugh; and yonder play:\n"
  "Saw I her ones eke full blissfully;\n"
  "And yonder ones to me gan she say,\n"
  "'Now, goode sweete! love me well, I pray;'\n"
  "And yond so gladly gan she me behold,\n"
  "That to the death my heart is to her hold.*               *holden, bound\n"
  "\n"
  "\"And at that corner, in the yonder house,\n"
  "Heard I mine allerlevest* lady dear,                     *dearest of all\n"
  "So womanly, with voice melodious,\n"
  "Singe so well, so goodly and so clear,\n"
  "That in my soule yet me thinks I hear\n"
  "The blissful sound; and in that yonder place\n"
  "My lady first me took unto her grace.\"\n"
  "\n"
  "Then he went to the gates, and gazed along the way by which\n"
  "he had attended Cressida at her departure; then he fancied that\n"
  "all the passers-by pitied him; and thus he drove forth a day or\n"
  "two more, singing a song, of few words, which he had made to\n"
  "lighten his heart:\n"
  "\n"
  "\"O star, of which I lost have all the light,\n"
  "With hearte sore well ought I to bewail,\n"
  "That ever dark in torment, night by night,\n"
  "Toward my death, with wind I steer and sail;\n"
  "For which, the tenthe night, if that I fail*      *miss; be left without\n"
  "The guiding of thy beames bright an hour,\n"
  "My ship and me Charybdis will devour.\"\n"
  "\n"
  "By night he prayed the moon to run fast about her sphere; by\n"
  "day he reproached the tardy sun -- dreading that Phaethon had\n"
  "come to life again, and was driving the chariot of Apollo out of\n"
  "its straight course. Meanwhile Cressida, among the Greeks, was\n"
  "bewailing the refusal of her father to let her return, the certainty\n"
  "that her lover would think her false, and the hopelessness of any\n"
  "attempt to steal away by night. Her bright face waxed pale, her\n"
  "limbs lean, as she stood all day looking toward Troy; thinking\n"
  "on her love and all her past delights, regretting that she had not\n"
  "followed the counsel of Troilus to steal away with him, and\n"
  "finally vowing that she would at all hazards return to the city.\n"
  "But she was fated, ere two months, to be full far from any such\n"
  "intention; for Diomede now brought all his skill into play, to\n"
  "entice Cressida into his net. On the tenth day, Diomede, \"as\n"
  "fresh as branch in May,\" came to the tent of Cressida, feigning\n"
  "business with Calchas.\n"
  "\n"
  "Cresside, at shorte wordes for to tell,\n"
  "Welcomed him, and down by her him set,\n"
  "And he was *eath enough to make dwell;*       *easily persuaded to stay*\n"
  "And after this, withoute longe let,*                              *delay\n"
  "The spices and the wine men forth him fet,*                     *fetched\n"
  "And forth they speak of this and that y-fere,*                 *together\n"
  "As friendes do, of which some shall ye hear.\n"
  "\n"
  "He gan first fallen of the war in speech\n"
  "Between them and the folk of Troye town,\n"
  "And of the siege he gan eke her beseech\n"
  "To tell him what was her opinioun;\n"
  "From that demand he so descended down\n"
  "To aske her, if that her strange thought\n"
  "The Greekes' guise,* and workes that they wrought.              *fashion\n"
  "\n"
  "And why her father tarried* so long                             *delayed\n"
  "To wedde her unto some worthy wight.\n"
  "Cressida, that was in her paines strong\n"
  "For love of Troilus, her owen knight,\n"
  "So farforth as she cunning* had or might,                       *ability\n"
  "Answer'd him then; but, as for his intent,*                     *purpose\n"
  "It seemed not she wiste* what he meant.                            *knew\n"
  "\n"
  "But natheless this ilke* Diomede                                   *same\n"
  "Gan *in himself assure,* and thus he said;              *grow confident*\n"
  "\"If I aright have *taken on you heed,*                    *observed you*\n"
  "Me thinketh thus, O lady mine Cresside,\n"
  "That since I first hand on your bridle laid,\n"
  "When ye out came of Troye by the morrow,\n"
  "Ne might I never see you but in sorrow.\n"
  "\n"
  "\"I cannot say what may the cause be,\n"
  "But if for love of some Trojan it were;\n"
  "*The which right sore would a-thinke me*            *which it would much\n"
  "That ye for any wight that dwelleth there              pain me to think*\n"
  "Should [ever] spill* a quarter of a tear,                          *shed\n"
  "Or piteously yourselfe so beguile;*                             *deceive\n"
  "For dreadeless* it is not worth the while.                  *undoubtedly\n"
  "\n"
  "\"The folk of Troy, as who saith, all and some\n"
  "In prison be, as ye yourselfe see;\n"
  "From thence shall not one alive come\n"
  "For all the gold betwixte sun and sea;\n"
  "Truste this well, and understande me;\n"
  "There shall not one to mercy go alive,\n"
  "All* were he lord of worldes twice five.                       *although\n"
  "\n"
  ".   .   .   .   .   .   .   .   .   .   .   .\n"
  "\n"
  "\"What will ye more, lovesome lady dear?\n"
  "Let Troy and Trojan from your hearte pace;\n"
  "Drive out that bitter hope, and make good cheer,\n"
  "And call again the beauty of your face,\n"
  "That ye with salte teares so deface;\n"
  "For Troy is brought into such jeopardy,\n"
  "That it to save is now no remedy.\n"
  "\n"
  "\"And thinke well, ye shall in Greekes find\n"
  "A love more perfect, ere that it be night,\n"
  "Than any Trojan is, and more kind,\n"
  "And better you to serve will do his might;\n"
  "And, if ye vouchesafe, my lady bright,\n"
  "I will be he, to serve you, myselve, --\n"
  "Yea, lever* than be a lord of Greekes twelve!\"                   *rather\n"
  "\n"
  "And with that word he gan to waxe red,\n"
  "And in his speech a little while he quoke,*            *quaked; trembled\n"
  "And cast aside a little with his head,\n"
  "And stint a while; and afterward he woke,\n"
  "And soberly on her he threw his look,\n"
  "And said, \"I am, albeit to you no joy,\n"
  "As gentle* man as any wight in Troy.                          *high-born\n"
  "\n"
  "\"But, hearte mine! since that I am your man,*         *leigeman, subject\n"
  "And [you] be the first of whom I seeke grace,                  (in love)\n"
  "To serve you as heartily as I can,\n"
  "And ever shall, while I to live have space,\n"
  "So, ere that I depart out of this place,\n"
  "Ye will me grante that I may, to-morrow,\n"
  "At better leisure, telle you my sorrow.\"\n"
  "\n"
  "";
// }

const char poemTroilusAndCressida4[] PGMSECTION = // { // 30889 bytes
  "Why should I tell his wordes that he said?\n"
  "He spake enough for one day at the mest;*                          *most\n"
  "It proveth well he spake so, that Cresseide\n"
  "Granted upon the morrow, at his request,\n"
  "Farther to speake with him, at the least,\n"
  "So that he would not speak of such mattere;\n"
  "And thus she said to him, as ye may hear:\n"
  "\n"
  "As she that had her heart on Troilus\n"
  "So faste set, that none might it arace;*                    *uproot <83>\n"
  "And strangely* she spake, and saide thus;       *distantly, unfriendlily\n"
  "\"O Diomede! I love that ilke place\n"
  "Where I was born; and Jovis, for his grace,\n"
  "Deliver it soon of all that doth it care!*                      *afflict\n"
  "God, for thy might, so *leave it* well to fare!\"              *grant it*\n"
  "\n"
  "She knows that the Greeks would fain wreak their wrath on\n"
  "Troy, if they might; but that shall never befall: she knows that\n"
  "there are Greeks of high condition -- though as worthy men\n"
  "would be found in Troy: and she knows that Diomede could\n"
  "serve his lady well.\n"
  "\n"
  "\"But, as to speak of love, y-wis,\" she said,\n"
  "\"I had a lord, to whom I wedded was, <84>\n"
  "He whose mine heart was all, until he died;\n"
  "And other love, as help me now Pallas,\n"
  "There in my heart nor is, nor ever was;\n"
  "And that ye be of noble and high kindred,\n"
  "I have well heard it tellen, out of dread.*                       *doubt\n"
  "\n"
  "\"And that doth* me to have so great a wonder                    *causeth\n"
  "That ye will scornen any woman so;\n"
  "Eke, God wot, love and I be far asunder;\n"
  "I am disposed bet, so may I go,*                        *fare or prosper\n"
  "Unto my death to plain and make woe;\n"
  "What I shall after do I cannot say,\n"
  "But truely as yet *me list not play.*                 *I am not disposed\n"
  "                                                              *for sport\n"
  "\"Mine heart is now in tribulatioun;\n"
  "And ye in armes busy be by day;\n"
  "Hereafter, when ye wonnen have the town,\n"
  "Parauntre* then, so as it happen may,                      *peradventure\n"
  "That when I see that I never *ere sey,*                     *saw before*\n"
  "Then will I work that I never ere wrought;\n"
  "This word to you enough sufficen ought.\n"
  "\n"
  "\"To-morrow eke will I speak with you fain,*                   *willingly\n"
  "So that ye touche naught of this mattere;\n"
  "And when you list, ye may come here again,\n"
  "And ere ye go, thus much I say you here:\n"
  "As help me Pallas, with her haires clear,\n"
  "If that I should of any Greek have ruth,\n"
  "It shoulde be yourselfe, by my truth!\n"
  "\n"
  "\"I say not therefore that I will you love;\n"
  "*Nor say not nay;* but, in conclusioun,                  *nor say I that\n"
  "I meane well, by God that sits above!\"                       I will not*\n"
  "And therewithal she cast her eyen down,\n"
  "And gan to sigh, and said; \"O Troye town!\n"
  "Yet bid* I God, in quiet and in rest                               *pray\n"
  "I may you see, or *do my hearte brest!\"*       *cause my heart to break*\n"
  "\n"
  "But in effect, and shortly for to say,\n"
  "This Diomede all freshly new again\n"
  "Gan pressen on, and fast her mercy pray;\n"
  "And after this, the soothe for to sayn,\n"
  "Her glove he took, of which he was full fain,\n"
  "And finally, when it was waxen eve,\n"
  "And all was well, he rose and took his leave.\n"
  "\n"
  "Cressida retired to rest:\n"
  "\n"
  "Returning in her soul ay up and down\n"
  "The wordes of this sudden Diomede,<85>\n"
  "His great estate,* the peril of the town,                          *rank\n"
  "And that she was alone, and hadde need\n"
  "Of friendes' help; and thus began to dread\n"
  "The causes why, the soothe for to tell,\n"
  "That she took fully the purpose for to dwell.*         *remain (with the\n"
  "                                                                 Greeks)\n"
  "The morrow came, and, ghostly* for to speak,                    *plainly\n"
  "This Diomede is come unto Cresseide;\n"
  "And shortly, lest that ye my tale break,\n"
  "So well he for himselfe spake and said,\n"
  "That all her sighes sore adown he laid;\n"
  "And finally, the soothe for to sayn,\n"
  "He refte* her the great** of all her pain.      *took away **the greater\n"
  "                                                                 part of\n"
  "And after this, the story telleth us\n"
  "That she him gave the faire baye steed\n"
  "The which she ones won of Troilus;\n"
  "And eke a brooch (and that was little need)\n"
  "That Troilus' was, she gave this Diomede;\n"
  "And eke, the bet from sorrow him to relieve,\n"
  "She made him wear a pensel* of her sleeve.                 *pendant <86>\n"
  "\n"
  "I find eke in the story elleswhere,\n"
  "When through the body hurt was Diomede\n"
  "By Troilus, she wept many a tear,\n"
  "When that she saw his wide woundes bleed,\n"
  "And that she took to keepe* him good heed,               *tend, care for\n"
  "And, for to heal him of his sorrow's smart,\n"
  "Men say, I n'ot,* that she gave him her heart.                 *know not\n"
  "\n"
  "And yet, when pity had thus completed the triumph of\n"
  "inconstancy, she made bitter moan over her falseness to one of\n"
  "the noblest and worthiest men that ever was; but it was now too\n"
  "late to repent, and at all events she resolved that she would be\n"
  "true to Diomede -- all the while weeping for pity of the absent\n"
  "Troilus, to whom she wished every happiness. The tenth day,\n"
  "meantime, had barely dawned, when Troilus, accompanied by\n"
  "Pandarus, took his stand on the walls, to watch for the return of\n"
  "Cressida. Till noon they stood, thinking that every corner from\n"
  "afar was she; then Troilus said that doubtless her old father bore\n"
  "the parting ill, and had detained her till after dinner; so they\n"
  "went to dine, and returned to their vain observation on the\n"
  "walls. Troilus invented all kinds of explanations for his\n"
  "mistress's delay; now, her father would not let her go till eve;\n"
  "now, she would ride quietly into the town after nightfall, not to\n"
  "be observed; now, he must have mistaken the day. For five or\n"
  "six days he watched, still in vain, and with decreasing hope.\n"
  "Gradually his strength decayed, until he could walk only with a\n"
  "staff; answering the wondering inquiries of his friends, by saying\n"
  "that he had a grievous malady about his heart. One day he\n"
  "dreamed that in a forest he saw Cressida in the embrace of a\n"
  "boar; and he had no longer doubt of her falsehood. Pandarus,\n"
  "however, explained away the dream to mean merely that\n"
  "Cressida was detained by her father, who might be at the point\n"
  "of death; and he counselled the disconsolate lover to write a\n"
  "letter, by which he might perhaps get at the truth. Troilus\n"
  "complied, entreating from his mistress, at the least, a \"letter of\n"
  "hope;\" and the lady answered, that she could not come now, but\n"
  "would so soon as she might; at the same time \"making him great\n"
  "feast,\" and swearing that she loved him best -- \"of which he\n"
  "found but bottomless behest [which he found but groundless\n"
  "promises].\" Day by day increased the woe of Troilus; he laid\n"
  "himself in bed, neither eating, nor drinking, nor sleeping, nor\n"
  "speaking, almost distracted by the thought of Cressida's\n"
  "unkindness. He related his dream to his sister Cassandra, who\n"
  "told him that the boar betokened Diomede, and that,\n"
  "wheresoever his lady was, Diornede certainly had her heart, and\n"
  "she was his: \"weep if thou wilt, or leave, for, out of doubt, this\n"
  "Diomede is in, and thou art out.\" Troilus, enraged, refused to\n"
  "believe Cassandra's interpretation; as well, he cried, might such\n"
  "a story be credited of Alcestis, who devoted her life for her\n"
  "husband; and in his wrath he started from bed, \"as though all\n"
  "whole had him y-made a leach [physician],\" resolving to find\n"
  "out the truth at all hazards. The death of Hector meanwhile\n"
  "enhanced the sorrow which he endured; but he found time to\n"
  "write often to Cressida, beseeching her to come again and hold\n"
  "her truth; till one day his false mistress, out of pity, wrote him\n"
  "again, in these terms:\n"
  "\n"
  "\"Cupide's son, ensample of goodlihead,*              *beauty, excellence\n"
  "O sword of knighthood, source of gentleness!\n"
  "How might a wight in torment and in dread,\n"
  "And healeless,* you send as yet gladness?              *devoid of health\n"
  "I hearteless, I sick, I in distress?\n"
  "Since ye with me, nor I with you, may deal,\n"
  "You neither send I may nor heart nor heal.\n"
  "\n"
  "\"Your letters full, the paper all y-plainted,*             *covered with\n"
  "Commoved have mine heart's pitt;                            complainings\n"
  "I have eke seen with teares all depainted\n"
  "Your letter, and how ye require me\n"
  "To come again; the which yet may not be;\n"
  "But why, lest that this letter founden were,\n"
  "No mention I make now for fear.\n"
  "\n"
  "\"Grievous to me, God wot, is your unrest,\n"
  "Your haste,* and that the goddes' ordinance                  *impatience\n"
  "It seemeth not ye take as for the best;\n"
  "Nor other thing is in your remembrance,\n"
  "As thinketh me, but only your pleasance;\n"
  "But be not wroth, and that I you beseech,\n"
  "For that I tarry is *all for wicked speech.*         *to avoid malicious\n"
  "                                                                 gossip*\n"
  "\"For I have heard well more than I wend*                *weened, thought\n"
  "Touching us two, how thinges have stood,\n"
  "Which I shall with dissimuling amend;\n"
  "And, be not wroth, I have eke understood\n"
  "How ye ne do but holde me on hand; <87>\n"
  "But now *no force,* I cannot in you guess                    *no matter*\n"
  "But alle truth and alle gentleness.\n"
  "\n"
  "\"Comen I will, but yet in such disjoint*             *jeopardy, critical\n"
  "I stande now, that what year or what day                        position\n"
  "That this shall be, that can I not appoint;\n"
  "But in effect I pray you, as I may,\n"
  "For your good word and for your friendship ay;\n"
  "For truely, while that my life may dure,\n"
  "As for a friend, ye may *in me assure.*                   *depend on me*\n"
  "\n"
  "\"Yet pray I you, *on evil ye not take*              *do not take it ill*\n"
  "That it is short, which that I to you write;\n"
  "I dare not, where I am, well letters make;\n"
  "Nor never yet ne could I well endite;\n"
  "Eke *great effect men write in place lite;*      *men write great matter\n"
  "Th' intent is all, and not the letter's space;          in little space*\n"
  "And fare now well, God have you in his grace!\n"
  "                           \"La Vostre C.\"\n"
  "\n"
  "Though he found this letter \"all strange,\" and thought it like \"a\n"
  "kalendes of change,\" <88> Troilus could not believe his lady so\n"
  "cruel as to forsake him; but he was put out of all doubt, one day\n"
  "that, as he stood in suspicion and melancholy, he saw a \"coat-\n"
  "armour\" borne along the street, in token of victory, before\n"
  "Deiphobus his brother. Deiphobus had won it from Diomede in\n"
  "battle that day; and Troilus, examining it out of curiosity, found\n"
  "within the collar a brooch which he had given to Cressida on the\n"
  "morning she left Troy, and which she had pledged her faith to\n"
  "keep for ever in remembrance of his sorrow and of him. At this\n"
  "fatal discovery of his lady's untruth,\n"
  "\n"
  "Great was the sorrow and plaint of Troilus;\n"
  "But forth her course Fortune ay gan to hold;\n"
  "Cressida lov'd the son of Tydeus,\n"
  "And Troilus must weep in cares cold.\n"
  "Such is the world, whoso it can behold!\n"
  "In each estate is little hearte's rest;\n"
  "God lend* us each to take it for the best!                        *grant\n"
  "\n"
  "In many a cruel battle Troilus wrought havoc among the\n"
  "Greeks, and often he exchanged blows and bitter words with\n"
  "Diomede, whom he always specially sought; but it was not their\n"
  "lot that either should fall by the other's hand. The poet's\n"
  "purpose, however, he tells us, is to relate, not the warlike deeds\n"
  "of Troilus, which Dares has fully told, but his love-fortunes:\n"
  "\n"
  "Beseeching ev'ry lady bright of hue,\n"
  "And ev'ry gentle woman, *what she be,*               *whatsoever she be*\n"
  "Albeit that Cressida was untrue,\n"
  "That for that guilt ye be not wroth with me;\n"
  "Ye may her guilt in other bookes see;\n"
  "And gladder I would writen, if you lest,\n"
  "Of Penelope's truth, and good Alceste.\n"
  "\n"
  "Nor say I not this only all for men,\n"
  "But most for women that betrayed be\n"
  "Through false folk (God give them sorrow, Amen!)\n"
  "That with their greate wit and subtilty\n"
  "Betraye you; and this commoveth me\n"
  "To speak; and in effect you all I pray,\n"
  "Beware of men, and hearken what I say.\n"
  "\n"
  "Go, little book, go, little tragedy!\n"
  "There God my maker, yet ere that I die,\n"
  "So send me might to make some comedy!\n"
  "But, little book, *no making thou envy,*  *be envious of no poetry* <89>\n"
  "But subject be unto all poesy;\n"
  "And kiss the steps, where as thou seest space,\n"
  "Of Virgil, Ovid, Homer, Lucan, Stace.\n"
  "\n"
  "And, for there is so great diversity\n"
  "In English, and in writing of our tongue,\n"
  "So pray I God, that none miswrite thee,\n"
  "Nor thee mismetre for default of tongue!\n"
  "And read whereso thou be, or elles sung,\n"
  "That thou be understanden, God I 'seech!*                       *beseech\n"
  "But yet to purpose of my *rather speech.*         *earlier subject* <90>\n"
  "\n"
  "The wrath, as I began you for to say,\n"
  "Of Troilus the Greekes boughte dear;\n"
  "For thousandes his handes *made dey,*                      *made to die*\n"
  "As he that was withouten any peer,\n"
  "Save in his time Hector, as I can hear;\n"
  "But, well-away! save only Godde's will,\n"
  "Dispiteously him slew the fierce Achill'.\n"
  "\n"
  "And when that he was slain in this mannere,\n"
  "His lighte ghost* full blissfully is went                        *spirit\n"
  "Up to the hollowness of the seventh sphere <91>\n"
  "In converse leaving ev'ry element;\n"
  "And there he saw, with full advisement,*     *observation, understanding\n"
  "Th' erratic starres heark'ning harmony,\n"
  "With soundes full of heav'nly melody.\n"
  "\n"
  "And down from thennes fast he gan advise*             *consider, look on\n"
  "This little spot of earth, that with the sea\n"
  "Embraced is; and fully gan despise\n"
  "This wretched world, and held all vanity,\n"
  "*To respect of the plein felicity*                   *in comparison with\n"
  "That is in heav'n above; and, at the last,            the full felicity*\n"
  "Where he was slain his looking down he cast.\n"
  "\n"
  "And in himself he laugh'd right at the woe\n"
  "Of them that wepte for his death so fast;\n"
  "And damned* all our works, that follow so                     *condemned\n"
  "The blinde lust, the which that may not last,\n"
  "And shoulden* all our heart on heaven cast;             *while we should\n"
  "And forth he wente, shortly for to tell,\n"
  "Where as Mercury sorted* him to dwell.                    *allotted <92>\n"
  "\n"
  "Such fine* hath, lo! this Troilus for love!                         *end\n"
  "Such fine hath all his *greate worthiness!*         *exalted royal rank*\n"
  "Such fine hath his estate royal above!\n"
  "Such fine his lust,* such fine hath his nobless!               *pleasure\n"
  "Such fine hath false worlde's brittleness!*     *fickleness, instability\n"
  "And thus began his loving of Cresside,\n"
  "As I have told; and in this wise he died.\n"
  "\n"
  "O young and freshe folke, *he or she,*                   *of either sex*\n"
  "In which that love upgroweth with your age,\n"
  "Repaire home from worldly vanity,\n"
  "And *of your heart upcaste the visage*         *\"lift up the countenance\n"
  "To thilke God, that after his image                     of your heart.\"*\n"
  "You made, and think that all is but a fair,\n"
  "This world that passeth soon, as flowers fair!\n"
  "\n"
  "And love Him, the which that, right for love,\n"
  "Upon a cross, our soules for to bey,*                       *buy, redeem\n"
  "First starf,* and rose, and sits in heav'n above;                  *died\n"
  "For he will false* no wight, dare I say,                  *deceive, fail\n"
  "That will his heart all wholly on him lay;\n"
  "And since he best to love is, and most meek,\n"
  "What needeth feigned loves for to seek?\n"
  "\n"
  "Lo! here of paynims* cursed olde rites!                          *pagans\n"
  "Lo! here what all their goddes may avail!\n"
  "Lo! here this wretched worlde's appetites!               *end and reward\n"
  "Lo! here the *fine and guerdon for travail,*                  of labour*\n"
  "Of Jove, Apollo, Mars, and such rascaille*                  *rabble <93>\n"
  "Lo! here the form of olde clerkes' speech,\n"
  "In poetry, if ye their bookes seech!*                      *seek, search\n"
  "\n"
  "\n"
  "L'Envoy of Chaucer.\n"
  "\n"
  "\n"
  "O moral Gower! <94> this book I direct.\n"
  "To thee, and to the philosophical Strode, <95>\n"
  "To vouchesafe, where need is, to correct,\n"
  "Of your benignities and zeales good.\n"
  "And to that soothfast Christ that *starf on rood*    *died on the cross*\n"
  "With all my heart, of mercy ever I pray,\n"
  "And to the Lord right thus I speak and say:\n"
  "\n"
  "\"Thou One, and Two, and Three, *etern on live,*       *eternally living*\n"
  "That reignest ay in Three, and Two, and One,\n"
  "Uncircumscrib'd, and all may'st circumscrive,*               *comprehend\n"
  "From visible and invisible fone*                                   *foes\n"
  "Defend us in thy mercy ev'ry one;\n"
  "So make us, Jesus, *for thy mercy dign,*           *worthy of thy mercy*\n"
  "For love of Maid and Mother thine benign!\"\n"
  "\n"
  "Explicit Liber Troili et Cresseidis. <96>\n"
  "\n"
  "\n"
  "Notes to Troilus and Cressida\n"
  "\n"
  "\n"
  "1. The double sorrow: First his suffering before his love was\n"
  "successful; and then his grief after his lady had been separated\n"
  "from him, and had proved unfaithful.\n"
  "\n"
  "2. Tisiphone: one of the Eumenides, or Furies, who avenged on\n"
  "men in the next world the crimes committed on earth. Chaucer\n"
  "makes this grim invocation most fitly, since the Trojans were\n"
  "under the curse of the Eumenides, for their part in the offence\n"
  "of Paris in carrying off Helen, the wife of his host Menelaus,\n"
  "and thus impiously sinning against the laws of hospitality.\n"
  "\n"
  "3. See Chaucer's description of himself in \"The House Of\n"
  "Fame,\" and note 11 to that poem.\n"
  "\n"
  "4. The Palladium, or image of Pallas (daughter of Triton and\n"
  "foster-sister of Athena), was said to have fallen from heaven at\n"
  "Troy, where Ilus was just beginning to found the city; and Ilus\n"
  "erected a sanctuary, in which it was preserved with great\n"
  "honour and care, since on its safety was supposed to depend the\n"
  "safety of the city. In later times a Palladium was any statue of\n"
  "the goddess Athena kept for the safeguard of the city that\n"
  "possessed it.\n"
  "\n"
  "5. \"Oh, very god!\": oh true divinity! -- addressing Cressida.\n"
  "\n"
  "6. Ascaunce: as if to say -- as much as to say. The word\n"
  "represents \"Quasi dicesse\" in Boccaccio. See note 5 to the\n"
  "Sompnour's Tale.\n"
  "\n"
  "7. Eft: another reading is \"oft.\"\n"
  "\n"
  "8. Arten: constrain -- Latin, \"arceo.\"\n"
  "\n"
  "9. The song is a translation of Petrarch's 88th Sonnet, which\n"
  "opens thus:\n"
  "\"S'amor non e, che dunque e quel ch'i'sento.\"\n"
  "\n"
  "10. If maugre me: If (I burn) in spite of myself. The usual\n"
  "reading is, \"If harm agree me\" = if my hurt contents me: but\n"
  "evidently the antithesis is lost which Petrarch intended when,\n"
  "after \"s'a mia voglia ardo,\" he wrote \"s'a mal mio grado\" = if\n"
  "against my will; and Urry's Glossary points out the probability\n"
  "that in transcription the words \"If that maugre me\" may have\n"
  "gradually changed into \"If harm agre me.\"\n"
  "\n"
  "11. The Third of May seems either to have possessed peculiar\n"
  "favour or significance with Chaucer personally, or to have had a\n"
  "special importance in connection with those May observances\n"
  "of which the poet so often speaks. It is on the third night of\n"
  "May that Palamon, in The Knight's Tale, breaks out of prison,\n"
  "and at early morn encounters in the forest Arcita, who has gone\n"
  "forth to pluck a garland in honour of May; it is on the third\n"
  "night of May that the poet hears the debate of \"The Cuckoo and\n"
  "the Nightingale\"; and again in the present passage the favoured\n"
  "date recurs.\n"
  "\n"
  "12. Went: turning; from Anglo-Saxon, \"wendan;\" German,\n"
  "\"wenden.\" The turning and tossing of uneasy lovers in bed is,\n"
  "with Chaucer, a favourite symptom of their passion. See the\n"
  "fifth \"statute,\" in The Court of Love.\n"
  "\n"
  "13. Procne, daughter of Pandion, king of Attica, was given to\n"
  "wife to Tereus in reward for his aid against an enemy; but\n"
  "Tereus dishonoured Philomela, Procne's sister; and his wife, in\n"
  "revenge, served up to him the body of his own child by her.\n"
  "Tereus, infuriated, pursued the two sisters, who prayed the\n"
  "gods to change them into birds. The prayer was granted;\n"
  "Philomela became a nightingale, Procne a swallow, and Tereus\n"
  "a hawk.\n"
  "\n"
  "14. Fished fair: a proverbial phrase which probably may be best\n"
  "represented by the phrase \"done great execution.\"\n"
  "\n"
  "15. The fair gem virtueless:  possessing none of the virtues\n"
  "which in the Middle Ages were universally believed to be\n"
  "inherent in precious stones.\n"
  "\n"
  "16. The crop and root: the most perfect example. See note 29\n"
  "to the Knight's Tale.\n"
  "\n"
  "17. Eme: uncle; the mother's brother; still used in Lancashire.\n"
  "Anglo-Saxon, \"eame;\" German, \"Oheim.\"\n"
  "\n"
  "18. Dardanus: the mythical ancestor of the Trojans, after whom\n"
  "the gate is supposed to be called.\n"
  "\n"
  "19. All the other gates were secured with chains, for better\n"
  "defence against the besiegers.\n"
  "\n"
  "20. Happy day:  good fortune; French, \"bonheur;\" both \"happy\n"
  "day\" and \"happy hour\" are borrowed from the astrological\n"
  "fiction about the influence of the time of birth.\n"
  "\n"
  "21. Horn, and nerve, and rind: The various layers or materials\n"
  "of the shield -- called boagrion in the Iliad -- which was made\n"
  "from the hide of the wild bull.\n"
  "\n"
  "22. His brother:  Hector.\n"
  "\n"
  "23. Who gives me drink?: Who has given me a love-potion, to\n"
  "charm my heart thus away?\n"
  "\n"
  "24. That plaited she full oft in many a fold: She deliberated\n"
  "carefully, with many arguments this way and that.\n"
  "\n"
  "25. Through which I mighte stand in worse plight: in a worse\n"
  "position in the city; since she might through his anger lose the\n"
  "protection of his brother Hector.\n"
  "\n"
  "26. I am not religious: I am not in holy vows. See the complaint\n"
  "of the nuns in \"The Court of Love.\"\n"
  "\n"
  "27. The line recalls Milton's \"dark with excessive bright.\"\n"
  "\n"
  "28. No weal is worth, that may no sorrow drien: the meaning is,\n"
  "that whosoever cannot endure sorrow deserves not happiness.\n"
  "\n"
  "29. French, \"verre;\" glass.\n"
  "\n"
  "30. From cast of stones ware him in the werre: let him beware\n"
  "of casting stones in battle. The proverb in its modern form\n"
  "warns those who live in glass houses of the folly of throwing\n"
  "stones.\n"
  "\n"
  "31. Westren:  to west or wester -- to decline towards the west;\n"
  "so Milton speaks of the morning star as sloping towards\n"
  "heaven's descent \"his westering wheel.\"\n"
  "\n"
  "32. A pike with ass's feet etc.: this is merely another version of\n"
  "the well-known example of incongruity that opens the \"Ars\n"
  "Poetica\" of Horace.\n"
  "\n"
  "33. Tristre: tryst; a preconcerted spot to which the beaters\n"
  "drove the game, and at which the sportsmen waited with their\n"
  "bows.\n"
  "\n"
  "34. A kankerdort: a condition or fit of perplexed anxiety;\n"
  "probably connected with the word \"kink\" meaning in sea phrase\n"
  "a twist in an rope -- and, as a verb, to twist or entangle.\n"
  "\n"
  "35. They feel in times, with vapour etern: they feel in their\n"
  "seasons, by the emission of an eternal breath or inspiration (that\n"
  "God loves, &c.)\n"
  "\n"
  "36. The idea of this stanza is the same with that developed in\n"
  "the speech of Theseus at the close of The Knight's Tale; and it is\n"
  "probably derived from the lines of Boethius, quoted in note 91\n"
  "to that Tale.\n"
  "\n"
  "37. In this and the following lines reappears the noble doctrine\n"
  "of the exalting and purifying influence of true love, advanced in\n"
  "\"The Court of Love,\" \"The Cuckoo and the Nightingale,\" &c.\n"
  "\n"
  "38. Weir: a trap or enclosed place in a stream, for catching fish.\n"
  "See note 10 to The Assembly of Fowls.\n"
  "\n"
  "39. Nor might one word for shame to it say: nor could he\n"
  "answer one word for shame (at the stratagem that brought\n"
  "Cressida to implore his protection)\n"
  "\n"
  "40. \"All n'ere he malapert, nor made avow\n"
  "     Nor was so bold to sing a foole's mass;\"\n"
  "i.e. although he was not over-forward and made no confession\n"
  "(of his love), or was so bold as to be rash and ill-advised in his\n"
  "declarations of love and worship.\n"
  "\n"
  "41. Pandarus wept as if he would turn to water; so, in The\n"
  "Squire's Tale, did Canace weep for the woes of the falcon.\n"
  "\n"
  "42. If I breake your defence: if I transgress in whatever you may\n"
  "forbid; French, \"defendre,\" to prohibit.\n"
  "\n"
  "43. These lines and the succeeding stanza are addressed to\n"
  "Pandarus, who had interposed some words of incitement to\n"
  "Cressida.\n"
  "\n"
  "44.  In \"The Court of Love,\" the poet says of Avaunter, that\n"
  "\"his ancestry of kin was to Lier; and the stanza in which that\n"
  "line occurs  expresses precisely the same idea as in the text.\n"
  "Vain boasters  of ladies' favours are also satirised in \"The House\n"
  "of Fame\".\n"
  "\n"
  "45. Nice:  silly, stupid; French, \"niais.\"\n"
  "\n"
  "46.\"Reheating\" is read by preference for \"richesse,\" which\n"
  "stands in the older printed editions; though \"richesse\" certainly\n"
  "better represents the word used in the original of Boccaccio --\n"
  "\"dovizia,\" meaning abundance or wealth.\n"
  "\n"
  "47. \"Depart it so, for widewhere is wist\n"
  "     How that there is diversity requer'd\n"
  "     Betwixte thinges like, as I have lear'd:\"\n"
  "i.e. make this distinction, for it is universally known that there is\n"
  "a great difference between things that seem the same, as I have\n"
  "learned.\n"
  "\n"
  "48. Frepe: the set, or company; French, \"frappe,\" a stamp (on\n"
  "coins), a set (of moulds).\n"
  "\n"
  "49. To be \"in the wind\" of noisy magpies, or other birds that\n"
  "might spoil sport by alarming the game, was not less desirable\n"
  "than to be on the \"lee-side\" of the game itself, that the hunter's\n"
  "presence might not be betrayed by the scent. \"In the wind of,\"\n"
  "thus signifies not to windward of, but to leeward of -- that is, in\n"
  "the wind that comes from the object of pursuit.\n"
  "\n"
  "50. Bothe fremd and tame: both foes and friends -- literally,\n"
  "both wild and tame, the sporting metaphor being sustained.\n"
  "\n"
  "51. The lovers are supposed to say, that nothing is wanting but\n"
  "to know the time at which they should meet.\n"
  "\n"
  "52. A  tale of Wade: see note 5 to the Merchant's Tale.\n"
  "\n"
  "53. Saturn, and Jove, in Cancer joined were: a conjunction that\n"
  "imported rain.\n"
  "\n"
  "54. Smoky rain: An admirably graphic description of dense rain.\n"
  "\n"
  "55. For the force of \"cold,\" see note 22 to the Nun's Priest's\n"
  "Tale.\n"
  "\n"
  "56. Goddes seven:  The divinities who gave their names to the\n"
  "seven planets, which, in association with the seven metals, are\n"
  "mentioned in The Canon's Yeoman's Tale.\n"
  "\n"
  "57. Assayed:  experienced, tasted. See note 6 to the Squire's\n"
  "Tale.\n"
  "\n"
  "58. Now is it better than both two were lorn: better this happy\n"
  "issue, than that both two should be lost (through the sorrow of\n"
  "fruitless love).\n"
  "\n"
  "59. Made him such feast: French, \"lui fit fete\" -- made holiday\n"
  "for him.\n"
  "\n"
  "60. The cock is called, in \"The Assembly of Fowls,\" \"the\n"
  "horologe of thorpes lite;\" [the clock of little villages] and in The\n"
  "Nun's Priest's Tale Chanticleer knew by nature each ascension\n"
  "of the equinoctial, and, when the sun had ascended fifteen\n"
  "degrees, \"then crew he, that it might not be amended.\" Here he\n"
  "is termed the \"common astrologer,\" as employing for the public\n"
  "advantage his knowledge of astronomy.\n"
  "\n"
  "61. Fortuna Major: the planet Jupiter.\n"
  "\n"
  "62. When Jupiter visited Alcmena in the form of her husband\n"
  "Amphitryon, he is said to have prolonged the night to the length\n"
  "of three natural nights. Hercules was the fruit of the union.\n"
  "\n"
  "63. Chaucer seems to confound Titan, the title of the sun, with\n"
  "Tithonus (or Tithon, as contracted in poetry), whose couch\n"
  "Aurora was wont to share.\n"
  "\n"
  "64. So, in \"Locksley Hall,\" Tennyson says that \"a sorrow's\n"
  "crown of sorrow is rememb'ring better things.\" The original is in\n"
  "Dante's words:- -\n"
  "\"Nessun maggior dolore\n"
  " Che ricordarsi del tempo felice\n"
  " Nella miseria.\" -- \"Inferno,\" v. 121.\n"
  "(\"There is no greater sorrow than to remember happy times\n"
  "when in misery\")\n"
  "\n"
  "65. As great a craft is to keep weal as win: it needs as much\n"
  "skill to keep prosperity as to attain it.\n"
  "\n"
  "66. To heap: together. See the reference to Boethius in note 91\n"
  "to the Knight's Tale.\n"
  "\n"
  "67. The smalle beastes let he go beside: a charming touch,\n"
  "indicative of the noble and generous inspiration of his love.\n"
  "\n"
  "68. Mew: the cage or chamber in which hawks were kept and\n"
  "carefully tended during the moulting season.\n"
  "\n"
  "69. Love of steel:  love as true as steel.\n"
  "\n"
  "70. Pandarus, as it repeatedly appears, was an unsucsessful\n"
  "lover.\n"
  "\n"
  "71. \"Each for his virtue holden is full dear,\n"
  "     Both heroner, and falcon for rivere\":--\n"
  "That is, each is esteemed for a special virtue or faculty, as the\n"
  "large gerfalcon for the chase of heron, the smaller goshawk for\n"
  "the chase of river fowl.\n"
  "\n"
  "72. Zausis: An author of whom no record survives.\n"
  "\n"
  "73. And upon new case lieth new advice:  new counsels must be\n"
  "adopted as new circumstances arise.\n"
  "\n"
  "74. Hid in mew: hidden in a place remote from the world -- of\n"
  "which Pandarus thus betrays ignorance.\n"
  "\n"
  "75. The modern phrase \"sixes and sevens,\" means \"in\n"
  "confusion:\" but here the idea of gaming perhaps suits the sense\n"
  "better -- \"set the world upon a cast of the dice.\"\n"
  "\n"
  "76. The controversy between those who maintained the doctrine\n"
  "of predestination and those who held that of free-will raged\n"
  "with no less animation at Chaucer's day, and before it, than it\n"
  "has done in the subsequent five centuries; the Dominicans\n"
  "upholding the sterner creed, the Franciscans taking the other\n"
  "side. Chaucer has more briefly, and with the same care not to\n"
  "commit himself, referred to the discussion in The Nun's Priest's\n"
  "Tale.\n"
  "\n"
  "77. That have their top full high and smooth y-shore: that are\n"
  "eminent among the clergy, who wear the tonsure.\n"
  "\n"
  "78. Athamante: Athamas, son of Aeolus; who, seized with\n"
  "madness, under the wrath of Juno for his neglect of his wife\n"
  "Nephele, slew his son Learchus.\n"
  "\n"
  "79. Simois:  one of the rivers of the Troad, flowing into the\n"
  "Xanthus.\n"
  "\n"
  "80. Troilus was the son of Priam and Hecuba.\n"
  "\n"
  "81. The son of Tydeus:  Diomedes; far oftener called Tydides,\n"
  "after his father Tydeus, king of Argos.\n"
  "\n"
  "82. Couthe more than the creed:  knew more than the mere\n"
  "elements (of the science of Love).\n"
  "\n"
  "83. Arache: wrench away, unroot (French, \"arracher\"); the\n"
  "opposite of \"enrace,\" to root in, implant.\n"
  "\n"
  "84. It will be remembered that, at the beginning of the first\n"
  "book, Cressida is introduced to us as a widow.\n"
  "\n"
  "85. Diomede is called \"sudden,\" for the unexpectedness of his\n"
  "assault on Cressida's heart -- or, perhaps, for the abrupt\n"
  "abandonment of his indifference to love.\n"
  "\n"
  "86. Penscel:  a pennon or pendant; French, \"penoncel.\" It  was\n"
  "the custom in chivalric times for a knight to wear, on days of\n"
  "tournament or in battle, some such token of his lady's favour, or\n"
  "badge of his service to her.\n"
  "\n"
  "87. She has been told that Troilus is deceiving her.\n"
  "\n"
  "88. The Roman kalends were the first day of the month, when a\n"
  "change of weather was usually expected.\n"
  "\n"
  "89. Maker, and making, words used in the Middle Ages to\n"
  "signify the composer and the composition of poetry, correspond\n"
  "exactly with the Greek \"poietes\" and \"poiema,\" from \"poieo,\" I\n"
  "make.\n"
  "\n"
  "90. My rather speech:  my earlier, former subject; \"rather\" is the\n"
  "cormparative of the old adjective \"rath,\" early.\n"
  "\n"
  "91. Up to the hollowness of the seventh sphere: passing up\n"
  "through the hollowness or concavity of the spheres, which all\n"
  "revolve round each other and are all contained by God (see note\n"
  "5 to the Assembly of Fowls), the soul of Troilus, looking\n"
  "downward, beholds the converse or convex side of the spheres\n"
  "which it has traversed.\n"
  "\n"
  "92. Sorted: allotted; from Latin, \"sors,\" lot, fortune.\n"
  "\n"
  "93. Rascaille: rabble; French, \"racaille\" -- a mob or multitude,\n"
  "the riff-raff; so Spencer speaks of the \"rascal routs\" of inferior\n"
  "combatants.\n"
  "\n"
  "94. John Gower, the poet, a contemporary and friend of\n"
  "Chaucer's; author, among other works, of the \"Confessio\n"
  "Amantis.\" See note 1 to the Man of Law's Tale.\n"
  "\n"
  "95. Strode was an eminent scholar of Merton College, Oxford,\n"
  "and tutor to Chaucer's son Lewis.\n"
  "\n"
  "96. Explicit Liber Troili et Cresseidis: \"The end of the book of\n"
  "Troilus and Cressida.\"\n"
  "\n"
  "\n"
  "\n"
  "";
// }

const char poemChaucersDream0[] PGMSECTION = // { // 17117 bytes
  "CHAUCER'S DREAM.\n"
  "\n"
  "\n"
  "[This pretty allegory, or rather conceit, containing one or two\n"
  "passages that for vividness and for delicacy yield to nothing in\n"
  "the whole range of Chaucer's poetry, had never been printed\n"
  "before the year 1597, when it was included in the edition of\n"
  "Speght. Before that date, indeed, a Dream of Chaucer had been\n"
  "printed; but the poem so described was in reality \"The Book of\n"
  "the Duchess; or the Death of Blanche, Duchess of Lancaster\" --\n"
  "which is not included in the present edition. Speght says that\n"
  "\"This Dream, devised by Chaucer, seemeth to be a covert report\n"
  "of the marriage of John of Gaunt, the King's son, with Blanche,\n"
  "the daughter of Henry, Duke of Lancaster; who after long love\n"
  "(during the time whereof the poet feigneth them to be dead)\n"
  "were in the end, by consent of friends, happily married; figured\n"
  "by a bird bringing in his bill an herb, which restored them to life\n"
  "again. Here also is showed Chaucer's match with a certain\n"
  "gentlewoman, who, although she was a stranger, was,\n"
  "notwithstanding, so well liked and loved of the Lady Blanche\n"
  "and her Lord, as Chaucer himself also was, that gladly they\n"
  "concluded a marriage between them.\" John of Gaunt, at the age\n"
  "of nineteen, and while yet Earl of Richmond, was married to the\n"
  "Lady Blanche at Reading in May 1359; Chaucer, then a prisoner\n"
  "in France, probably did not return to England till peace was\n"
  "concluded in the following year; so that his marriage to Philippa\n"
  "Roet, the sister of the Duchess Blanche's favourite attendant\n"
  "Katharine Roet, could not have taken place till some time after\n"
  "that of the Duke. In the poem, it is represented to have\n"
  "immediately followed; but no consequence need be attached to\n"
  "that statement. Enough that it followed at no great interval of\n"
  "time; and that the intimate relations which Chaucer had already\n"
  "begun to form with John of Gaunt, might well warrant him in\n"
  "writing this poem on the occasion of the Duke's marriage, and\n"
  "in weaving his own love-fortunes with those of the principal\n"
  "figures. In the necessary abridgement of the poem for the\n"
  "present edition, the subsidiary branch of the allegory, relating to\n"
  "the poet's own love affair, has been so far as possible separated\n"
  "from the main branch, which shadows forth the fortunes of John\n"
  "and Blanche. The poem, in full, contains, with an \"Envoy\"\n"
  "arbitrarily appended, 2233 lines; of which 510 are given here.]\n"
  "(Transcriber's note: modern scholars believe that Chaucer was\n"
  "not the author of this poem)\n"
  "\n"
  "\n"
  "WHEN Flora, the queen of pleasance,\n"
  "Had wholly *achiev'd the obeisance*                  *won the obedience*\n"
  "Of the fresh and the new season,\n"
  "Thorough ev'ry region;\n"
  "And with her mantle *whole covert*                      *wholly covered*\n"
  "What winter had *made discovert,* --                          *stripped*\n"
  "\n"
  "On a May night, the poet lay alone, thinking of his lady, and all\n"
  "her beauty; and, falling asleep, he dreamed that he was in an\n"
  "island\n"
  "\n"
  "Where wall, and gate, was all of glass,\n"
  "And so was closed round about,\n"
  "That leaveless* none came in nor out;                *without permission\n"
  "Uncouth and strange to behold;\n"
  "For ev'ry gate, of fine gold,\n"
  "A thousand fanes,* ay turning,                      *vanes, weathercocks\n"
  "Entuned* had, and birds singing                 *contrived so as to emit\n"
  "Diversely, on each fane a pair,                          a musical sound\n"
  "With open mouth, against the air; <1>\n"
  "And *of a suit* were all the tow'rs,                  *of the same plan*\n"
  "Subtilly *carven aft* flow'rs                      *carved to represent*\n"
  "Of uncouth colours, *during ay,*                       *lasting forever*\n"
  "That never be none seen in May,\n"
  "With many a small turret high;\n"
  "But man alive I could not sigh,*                                    *see\n"
  "Nor creatures, save ladies play,*                 *disporting themselves\n"
  "Which were such of their array,\n"
  "That, as me thought, *of goodlihead*                    *for comeliness*\n"
  "They passed all, and womanhead.\n"
  "For to behold them dance and sing,\n"
  "It seemed like none earthly thing;\n"
  "\n"
  "And all were of the same age, save one; who was advanced in\n"
  "years, though no less gay in demeanour than the rest. While he\n"
  "stood admiring the richness and beauty of the place, and the\n"
  "fairness of the ladies, which had the notable gift of enduring\n"
  "unimpaired till death, the poet was accosted by the old lady, to\n"
  "whom he had to yield himself prisoner; because the ordinance of\n"
  "the isle was, that no man should dwell there; and the ladies' fear\n"
  "of breaking the law was enhanced by the temporary absence of\n"
  "their queen from the realm. Just at this moment the cry was\n"
  "raised that the queen came; all the ladies hastened to meet her;\n"
  "and soon the poet saw her approach -- but in her company his\n"
  "mistress, wearing the same garb, and a seemly knight. All the\n"
  "ladies wondered greatly at this; and the queen explained:\n"
  "\n"
  "\"My sisters, how it hath befall,*                              *befallen\n"
  "I trow ye know it one and all,\n"
  "That of long time here have I been\n"
  "Within this isle biding as queen,\n"
  "Living at ease, that never wight\n"
  "More perfect joye have not might;\n"
  "And to you been of governance\n"
  "Such as you found in whole pleasance, <2>\n"
  "In every thing as ye know,\n"
  "After our custom and our law;\n"
  "Which how they firste founded were,\n"
  "I trow ye wot all the mannere.\n"
  "And who the queen is of this isle, --\n"
  "As I have been this longe while, --\n"
  "Each seven years must, of usage,\n"
  "Visit the heav'nly hermitage,\n"
  "Which on a rock so highe stands,\n"
  "In a strange sea, out from all lands,\n"
  "That for to make the pilgrimage\n"
  "Is call'd a perilous voyage;\n"
  "For if the wind be not good friend,\n"
  "The journey dureth to the end\n"
  "Of him which that it undertakes;\n"
  "Of twenty thousand not one scapes.\n"
  "Upon which rock groweth a tree,\n"
  "That certain years bears apples three;\n"
  "Which three apples whoso may have,\n"
  "Is *from all displeasance y-save*                   *safe from all pain*\n"
  "That in the seven years may fall;\n"
  "This wot you well, both one and all.\n"
  "For the first apple and the hext,*                          *highest <3>\n"
  "Which groweth unto you the next,\n"
  "Hath three virtues notable,\n"
  "And keepeth youth ay durable,\n"
  "Beauty, and looks, ever-in-one,*                            *continually\n"
  "And is the best of ev'ry one.\n"
  "The second apple, red and green,\n"
  "Only with lookes of your eyne,\n"
  "You nourishes in great pleasance,\n"
  "Better than partridge or fesaunce,*                            *pheasant\n"
  "And feedeth ev'ry living wight\n"
  "Pleasantly, only with the sight.\n"
  "And the third apple of the three,\n"
  "Which groweth lowest on the tree,\n"
  "Whoso it beareth may not fail*                     *miss, fail to obtain\n"
  "That* to his pleasance may avail.                            *that which\n"
  "So your pleasure and beauty rich,\n"
  "Your during youth ever y-lich,*                                   *alike\n"
  "Your truth, your cunning,* and your weal,                     *knowledge\n"
  "Hath flower'd ay, and your good heal,\n"
  "Without sickness or displeasance,\n"
  "Or thing that to you was noyance.*                      *offence, injury\n"
  "So that you have as goddesses\n"
  "Lived above all princesses.\n"
  "Now is befall'n, as ye may see;\n"
  "To gather these said apples three,\n"
  "I have not fail'd, against the day,\n"
  "Thitherward to take the way,\n"
  "*Weening to speed* as I had oft.                  *expecting to succeed*\n"
  "But when I came, I found aloft\n"
  "My sister, which that hero stands,\n"
  "Having those apples in her hands,\n"
  "Advising* them, and nothing said,                  *regarding, gazing on\n"
  "But look'd as she were *well apaid:*                         *satisfied*\n"
  "And as I stood her to behold,\n"
  "Thinking how my joys were cold,\n"
  "Since I these apples *have not might,*                  *might not have*\n"
  "Even with that so came this knight,\n"
  "And in his arms, of me unware,\n"
  "Me took, and to his ship me bare,\n"
  "And said, though him I ne'er had seen,\n"
  "Yet had I long his lady been;\n"
  "Wherefore I shoulde with him wend,\n"
  "And he would, to his life's end,\n"
  "My servant be; and gan to sing,\n"
  "As one that had won a rich thing.\n"
  "Then were my spirits from me gone,\n"
  "So suddenly every one,\n"
  "That in me appear'd but death,\n"
  "For I felt neither life nor breath,\n"
  "Nor good nor harme none I knew,\n"
  "The sudden pain me was so new,\n"
  "That *had not the hasty grace be*               *had it not been for the\n"
  "Of this lady, that from the tree                        prompt kindness*\n"
  "Of her gentleness so bled,*                                    *hastened\n"
  "Me to comforten, I had died;\n"
  "And of her three apples she one\n"
  "Into mine hand there put anon,\n"
  "Which brought again my mind and breath,\n"
  "And me recover'd from the death.\n"
  "Wherefore to her so am I hold,*                       *beholden, obliged\n"
  "That for her all things do I wo'ld,\n"
  "For she was leach* of all my smart,                           *physician\n"
  "And from great pain so quit* my heart.                        *delivered\n"
  "And as God wot, right as ye hear,\n"
  "Me to comfort with friendly cheer,\n"
  "She did her prowess and her might.\n"
  "And truly eke so did this knight,\n"
  "In that he could; and often said,\n"
  "That of my woe he was *ill paid,*              *distressed, ill-pleased*\n"
  "And curs'd the ship that him there brought,\n"
  "The mast, the master that it wrought.\n"
  "And, as each thing must have an end,\n"
  "My sister here, our bother friend, <4>\n"
  "Gan with her words so womanly\n"
  "This knight entreat, and cunningly,\n"
  "For mine honour and hers also,\n"
  "And said that with her we should go\n"
  "Both in her ship, where she was brought,\n"
  "Which was so wonderfully wrought,\n"
  "So clean, so rich, and so array'd,\n"
  "That we were both content and paid;*                          *satisfied\n"
  "And me to comfort and to please,\n"
  "And my heart for to put at ease,\n"
  "She took great pain in little while,\n"
  "And thus hath brought us to this isle\n"
  "As ye may see; wherefore each one\n"
  "I pray you thank her one and one,\n"
  "As heartily as ye can devise,\n"
  "Or imagine in any wise.\"\n"
  "\n"
  "At once there then men mighte see'n,\n"
  "A world of ladies fall on kneen\n"
  "Before my lady, --\n"
  "\n"
  "Thanking her, and placing themselves at her commandment.\n"
  "Then the queen sent the aged lady to the knight, to learn of him\n"
  "why he had done her all this woe; and when the messenger had\n"
  "discharged her mission, telling the knight that in the general\n"
  "opinion he had done amiss, he fell down suddenly as if dead for\n"
  "sorrow and repentance. Only with great difficulty, by the queen\n"
  "herself, was he restored to consciousness and comfort; but\n"
  "though she spoke kind and hope-inspiring words, her heart was\n"
  "not in her speech,\n"
  "\n"
  "For her intent was, to his barge\n"
  "Him for to bring against the eve,\n"
  "With certain ladies, and take leave,\n"
  "And pray him, of his gentleness,\n"
  "To *suffer her* thenceforth in peace,                    *let her dwell*\n"
  "As other princes had before;\n"
  "And from thenceforth, for evermore,\n"
  "She would him worship in all wise\n"
  "That gentlenesse might devise;\n"
  "And *pain her* wholly to fulfil,               *make her utmost efforts*\n"
  "In honour, his pleasure and will.\n"
  "\n"
  "And during thus this knighte's woe, --\n"
  "Present* the queen and other mo',                *(there being) present*\n"
  "My lady and many another wight, --\n"
  "Ten thousand shippes at a sight\n"
  "I saw come o'er the wavy flood,\n"
  "With sail and oar; that, as I stood\n"
  "Them to behold, I gan marvail\n"
  "From whom might come so many a sail;\n"
  "For, since the time that I was born,\n"
  "Such a navy therebeforn\n"
  "Had I not seen, nor so array'd,\n"
  "That for the sight my hearte play'd\n"
  "Ay to and fro within my breast;\n"
  "For joy long was ere it would rest.\n"
  "For there were sailes *full of flow'rs;*      *embroidered with flowers*\n"
  "After, castles with huge tow'rs, <5>\n"
  "Seeming full of armes bright,\n"
  "That wond'rous lusty* was the sight;                           *pleasant\n"
  "With large tops, and mastes long,\n"
  "Richly depaint' and *rear'd among.*                  *raised among them*\n"
  "At certain times gan repair\n"
  "Smalle birdes down from the air,\n"
  "And on the shippes' bounds* about                              *bulwarks\n"
  "Sat and sang, with voice full out,\n"
  "Ballads and lays right joyously,\n"
  "As they could in their harmony.\n"
  "\n"
  "The ladies were alarmed and sorrow-stricken at sight of the\n"
  "ships, thinking that the knight's companions were on board; and\n"
  "they went towards the walls of the isle, to shut the gates. But it\n"
  "was Cupid who came; and he had already landed, and marched\n"
  "straight to the place where the knight lay. Then he chid the\n"
  "queen for her unkindness to his servant; shot an arrow into her\n"
  "heart; and passed through the crowd, until he found the poet's\n"
  "lady, whom he saluted and complimented, urging her to have\n"
  "pity on him that loved her. While the poet, standing apart, was\n"
  "revolving all this in his mind, and resolving truly to serve his\n"
  "lady, he saw the queen advance to Cupid, with a petition in\n"
  "which she besought forgiveness of past offences, and promised\n"
  "continual and zealous service till her death. Cupid smiled, and\n"
  "said that he would be king within that island, his new conquest;\n"
  "then, after long conference with the queen, he called a council\n"
  "for the morrow, of all who chose to wear his colours. In the\n"
  "morning, such was the press of ladies, that scarcely could\n"
  "standing-room be found in all the plain. Cupid presided; and one\n"
  "of his counsellors addressed the mighty crowd, promising that\n"
  "ere his departure his lord should bring to an agreement all the\n"
  "parties there present. Then Cupid gave to the knight and the\n"
  "dreamer each his lady; promised his favour to all the others in\n"
  "that place who would truly and busily serve in love; and at\n"
  "evening took his departure. Next morning, having declined the\n"
  "proffered sovereignty of the island, the poet's mistress also\n"
  "embarked, leaving him behind; but he dashed through the\n"
  "waves, was drawn on board her ship from peril of death, and\n"
  "graciously received into his lady's lasting favour. Here the poet\n"
  "awakes, finding his cheeks and body all wet with tears; and,\n"
  "removing into another chamber, to rest more in peace, he falls\n"
  "asleep anew, and continues the dream. Again he is within the\n"
  "island, where the knight and all the ladies are assembled on a\n"
  "green, and it is resolved by the assembly, not only that the\n"
  "knight shall be their king, but that every lady there shall be\n"
  "wedded also. It is determined that the knight shall depart that\n"
  "very day, and return, within ten days, with such a host of\n"
  "Benedicts, that none in the isle need lack husbands. The knight\n"
  "\n"
  "Anon into a little barge\n"
  "Brought was, late against an eve,\n"
  "Where of all he took his leave.\n"
  "Which barge was, as a man thought,\n"
  "Aft* his pleasure to him brought;                         *according to*\n"
  "The queen herself accustom'd ay\n"
  "In the same barge to play.*                              *take her sport\n"
  "It needed neither mast nor rother*                               *rudder\n"
  "(I have not heard of such another),\n"
  "Nor master for the governance;*                                *steering\n"
  "It sailed by thought and pleasance,\n"
  "Withoute labour, east and west;\n"
  "All was one, calm or tempest. <6>\n"
  "And I went with, at his request,\n"
  "And was the first pray'd to the feast.*                *the bridal feast\n"
  "When he came unto his country,\n"
  "And passed had the wavy sea,\n"
  "In a haven deep and large\n"
  "He left his rich and noble barge,\n"
  "And to the court, shortly to tell,\n"
  "He went, where he was wont to dwell, --\n"
  "\n"
  "And was gladly received as king by the estates of the land; for\n"
  "during his absence his father, \"old, and wise, and hoar,\" had\n"
  "died, commending to their fidelity his absent son. The prince\n"
  "related to the estates his journey, and his success in finding the\n"
  "princess in quest of whom he had gone seven years before; and\n"
  "said that he must have sixty thousand guests at his marriage\n"
  "feast. The lords gladly guaranteed the number within the set\n"
  "time; but afterwards they found that fifteen days must be spent\n"
  "in the necessary preparations. Between shame and sorrow, the\n"
  "prince, thus compelled to break his faith, took to his bed, and,\n"
  "in wailing and self-reproach,\n"
  "\n"
  "-- Endur'd the days fifteen,\n"
  "Till that the lords, on an evene,*                              *evening\n"
  "Him came and told they ready were,\n"
  "And showed in few wordes there,\n"
  "How and what wise they had *purvey'd                  *provided suitably\n"
  "For his estate,* and to him said,                           to his rank*\n"
  "That twenty thousand knights of name,\n"
  "And forty thousand without blame,\n"
  "Alle come of noble ligne*                                 *line, lineage\n"
  "Together in a company\n"
  "Were lodged on a river's side,\n"
  "Him and his pleasure there t'abide.\n"
  "The prince then for joy uprose,\n"
  "And, where they lodged were, he goes,\n"
  "Withoute more, that same night,\n"
  "And there his supper *made to dight;*                     *had prepared*\n"
  "And with them bode* till it was day.                     *abode, waited*\n"
  "And forthwith to take his journey,\n"
  "Leaving the strait, holding the large,\n"
  "Till he came to his noble barge:\n"
  "And when the prince, this lusty knight,\n"
  "With his people in armes bright,\n"
  "Was come where he thought to pass,*                   *cross to the isle\n"
  "And knew well none abiding was\n"
  "Behind, but all were there present,\n"
  "Forthwith anon all his intent\n"
  "He told them there, and made his cries*                    *proclamation\n"
  "Thorough his hoste that day twice,\n"
  "Commanding ev'ry living wight\n"
  "There being present in his sight,\n"
  "To be the morrow on the rivage,*                                  *shore\n"
  "There he begin would his voyage.\n"
  "\n"
  "";
// }

const char poemChaucersDream1[] PGMSECTION = // { // 16018 bytes
  "The morrow come, the *cry was kept*            *proclamation was obeyed*\n"
  "But few were there that night that slept,\n"
  "But *truss'd and purvey'd* for the morrow;      *packed up and provided*\n"
  "For fault* of ships was all their sorrow;                *lack, shortage\n"
  "For, save the barge, and other two,\n"
  "Of shippes there I saw no mo'.\n"
  "Thus in their doubtes as they stood,\n"
  "Waxing the sea, coming the flood,\n"
  "Was cried \"To ship go ev'ry wight!\"\n"
  "Then was but *hie that hie him might,*       *whoever could hasten, did*\n"
  "And to the barge, me thought, each one\n"
  "They went, without was left not one,\n"
  "Horse, nor male*, truss, nor baggage,                     *trunk, wallet\n"
  "Salad*, spear, gardebrace,** nor page,        *helmet<7> **arm-shield<8>\n"
  "But was lodged and room enough;\n"
  "At which shipping me thought I lough,*                          *laughed\n"
  "And gan to marvel in my thought,\n"
  "How ever such a ship was wrought.*                          *constructed\n"
  "For *what people that can increase,*     *however the numbers increased*\n"
  "Nor ne'er so thick might be the prease,*                   *press, crowd\n"
  "But alle hadde room at will;\n"
  "There was not one was lodged ill.\n"
  "For, as I trow, myself the last\n"
  "Was one, and lodged by the mast;\n"
  "And where I look'd I saw such room\n"
  "As all were lodged in a town.\n"
  "Forth went the ship, said was the creed;<9>\n"
  "And on their knees, *for their good speed,*        *to pray for success*\n"
  "Down kneeled ev'ry wight a while,\n"
  "And prayed fast that to the isle\n"
  "They mighte come in safety,\n"
  "The prince and all the company.\n"
  "With worship and withoute blame,\n"
  "Or disclander* of his name,                           *reproach, slander\n"
  "Of the promise he should return\n"
  "Within the time he did sojourn\n"
  "In his lande biding* his host;                              *waiting for\n"
  "This was their prayer least and most:\n"
  "To keep the day it might not be'n,\n"
  "That he appointed with the queen.\n"
  "\n"
  "Wherefore the prince slept neither day nor night, till he and his\n"
  "people landed on the glass-walled isle, \"weening to be in heav'n\n"
  "that night.\" But ere they had gone a little way, they met a lady\n"
  "all in black, with piteous countenance, who reproached the\n"
  "prince for his untruth, and informed him that, unable to bear the\n"
  "reproach to their name, caused by the lightness of their trust in\n"
  "strangers, the queen and all the ladies of the isle had vowed\n"
  "neither to eat, nor drink, nor sleep, nor speak, nor cease\n"
  "weeping till all were dead. The queen had died the first; and half\n"
  "of the other ladies had already \"under the earth ta'en lodging\n"
  "new.\" The woeful recorder of all these woes invites the prince\n"
  "to behold the queen's hearse:\n"
  "\n"
  "\"Come within, come see her hearse\n"
  "Where ye shall see the piteous sight\n"
  "That ever yet was shown to knight;\n"
  "For ye shall see ladies stand,\n"
  "Each with a greate rod in hand,\n"
  "Clad in black, with visage white,\n"
  "Ready each other for to smite,\n"
  "If any be that will not weep;\n"
  "Or who makes countenance to sleep.\n"
  "They be so beat, that all so blue\n"
  "They be as cloth that dy'd is new.\"\n"
  "\n"
  "Scarcely has the lady ceased to speak, when the prince plucks\n"
  "forth a dagger, plunges it into his heart, and, drawing but one\n"
  "breath, expires.\n"
  "\n"
  "For whiche cause the lusty host,\n"
  "Which [stood] in battle on the coast,\n"
  "At once for sorrow such a cry\n"
  "Gan rear, thorough* the company,                             *throughout\n"
  "That to the heav'n heard was the soun',\n"
  "And under th'earth as far adown,\n"
  "And wilde beastes for the fear\n"
  "So suddenly affrayed* were,                                      *afraid\n"
  "That for the doubt, while they might dure,*     *have a chance of safety\n"
  "They ran as of their lives unsure,\n"
  "From the woodes into the plain,\n"
  "And from valleys the high mountain\n"
  "They sought, and ran as beastes blind,\n"
  "That clean forgotten had their kind.*                            *nature\n"
  "\n"
  "The lords of the laggard host ask the woebegone lady what\n"
  "should be done; she answers that nothing can now avail, but\n"
  "that for remembrance they should build in their land, open to\n"
  "public view, \"in some notable old city,\" a chapel engraved with\n"
  "some memorial of the queen. And straightway, with a sigh, she\n"
  "also \"pass'd her breath.\"\n"
  "\n"
  "Then said the lordes of the host,\n"
  "And so concluded least and most,\n"
  "That they would ay in houses of thack*                           *thatch\n"
  "Their lives lead, <10> and wear but black,\n"
  "And forsake all their pleasances,\n"
  "And turn all joy to penances;\n"
  "And bare the dead prince to the barge,\n"
  "And named *them should* have the charge;              *those who should*\n"
  "And to the hearse where lay the queen\n"
  "The remnant went, and down on kneen,\n"
  "Holding their hands on high, gan cry,\n"
  "\"Mercy! mercy!\" *evereach thry;*                       *each one thrice*\n"
  "And curs'd the time that ever sloth\n"
  "Should have such masterdom of troth.\n"
  "And to the barge, a longe mile,\n"
  "They bare her forth; and, in a while,\n"
  "All the ladies, one and one,\n"
  "By companies were brought each one.\n"
  "And pass'd the sea, and took the land,\n"
  "And in new hearses, on a sand,\n"
  "Put and brought were all anon,\n"
  "Unto a city clos'd with stone,\n"
  "Where it had been used ay\n"
  "The kinges of the land to lay,\n"
  "After they reigned in honours;\n"
  "And writ was which were conquerours;\n"
  "In an abbey of nunnes black,\n"
  "Which accustom'd were to wake,\n"
  "And of usage rise each a-night,\n"
  "To pray for ev'ry living wight.\n"
  "And so befell, as is the guise,\n"
  "Ordain'd and said was the service\n"
  "Of the prince and eke of the queen,\n"
  "So devoutly as mighte be'n;\n"
  "And, after that, about the hearses,\n"
  "Many orisons and verses,\n"
  "Withoute note* <11> full softely                                  *music\n"
  "Said were, and that full heartily;\n"
  "That all the night, till it was day,\n"
  "The people in the church gan pray\n"
  "Unto the Holy Trinity,\n"
  "Of those soules to have pity.\n"
  "\n"
  "And when the nighte past and run\n"
  "Was, and the newe day begun, --\n"
  "The young morrow with rayes red,\n"
  "Which from the sun all o'er gan spread,\n"
  "Attemper'd* cleare was and fair,                          *clement, calm\n"
  "And made a time of wholesome air, --\n"
  "Befell a wondrous case* and strange                       *chance, event\n"
  "Among the people, and gan change\n"
  "Soon the word, and ev'ry woe\n"
  "Unto a joy, and some to two.\n"
  "\n"
  "A bird, all feather'd blue and green,\n"
  "With brighte rays like gold between,\n"
  "As small thread over ev'ry joint,\n"
  "All full of colour strange and coint,*                           *quaint\n"
  "Uncouth* and wonderful to sight,                             *unfamiliar\n"
  "Upon the queene's hearse gan light,\n"
  "And sung full low and softely\n"
  "Three songes in their harmony,\n"
  "*Unletted of* every wight;                               *unhindered by*\n"
  "Till at the last an aged knight,\n"
  "Which seem'd a man in greate thought,\n"
  "Like as he set all thing at nought,\n"
  "With visage and eyes all forwept,*                     *steeped in tears\n"
  "And pale, as a man long unslept,\n"
  "By the hearses as he stood,\n"
  "With hasty handling of his hood\n"
  "Unto a prince that by him past,\n"
  "Made the bird somewhat aghast.*                              *frightened\n"
  "Wherefore he rose and left his song,\n"
  "And departed from us among,\n"
  "And spread his winges for to pass\n"
  "By the place where he enter'd was.\n"
  "And in his haste, shortly to tell,\n"
  "Him hurt, that backward down he fell,\n"
  "From a window richly paint,\n"
  "With lives of many a divers saint,\n"
  "And beat his winges and bled fast,\n"
  "And of the hurt thus died and past;\n"
  "And lay there well an hour and more\n"
  "Till, at the last, of birds a score\n"
  "Came and assembled at the place\n"
  "Where the window broken was,\n"
  "And made such waimentatioun,*                               *lamentation\n"
  "That pity was to hear the soun',\n"
  "And the warbles of their throats,\n"
  "And the complaint of their notes,\n"
  "Which from joy clean was reversed.\n"
  "And of them one the glass soon pierced,\n"
  "And in his beak, of colours nine,\n"
  "An herb he brought, flow'rless, all green,\n"
  "Full of smalle leaves, and plain,*                               *smooth\n"
  "Swart,* and long, with many a vein.                               *black\n"
  "And where his fellow lay thus dead,\n"
  "This herb he down laid by his head,\n"
  "And dressed* it full softely,                                  *arranged\n"
  "And hung his head, and stood thereby.\n"
  "Which herb, in less than half an hour,\n"
  "Gan over all knit,* and after flow'r                                *bud\n"
  "Full out; and waxed ripe the seed;\n"
  "And, right as one another feed\n"
  "Would, in his beak he took the grain,\n"
  "And in his fellow's beak certain\n"
  "It put, and thus within the third*             *i.e. third hour after it\n"
  "Upstood and pruned him the bird,                                had died\n"
  "Which dead had been in all our sight;\n"
  "And both together forth their flight\n"
  "Took, singing, from us, and their leave;\n"
  "Was none disturb them would nor grieve.\n"
  "And, when they parted were and gone,\n"
  "Th' abbess the seedes soon each one\n"
  "Gathered had, and in her hand\n"
  "The herb she took, well avisand*                       *considering <12>\n"
  "The leaf, the seed, the stalk, the flow'r,\n"
  "And said it had a good savour,\n"
  "And was no common herb to find,\n"
  "And well approv'd of *uncouth kind,*                    *strange nature*\n"
  "And more than other virtuous;\n"
  "Whoso might it have for to use\n"
  "In his need, flower, leaf, or grain,\n"
  "Of his heal might be certain.\n"
  "[She] laid it down upon the hearse\n"
  "Where lay the queen; and gan rehearse\n"
  "Each one to other what they had seen.\n"
  "And, *taling thus,* the seed wax'd green,             *as they gossiped*\n"
  "And on the dry hearse gan to spring, --\n"
  "Which me thought was a wondrous thing, --\n"
  "And, after that, flow'r and new seed;\n"
  "Of which the people all took heed,\n"
  "And said it was some great miracle,\n"
  "Or medicine fine more than treacle;  <12>\n"
  "And were well done there to assay\n"
  "If it might ease, in any way,\n"
  "The corpses, which with torchelight\n"
  "They waked had there all that night.\n"
  "Soon did the lordes there consent,\n"
  "And all the people thereto content,\n"
  "With easy words and little fare;*                          *ado, trouble\n"
  "And made the queene's visage bare,\n"
  "Which showed was to all about,\n"
  "Wherefore in swoon fell all the rout,*                   *company, crowd\n"
  "And were so sorry, most and least,\n"
  "That long of weeping they not ceas'd;\n"
  "For of their lord the remembrance\n"
  "Unto them was such displeasance.*                        *cause of grief\n"
  "That for to live they called pain,\n"
  "So were they very true and plain.\n"
  "And after this the good abbess\n"
  "Of the grains gan choose and dress*                             *prepare\n"
  "Three, with her fingers clean and smale,*                         *small\n"
  "And in the queenes mouth, by tale,\n"
  "One after other, full easily\n"
  "She put, and eke full cunningly.*                             *skilfully\n"
  "Which showed some such virtue.\n"
  "That proved was the medicine true.\n"
  "For with a smiling countenance\n"
  "The queen uprose, and of usance*                                 *custom\n"
  "As she was wont, to ev'ry wight\n"
  "She *made good cheer;* for whiche sight               *showed a gracious\n"
  "The people, kneeling on the stones,                         countenance*\n"
  "Thought they in heav'n were, soul and bones;\n"
  "And to the prince, where that he lay,\n"
  "They went to make the same assay.*                    *trial, experiment\n"
  "And when the queen it understood,\n"
  "And how the medicine was good,\n"
  "She pray'd that she might have the grains,\n"
  "To relieve him from the pains\n"
  "Which she and he had both endur'd.\n"
  "And to him went, and so him cur'd,\n"
  "That, within a little space,\n"
  "Lusty and fresh alive he was,\n"
  "And in good heal, and whole of speech,\n"
  "And laugh'd, and said, *\"Gramercy, leach!\"*              *\"Great thanks,\n"
  "For which the joy throughout the town                    my physician!\"*\n"
  "So great was, that the belles' soun'\n"
  "Affray'd the people a journey*                       *to the distance of\n"
  "About the city ev'ry way;                               a day's journey*\n"
  "And came and ask'd the cause, and why\n"
  "They rungen were so stately.*                         *proudly, solemnly\n"
  "And after that the queen, th'abbess,\n"
  "Made diligence, <14> ere they would cease,\n"
  "Such, that of ladies soon a rout*                        *company, crowd\n"
  "Suing* the queen was all about;                               *following\n"
  "And, call'd by name each one and told,*                        *numbered\n"
  "Was none forgotten, young nor old.\n"
  "There mighte men see joyes new,\n"
  "When the medicine, fine and true,\n"
  "Thus restor'd had ev'ry wight,\n"
  "So well the queen as the knight,\n"
  "Unto perfect joy and heal,\n"
  "That *floating they were in such weal*                 *swimming in such\n"
  "As folk that woulden in no wise                               happiness*\n"
  "Desire more perfect paradise.\n"
  "\n"
  "On the morrow a general assembly was convoked, and it was\n"
  "resolved that the wedding feast should be celebrated within the\n"
  "island. Messengers were sent to strange realms, to invite kings,\n"
  "queens, duchesses, and princesses; and a special embassy was\n"
  "despatched, in the magic barge, to seek the poet's mistress --\n"
  "who was brought back after fourteen days, to the great joy of\n"
  "the queen. Next day took place the wedding of the prince and\n"
  "all the knights to the queen and all the ladies; and a three\n"
  "months' feast followed, on a large plain \"under a wood, in a\n"
  "champaign, betwixt a river and a well, where never had abbey\n"
  "nor cell been, nor church, house, nor village, in time of any\n"
  "manne's age.\" On the day after the general wedding, all\n"
  "entreated the poet's lady to consent to crown his love with\n"
  "marriage; she yielded; the bridal was splendidly celebrated; and\n"
  "to the sound of marvellous music the poet awoke, to find\n"
  "neither lady nor creature -- but only old portraitures on the\n"
  "tapestry, of horsemen, hawks, and hounds, and hurt deer full of\n"
  "wounds. Great was his grief that he had lost all the bliss of his\n"
  "dream; and he concludes by praying his lady so to accept his\n"
  "love-service, that the dream may turn to reality.\n"
  "\n"
  "Or elles, without more I pray,\n"
  "That this night, ere it be day,\n"
  "I may unto my dream return,\n"
  "And sleeping so forth ay sojourn\n"
  "Aboute the Isle of Pleasance,\n"
  "*Under my lady's obeisance,*                        *subject to my lady*\n"
  "In her service, and in such wise,\n"
  "As it may please her to devise;\n"
  "And grace once to be accept',\n"
  "Like as I dreamed when I slept,\n"
  "And dure a thousand year and ten\n"
  "In her good will: Amen, amen!\n"
  "\n"
  "\n"
  "Notes to Chaucer's Dream\n"
  "\n"
  "\n"
  "1. The birds on the weathervanes were set up facing the wind,\n"
  "so that it entered their open mouths, and by some mechanism\n"
  "produced the musical sound.\n"
  "\n"
  "2. \"And to you been of governance\n"
  "    Such as you found in whole pleasance\"\n"
  "That is, \"and have governed you in a manner which you have\n"
  "found wholly pleasant.\"\n"
  "\n"
  "3. Hext: highest; from \"high,\" as \"next\" from \"nigh.\" Compare\n"
  "the sounds of the German, \"hoechst,\" highest, and \"naechst,\"\n"
  "next.\n"
  "\n"
  "4. \"Your brother friend,\" is the common reading; but the phrase\n"
  "has no apparent applicability; and perhaps the better reading is\n"
  "\"our bother friend\" -- that is, the lady who has proved herself a\n"
  "friend both to me and to you. In the same way, Reason, in\n"
  "Troilus' soliloquy on the impending loss of his mistress, is made,\n"
  "addressing Troilus and Cressida, to speaks of \"your bother,\" or\n"
  "\"bothe,\" love.\n"
  "\n"
  "5. The ships had  high embattled poops and forecastles, as in\n"
  "mediaeval ships of war.\n"
  "\n"
  "6. Compare Spenser's account of Phaedria's barque, in \"The\n"
  "Faerie Queen,\" canto vi. book ii.; and, mutatis mutandis,\n"
  "Chaucer's description of the wondrous horse, in The Squire's\n"
  "Tale.\n"
  "\n"
  "7. Salad: a small helmet; french, \"salade.\"\n"
  "\n"
  "8. Gardebrace: French, \"garde-bras,\" an arm-shield; probably\n"
  "resembling the \"gay bracer\" which the Yeoman, in the Prologue\n"
  "to The Canterbury Tales, wears on his arm.\n"
  "\n"
  "9. Confession and prayer were the usual preliminaries of any\n"
  "enterprise in those superstitious days; and in these days of\n"
  "enlightenment the fashion yet lingers among the most\n"
  "superstitious class -- the fisher-folk.\n"
  "\n"
  "10. The knights resolved that they would quit their castles and\n"
  "houses of stone for humble huts.\n"
  "\n"
  "11. The knight and lady were buried without music, although\n"
  "the office for the dead was generally sung.\n"
  "\n"
  "12. Avisand: considering; present participle from \"avise\" or\n"
  "\"advise.\"\n"
  "\n"
  "13. Treacle; corrupted from Latin, \"therisca,\" an antidote. The\n"
  "word is used for medicine in general.\n"
  "\n"
  "14. The abbess made diligence: i.e. to administer the grain to\n"
  "the dead ladies.\n"
  "\n"
  "\n"
  "\n"
  "";
// }

const char prologueToTheLegendOfGoodWomen0[] PGMSECTION = // { // 18989 bytes
  "THE PROLOGUE TO THE LEGEND OF GOOD WOMEN.\n"
  "\n"
  "\n"
  "[SOME difference of opinion exists as to the date at\n"
  "which Chaucer wrote \"The Legend of Good\n"
  "Women.\" Those who would fix that date at a\n"
  "period not long before the poet's death -- who\n"
  "would place the poem, indeed, among his closing\n"
  "labours -- support their opinion by the fact that the\n"
  "Prologue recites most of Chaucer's principal\n"
  "works, and glances, besides, at a long array of\n"
  "other productions, too many to be fully catalogued.\n"
  "But, on the other hand, it is objected that the\n"
  "\"Legend\" makes no mention of \"The Canterbury\n"
  "Tales\" as such; while two of those Tales -- the\n"
  "Knight's and the Second Nun's -- are enumerated\n"
  "by the titles which they bore as separate\n"
  "compositions, before they were incorporated in the\n"
  "great collection: \"The Love of Palamon and\n"
  "Arcite,\" and \"The Life of Saint Cecile\" (see note 1\n"
  "to the Second Nun's tale). Tyrwhitt seems perfectly\n"
  "justified in placing the composition of the poem\n"
  "immediately before that of Chaucer's magnum\n"
  "opus, and after the marriage of Richard II to his\n"
  "first queen, Anne of Bohemia. That event took\n"
  "place in 1382; and since it is to Anne that the poet\n"
  "refers when he makes Alcestis bid him give his\n"
  "poem to the queen \"at Eltham or at Sheen,\" the\n"
  "\"Legend\" could not have been written earlier. The\n"
  "old editions tell us that \"several ladies in the Court\n"
  "took offence at Chaucer's large speeches against\n"
  "the untruth of women; therefore the queen enjoin'd\n"
  "him to compile this book in the commendation of\n"
  "sundry maidens and wives, who show'd themselves\n"
  "faithful to faithless men. This seems to have been\n"
  "written after The Flower and the Leaf.\" Evidently it\n"
  "was, for distinct references to that poem are to be\n"
  "found in the Prologue; but more interesting is the\n"
  "indication which it furnishes, that \"Troilus and\n"
  "Cressida\" was the work, not of the poet's youth,\n"
  "but of his maturer age. We could hardly expect the\n"
  "queen -- whether of Love or of England -- to\n"
  "demand seriously from Chaucer a retractation of\n"
  "sentiments which he had expressed a full\n"
  "generation before, and for which he had made\n"
  "atonement by the splendid praises of true love sung\n"
  "in \"The Court of Love,\" \"The Cuckoo and the\n"
  "Nightingale,\" and other poems of youth and middle\n"
  "life. But \"Troilus and Cressida\" is coupled with\n"
  "\"The Romance of the Rose,\" as one of the poems\n"
  "which had given offence to the servants and the\n"
  "God of Love; therefore we may suppose it to have\n"
  "more prominently engaged courtly notice at a later\n"
  "period of the poet's life, than even its undoubted\n"
  "popularity could explain. At whatever date, or in\n"
  "whatever circumstances, undertaken, \"The Legend\n"
  "of Good Women\" is a fragment. There are several\n"
  "signs that it was designed to contain the stories of\n"
  "twenty-five ladies, although the number of the\n"
  "good women is in the poem itself set down at\n"
  "nineteen; but nine legends only were actually\n"
  "composed, or have come down to us. They are,\n"
  "those of Cleopatra Queen of Egypt (126 lines),\n"
  "Thisbe of Babylon (218), Dido Queen of Carthage\n"
  "(442), Hypsipyle and Medea (312), Lucrece of\n"
  "Rome (206), Ariadne of Athens (340), Phiomela\n"
  "(167), Phyllis (168), and Hypermnestra (162).\n"
  "Prefixed to these stories, which are translated or\n"
  "imitated from Ovid, is a Prologue containing 579\n"
  "lines -- the only part of the \"Legend\" given in the\n"
  "present edition. It is by far the most original, the\n"
  "strongest, and most pleasing part of the poem; the\n"
  "description of spring, and of his enjoyment of that\n"
  "season, are in Chaucer's best manner; and the\n"
  "political philosophy by which Alcestis mitigates the\n"
  "wrath of Cupid, adds another to the abounding\n"
  "proofs that, for his knowledge of the world,\n"
  "Chaucer fairly merits the epithet of \"many-sided\"\n"
  "which Shakespeare has won by his knowledge of\n"
  "man.]\n"
  "\n"
  "\n"
  "A THOUSAND times I have hearde tell,\n"
  "That there is joy in heav'n, and pain in hell;\n"
  "And I accord* it well that it is so;                       *grant, agree\n"
  "But, natheless, yet wot* I well also,                              *know\n"
  "That there is none dwelling in this country\n"
  "That either hath in heav'n or hell y-be;*                          *been\n"
  "Nor may of it no other wayes witten*                               *know\n"
  "But as he hath heard said, or found it written;\n"
  "For by assay* there may no man it preve.**              *practical trial\n"
  "                                                           **prove, test\n"
  "But God forbid but that men should believe\n"
  "Well more thing than men have seen with eye!\n"
  "Men shall not weenen ev'ry thing a lie\n"
  "*But if* himself it seeth, or else do'th;                        *unless\n"
  "For, God wot, thing is never the less sooth,*                      *true\n"
  "Though ev'ry wighte may it not y-see.\n"
  "Bernard, the Monke, saw not all, pardie! <1>\n"
  "Then muste we to bookes that we find\n"
  "(Through which that olde thinges be in mind),\n"
  "And to the doctrine of these olde wise,\n"
  "Give credence, in ev'ry skilful* wise,                       *reasonable\n"
  "That tellen of these old approved stories,\n"
  "Of holiness, of regnes,* of victories,                 *reigns, kingdoms\n"
  "Of love, of hate, and other sundry things\n"
  "Of which I may not make rehearsings;\n"
  "And if that olde bookes were away,\n"
  "Y-lorn were of all remembrance the key.\n"
  "Well ought we, then, to honour and believe\n"
  "These bookes, where we have none other preve.*                    *proof\n"
  "\n"
  "And as for me, though that I know but lite,*                     *little\n"
  "On bookes for to read I me delight,\n"
  "And to them give I faith and good credence,\n"
  "And in my heart have them in reverence,\n"
  "So heartily, that there is *game none* <2>                *no amusement*\n"
  "That from my bookes maketh me to go'n,\n"
  "But it be seldom on the holyday;\n"
  "Save, certainly, when that the month of May\n"
  "Is comen, and I hear the fowles sing,\n"
  "And that the flowers ginnen for to spring,\n"
  "Farewell my book and my devotion!\n"
  "\n"
  "Now have I then such a condition,\n"
  "That, above all the flowers in the mead,\n"
  "Then love I most these flowers white and red,\n"
  "Such that men calle Day's-eyes in our town;\n"
  "To them have I so great affectioun,\n"
  "As I said erst, when comen is the May,\n"
  "That in my bed there dawneth me no day\n"
  "That I n'am* up, and walking in the mead,                        *am not\n"
  "To see this flow'r against the sunne spread,\n"
  "When it upriseth early by the morrow;\n"
  "That blissful sight softeneth all my sorrow,\n"
  "So glad am I, when that I have presence\n"
  "Of it, to do it alle reverence,\n"
  "As she that is of alle flowers flow'r,\n"
  "Fulfilled of all virtue and honour,\n"
  "And ever alike fair, and fresh of hue;\n"
  "As well in winter, as in summer new,\n"
  "This love I ever, and shall until I die;\n"
  "All* swear I not, of this I will not lie,                      *although\n"
  "There loved no wight hotter in his life.\n"
  "And when that it is eve, I runne blife,*               *quickly, eagerly\n"
  "As soon as ever the sun begins to west,*               *decline westward\n"
  "To see this flow'r, how it will go to rest,\n"
  "For fear of night, so hateth she darkness!\n"
  "Her cheer* is plainly spread in the brightness              *countenance\n"
  "Of the sunne, for there it will unclose.\n"
  "Alas! that I had English, rhyme or prose,\n"
  "Sufficient this flow'r to praise aright!\n"
  "But help me, ye that have *cunning or might;*           *skill or power*\n"
  "Ye lovers, that can make of sentiment,\n"
  "In this case ought ye to be diligent\n"
  "To further me somewhat in my labour,\n"
  "Whether ye be with the Leaf or the Flow'r; <3>\n"
  "For well I wot, that ye have herebefore\n"
  "Of making ropen,* and led away the corn; <4>                     *reaped\n"
  "And I come after, gleaning here and there,\n"
  "And am full glad if I may find an ear\n"
  "Of any goodly word that you have left.\n"
  "And though it hap me to rehearsen eft*                            *again\n"
  "What ye have in your freshe songes said,\n"
  "Forbeare me, and be not *evil apaid,*                       *displeased*\n"
  "Since that ye see I do it in th'honour\n"
  "Of love, and eke in service of the flow'r\n"
  "Whom that I serve as I have wit or might. <5>\n"
  "She is the clearness, and the very* light,                         *true\n"
  "That in this darke world me winds* and leads;             *turns, guides\n"
  "The heart within my sorrowful breast you dreads,\n"
  "And loves so sore, that ye be, verily,\n"
  "The mistress of my wit, and nothing I.\n"
  "My word, my works, are knit so in your bond,\n"
  "That, as a harp obeyeth to the hand,\n"
  "That makes it sound after his fingering,\n"
  "Right so may ye out of my hearte bring\n"
  "Such voice, right as you list, to laugh or plain;*      *complain, mourn\n"
  "Be ye my guide, and lady sovereign.\n"
  "As to mine earthly god, to you I call,\n"
  "Both in this work, and in my sorrows all.\n"
  "\n"
  "But wherefore that I spake to give credence\n"
  "To old stories, and do them reverence,\n"
  "And that men muste more things believe\n"
  "Than they may see at eye, or elles preve,*                        *prove\n"
  "That shall I say, when that I see my time;\n"
  "I may not all at ones speak in rhyme.\n"
  "My busy ghost,* that thirsteth always new                        *spirit\n"
  "To see this flow'r so young, so fresh of hue,\n"
  "Constrained me with so greedy desire,\n"
  "That in my heart I feele yet the fire,\n"
  "That made me to rise ere it were day, --\n"
  "And this was now the first morrow of May, --\n"
  "With dreadful heart, and glad devotion,\n"
  "For to be at the resurrection\n"
  "Of this flower, when that it should unclose\n"
  "Against the sun, that rose as red as rose,\n"
  "That in the breast was of the beast* that day      *the sign of the Bull\n"
  "That Agenore's daughter led away. <6>\n"
  "And down on knees anon right I me set,\n"
  "And as I could this freshe flow'r I gret,*                      *greeted\n"
  "Kneeling alway, till it unclosed was,\n"
  "Upon the smalle, softe, sweete grass,\n"
  "That was with flowers sweet embroider'd all,\n"
  "Of such sweetness and such odour *o'er all,*                *everywhere*\n"
  "That, for to speak of gum, or herb, or tree,\n"
  "Comparison may none y-maked be;\n"
  "For it surmounteth plainly all odours,\n"
  "And for rich beauty the most gay of flow'rs.\n"
  "Forgotten had the earth his poor estate\n"
  "Of winter, that him naked made and mate,*            *dejected, lifeless\n"
  "And with his sword of cold so sore grieved;\n"
  "Now hath th'attemper* sun all that releaved**     *temperate **furnished\n"
  "That naked was, and clad it new again.                  anew with leaves\n"
  "The smalle fowles, of the season fain,*                            *glad\n"
  "That of the panter* and the net be scap'd,                     *draw-net\n"
  "Upon the fowler, that them made awhap'd*          *terrified, confounded\n"
  "In winter, and destroyed had their brood,\n"
  "In his despite them thought it did them good\n"
  "To sing of him, and in their song despise\n"
  "The foule churl, that, for his covetise,*                         *greed\n"
  "Had them betrayed with his sophistry*                        *deceptions\n"
  "This was their song: \"The fowler we defy,\n"
  "And all his craft:\" and some sunge clear\n"
  "Layes of love, that joy it was to hear,\n"
  "In worshipping* and praising of their make;**          *honouring **mate\n"
  "And for the blissful newe summer's sake,\n"
  "Upon the branches full of blossoms soft,\n"
  "In their delight they turned them full oft,\n"
  "And sunge, \"Blessed be Saint Valentine! <7>\n"
  "For on his day I chose you to be mine,\n"
  "Withoute repenting, my hearte sweet.\"\n"
  "And therewithal their heals began to meet,\n"
  "Yielding honour, and humble obeisances,\n"
  "To love, and did their other observances\n"
  "That longen unto Love and to Nature;\n"
  "Construe that as you list, I *do no cure.*                *care nothing*\n"
  "And those that hadde *done unkindeness,*              *committed offence\n"
  "As doth the tidife, <8> for newfangleness,         against natural laws*\n"
  "Besoughte mercy for their trespassing\n"
  "And humblely sange their repenting,\n"
  "And swore upon the blossoms to be true;\n"
  "So that their mates would upon them rue,*                     *take pity\n"
  "And at the laste made their accord.*                     *reconciliation\n"
  "All* found they Danger** for a time a lord,          *although **disdain\n"
  "Yet Pity, through her stronge gentle might,\n"
  "Forgave, and made mercy pass aright\n"
  "Through Innocence, and ruled Courtesy.\n"
  "But I ne call not innocence folly\n"
  "Nor false pity, for virtue is the mean,\n"
  "As Ethic <9> saith, in such manner I mean.\n"
  "And thus these fowles, void of all malice,\n"
  "Accorded unto Love, and lefte vice\n"
  "Of hate, and sangen all of one accord,\n"
  "\"Welcome, Summer, our governor and lord!\"\n"
  "And Zephyrus and Flora gentilly\n"
  "Gave to the flowers, soft and tenderly,\n"
  "Their sweete breath, and made them for to spread,\n"
  "As god and goddess of the flow'ry mead;\n"
  "In which me thought I mighte, day by day,\n"
  "Dwellen alway, the jolly month of May,\n"
  "Withoute sleep, withoute meat or drink.\n"
  "Adown full softly I began to sink,\n"
  "And, leaning on mine elbow and my side\n"
  "The longe day I shope* to abide,                     *resolved, prepared\n"
  "For nothing elles, and I shall not lie\n"
  "But for to look upon the daisy;\n"
  "That men by reason well it calle may\n"
  "The Daye's-eye, or else the Eye of Day,\n"
  "The empress and the flow'r of flowers all\n"
  "I pray to God that faire may she fall!\n"
  "And all that love flowers, for her sake:\n"
  "But, nathelesse, *ween not that I make*             *do not fancy that I\n"
  "In praising of the Flow'r against the Leaf,             write this poem*\n"
  "No more than of the corn against the sheaf;\n"
  "For as to me is lever none nor lother,\n"
  "I n'am withholden yet with neither n'other.<10>\n"
  "*Nor I n'ot* who serves Leaf, nor who the Flow'r;        *nor do I know*\n"
  "Well *brooke they* their service or labour!         *may they profit by*\n"
  "For this thing is all of another tun, <11>\n"
  "Of old story, ere such thing was begun.\n"
  "\n"
  "When that the sun out of the south gan west,\n"
  "And that this flow'r gan close, and go to rest,\n"
  "For darkness of the night, the which she dread;*                *dreaded\n"
  "Home to my house full swiftly I me sped,\n"
  "To go to rest, and early for to rise,\n"
  "To see this flower spread, as I devise.*                       *describe\n"
  "And in a little arbour that I have,\n"
  "That benched was of turfes fresh y-grave,* <12>                 *cut out\n"
  "I bade men shoulde me my couche make;\n"
  "For dainty* of the newe summer's sake,                         *pleasure\n"
  "I bade them strowe flowers on my bed.\n"
  "When I was laid, and had mine eyen hid,\n"
  "I fell asleep; within an hour or two,\n"
  "Me mette* how I lay in the meadow tho,**                 *dreamed **then\n"
  "To see this flow'r that I love so and dread.\n"
  "And from afar came walking in the mead\n"
  "The God of Love, and in his hand a queen;\n"
  "And she was clad in royal habit green;\n"
  "A fret* of gold she hadde next her hair,                           *band\n"
  "And upon that a white corown she bare,\n"
  "With flowrons* small, and, as I shall not lie,             *florets <13>\n"
  "For all the world right as a daisy\n"
  "Y-crowned is, with white leaves lite,*                            *small\n"
  "So were the flowrons of her crowne white.\n"
  "For of one pearle, fine, oriential,\n"
  "Her white crowne was y-maked all,\n"
  "For which the white crown above the green\n"
  "Made her like a daisy for to see'n,*                          *look upon\n"
  "Consider'd eke her fret of gold above.\n"
  "Y-clothed was this mighty God of Love\n"
  "In silk embroider'd, full of greene greves,*                     *boughs\n"
  "In which there was a fret of red rose leaves,\n"
  "The freshest since the world was first begun.\n"
  "His gilt hair was y-crowned with a sun,\n"
  "lnstead of gold, for* heaviness and weight;                    *to avoid\n"
  "Therewith me thought his face shone so bright,\n"
  "That well unnethes might I him behold;\n"
  "And in his hand me thought I saw him hold\n"
  "Two fiery dartes, as the gledes* red;                     *glowing coals\n"
  "And angel-like his winges saw I spread.\n"
  "And *all be* that men say that blind is he,                   *although*\n"
  "Algate* me thoughte that he might well see;               *at all events\n"
  "For sternly upon me he gan behold,\n"
  "So that his looking *did my hearte cold.*                 *made my heart\n"
  "And by the hand he held this noble queen,                     grow cold*\n"
  "Crowned with white, and clothed all in green,\n"
  "So womanly, so benign, and so meek,\n"
  "That in this worlde, though that men would seek.\n"
  "Half of her beauty shoulde they not find\n"
  "In creature that formed is by Kind;*                             *Nature\n"
  "And therefore may I say, as thinketh me,\n"
  "This song in praising of this lady free:\n"
  "\n"
  "\"Hide, Absolon, thy gilte* tresses clear;                        *golden\n"
  "Esther, lay thou thy meekness all adown;\n"
  "Hide, Jonathan, all thy friendly mannere,\n"
  "Penelope, and Marcia Catoun,<14>\n"
  "Make of your wifehood no comparisoun;\n"
  "Hide ye your beauties, Isoude <15> and Helene;\n"
  "My lady comes, that all this may distain.*               *outdo, obscure\n"
  "\n"
  "\"Thy faire body let it not appear,\n"
  "Lavine; <16> and thou, Lucrece of Rome town;\n"
  "And Polyxene, <17> that boughte love so dear,\n"
  "And Cleopatra, with all thy passioun,\n"
  "Hide ye your truth of love, and your renown;\n"
  "And thou, Thisbe, that hadst of love such pain\n"
  "My lady comes, that all this may distain.\n"
  "\n"
  "\"Hero, Dido, Laodamia, y-fere,*                                *together\n"
  "And Phyllis, hanging for Demophoon,\n"
  "And Canace, espied by thy cheer,\n"
  "Hypsipyle, betrayed by Jasoun,\n"
  "Make of your truthe neither boast nor soun';\n"
  "Nor Hypermnestr' nor Ariadne, ye twain;\n"
  "My lady comes, that all this may distain.\"\n"
  "\n"
  "This ballad may full well y-sungen be,\n"
  "As I have said erst, by my lady free;\n"
  "For, certainly, all these may not suffice\n"
  "*T'appaire with* my lady in no wise;                  *surpass in beauty\n"
  "For, as the sunne will the fire distain,                      or honour*\n"
  "So passeth all my lady sovereign,\n"
  "That is so good, so fair, so debonair,\n"
  "I pray to God that ever fall her fair!\n"
  "For *n'hadde comfort been* of her presence,               *had I not the\n"
  "I had been dead, without any defence,                        comfort of*\n"
  "For dread of Love's wordes, and his cheer;\n"
  "As, when time is, hereafter ye shall hear.\n"
  "Behind this God of Love, upon the green,\n"
  "I saw coming of Ladies nineteen,\n"
  "In royal habit, a full easy pace;\n"
  "And after them of women such a trace,*                            *train\n"
  "That, since that God Adam had made of earth,\n"
  "The thirde part of mankind, or the ferth,*                       *fourth\n"
  "*Ne ween'd I not* by possibility,                      *I never fancied*\n"
  "Had ever in this wide world y-be;*                                 *been\n"
  "And true of love these women were each one.\n"
  "Now whether was that a wonder thing, or non,*                       *not\n"
  "That, right anon as that they gan espy\n"
  "This flow'r, which that I call the daisy,\n"
  "Full suddenly they stenten* all at once,                        *stopped\n"
  "And kneeled down, as it were for the nonce,\n"
  "And sange with one voice, \"Heal and honour\n"
  "To truth of womanhead, and to this flow'r,\n"
  "*That bears our aller prize in figuring;*      *that in its figure bears\n"
  "Her white crowne bears the witnessing!\"           the prize from us all*\n"
  "And with that word, *a-compass enviroun*          *all around in a ring*\n"
  "They sette them full softely adown.\n"
  "First sat the God of Love, and since* his queen,             *afterwards\n"
  "With the white corowne, clad in green;\n"
  "And sithen* all the remnant by and by,                             *then\n"
  "As they were of estate, full courteously;\n"
  "And not a word was spoken in the place,\n"
  "The mountance* of a furlong way of space.                   *extent <18>\n"
  "\n"
  "";
// }

const char prologueToTheLegendOfGoodWomen1[] PGMSECTION = // { // 18873 bytes
  "I, kneeling by this flow'r, in good intent\n"
  "Abode, to knowe what this people meant,\n"
  "As still as any stone, till, at the last,\n"
  "The God of Love on me his eyen cast,\n"
  "And said, \"Who kneeleth there? \"and I answer'd\n"
  "Unto his asking, when that I it heard,\n"
  "And said, \"It am I,\" and came to him near,\n"
  "And salued* him. Quoth he, \"What dost thou here,                *saluted\n"
  "So nigh mine owen flow'r, so boldely?\n"
  "It were better worthy, truely,\n"
  "A worm to nighe* near my flow'r than thou.\"         *approach, draw nigh\n"
  "\"And why, Sir,\" quoth I, \"an' it liketh you?\"\n"
  "\"For thou,\" quoth he, \"art thereto nothing able,\n"
  "It is my relic,* dign** and delectable,            *emblem <19> **worthy\n"
  "And thou my foe, and all my folk warrayest,*       *molestest, censurest\n"
  "And of mine olde servants thou missayest,\n"
  "And hind'rest them, with thy translation,\n"
  "And lettest* folk from their devotion                        *preventest\n"
  "To serve me, and holdest it folly\n"
  "To serve Love; thou may'st it not deny;\n"
  "For in plain text, withoute need of glose,*              *comment, gloss\n"
  "Thu hast translated the Romance of the Rose,\n"
  "That is a heresy against my law,\n"
  "And maketh wise folk from me withdraw;\n"
  "And of Cresside thou hast said as thee list,\n"
  "That maketh men to women less to trust,\n"
  "That be as true as e'er was any steel.\n"
  "Of thine answer *advise thee right weel;*          *consider right well*\n"
  "For though that thou *renied hast my lay,*               *abjured my law\n"
  "As other wretches have done many a day,                     or religion*\n"
  "By Sainte Venus, that my mother is,\n"
  "If that thou live, thou shalt repente this,\n"
  "So cruelly, that it shall well be seen.\"\n"
  "\n"
  "Then spake this Lady, clothed all in green,\n"
  "And saide, \"God, right of your courtesy,\n"
  "Ye mighte hearken if he can reply\n"
  "Against all this, that ye have *to him meved;*    *advanced against him*\n"
  "A godde shoulde not be thus aggrieved,\n"
  "But of his deity he shall be stable,\n"
  "And thereto gracious and merciable.*                           *merciful\n"
  "And if ye n'ere* a god, that knoweth all,                      *were not\n"
  "Then might it be, as I you telle shall,\n"
  "This man to you may falsely be accused,\n"
  "Whereas by right him ought to be excused;\n"
  "For in your court is many a losengeour,*                  *deceiver <20>\n"
  "And many a *quaint toteler accusour,*     *strange prating accuser <21>*\n"
  "That tabour* in your eares many a soun',                           *drum\n"
  "Right after their imaginatioun,\n"
  "To have your dalliance,* and for envy;           *pleasant conversation,\n"
  "These be the causes, and I shall not lie,                        company\n"
  "Envy is lavender* of the Court alway,                         *laundress\n"
  "For she departeth neither night nor day <22>\n"
  "Out of the house of Caesar, thus saith Dant';\n"
  "Whoso that go'th, algate* she shall not want.             *at all events\n"
  "And eke, parauntre,* for this man is nice,**     *peradventure **foolish\n"
  "He mighte do it guessing* no malice;                           *thinking\n"
  "For he useth thinges for to make;*                       *compose poetry\n"
  "Him *recketh naught of * what mattere he take;       *cares nothing for*\n"
  "Or he was bidden *make thilke tway*                  *compose those two*\n"
  "Of* some person, and durst it not withsay;*           *by **refuse, deny\n"
  "Or him repenteth utterly of this.\n"
  "He hath not done so grievously amiss,\n"
  "To translate what olde clerkes write,\n"
  "As though that he of malice would endite,*                   *write down\n"
  "*Despite of* Love, and had himself it wrought.            *contempt for*\n"
  "This should a righteous lord have in his thought,\n"
  "And not be like tyrants of Lombardy,\n"
  "That have no regard but at tyranny.\n"
  "For he that king or lord is naturel,\n"
  "Him oughte not be tyrant or cruel, <23>\n"
  "As is a farmer, <24> to do the harm he can;\n"
  "He muste think, it is his liegeman,\n"
  "And is his treasure, and his gold in coffer;\n"
  "This is the sentence* of the philosopher:            *opinion, sentiment\n"
  "A king to keep his lieges in justice,\n"
  "Withoute doubte that is his office.\n"
  "All* will he keep his lords in their degree, --                *although\n"
  "As it is right and skilful* that they be,                    *reasonable\n"
  "Enhanced and honoured, and most dear,\n"
  "For they be halfe* in this world here, --                      *demigods\n"
  "Yet must he do both right to poor and rich,\n"
  "All be that their estate be not y-lich;*                          *alike\n"
  "And have of poore folk compassion.\n"
  "For lo! the gentle kind of the lion;\n"
  "For when a fly offendeth him, or biteth,\n"
  "He with his tail away the flye smiteth,\n"
  "All easily; for of his gentery*                               *nobleness\n"
  "Him deigneth not to wreak him on a fly,\n"
  "As doth a cur, or else another beast.\n"
  "*In noble corage ought to be arrest,*           *in a noble nature ought\n"
  "And weighen ev'rything by equity,                  to be self-restraint*\n"
  "And ever have regard to his degree.\n"
  "For, Sir, it is no mastery for a lord\n"
  "To damn* a man, without answer of word;                         *condemn\n"
  "And for a lord, that is *full foul to use.*     *most infamous practice*\n"
  "And it be so he* may him not excuse,                       *the offender\n"
  "But asketh mercy with a dreadful* heart,                 *fearing, timid\n"
  "And proffereth him, right in his bare shirt,\n"
  "To be right at your owen judgement,\n"
  "Then ought a god, by short advisement,*                    *deliberation\n"
  "Consider his own honour, and his trespass;\n"
  "For since no pow'r of death lies in this case,\n"
  "You ought to be the lighter merciable;\n"
  "Lette* your ire, and be somewhat tractable!                    *restrain\n"
  "This man hath served you of his cunning,*                *ability, skill\n"
  "And further'd well your law in his making.*            *composing poetry\n"
  "Albeit that he cannot well endite,\n"
  "Yet hath he made lewed* folk delight                           *ignorant\n"
  "To serve you, in praising of your name.\n"
  "He made the book that hight the House of Fame,\n"
  "And eke the Death of Blanche the Duchess,\n"
  "And the Parliament of Fowles, as I guess,\n"
  "And all the Love of Palamon and Arcite, <25>\n"
  "Of Thebes, though the story is known lite;*                      *little\n"
  "And many a hymne for your holydays,\n"
  "That highte ballads, roundels, virelays.\n"
  "And, for to speak of other holiness,\n"
  "He hath in prose translated Boece, <26>\n"
  "And made the Life also of Saint Cecile;\n"
  "He made also, gone is a greate while,\n"
  "Origenes upon the Magdalene. <27>\n"
  "Him oughte now to have the lesse pain;*                         *penalty\n"
  "He hath made many a lay, and many a thing.\n"
  "Now as ye be a god, and eke a king,\n"
  "I your Alcestis, <28> whilom queen of Thrace,\n"
  "I aske you this man, right of your grace,\n"
  "That ye him never hurt in all his life;\n"
  "And he shall sweare to you, and that blife,*                    *quickly\n"
  "He shall no more aguilten* in this wise,                         *offend\n"
  "But shall maken, as ye will him devise,\n"
  "Of women true in loving all their life,\n"
  "Whereso ye will, of maiden or of wife,\n"
  "And further you as much as he missaid\n"
  "Or* in the Rose, or elles in Cresseide.\"                         *either\n"
  "\n"
  "The God of Love answered her anon:\n"
  "\"Madame,\" quoth he, \"it is so long agone\n"
  "That I you knew, so charitable and true,\n"
  "That never yet, since that the world was new,\n"
  "To me ne found I better none than ye;\n"
  "If that I woulde save my degree,\n"
  "I may nor will not warne* your request;                          *refuse\n"
  "All lies in you, do with him as you lest.\n"
  "I all forgive withoute longer space;*                             *delay\n"
  "For he who gives a gift, or doth a grace,\n"
  "Do it betimes, his thank is well the more; <29>\n"
  "And deeme* ye what he shall do therefor.                        *adjudge\n"
  "Go thanke now my Lady here,\" quoth he.\n"
  "I rose, and down I set me on my knee,\n"
  "And saide thus; \"Madame, the God above\n"
  "Foryielde* you that ye the God of Love                           *reward\n"
  "Have made me his wrathe to forgive;\n"
  "And grace* so longe for to live,                          *give me grace\n"
  "That I may knowe soothly what ye be,\n"
  "That have me help'd, and put in this degree!\n"
  "But truely I ween'd, as in this case,\n"
  "Naught t' have aguilt,* nor done to Love trespass;**           *offended\n"
  "For why? a true man, withoute dread,                           **offence\n"
  "Hath not *to parte with* a thieve's deed.                 *any share in*\n"
  "Nor a true lover oughte me to blame,\n"
  "Though that I spoke a false lover some shame.\n"
  "They oughte rather with me for to hold,\n"
  "For that I of Cressida wrote or told,\n"
  "Or of the Rose, *what so mine author meant;*   *made a true translation*\n"
  "Algate, God wot, it was mine intent                         *by all ways\n"
  "To further truth in love, and it cherice,*                      *cherish\n"
  "And to beware from falseness and from vice,\n"
  "By such example; this was my meaning.\"\n"
  "\n"
  "And she answer'd; \"Let be thine arguing,\n"
  "For Love will not counterpleaded be <30>\n"
  "In right nor wrong, and learne that of me;\n"
  "Thou hast thy grace, and hold thee right thereto.\n"
  "Now will I say what penance thou shalt do\n"
  "For thy trespass;* and understand it here:                      *offence\n"
  "Thou shalt, while that thou livest, year by year,\n"
  "The moste partie of thy time spend\n"
  "In making of a glorious Legend\n"
  "Of Goode Women, maidenes and wives,\n"
  "That were true in loving all their lives;\n"
  "And tell of false men that them betray,\n"
  "That all their life do naught but assay\n"
  "How many women they may do a shame;\n"
  "For in your world that is now *held a game.*        *considered a sport*\n"
  "And though thou like not a lover be, <31>\n"
  "Speak well of love; this penance give I thee.\n"
  "And to the God of Love I shall so pray,\n"
  "That he shall charge his servants, by any way,\n"
  "To further thee, and well thy labour quite:*                    *requite\n"
  "Go now thy way, thy penance is but lite.\n"
  "And, when this book ye make, give it the queen\n"
  "On my behalf, at Eltham, or at Sheen.\"\n"
  "\n"
  "The God of Love gan smile, and then he said:\n"
  "\"Know'st thou,\" quoth he, \"whether this be wife or maid,\n"
  "Or queen, or countess, or of what degree,\n"
  "That hath so little penance given thee,\n"
  "That hath deserved sorely for to smart?\n"
  "But pity runneth soon in gentle* heart; <32>                 *nobly born\n"
  "That may'st thou see, she kitheth* what she is.                 *showeth\n"
  "And I answer'd: \"Nay, Sir, so have I bliss,\n"
  "No more but that I see well she is good.\"\n"
  "\"That is a true tale, by my hood,\"\n"
  "Quoth Love; \"and that thou knowest well, pardie!\n"
  "If it be so that thou advise* thee.                             *bethink\n"
  "Hast thou not in a book, li'th* in thy chest,               *(that) lies\n"
  "The greate goodness of the queen Alceste,\n"
  "That turned was into a daisy\n"
  "She that for her husbande chose to die,\n"
  "And eke to go to hell rather than he;\n"
  "And Hercules rescued her, pardie!\n"
  "And brought her out of hell again to bliss?\"\n"
  "And I answer'd again, and saide; \"Yes,\n"
  "Now know I her; and is this good Alceste,\n"
  "The daisy, and mine own hearte's rest?\n"
  "Now feel I well the goodness of this wife,\n"
  "That both after her death, and in her life,\n"
  "Her greate bounty* doubleth her renown.                          *virtue\n"
  "Well hath she quit* me mine affectioun                      *recompensed\n"
  "That I have to her flow'r the daisy;\n"
  "No wonder is though Jove her stellify, <33>\n"
  "As telleth Agathon, <34> for her goodness;\n"
  "Her white crowne bears of it witness;\n"
  "For all so many virtues hadde she\n"
  "As smalle flowrons in her crowne be.\n"
  "In remembrance of her, and in honour,\n"
  "Cybele made the daisy, and the flow'r,\n"
  "Y-crowned all with white, as men may see,\n"
  "And Mars gave her a crowne red, pardie!\n"
  "Instead of rubies set among the white.\"\n"
  "\n"
  "Therewith this queen wax'd red for shame a lite\n"
  "When she was praised so in her presence.\n"
  "Then saide Love: \"A full great negligence\n"
  "Was it to thee, that ilke* time thou made                     *that same\n"
  "'Hide Absolon thy tresses,' in ballade,\n"
  "That thou forgot her in thy song to set,\n"
  "Since that thou art so greatly in her debt,\n"
  "And knowest well that calendar* is she                   *guide, example\n"
  "To any woman that will lover be:\n"
  "For she taught all the craft of true loving,\n"
  "And namely* of wifehood the living,                          *especially\n"
  "And all the boundes that she ought to keep:\n"
  "Thy little wit was thilke* time asleep.                            *that\n"
  "But now I charge thee, upon thy life,\n"
  "That in thy Legend thou make* of this wife,            *poetise, compose\n"
  "When thou hast other small y-made before;\n"
  "And fare now well, I charge thee no more.\n"
  "But ere I go, thus much I will thee tell, --\n"
  "Never shall no true lover come in hell.\n"
  "These other ladies, sitting here a-row,\n"
  "Be in my ballad, if thou canst them know,\n"
  "And in thy bookes all thou shalt them find;\n"
  "Have them in thy Legend now all in mind;\n"
  "I mean of them that be in thy knowing.\n"
  "For here be twenty thousand more sitting\n"
  "Than that thou knowest, goode women all,\n"
  "And true of love, for aught that may befall;\n"
  "Make the metres of them as thee lest;\n"
  "I must go home, -- the sunne draweth west, --\n"
  "To Paradise, with all this company:\n"
  "And serve alway the freshe daisy.\n"
  "At Cleopatra I will that thou begin,\n"
  "And so forth, and my love so shalt thou win;\n"
  "For let see now what man, that lover be,\n"
  "Will do so strong a pain for love as she.\n"
  "I wot well that thou may'st not all it rhyme,\n"
  "That suche lovers didden in their time;\n"
  "It were too long to readen and to hear;\n"
  "Suffice me thou make in this mannere,\n"
  "That thou rehearse of all their life the great,*              *substance\n"
  "After* these old authors list for to treat;                *according as\n"
  "For whoso shall so many a story tell,\n"
  "Say shortly, or he shall too longe dwell.\"\n"
  "\n"
  "And with that word my bookes gan I take,\n"
  "And right thus on my Legend gan I make.\n"
  "\n"
  "Thus endeth the Prologue.\n"
  "\n"
  "\n"
  "Notes to The prologue to The Legend of Good Women\n"
  "\n"
  "\n"
  "1. Bernard, the Monke, saw not all, pardie!: a proverbial saying,\n"
  "signifying that even the wisest, or those who claim to be the\n"
  "wisest, cannot know everything. Saint Bernard, who was the\n"
  "last, or among the last, of the Fathers, lived in the first half of\n"
  "the twelfth century.\n"
  "\n"
  "2. Compare Chaucer's account of his habits, in \"The House of\n"
  "Fame.\"\n"
  "\n"
  "3. See introductory note to \"The Flower and the Leaf.\"\n"
  "\n"
  "4.                  \"ye have herebefore\n"
  "Of making ropen, and led away the corn\"\n"
  "The meaning is, that the \"lovers\" have long ago said all that can\n"
  "be said, by way of poetry, or \"making\" on the subject. See note\n"
  "89 to \"Troilus and Cressida\" for the etymology of \"making\"\n"
  "meaning \"writing poetry.\"\n"
  "\n"
  "5. The poet glides here into an address to his lady.\n"
  "\n"
  "6. Europa was the daughter of Agenores, king of Phrygia. She\n"
  "was carried away to Crete by Jupiter, disguised as a lovely and\n"
  "tame bull, on whose back Europa mounted as she was sporting\n"
  "with her maidens by the sea-shore. The story is beautifully told\n"
  "in Horace, Odes, iii. 27.\n"
  "\n"
  "7. See \"The Assembly of Fowls,\" which was supposed to\n"
  "happen on St. Valentine's day.\n"
  "\n"
  "8. The tidife:  The titmouse, or any other small bird, which\n"
  "sometimes brings up the cuckoo's young when its own have\n"
  "been destroyed. See note 44 to \"The Assembly of Fowls.\"\n"
  "\n"
  "9. Ethic: the \"Ethics\" of Aristotle.\n"
  "\n"
  "10. \"For as to me is lever none nor lother,\n"
  "    I n'am withholden yet with neither n'other.\"\n"
  "i.e For as neither is more liked or disliked by me, I am not\n"
  "bound by, holden to, either the one or the other.\n"
  "\n"
  "11. All of another tun i.e. wine of another tun -- a quite\n"
  "different matter.\n"
  "\n"
  "12. Compare the description of the arbour in \"The Flower and\n"
  "the Leaf.\"\n"
  "\n"
  "13. Flowrons: florets; little flowers on the disk of the main\n"
  "flower; French \"fleuron.\"\n"
  "\n"
  "14. Mr Bell thinks that Chaucer here praises the complaisance\n"
  "of Marcia, the wife of Cato, in complying with his will when he\n"
  "made her over to his friend Hortensius. It would be in better\n"
  "keeping with the spirit of the poet's praise, to believe that we\n"
  "should read \"Porcia Catoun\" -- Porcia the daughter of Cato,\n"
  "who was married to Brutus, and whose perfect wifehood has\n"
  "been celebrated in The Franklin's Tale. See note 25 to the\n"
  "Franklin's Tale.\n"
  "\n"
  "15. Isoude: See note 21 to \"The Assembly of Fowls\".\n"
  "\n"
  "16. Lavine: Lavinia, the heroine of the Aeneid, who became the\n"
  "wife of Aeneas.\n"
  "\n"
  "17. Polyxena, daughter of Priam, king of Troy, fell in\n"
  "love with Achilles, and, when he was killed, she fled to the\n"
  "Greek camp, and slew herself on the tomb of her hero-lover.\n"
  "\n"
  "18. Mountance: extent, duration. See note 84 to \"The House of\n"
  "Fame\".\n"
  "\n"
  "19. Relic: emblem; or cherished treasure; like the relics at\n"
  "the shrines of saints.\n"
  "\n"
  "20. Losengeour: deceiver. See note 31 to the Nun's Priest's\n"
  "Tale.\n"
  "\n"
  "21. \"Toteler\" is an old form of the word \"tatler,\" from the\n"
  "Anglo-Saxon, \"totaelan,\" to talk much, to tattle.\n"
  "\n"
  "22. Envy is lavender of the court alway: a \"lavender\"  is a\n"
  "washerwoman or laundress; the word represents \"meretrice\"in\n"
  "Dante's original -- meaning a courtezan; but we can well\n"
  "understand that Chaucer thought it prudent, and at the same\n"
  "time more true to the moral state of the English Court, to\n"
  "change the character assigned to Envy. He means that Envy is\n"
  "perpetually at Court, like some garrulous, bitter old woman\n"
  "employed there in the most servile offices, who remains at her\n"
  "post through all the changes among the courtiers. The passage\n"
  "cited from Dante will be found in the \"Inferno,\" canto xiii. 64 --\n"
  "69.\n"
  "\n"
  "23. Chaucer says that the usurping lords who seized on the\n"
  "government of the free Lombard cities, had no regard for any\n"
  "rule of government save sheer tyranny  -- but a natural lord, and\n"
  "no usurper, ought not to be a tyrant.\n"
  "\n"
  "24. Farmer: one who merely farms power or revenue for his\n"
  "own purposes and his own gain.\n"
  "\n"
  "25. This was the first version of the Knight's tale. See the\n"
  "introductory note, above\n"
  "\n"
  "26. Boece: Boethius' \"De Consolatione Philosophiae;\" to which\n"
  "frequent reference is made in The Canterbury Tales. See, for\n"
  "instances, note 91 to the Knight's Tale; and note 34 to the\n"
  "Squire's Tale.\n"
  "\n"
  "27. A poem entitled \"The Lamentation of Mary Magdalene,\"\n"
  "said to have been \"taken out of St Origen,\" is included in the\n"
  "editions of Chaucer; but its authenticity, and consequently its\n"
  "identity with the poem here mentioned, are doubted.\n"
  "\n"
  "28. For the story of Alcestis, see note 11 to \"The Court of\n"
  "Love.\"\n"
  "\n"
  "29. \"For he who gives a gift, or doth a grace,\n"
  "     Do it betimes, his thank is well the more\"\n"
  "A paraphrase of the well-known proverb, \"Bis dat qui cito dat.\"\n"
  "(\"He gives twice who gives promptly\")\n"
  "\n"
  "30. The same prohibition occurs in the Fifteenth Statute of \"The\n"
  "Court of Love.\"\n"
  "\n"
  "31. Chaucer is always careful to allege his abstinence from the\n"
  "pursuits of gallantry; he does so prominently in \"The Court of\n"
  "Love,\" \"The Assembly of Fowls,\" and \"The House of Fame.\"\n"
  "\n"
  "32. Pity runneth soon in gentle heart: the same is said of\n"
  "Theseus, in The Knight's Tale, and of Canace, by the falcon, in\n"
  "The Squire's Tale.\n"
  "\n"
  "33. Stellify: assign to a place among the stars; as Jupiter did to\n"
  "Andromeda and Cassiopeia.\n"
  "\n"
  "34. Agathon: there was an Athenian dramatist of this name,\n"
  "who might have made the virtues and fortunes of Alcestis his\n"
  "theme; but the reference is too vague for the author to be\n"
  "identified with any confidence.\n"
  "\n"
  "\n"
  "\n"
  "";
// }

const char chaucersABC[] PGMSECTION = // { // 11675 bytes
  "                       CHAUCER'S A. B. C. <1>\n"
  "                             CALLED\n"
  "                  LA PRIERE DE NOSTRE DAME <2>\n"
  "\n"
  "\n"
  "                               A.\n"
  "\n"
  "ALMIGHTY and all-merciable* Queen,                         *all-merciful\n"
  "To whom all this world fleeth for succour,\n"
  "To have release of sin, of sorrow, of teen!*                 *affliction\n"
  "Glorious Virgin! of all flowers flow'r,\n"
  "To thee I flee, confounded in errour!\n"
  "Help and relieve, almighty debonair,*                  *gracious, gentle\n"
  "Have mercy of my perilous languour!\n"
  "Vanquish'd me hath my cruel adversair.\n"
  "\n"
  "                               B.\n"
  "\n"
  "Bounty* so fix'd hath in thy heart his tent,          *goodness, charity\n"
  "That well I wot thou wilt my succour be;\n"
  "Thou canst not *warne that* with good intent             *refuse he who*\n"
  "Asketh thy help, thy heart is ay so free!\n"
  "Thou art largess* of plein** felicity,          *liberal bestower **full\n"
  "Haven and refuge of quiet and rest!\n"
  "Lo! how that thieves seven <3> chase me!\n"
  "Help, Lady bright, ere that my ship to-brest!*      *be broken to pieces\n"
  "\n"
  "                               C.\n"
  "\n"
  "Comfort is none, but in you, Lady dear!\n"
  "For lo! my sin and my confusion,\n"
  "Which ought not in thy presence to appear,\n"
  "Have ta'en on me a grievous action,*                            *control\n"
  "Of very right and desperation!\n"
  "And, as by right, they mighte well sustene\n"
  "That I were worthy my damnation,\n"
  "Ne were it mercy of you, blissful Queen!\n"
  "\n"
  "                               D.\n"
  "\n"
  "Doubt is there none, Queen of misericorde,*                  *compassion\n"
  "That thou art cause of grace and mercy here;\n"
  "God vouchesaf'd, through thee, with us t'accord;*      *to be reconciled\n"
  "For, certes, Christe's blissful mother dear!\n"
  "Were now the bow y-bent, in such mannere\n"
  "As it was first, of justice and of ire,\n"
  "The rightful God would of no mercy hear;\n"
  "But through thee have we grace as we desire.\n"
  "\n"
  "                               E.\n"
  "\n"
  "Ever hath my hope of refuge in thee be';\n"
  "For herebefore full oft in many a wise\n"
  "Unto mercy hast thou received me.\n"
  "But mercy, Lady! at the great assize,\n"
  "When we shall come before the high Justice!\n"
  "So little fruit shall then in me be found,\n"
  "That,* thou ere that day correcte me,                            *unless\n"
  "Of very right my work will me confound.\n"
  "\n"
  "                               F.\n"
  "\n"
  "Flying, I flee for succour to thy tent,\n"
  "Me for to hide from tempest full of dread;\n"
  "Beseeching you, that ye you not absent,\n"
  "Though I be wick'. O help yet at this need!\n"
  "All* have I been a beast in wit and deed,                      *although\n"
  "Yet, Lady! thou me close in with thy grace;\n"
  "*Thine enemy and mine,* -- Lady, take heed! --               *the devil*\n"
  "Unto my death in point is me to chase.\n"
  "\n"
  "                               G.\n"
  "\n"
  "Gracious Maid and Mother! which that never\n"
  "Wert bitter nor in earthe nor in sea, <4>\n"
  "But full of sweetness and of mercy ever,\n"
  "Help, that my Father be not wroth with me!\n"
  "Speak thou, for I ne dare Him not see;\n"
  "So have I done in earth, alas the while!\n"
  "That, certes, but if thou my succour be,\n"
  "To sink etern He will my ghost exile.\n"
  "\n"
  "                               H.\n"
  "\n"
  "He vouchesaf'd, tell Him, as was His will,\n"
  "Become a man, *as for our alliance,*               *to ally us with god*\n"
  "And with His blood He wrote that blissful bill\n"
  "Upon the cross, as general acquittance\n"
  "To ev'ry penitent in full creance;*                              *belief\n"
  "And therefore, Lady bright! thou for us pray;\n"
  "Then shalt thou stenten* alle His grievance,              *put an end to\n"
  "And make our foe to failen of his prey.\n"
  "\n"
  "                               I.\n"
  "\n"
  "I wote well thou wilt be our succour,\n"
  "Thou art so full of bounty in certain;\n"
  "For, when a soule falleth in errour,\n"
  "Thy pity go'th, and haleth* him again;                          *draweth\n"
  "Then makest thou his peace with his Sov'reign,\n"
  "And bringest him out of the crooked street:\n"
  "Whoso thee loveth shall not love in vain,\n"
  "That shall he find *as he the life shall lete.*          *when he leaves\n"
  "                                                                   life*\n"
  "                               K.\n"
  "\n"
  "*Kalendares illumined* be they                     *brilliant exemplars*\n"
  "That in this world be lighted with thy name;\n"
  "And whoso goeth with thee the right way,\n"
  "Him shall not dread in soule to be lame;\n"
  "Now, Queen of comfort! since thou art the same\n"
  "To whom I seeke for my medicine,\n"
  "Let not my foe no more my wound entame;*                 *injure, molest\n"
  "My heal into thy hand all I resign.\n"
  "\n"
  "                               L.\n"
  "\n"
  "Lady, thy sorrow can I not portray\n"
  "Under that cross, nor his grievous penance;\n"
  "But, for your bothe's pain, I you do pray,\n"
  "Let not our *aller foe* make his boastance,        *the foe of us all --\n"
  "That he hath in his listes, with mischance,                       Satan*\n"
  "*Convicte that* ye both have bought so dear;       *ensnared that which*\n"
  "As I said erst, thou ground of all substance!\n"
  "Continue on us thy piteous eyen clear.\n"
  "\n"
  "                               M.\n"
  "\n"
  "Moses, that saw the bush of flames red\n"
  "Burning, of which then never a stick brenn'd,*                   *burned\n"
  "Was sign of thine unwemmed* maidenhead.                     *unblemished\n"
  "Thou art the bush, on which there gan descend\n"
  "The Holy Ghost, the which that Moses wend*             *weened, supposed\n"
  "Had been on fire; and this was in figure. <5>\n"
  "Now, Lady! from the fire us do defend,\n"
  "Which that in hell eternally shall dure.\n"
  "\n"
  "                               N.\n"
  "\n"
  "Noble Princess! that never haddest peer;\n"
  "Certes if any comfort in us be,\n"
  "That cometh of thee, Christe's mother dear!\n"
  "We have none other melody nor glee,*                           *pleasure\n"
  "Us to rejoice in our adversity;\n"
  "Nor advocate, that will and dare so pray\n"
  "For us, and for as little hire as ye,\n"
  "That helpe for an Ave-Mary or tway.\n"
  "\n"
  "                               O.\n"
  "\n"
  "O very light of eyen that be blind!\n"
  "O very lust* of labour and distress!                   *relief, pleasure\n"
  "O treasurer of bounty to mankind!\n"
  "The whom God chose to mother for humbless!\n"
  "From his ancill* <6> he made thee mistress                     *handmaid\n"
  "Of heav'n and earth, our *billes up to bede;*   *offer up our petitions*\n"
  "This world awaiteth ever on thy goodness;\n"
  "For thou ne failedst never wight at need.\n"
  "\n"
  "                               P.\n"
  "\n"
  "Purpose I have sometime for to enquere\n"
  "Wherefore and why the Holy Ghost thee sought,\n"
  "When Gabrielis voice came to thine ear;\n"
  "He not to war* us such a wonder wrought,                        *afflict\n"
  "But for to save us, that sithens us bought:\n"
  "Then needeth us no weapon us to save,\n"
  "But only, where we did not as we ought,\n"
  "Do penitence, and mercy ask and have.\n"
  "\n"
  "                               Q.\n"
  "\n"
  "Queen of comfort, right when I me bethink\n"
  "That I aguilt* have bothe Him and thee,                        *offended\n"
  "And that my soul is worthy for to sink,\n"
  "Alas! I, caitiff, whither shall I flee?\n"
  "Who shall unto thy Son my meane* be?                 *medium of approach\n"
  "Who, but thyself, that art of pity well?*                      *fountain\n"
  "Thou hast more ruth on our adversity\n"
  "Than in this world might any tongue tell!\n"
  "\n"
  "                               R.\n"
  "\n"
  "Redress me, Mother, and eke me chastise!\n"
  "For certainly my Father's chastising\n"
  "I dare not abiden in no wise,\n"
  "So hideous is his full reckoning.\n"
  "Mother! of whom our joy began to spring,\n"
  "Be ye my judge, and eke my soule's leach;*                    *physician\n"
  "For ay in you is pity abounding\n"
  "To each that will of pity you beseech.\n"
  "\n"
  "                               S.\n"
  "\n"
  "Sooth is it that He granteth no pity\n"
  "Withoute thee; for God of his goodness\n"
  "Forgiveth none, *but it like unto thee;*               *unless it please\n"
  "He hath thee made vicar and mistress                               thee*\n"
  "Of all this world, and eke governess\n"
  "Of heaven; and represseth his justice\n"
  "After* thy will; and therefore in witness                  *according to\n"
  "He hath thee crowned in so royal wise.\n"
  "\n"
  "                               T.\n"
  "\n"
  "Temple devout! where God chose his wonning,*                      *abode\n"
  "From which, these misbeliev'd deprived be,\n"
  "To you my soule penitent I bring;\n"
  "Receive me, for I can no farther flee.\n"
  "With thornes venomous, O Heaven's Queen!\n"
  "For which the earth accursed was full yore,\n"
  "I am so wounded, as ye may well see,\n"
  "That I am lost almost, it smart so sore!\n"
  "\n"
  "                               V.\n"
  "\n"
  "Virgin! that art so noble of apparail,*                          *aspect\n"
  "That leadest us into the highe tow'r\n"
  "Of Paradise, thou me *wiss and counsail*            *direct and counsel*\n"
  "How I may have thy grace and thy succour;\n"
  "All have I been in filth and in errour,\n"
  "Lady! *on that country thou me adjourn,*         *take me to that place*\n"
  "That called is thy bench of freshe flow'r,\n"
  "There as that mercy ever shall sojourn.\n"
  "\n"
  "                               X.\n"
  "\n"
  "Xpe <7> thy Son, that in this world alight,\n"
  "Upon a cross to suffer his passioun,\n"
  "And suffer'd eke that Longeus his heart pight,* <8>             *pierced\n"
  "And made his hearte-blood to run adown;\n"
  "And all this was for my salvatioun:\n"
  "And I to him am false and eke unkind,\n"
  "And yet he wills not my damnation;\n"
  "*This thank I you,* succour of all mankind!               *for this I am\n"
  "                                                        indebted to you*\n"
  "                               Y.\n"
  "\n"
  "Ysaac was figure of His death certain,\n"
  "That so farforth his father would obey,\n"
  "That him *ne raughte* nothing to be slain;                *he cared not*\n"
  "Right so thy Son list as a lamb to dey:*                            *die\n"
  "Now, Lady full of mercy! I you pray,\n"
  "Since he his mercy 'sured me so large,\n"
  "Be ye not scant, for all we sing and say,\n"
  "That ye be from vengeance alway our targe.*             *shield, defence\n"
  "\n"
  "                               Z.\n"
  "\n"
  "Zachary you calleth the open well <9>\n"
  "That washed sinful soul out of his guilt;\n"
  "Therefore this lesson out I will to tell,\n"
  "That, n'ere* thy tender hearte, we were spilt.**        *were it not for\n"
  "Now, Lady brighte! since thou canst and wilt,        *destroyed, undone*\n"
  "Be to the seed of Adam merciable;*                             *merciful\n"
  "Bring us unto that palace that is built\n"
  "To penitents that be *to mercy able!*             *fit to receive mercy*\n"
  "\n"
  "\n"
  "Explicit.*                                                      *The end\n"
  "\n"
  "\n"
  "Notes to Chaucer's A. B. C.\n"
  "\n"
  "1. Chaucer's A. B. C. -- a prayer to the Virgin, in twenty three\n"
  "verses, beginning with the letters of the alphabet in their\n"
  "order -- is said to have been written \"at the request of Blanche,\n"
  "Duchess of Lancaster, as a prayer for her private use, being a\n"
  "woman in her religion very devout.\" It was first printed in\n"
  "Speght's edition of 1597.\n"
  "\n"
  "2. La Priere De Nostre Dame: French, \"The Prayer of Our\n"
  "Lady.\"\n"
  "\n"
  "3. Thieves seven: i.e. the seven deadly sins\n"
  "\n"
  "4. Mary's name recalls the waters of \"Marah\" or bitterness\n"
  "(Exod. xv. 23), or the prayer of Naomi in her grief that she\n"
  "might be called not Naomi, but \"Mara\" (Ruth i. 20). Mary,\n"
  "however, is understood to mean \"exalted.\"\n"
  "\n"
  "5. A typical representation. See The Prioress's Tale, third\n"
  "stanza.\n"
  "\n"
  "6. The reference evidently is to Luke i. 38 -- \"Ecce ancilla\n"
  "Domini,\" (\"Behold the handmaid of the Lord\") the Virgin's\n"
  "humble answer to Gabriel at the Annunciation.\n"
  "\n"
  "7. \"Xpe\" represents the Greek letters chi rho epsilon, and is a\n"
  "contraction for \"Christe.\"\n"
  "\n"
  "8. According to tradition, the soldier who struck the Saviour to\n"
  "the heart with his spear was named Longeus, and was blind;\n"
  "but, touching his eyes by chance with the mingled blood and\n"
  "water that flowed down the shaft upon his hands, he was\n"
  "instantly restored to sight.\n"
  "\n"
  "9. \"In that day there shall be a fountain opened to the house of\n"
  "David and to the inhabitants of Jerusalem for sin and for\n"
  "uncleanness\" (Zech. xiii. 1).\n"
  "\n"
  "\n"
  "\n"
  "";
// }

const char miscellaneousPoems[] PGMSECTION = // { // 15957 bytes
  "                 A GOODLY BALLAD OF CHAUCER.<1>\n"
  "\n"
  "\n"
  "MOTHER of nurture, best belov'd of all,\n"
  "And freshe flow'r, to whom good thrift God send\n"
  "Your child, if it lust* you me so to call,                       *please\n"
  "*All be I*  unable myself so to pretend,                  *although I be\n"
  "To your discretion I recommend\n"
  "My heart and all, with ev'ry circumstance,\n"
  "All wholly to be under your governance.\n"
  "\n"
  "Most desire I, and have and ever shall,\n"
  "Thinge which might your hearte's ease amend\n"
  "Have me excus'd, my power is but small;\n"
  "Nathless, of right, ye oughte to commend\n"
  "My goode will, which fame would entend*                  *attend, strive\n"
  "To do you service; for my suffisance*                       *contentment\n"
  "Is wholly to be under your governance.\n"
  "\n"
  "Mieux un in heart which never shall apall, <2>\n"
  "Ay fresh and new, and right glad to dispend\n"
  "My time in your service, what so befall,\n"
  "Beseeching your excellence to defend\n"
  "My simpleness, if ignorance offend\n"
  "In any wise; since that mine affiance\n"
  "Is wholly to be under your governance.\n"
  "\n"
  "Daisy of light, very ground of comfort,\n"
  "The sunne's daughter ye light, as I read;\n"
  "For when he west'reth, farewell your disport!\n"
  "By your nature alone, right for pure dread\n"
  "Of the rude night, that with his *boistous weed*          *rude garment*\n"
  "Of darkness shadoweth our hemisphere,\n"
  "Then close ye, my life's lady dear!\n"
  "\n"
  "Dawneth the day unto his kind resort,\n"
  "And Phoebus your father, with his streames red,\n"
  "Adorns the morrow, consuming the sort*                            *crowd\n"
  "Of misty cloudes, that would overlade\n"
  "True humble heartes with their mistihead.*           *dimness, mistiness\n"
  "New comfort adaws,* when your eyen clear                 *dawns, awakens\n"
  "Disclose and spread, my life's lady dear.\n"
  "\n"
  "Je voudrais* -- but the greate God disposeth,              *I would wish\n"
  "And maketh casual, by his Providence,\n"
  "Such thing as manne's fraile wit purposeth,\n"
  "All for the best, if that your conscience\n"
  "Not grudge it, but in humble patience\n"
  "It receive; for God saith, withoute fable,\n"
  "A faithful heart ever is acceptable.\n"
  "\n"
  "Cauteles* whoso useth gladly, gloseth;**              *cautious speeches\n"
  "To eschew such it is right high prudence;                    **deceiveth\n"
  "What ye said ones mine heart opposeth,\n"
  "That my writing japes* in your absence            *jests, coarse stories\n"
  "Pleased you much better than my presence:\n"
  "Yet can I more; ye be not excusable;\n"
  "A faithful heart is ever acceptable.\n"
  "\n"
  "Quaketh my pen; my spirit supposeth\n"
  "That in my writing ye will find offence;\n"
  "Mine hearte welketh* thus; anon it riseth;              *withers, faints\n"
  "Now hot, now cold, and after in fervence;\n"
  "That is amiss, is caus'd of negligence,\n"
  "And not of malice; therefore be merciable;\n"
  "A faithful heart is ever acceptable.\n"
  "\n"
  "                            L'Envoy.\n"
  "\n"
  "Forthe, complaint! forth, lacking eloquence;\n"
  "Forth little letter, of enditing lame!\n"
  "I have besought my lady's sapience\n"
  "On thy behalfe, to accept in game\n"
  "Thine inability; do thou the same.\n"
  "Abide! have more yet! *Je serve Joyesse!*                  *I serve Joy*\n"
  "Now forth, I close thee in holy Venus' name!\n"
  "Thee shall unclose my hearte's governess.\n"
  "\n"
  "\n"
  "Notes To a Goodly Ballad Of Chaucer\n"
  "\n"
  "\n"
  "1. This elegant little poem is believed to have been addressed to\n"
  "Margaret, Countess of Pembroke, in whose name Chaucer\n"
  "found one of those opportunities of praising the daisy he never\n"
  "lost. (Transcriber's note: Modern scholars believe that Chaucer\n"
  "was not the author of this poem)\n"
  "\n"
  "2. Mieux un in heart which never shall apall: better one who in\n"
  "heart shall never pall -- whose love will never weary.\n"
  "\n"
  "\n"
  "\n"
  "                 A BALLAD SENT TO KING RICHARD.\n"
  "\n"
  "\n"
  "SOMETIME this world was so steadfast and stable,\n"
  "That man's word was held obligation;\n"
  "And now it is so false and deceivable,*                       *deceitful\n"
  "That word and work, as in conclusion,\n"
  "Be nothing one; for turned up so down\n"
  "Is all this world, through meed* and wilfulness,                *bribery\n"
  "That all is lost for lack of steadfastness.\n"
  "\n"
  "What makes this world to be so variable,\n"
  "But lust* that folk have in dissension?                        *pleasure\n"
  "For now-a-days a man is held unable*                    *fit for nothing\n"
  "*But if* he can, by some collusion,**             *unless* *fraud, trick\n"
  "Do his neighbour wrong or oppression.\n"
  "What causeth this but wilful wretchedness,\n"
  "That all is lost for lack of steadfastness?\n"
  "\n"
  "Truth is put down, reason is holden fable;\n"
  "Virtue hath now no domination;\n"
  "Pity exil'd, no wight is merciable;\n"
  "Through covetise is blent* discretion;                          *blinded\n"
  "The worlde hath made permutation\n"
  "From right to wrong, from truth to fickleness,\n"
  "That all is lost for lack of steadfastness.\n"
  "\n"
  "                            L'Envoy.\n"
  "\n"
  "O Prince! desire to be honourable;\n"
  "Cherish thy folk, and hate extortion;\n"
  "Suffer nothing that may be reprovable*            *a subject of reproach\n"
  "To thine estate, done in thy region;*                           *kingdom\n"
  "Show forth the sword of castigation;\n"
  "Dread God, do law, love thorough worthiness,\n"
  "And wed thy folk again to steadfastness!\n"
  "\n"
  "\n"
  "\n"
  "               L'ENVOY OF CHAUCER TO BUKTON. <1>\n"
  "\n"
  "\n"
  "My Master Bukton, when of Christ our King\n"
  "Was asked, What is truth or soothfastness?\n"
  "He not a word answer'd to that asking,\n"
  "As who saith, no man is all true, I guess;\n"
  "And therefore, though I highte* to express                     *promised\n"
  "The sorrow and woe that is in marriage,\n"
  "I dare not write of it no wickedness,\n"
  "Lest I myself fall eft* in such dotage.**                 *again **folly\n"
  "\n"
  "I will not say how that it is the chain\n"
  "Of Satanas, on which he gnaweth ever;\n"
  "But I dare say, were he out of his pain,\n"
  "As by his will he would be bounden never.\n"
  "But thilke* doated fool that eft had lever                         *that\n"
  "Y-chained be, than out of prison creep,\n"
  "God let him never from his woe dissever,\n"
  "Nor no man him bewaile though he weep!\n"
  "\n"
  "But yet, lest thou do worse, take a wife;\n"
  "Bet is to wed than burn in worse wise; <2>\n"
  "But thou shalt have sorrow on thy flesh *thy life,*       *all thy life*\n"
  "And be thy wife's thrall, as say these wise.\n"
  "And if that Holy Writ may not suffice,\n"
  "Experience shall thee teache, so may hap,\n"
  "That thee were lever to be taken in Frise, <3>\n"
  "Than eft* to fall of wedding in the trap.                         *again\n"
  "\n"
  "This little writ, proverbes, or figure,\n"
  "I sende you; take keep* of it, I read!                             *heed\n"
  "\"Unwise is he that can no weal endure;\n"
  "If thou be sicker,* put thee not in dread.\"**      *in security **danger\n"
  "The Wife of Bath I pray you that you read,\n"
  "Of this mattere which that we have on hand.\n"
  "God grante you your life freely to lead\n"
  "In freedom, for full hard is to be bond.\n"
  "\n"
  "\n"
  "Notes to L'Envoy of Chaucer to Bukton.\n"
  "\n"
  "\n"
  "1. Tyrwhitt, founding on the reference to the Wife of Bath,\n"
  "places this among Chaucer's latest compositions; and states that\n"
  "one Peter de Bukton held the office of king's escheator for\n"
  "Yorkshire in 1397. In some of the old editions, the verses were\n"
  "made the Envoy to the Book of the Duchess Blanche -- in very\n"
  "bad taste, when we consider that the object of that poem was to\n"
  "console John of Gaunt under the loss of his wife.\n"
  "\n"
  "2. \"But if they cannot contain, let them marry: for it is better to\n"
  "marry than to burn.\"  1 Cor. vii. 9\n"
  "\n"
  "3. Lever to be taken in Frise: better to be taken prisoner in\n"
  "Friesland -- where probably some conflict was raging at the\n"
  "time.\n"
  "\n"
  "\n"
  "\n"
  "                    A BALLAD OF GENTLENESS.\n"
  "\n"
  "\n"
  "THE firste stock-father of gentleness, <1>\n"
  "What man desireth gentle for to be,\n"
  "Must follow his trace, and all his wittes dress,*                 *apply\n"
  "Virtue to love, and vices for to flee;\n"
  "For unto virtue longeth dignity,\n"
  "And not the reverse, safely dare I deem,\n"
  "*All wear he* mitre, crown, or diademe.                *whether he wear*\n"
  "\n"
  "This firste stock was full of righteousness,\n"
  "True of his word, sober, pious, and free,\n"
  "*Clean of his ghost,* and loved business,               *pure of spirit*\n"
  "Against the vice of sloth, in honesty;\n"
  "And, but his heir love virtue as did he,\n"
  "He is not gentle, though he riche seem,\n"
  "All wear he mitre, crown, or diademe.\n"
  "\n"
  "Vice may well be heir to old richess,\n"
  "But there may no man, as men may well see,\n"
  "Bequeath his heir his virtuous nobless;\n"
  "That is appropried* to no degree,                    *specially reserved\n"
  "But to the first Father in majesty,\n"
  "Which makes his heire him that doth him queme,*                  *please\n"
  "All wear he mitre, crown, or diademe.\n"
  "\n"
  "\n"
  "Notes to A Ballad of Gentleness\n"
  "\n"
  "\n"
  "1. The firste stock-father of gentleness: Christ\n"
  "\n"
  "\n"
  "\n"
  "THE COMPLAINT OF CHAUCER TO HIS  PURSE.\n"
  "\n"
  "\n"
  "To you, my purse, and to none other wight,\n"
  "Complain I, for ye be my lady dear!\n"
  "I am sorry now that ye be so light,\n"
  "For certes ye now make me heavy cheer;\n"
  "Me were as lief be laid upon my bier.\n"
  "For which unto your mercy thus I cry,\n"
  "Be heavy again, or elles must I die!\n"
  "\n"
  "Now vouchesafe this day, ere it be night,\n"
  "That I of you the blissful sound may hear,\n"
  "Or see your colour like the sunne bright,\n"
  "That of yellowness hadde peer.\n"
  "Ye be my life! Ye be my hearte's steer!*                         *rudder\n"
  "Queen of comfort and of good company!\n"
  "Be heavy again, or elles must I die!\n"
  "\n"
  "Now, purse! that art to me my life's light\n"
  "And savour, as down in this worlde here,\n"
  "Out of this towne help me through your might,\n"
  "Since that you will not be my treasurere;\n"
  "For I am shave as nigh as any frere. <1>\n"
  "But now I pray unto your courtesy,\n"
  "Be heavy again, or elles must I die!\n"
  "\n"
  "                  Chaucer's Envoy to the King.\n"
  "\n"
  "O conqueror of Brute's Albion, <2>\n"
  "Which by lineage and free election\n"
  "Be very king, this song to you I send;\n"
  "And ye which may all mine harm amend,\n"
  "Have mind upon my supplication!\n"
  "\n"
  "\n"
  "Notes to The Complaint of Chaucer to his Purse\n"
  "\n"
  "\n"
  "1. \"I am shave as nigh as any frere\" i.e. \"I am as bare of coin as\n"
  "a friar's tonsure of hair.\"\n"
  "\n"
  "2. Brute, or Brutus, was the legendary first king of Britain.\n"
  "\n"
  "\n"
  "GOOD COUNSEL OF CHAUCER. <1>\n"
  "\n"
  "FLEE from the press, and dwell with soothfastness;\n"
  "Suffice thee thy good, though it be small;\n"
  "For hoard hath hate, and climbing tickleness,*              *instability\n"
  "Press hath envy, and *weal is blent* o'er all,   *prosperity is blinded*\n"
  "Savour* no more than thee behove shall;                *have a taste for\n"
  "Read* well thyself, that other folk canst read;                 *counsel\n"
  "And truth thee shall deliver, it is no dread.*                    *doubt\n"
  "\n"
  "Paine thee not each crooked to redress,\n"
  "In trust of her that turneth as a ball; <2>\n"
  "Great rest standeth in little business:\n"
  "Beware also to spurn against a nail; <3>\n"
  "Strive not as doth a crocke* with a wall;                   *earthen pot\n"
  "Deeme* thyself that deemest others' deed,                         *judge\n"
  "And truth thee shall deliver, it is no dread.\n"
  "\n"
  "What thee is sent, receive in buxomness;*                    *submission\n"
  "The wrestling of this world asketh a fall;\n"
  "Here is no home, here is but wilderness.\n"
  "Forth, pilgrim! Forthe beast, out of thy stall!\n"
  "Look up on high, and thank thy God of all!\n"
  "*Weive thy lust,* and let thy ghost* thee lead,             *forsake thy\n"
  " And truth thee shall deliver, it is no dread.             inclinations*\n"
  "                                                                 *spirit\n"
  "\n"
  "Notes to Good Counsel of Chaucer\n"
  "\n"
  "\n"
  "1. This poem is said to have been composed by Chaucer \"upon\n"
  "his deathbed, lying in anguish.\"\n"
  "\n"
  "2. Her that turneth as a ball: Fortune.\n"
  "\n"
  "3. To spurn against a nail; \"against the pricks.\"\n"
  "\n"
  "\n"
  "\n"
  "PROVERBS OF CHAUCER. <1>\n"
  "\n"
  "\n"
  "WHAT should these clothes thus manifold,\n"
  "Lo! this hot summer's day?\n"
  "After great heate cometh cold;\n"
  "No man cast his pilche* away.                     *pelisse, furred cloak\n"
  "Of all this world the large compass\n"
  "Will not in mine arms twain;\n"
  "Who so muche will embrace,\n"
  "Little thereof he shall distrain.*                                *grasp\n"
  "\n"
  "The world so wide, the air so remuable,*                       *unstable\n"
  "The silly man so little of stature;\n"
  "The green of ground and clothing so mutable,\n"
  "The fire so hot and subtile of nature;\n"
  "The water *never in one* -- what creature               *never the same*\n"
  "That made is of these foure <2> thus flitting,\n"
  "May steadfast be, as here, in his living?\n"
  "\n"
  "The more I go, the farther I am behind;\n"
  "The farther behind, the nearer my war's end;\n"
  "The more I seek, the worse can I find;\n"
  "The lighter leave, the lother for to wend; <3>\n"
  "The better I live, the more out of mind;\n"
  "Is this fortune, *n'ot I,* or infortune;*       *I know not* *misfortune\n"
  "Though I go loose, tied am I with a loigne.*               *line, tether\n"
  "\n"
  "\n"
  "Notes to Proverbs of Chaucer\n"
  "\n"
  "\n"
  "1. (Transcriber's Note: Modern scholars believe that Chaucer's\n"
  "may have been the author  of the first stanza of this poem, but\n"
  "was not the author of the second and third).\n"
  "\n"
  "2. These foure: that is, the four elements, of which man was\n"
  "believed to be composed.\n"
  "\n"
  "3. The lighter leave, the lother for to wend: The more easy\n"
  "(through age) for me to depart, the less willing I am to go.\n"
  "\n"
  "\n"
  "\n"
  "VIRELAY.  <1>\n"
  "\n"
  "\n"
  "ALONE walking\n"
  "In thought plaining,\n"
  "And sore sighing;\n"
  "            All desolate,\n"
  "Me rememb'ring\n"
  "Of my living;\n"
  "My death wishing\n"
  "            Both early and late.\n"
  "\n"
  "Infortunate\n"
  "Is so my fate,\n"
  "That, wot ye what?\n"
  "            Out of measure\n"
  "My life I hate;\n"
  "Thus desperate,\n"
  "In such poor estate,\n"
  "            Do I endure.\n"
  "\n"
  "Of other cure\n"
  "Am I not sure;\n"
  "Thus to endure\n"
  "            Is hard, certain;\n"
  "Such is my ure,*                                            *destiny <2>\n"
  "I you ensure;\n"
  "What creature\n"
  "            May have more pain?\n"
  "\n"
  "My truth so plain\n"
  "Is taken in vain,\n"
  "And great disdain\n"
  "            In remembrance;\n"
  "Yet I full fain\n"
  "Would me complain,\n"
  "Me to abstain\n"
  "            From this penance.\n"
  "\n"
  "But, in substance,\n"
  "None alleggeance*                                           *alleviation\n"
  "Of my grievance\n"
  "            Can I not find;\n"
  "Right so my chance,\n"
  "With displeasance,\n"
  "Doth me advance;\n"
  "            And thus an end.\n"
  "\n"
  "\n"
  "Notes to Virelay\n"
  "\n"
  "\n"
  "1. (Transcriber's note: Modern scholars believe that Chaucer\n"
  "was not the author of this poem)\n"
  "\n"
  "2. Ure: \"heur,\" or destiny; the same word that enters into\n"
  "\"bonheur\" and \"malheur.\" (French: happiness & unhappiness)\n"
  "\n"
  "\n"
  "\n"
  "                    \"SINCE I FROM LOVE.\" <1>\n"
  "\n"
  "\n"
  "SINCE I from Love escaped am so fat,\n"
  "I ne'er think to be in his prison ta'en;\n"
  "Since I am free, I count him not a bean.\n"
  "\n"
  "He may answer, and saye this and that;\n"
  "I *do no force,* I speak right as I mean;                     *care not*\n"
  "Since I from Love escaped am so fat.\n"
  "\n"
  "Love hath my name struck out of his slat,*                  *slate, list\n"
  "And he is struck out of my bookes clean,\n"
  "For ever more; there is none other mean;\n"
  "Since I from Love escaped am so fat.\n"
  "\n"
  "\n"
  "Notes to \"Since I from Love\"\n"
  "\n"
  "\n"
  "1. (Transcriber's note: Modern scholars believe that Chaucer\n"
  "was not the author of this poem)\n"
  "\n"
  "\n"
  "\n"
  "CHAUCER'S WORDS TO HIS SCRIVENER.\n"
  "\n"
  "\n"
  "ADAM Scrivener, if ever it thee befall\n"
  "Boece or Troilus for to write anew,\n"
  "Under thy long locks thou may'st have the scall*                   *scab\n"
  "But *after my making* thou write more true!             *according to my\n"
  "So oft a day I must thy work renew,                           composing*\n"
  "It to correct, and eke to rub and scrape;\n"
  "And all is through thy negligence and rape.*                      *haste\n"
  "\n"
  "\n"
  "\n"
  "CHAUCER'S PROPHECY. <1>\n"
  "\n"
  "\n"
  "WHEN priestes *failen in their saws,*               *come short of their\n"
  "And lordes turne Godde's laws                                profession*\n"
  "                       Against the right;\n"
  "And lechery is holden as *privy solace,*                *secret delight*\n"
  "And robbery as free purchase,\n"
  "                      Beware then of ill!\n"
  "Then shall the Land of Albion\n"
  "Turne to confusion,\n"
  "                     As sometime it befell.\n"
  "\n"
  "Ora pro Anglia Sancta Maria, quod Thomas Cantuaria. <2>\n"
  "\n"
  "Sweet Jesus, heaven's King,\n"
  "Fair and best of all thing,\n"
  "You bring us out of this mourning,\n"
  "To come to thee at our ending!\n"
  "\n"
  "\n"
  "Notes to Chaucer's Prophecy.\n"
  "\n"
  "\n"
  "1. (Transcriber's note: Modern scholars believe that Chaucer\n"
  "was not the author of this poem)\n"
  "\n"
  "2. \"Holy Mary, pray for England, as does Thomas of\n"
  "Canterbury\" (i.e. St Thomas a Beckett)\n"
  "\n"
  "\n"
  "";
// }

